<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<roundcube:include file="/includes/links.html" />
</head>
<body>

<roundcube:object name="logo" src="/images/roundcube_logo.png" id="logo" border="0" />

<div style="width:400px; margin:60px auto;">
$__page_content
</div>

</body>
</html>
