<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'Αρχειοθέτηση';
$labels['buttontitle'] = 'Αρχειοθέτηση μηνύματος';
$labels['archived'] = 'Αρχειοθετήθηκε με επιτυχία';
$labels['archivedreload'] = 'Επιτυχής αρχειοθέτηση. Ανανεώστε την σελίδα για να δείτε τους νέους φακέλους αρχειοθέτησης. ';
$labels['archiveerror'] = 'Ορισμένα μηνύματα δεν ήταν δυνατό να αρχειοθετηθούν. ';
$labels['archivefolder'] = 'Αρχειοθέτηση';
$labels['settingstitle'] = 'Αρχειοθέτηση';
$labels['archivetype'] = 'Τμηματοποίηση αρχείου με βάση';
$labels['archivetypeyear'] = 'Έτος (π.χ. Αρχείο/2012)';
$labels['archivetypemonth'] = 'Μήνα (π.χ. Αρχείο/2012/06)';
$labels['archivetypetbmonth'] = 'Μήνας - Συμβατός με Thunderbird (π.χ. Αρχείο/2012/2012-06)';
$labels['archivetypefolder'] = 'Αρχικός φάκελος';
$labels['archivetypesender'] = 'Αποστολέας email';
$labels['unkownsender'] = 'άγνωστο';
$labels['readonarchive'] = 'Σημείωση του μηνύματος ως αναγνωσμένο στο αρχείο';
