<?php

/**
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Enigma plugin              |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/roundcube/roundcube-webmail/plugin-enigma/
*/

$labels['encryption'] = 'Kryptering';
$labels['enigmacerts'] = 'S/MIME Certifikater';
$labels['enigmakeys'] = 'PGP Nøgler';
$labels['keysfromto'] = 'Nøgler $from $to af $count';
$labels['keyname'] = 'Navn';
$labels['keyid'] = 'NøgleID';
$labels['keyuserid'] = 'Bruger ID';
$labels['keytype'] = 'Nøgletype';
$labels['fingerprint'] = 'Fingeravtryk';
$labels['subkeys'] = 'Undernøgler';
$labels['keyprops'] = 'Nøgleegenskaber';
$labels['basicinfo'] = 'Grundlæggende Oplysninger';
$labels['userids'] = 'Yderligere Brugere';
$labels['typepublickey'] = 'offentlig nøgle';
$labels['typekeypair'] = 'nøglepar';
$labels['keyattfound'] = 'Denne meddelelse indeholder vedhæftede PGP nøgl(er).';
$labels['keyattimport'] = 'Importer nøgl(er)';
$labels['typeencrypt'] = 'Krypter';
$labels['subkeyid'] = 'ID';
$labels['subkeycreated'] = 'Oprettet';
$labels['subkeyexpires'] = 'Udløber';
$labels['expiresnever'] = 'aldrig';
$labels['unknown'] = 'ukendt';
$labels['userid'] = 'ID';
$labels['valid'] = 'valid';
$labels['createkeys'] = 'Opret et nyt nøglepar';
$labels['importkeys'] = 'Importer nøgler';
$labels['keyremove'] = 'Fjern';
$labels['keychpass'] = 'Skift kodeord:';
$labels['newkeyident'] = 'Identificer';
$labels['newkeypass'] = 'Adgangskode';
$labels['newkeypassconfirm'] = 'Bekræft password';
$labels['newkeytype'] = 'Nøgletype';
$labels['keyimportlabel'] = 'Importer fra fil';
$labels['newkeysize'] = 'Nøglestørrelse';
$labels['key2048'] = '2048 bits - standard';
$labels['key4096'] = '4096 bits - mere sikker';
