<roundcube:object name="doctype" value="html5" />
<html>
<head>
<roundcube:include file="/includes/links.html" />
</head>
<body class="iframe<roundcube:exp expression="env:task != 'mail' ? ' floatingbuttons' : ' mail'" />">

<roundcube:if condition="env:task != 'mail'" />
<div id="filter-title" class="boxtitle"><roundcube:label name="managesieve.filterdef" /></div>
<roundcube:endif />

<div id="filter-form" class="boxcontent">
<roundcube:object name="filterform" />

<roundcube:if condition="env:task != 'mail'" />
<div id="footer">
<div class="footerleft formbuttons">
<roundcube:button command="plugin.managesieve-save" type="input" class="button mainaction" label="save" />
</div>
</div>
<roundcube:endif />

</form>
</div>

<roundcube:include file="/includes/footer.html" />

</body>
</html>
