<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-password/
*/

$labels['changepasswd']  = 'Измени лозинку';
$labels['curpasswd']  = 'Тренутна лозинка:';
$labels['newpasswd']  = 'Нова лозинка:';
$labels['confpasswd']  = 'Потврдите нову лозинку:';
$messages['nopassword'] = 'Унесите нову лозинку.';
$messages['nocurpassword'] = 'Унесите тренутну лозинку.';
$messages['passwordincorrect'] = 'Тренутна лозинка је нетачна.';
$messages['passwordinconsistency'] = 'Лозинке се не поклапају. Покушајте поново.';
$messages['crypterror'] = 'Није могуће сачувати нову лозинку. Недостаје функција за шифровање.';
$messages['connecterror'] = 'Није могуће сачувати нову лозинку. Грешка везе.';
$messages['internalerror'] = 'Није могуће сачувати нову лозинку.';
$messages['passwordshort'] = 'Лозинка мора имати најмање $lenght знакова.';
$messages['passwordweak'] = 'Лозинка мора да садржи најмање један број и један знак интерпункције.';
$messages['passwordforbidden'] = 'Лозинка садржи недозвољене знакове.';
$messages['firstloginchange'] = 'Ово је ваше прво пријављивање. Измените лозинку.';
$messages['disablednotice'] = 'Систем је тренутно у фази ремонта и измена лозинке за сада није могућа. Све ће се ускоро вратити у нормалу. Извињавамо се због неугодности.';
$messages['passwinhistory'] = 'Лозинка је раније већ коришћена.';
$messages['samepasswd'] = 'Нова лозинка се мора разликовати од старе.';
$messages['passwdexpirewarning'] = 'Упозорење! Ваша лозинка истиче ускоро. Промените је до $expirationdatetime.';
$messages['passwdexpired'] = 'Ваша лозинка је истекла. Морате је изменити одмах!';
$messages['passwdconstraintviolation'] = 'Лозинка не испуњава смернице. Вероватно је превише слаба.';
