#filtersetslistbox
{
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  width: 150px;
}

#filtersscreen
{
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 162px;
}

#filtersscreen.nosetlist
{
  left: 0;
}

#filterslistbox
{
  position: absolute;
  left: 0;
  top: 0;
  bottom: 0;
  width: 180px;
}

#filter-box
{
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 192px;
}

#filter-frame
{
  border-radius: 4px;
}

#filterslist,
#filtersetslist
{
  width: 100%;
  table-layout: fixed;
}

#filterslist tbody td,
#filtersetslist tbody td
{
  width: 100%;
  overflow: hidden;
  text-overflow: ellipsis;
}

#filterslist tbody tr.disabled td,
#filtersetslist tbody tr.disabled td
{
  color: #87A3AA;
  text-decoration: line-through;
}

#filtersetslist tbody td
{
  font-weight: bold;
}

#filterslist tbody tr.filtermoveup td
{
  border-top: 2px dotted #555 !important;
  padding-top: 5px;
}

#filterslist tbody tr.filtermovedown td
{
  border-bottom: 2px dotted #555 !important;
  padding-bottom: 4px;
}

body.iframe
{
  min-width: 620px;
}

#filter-form
{
  min-width: 550px;
  white-space: nowrap;
  padding: 20px 10px 10px 10px;
}

#filter-form legend,
#filter-form label {
  color: #666666;
  vertical-align: middle;
}

#filter-form li {
  border: none;
}

#filter-form .col-sm-4,
#filter-form .col-form-label {
  display: inline-block;
  min-width: 100px;
  line-height: 2.5;
}

#filter-form input[type=checkbox] {
  margin: 0;
}

#filter-form .col-form-label + div {
  display: inline;
}

#rules, #actions
{
  margin-top: 5px;
  padding: 0;
  border-collapse: collapse;
}

div.rulerow, div.actionrow
{
  width: auto;
  padding: 2px;
  white-space: nowrap;
  border: 1px solid white;
  background-color: #eee;
}

div.rulerow:hover, div.actionrow:hover
{
  background-color: #D9ECF4;
  border: 1px solid #BBD3DA;
}

div.rulerow table, div.actionrow table
{
  padding: 0px;
  min-width: 600px;
}

#filter-form td
{
  vertical-align: top;
}

#filter-form div.flexbox {
  margin: 0;
}

td.advbutton
{
  width: 1%;
  overflow: hidden;
}

td.advbutton a
{
  display: block;
  padding-top: 16px;
  height: 6px;
  width: 12px;
  text-decoration: none;
}

td.advbutton a span
{
  display: none;
}

td.advbutton a.show
{
  background: url(images/down_small.gif) center no-repeat;
}

td.advbutton a.hide
{
  background: url(images/up_small.gif) center no-repeat;
}

td.rowbuttons
{
  text-align: right;
  white-space: nowrap;
  width: 1%;
  padding-top: 3px;
}

td.rowactions
{
  white-space: nowrap;
  width: 1%;
  padding-top: 2px;
}

td.rowtargets
{
  white-space: nowrap;
  width: 98%;
  padding-left: 3px;
  padding-top: 2px;
}

td.rowtargets > div
{
  vertical-align: top;
  margin-top: 2px;
}

td.rowtargets div.adv
{
  padding-top: 3px;
  font-size: 10px;
}

td.rowtargets div.adv span.label
{
  display: inline-block;
  padding-right: 5px;
  min-width: 70px;
}

td.rowtargets div a {
  margin-left: 10px;
}

td.rowtargets div.adv input
{
  margin-bottom: 1px;
}

input.disabled, input.disabled:hover
{
  color: #999999;
}

input.error, textarea.error
{
  background-color: #FFFFC4;
}

input.box,
input.radio
{
  border: 0;
  margin-top: 0;
}

input.radio
{
  vertical-align: middle;
}

select.operator_selector
{
  width: 200px;
  vertical-align: top;
}

td.rowtargets span,
span.label
{
  color: #666666;
  font-size: 10px;
  white-space: nowrap;
}

td.rowtargets label
{
  color: black;
}

#footer
{
  padding-top: 5px;
  width: 100%;
}

#footer .footerleft label
{
  margin-left: 40px;
  white-space: nowrap;
}

.itemlist
{
  line-height: 25px;
}

.itemlist input
{
  vertical-align: middle;
}

span.sieve.error
{
  color: red;
  white-space: nowrap;
}

#managesieve-tip
{
  padding: 3px;
  background-color: #eee;
}

#filter-form a.button
{
  margin: 0;
  padding: 0;
  border: 0;
  border-radius: 0;
}

#filter-form a.button span
{
  display: none;
}

#filter-form a.button.add
{
  background: url(images/add.png) no-repeat;
  width: 30px;
  height: 20px;
  margin-right: 4px;
  display: inline-block;
}

#filter-form a.button.del
{
  background: url(images/del.png) no-repeat;
  width: 30px;
  height: 20px;
  display: inline-block;
}

#filter-form a.button.disabled
{
  opacity: 0.35;
  filter: alpha(opacity=35);
  cursor: default;
}

#filter-form select,
#filter-form input,
#filter-form textarea
{
  vertical-align: middle;
  max-width: 280px;
}

/* revert larry style button */
#filter-form input.button
{
  padding: 4px 12px;
}

fieldset
{
  border: 0;
  padding: 0;
  margin-bottom: 20px;
}

fieldset > legend
{
  display: block;
  font-size: 14px;
  font-weight: bold;
  padding-bottom: 10px;
  margin-bottom: 0;
}

/* smart multi-row input field */
.listarea
{
  border: 1px solid #B2B2B2;
  border-radius: 4px;
  box-shadow: inset 0 0 2px 1px rgba(0,0,0, 0.1);
  -webkit-box-shadow: inset 0 0 2px 1px rgba(0,0,0, 0.1);
  margin: 0;
  padding: 2px;
  display: inline-block;
  max-height: 59px;
  overflow-y: auto;
  vertical-align: middle;
}

td.rowtargets > span.listarea
{
  vertical-align: top;
  margin-top: 2px;
}

.listelement
{
  display: block;
  white-space: nowrap;
  background-color: #fff;
  border-top: 1px solid #e2e2e2;
  height: 14px;
  padding: 0;
  margin: 0;
  overflow: hidden;
  line-height: 14px;
}

.listarea.error .listelement
{
  background-color: #FFFFC4;
}

.listelement:first-child
{
  border-top: none;
}

#vacationform .listelement input,
#filter-form .listelement input
{
  border: none;
  border-radius: 0;
  box-shadow: none;
  outline: none;
  vertical-align: top;
  height: 14px;
  padding-top: 0;
  padding-bottom: 0;
  line-height: 14px;
  background-color: transparent;
}

.listelement input:focus
{
  box-shadow: none;
}

.listelement .reset
{
  display: inline-block;
  width: 16px;
  height: 16px;
  background: url(images/erase.png) -1px -1px no-repeat #eee;
  cursor: pointer;
}


/* fixes for popup window */

body.iframe.mail
{
  margin: 0;
  padding: 0;
}

body.iframe.mail #filter-form
{
  padding: 10px 5px 5px 5px;
}


/* vacation form */
#settings-sections .vacation a {
  background-image: url(images/vacation_icons.png);
  background-repeat: no-repeat;
  background-position: 7px 1px;
}

#settings-sections .vacation.selected a {
  background-position: 7px -23px;
}

#managesieve-vacation, #managesieve-forward {
  position: absolute;
  top: 0;
  left: 212px;
  right: 0;
  bottom: 0;
  overflow: auto;
}

#vacationform .listarea {
  max-height: 91px;
}

#vacationform td.vacation {
  white-space: nowrap;
}

#vacationform input.button {
  margin-left: 10px;
}

/* RAW editor and CodeMirror overrides */

.raweditor textarea {
  border: none;
  border-radius: 0;
  max-width: none !important;
  box-shadow: none;
  font-family: monospace;
  width: 99%;
  min-height: 300px;
}

.raweditor textarea,
.raweditor .CodeMirror {
  position: absolute;
  top: 34px;
  bottom: 45px;
  right: 0;
  left: 0;
  height: auto;
  background-color: #fdfdfd;
  border-bottom: 1px solid #eee;
}

.raweditor .CodeMirror-linebackground.line-error {
  background-color: #f00;
  opacity: 0.4;
}

.raweditor .errorGutter {
  width: 0.8em;
}

.raweditor #footer {
  position: absolute;
  bottom: 5px;
}

body.iframe.raweditor {
  min-width: 100px;
  overflow: hidden;
}
