<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Vyskytla sa chyba!';
$messages['loginfailed']  = 'Prihlasovanie bolo neúspešné.';
$messages['cookiesdisabled'] = 'Váš internetový prehliadač nepodporuje cookies, ktoré sú potrebné na prihlásenie.';
$messages['sessionerror'] = 'Vaša relácia nie je platná alebo vypršala jej platnosť.';
$messages['cookiesmismatch'] = 'Bola zistená nezhoda cookie. Prosím vyčistite súbory cookies vo vašom prehliadači.';
$messages['storageerror'] = 'Nepodarilo sa spojiť s úložným serverom.';
$messages['servererror'] = 'Chyba servera!';
$messages['servererrormsg'] = 'Chyba servera: $msg';
$messages['accountlocked'] = 'Bolo vykonaných príliš veľa neúspešných pokusov o prihlásenie. Skúste to prosím neskôr.';
$messages['connerror'] = 'Chyba pri pripájaní (nepodarilo sa spojiť so serverom)!';
$messages['dberror'] = 'Chyba databázy!';
$messages['dbconnerror'] = 'Nemožno sa pripojiť k databáze!';
$messages['windowopenerror'] = 'Bolo zablokované vyskakovacie okno!';
$messages['requesttimedout'] = 'Čas na vykonanie požiadavky uplynul';
$messages['errorreadonly'] = 'Akciu nemožno vykonať. Priečinok je určený len na čítanie.';
$messages['errornoperm'] = 'Akciu nemožno vykonať. Prístup bol odmietnutý.';
$messages['erroroverquota'] = 'Akciu nemožno vykonať. Nie je dostatok voľného miesta.';
$messages['erroroverquotadelete'] = 'Nie je dostatok voľného miesta. Vymažte nejakú správu pomocou klávesov SHIFT+DEL.';
$messages['invalidrequest'] = 'Neplatná požiadavka! Neuložili sa žiadne údaje.';
$messages['invalidhost'] = 'Neplatný názov servera.';
$messages['nomessagesfound'] = 'V tomto priečinku nie je žiadna správa.';
$messages['loggedout'] = 'Relácia bola úspešne prerušená. Dovidenia!';
$messages['mailboxempty'] = 'Schránka je prázdna';
$messages['nomessages'] = 'Žiadne správy';
$messages['refreshing'] = 'Obnovuje sa...';
$messages['loading'] = 'Načítava sa...';
$messages['uploading'] = 'Nahráva sa súbor...';
$messages['attaching'] = 'Prikladá sa súbor...';
$messages['uploadingmany'] = 'Nahrávajú sa súbory...';
$messages['loadingdata'] = 'Načítavajú sa údaje...';
$messages['checkingmail'] = 'Kontrolujú sa nové správy...';
$messages['sendingmessage'] = 'Správa sa odosiela...';
$messages['messagesent'] = 'Správa bola úspešne odoslaná.';
$messages['savingmessage'] = 'Správa sa ukladá...';
$messages['messagesaved'] = 'Správa bola uložená ako koncept.';
$messages['successfullysaved'] = 'Ukladanie bolo úspešne dokončené.';
$messages['savingresponse'] = 'Ukladanie textu odpovede...';
$messages['deleteresponseconfirm'] = 'Naozaj chcete vymazať text odpovede?';
$messages['nocontactselected'] = 'Ešte ste nevybrali žiadny kontakt.';
$messages['addedsuccessfully'] = 'Kontakt bol pridaný do adresára.';
$messages['contactexists'] = 'Kontakt s takouto e-mailovou adresou už existuje.';
$messages['contactnameexists'] = 'Kontakt s takýmto menom už existuje.';
$messages['blockedimages'] = 'Kvôli ochrane vášho súkromia boli v tejto správe zablokované vzdialené obrázky.';
$messages['blockedresources'] = 'Kvôli ochrane vášho súkromia boli zablokované vzdialené zdroje údajov.';
$messages['suspiciousemail'] = 'Táto správa obsahuje podozrivé e-mailové adresy, ktoré môžu byť podvodné.';
$messages['bccemail'] = 'Správy odoslané ďalej obsahujú utajených príjemcov (skrytú kópiu).';
$messages['bouncehint'] = 'Správa sa odošle bez akýchkoľvek úprav, napríklad s použitím pôvodného tela, hlavičiek a príjemcov.';
$messages['encryptedmessage'] = 'Táto správa je zašifrovaná, a nie je možné ju zobraziť. Prepáčte!';
$messages['externalmessagedecryption'] = 'Táto správa je zašifrovaná a dešifrovať ju môžete pomocou rozšírenia vášho prehliadača.';
$messages['nopubkeyfor'] = 'Pre $email sa nenašiel žiadny platný verejný kľúč';
$messages['nopubkeyforsender'] = 'Pre vašu identitu odosielateľa sa nenašiel žiadny platný verejný kľúč. Chcete správu iba zašifrovať pre príjemcov?';
$messages['encryptnoattachments'] = 'Prílohy, ktoré ste už uložili na server, nie je možné zašifrovať. Prosím pridajte ich znovu, v editore pre šifrovanie.';
$messages['searchpubkeyservers'] = 'Chcete vyhľadať servery s verejným kľúčom pre chýbajúce kľúče?';
$messages['encryptpubkeysfound'] = 'Našli sa nasledujúce verejné kľúče:';
$messages['keyservererror'] = 'Nepodarilo sa získať kľúč zo servera pre kľúče.';
$messages['keyimportsuccess'] = 'Verejný kľúč $key bol úspešne importovaný do okruhu vašich kľúčov.';
$messages['nocontactsfound'] = 'Nenašli sa žiadne kontakty.';
$messages['contactnotfound'] = 'Požadovaný kontakt sa nenašiel.';
$messages['contactsearchonly'] = 'Ak chcete vidieť kontakty z vybraného adresára, musíte použiť vyhľadávací formulár.';
$messages['sendingfailed'] = 'Nepodarilo sa odoslať správu.';
$messages['senttooquickly'] = 'Počkajte $sec sekúnd pred odoslaním tejto správy.';
$messages['errorsavingsent'] = 'Počas ukladania odoslanej správy sa vyskytla chyba.';
$messages['errorsaving'] = 'Počas ukladania sa vyskytla chyba.';
$messages['errormoving'] = 'Správu/správy nemožno presunúť.';
$messages['errorcopying'] = 'Správu/správy nemožno skopírovať,';
$messages['errordeleting'] = 'Správu/správy nemožno vymazať.';
$messages['errormarking'] = 'Nemožno označiť správu/správy.';
$messages['alerttitle'] = 'Pozor';
$messages['confirmationtitle'] = 'Naozaj...';
$messages['deletecontactconfirm']  = 'Naozaj chcete vymazať vybrané kontakty?';
$messages['deletegroupconfirm']  = 'Naozaj chcete vymazať vybranú skupinu?';
$messages['deletemessagesconfirm'] = 'Naozaj chcete vymazať vybrané správy?';
$messages['deletefolderconfirm']  = 'Naozaj chcete vymazať tento priečinok?';
$messages['movefolderconfirm']  = 'Naozaj chcete presunúť tento priečinok?';
$messages['purgefolderconfirm']  = 'Naozaj chcete vyprázdniť tento priečinok?';
$messages['contactdeleting'] = 'Vymazávajú sa kontakty...';
$messages['groupdeleting'] = 'Vymazáva sa skupina...';
$messages['folderdeleting'] = 'Vymazáva sa priečinok ...';
$messages['foldermoving'] = 'Presúva sa priečinok...';
$messages['foldersubscribing'] = 'Prebieha prihlasovanie k priečinku...';
$messages['folderunsubscribing'] = 'Prebieha odhlasovanie z priečinka...';
$messages['formincomplete'] = 'Formulár nie je kompletne vyplnený.';
$messages['noemailwarning'] = 'Prosím zadajte platnú e-mailovú adresu.';
$messages['nonamewarning']  = 'Prosím zadajte meno.';
$messages['nopagesizewarning'] = 'Prosím zadajte počet záznamov na stranu.';
$messages['nosenderwarning'] = 'Prosím zadajte e-mailovú adresu odosielateľa.';
$messages['recipientsadded'] = 'Pridanie príjemcu/príjemcov bolo úspešné.';
$messages['norecipientwarning'] = 'Prosím zadajte aspoň jedného príjemcu.';
$messages['disclosedrecipwarning'] = 'Všetci používatelia navzájom uvidia svoje e-mailové adresy. Ak si to neželáte a chcete chrániť ich súkromie, použite pole Skrytá kópia.';
$messages['disclosedreciptitle'] = 'Priveľa verejných príjemcov';
$messages['nosubjectwarning']  = '"Predmet" správy je prázdny. Chcete ho teraz zadať?';
$messages['nosubjecttitle']  = 'Bez predmetu';
$messages['nobodywarning'] = 'Chcete odoslať správu bez textu?';
$messages['notsentwarning'] = 'Správa nebola odoslaná a obsahuje neuložené zmeny. Chcete vykonané zmeny zrušiť?';
$messages['restoresavedcomposedata'] = 'Našla sa staršia správa, ktorú ste napísali ale neodoslali.\n\nPredmet: $subject\nUložené: $date\n\nChcete túto správu obnoviť?';
$messages['nosearchname'] = 'Prosím zadajte meno alebo e-mailovú adresu kontaktu.';
$messages['notuploadedwarning'] = 'Ešte neboli nahrané všetky súbory. Prosím čakajte alebo nahrávanie zrušte.';
$messages['searchsuccessful'] = 'Nájdené správy: $nr.';
$messages['contactsearchsuccessful'] = 'Nájdené kontakty: $nr.';
$messages['searchnomatch'] = 'Hľadaný výraz sa nenašiel.';
$messages['searching'] = 'Vyhľadáva sa...';
$messages['checking'] = 'Kontroluje sa...';
$messages['stillsearching'] = 'Vyhľadávanie stále prebieha...';
$messages['nospellerrors'] = 'Pri kontrole pravopisu neboli nájdené chyby.';
$messages['folderdeleted'] = 'Priečinok bol úspešne vymazaný.';
$messages['foldersubscribed'] = 'Prihlásenie k priečinku bolo úspešné.';
$messages['folderunsubscribed'] = 'Odhlásenie z priečinka bolo úspešné.';
$messages['folderpurged'] = 'Priečinok bol úspešne vyprázdnený.';
$messages['folderexpunged'] = 'Priečinok bol úspešne skomprimovaný.';
$messages['deletedsuccessfully'] = 'Vymazanie bolo úspešné.';
$messages['converting'] = 'Odstraňuje sa formátovanie...';
$messages['messageopenerror'] = 'Správu nemožno načítať zo servera.';
$messages['filelinkerror'] = 'Nepodarilo sa priložiť súbor.';
$messages['fileuploaderror'] = 'Nahrávanie súboru bolo neúspešné.';
$messages['csvfilemismatch'] = 'Import viacerých súborov CSV s rôznymi poliami nie je podporovaný.';
$messages['filesizeerror'] = 'Nahraný súbor prekročil maximálnu veľkosť $size.';
$messages['filecounterror'] = 'Naraz je možné vykonať upload max. $count súborov.';
$messages['msgsizeerror'] = 'Nepodarilo sa pripojiť súbor. Bola prekročená max. veľkosť správy ($size).';
$messages['msgsizeerrorfwd'] = 'Došlo k prekročeniu maximálnej veľkosti správy ($size). Počet správ, ktoré neboli pripojené: $num.';
$messages['copysuccess'] = 'Počet úspešne skopírovaných kontaktov: $nr.';
$messages['movesuccess'] = 'Počet úspešne presunutých kontaktov: $nr.';
$messages['copyerror'] = 'Kontakty nemožno kopírovať.';
$messages['moveerror'] = 'Kontakty nemožno presúvať.';
$messages['sourceisreadonly'] = 'Tento zdroj adries je určený len na čítanie.';
$messages['errorsavingcontact'] = 'Zmeny nebolo možné uložiť.';
$messages['movingmessage'] = 'Prebieha presúvanie správ(y)...';
$messages['copyingmessage'] = 'Prebieha kopírovanie správ(y)...';
$messages['copyingcontact'] = 'Prebieha kopírovanie kontaktov...';
$messages['movingcontact'] = 'Presúvanie kontaktov...';
$messages['deletingmessage'] = 'Prebieha vymazávanie správ(y)...';
$messages['markingmessage'] = 'Prebieha označovanie správ(y)...';
$messages['addingmember'] = 'Prebieha pridávanie kontaktov do skupiny...';
$messages['removingmember'] = 'Prebieha odstraňovanie kontaktov zo skupiny...';
$messages['receiptsent'] = 'Potvrdenie o prečítaní bolo odoslané.';
$messages['errorsendingreceipt'] = 'Potvrdenie nemožno odoslať.';
$messages['deleteidentityconfirm'] = 'Naozaj chcete vymazať túto identitu?';
$messages['nodeletelastidentity'] = 'Túto identitu nemožno vymazať, pretože je posledná.';
$messages['forbiddencharacter'] = 'Názov priečinka obsahuje nepovolený znak.';
$messages['selectimportfile'] = 'Zvoľte súbor, ktorý chcete importovať na server.';
$messages['addresswriterror'] = 'Do vybraného adresára nie je možné zapisovať údaje.';
$messages['contactaddedtogroup'] = 'Kontakty boli úspešne pridané do tejto skupiny.';
$messages['contactremovedfromgroup'] = 'Kontakty boli úspešne odstránené z tejto skupiny.';
$messages['nogroupassignmentschanged'] = 'Priradenia do skupín sa nezmenili.';
$messages['importwait'] = 'Prebieha importovanie, prosím čakajte...';
$messages['importformaterror'] = 'Importovanie nebolo úspešné! Nahraný súbor nie je platným súborom údajov pre importovanie.';
$messages['importconfirm'] = '<b>Počet úspešne naimportovaných kontaktov: $inserted</b>';
$messages['importconfirmskipped'] = '<b>Počet preskočených existujúcich záznamov: $skipped</b>';
$messages['importmessagesuccess'] = 'Počet úspešne naimportovaných správ: $nr';
$messages['importmessageerror'] = 'Importovanie bolo neúspešné! Odoslaný súbor nie je platným súborom pre importovanie';
$messages['opnotpermitted'] = 'Táto operácia nie je povolená!';
$messages['nofromaddress'] = 'Vo vybranej identite chýba e-mailová adresa.';
$messages['editorwarning'] = 'Prepnutie druhu editora môže spôsobiť stratu formátovania. Naozaj chcete pokračovať?';
$messages['httpreceivedencrypterror'] = 'Vyskytla sa vážna chyba v konfigurácii. Ihneď kontaktujte administrátora. <b>Vašu správu nemožno odoslať.</b>';
$messages['smtpconnerror'] = 'Chyba SMTP ($code): Neúspešné pripojenie k serveru.';
$messages['smtpautherror'] = 'Chyba SMTP ($code): Neúspešná autentifikácia.';
$messages['smtpfromerror'] = 'Chyba SMTP ($code): Nemožno nastaviť odosielateľa "$from" ($msg).';
$messages['smtptoerror'] = 'Chyba SMTP ($code): Nemožno pridať príjemcu "$to" ($msg).';
$messages['smtprecipientserror'] = 'Chyba SMTP: Nemožno spracovať zoznam príjemcov.';
$messages['smtputf8error'] = 'Chyba SMTP: server nepodporuje Unicode v e-mailovej adrese.';
$messages['smtpsizeerror'] = 'Chyba SMTP: veľkosť správy presahuje limit servera ($limit)';
$messages['smtperror'] = 'Chyba SMTP: $msg';
$messages['emailformaterror'] = 'Neplatná e-mailová adresa: $email';
$messages['toomanyrecipients'] = 'Príliš veľa príjemcov. Zredukujte počet príjemcov na $max.';
$messages['maxgroupmembersreached'] = 'Počet členov skupiny prekračuje maximum: $max';
$messages['internalerror'] = 'Došlo k internej chybe systému. Prosím skúste to ešte raz.';
$messages['contactdelerror'] = 'Nemožno vymazať kontakt(y).';
$messages['contactdeleted'] = 'Kontakty boli úspešne vymazané.';
$messages['contactrestoreerror'] = 'Nemožno obnoviť vymazané kontakty.';
$messages['contactrestored'] = 'Kontakty boli úspešne obnovené.';
$messages['groupdeleted'] = 'Skupina bola úspešne vymazaná.';
$messages['grouprenamed'] = 'Skupina bola úspešne premenovaná.';
$messages['groupcreated'] = 'Skupina bola úspešne vytvorená.';
$messages['savedsearchdeleted'] = 'Uložené výsledky vyhľadávania boli úspešne vymazané.';
$messages['savedsearchdeleteerror'] = 'Nemožno vymazať uložené výsledky vyhľadávania.';
$messages['savedsearchcreated'] = 'Uložené výsledky vyhľadávania boli úspešne vytvorené.';
$messages['savedsearchcreateerror'] = 'Nemožno vytvoriť uložené výsledky vyhľadávania.';
$messages['messagedeleted'] = 'Vymazanie správ(y) bolo úspešné.';
$messages['messagemoved'] = 'Presunutie správ(y) bolo úspešné.';
$messages['messagemovedtotrash'] = 'Presun správ(y) do koša bol úspešný.';
$messages['messagecopied'] = 'Kopírovanie správ(y) bolo úspešné.';
$messages['messagemarked'] = 'Označovanie správ(y) bolo úspešné.';
$messages['autocompletechars'] = 'Zadajte najmenej $min znakov pre automatické dopĺňanie.';
$messages['autocompletemore'] = 'Našlo sa viacero záznamov. Zadajte prosím viac znakov.';
$messages['namecannotbeempty'] = 'Meno nemôže byť prázdne.';
$messages['nametoolong'] = 'Meno je príliš dlhé.';
$messages['namedotforbidden'] = 'Názov priečinka nemôže začínať bodkou.';
$messages['folderupdated'] = 'Priečinok bol úspešne aktualizovaný.';
$messages['foldercreated'] = 'Priečinok bol úspešne vytvorený.';
$messages['invalidimageformat'] = 'Neplatný formát obrázka';
$messages['mispellingsfound'] = 'V správe boli nájdené pravopisné chyby.';
$messages['parentnotwritable'] = 'Nemožno vytvoriť/presunúť priečinok do vybraného rodičovského priečinka. Nemáte prístupové oprávnenia.';
$messages['messagetoobig'] = 'Časť správy je príliš veľká na spracovanie.';
$messages['attachmentvalidationerror'] = 'Táto príloha je podozrivá, pretože jej typ sa nezhoduje s typom deklarovaným v správe. Ak odosielateľovi nedôverujete, nemali by ste ju otvárať v prehliadači, pretože môže mať škodlivý obsah.<br/><br/><em>Očakávalo sa: $expected; našlo sa: $detected</em>';
$messages['noscriptwarning'] = 'Upozornenie: Táto webmailová služba vyžaduje Javascript! Ak ju chcete používať, prosím aktivujte Javascript v nastaveniach svojho prehliadača.';
$messages['messageissent'] = 'Správa už bola odoslaná, ešte však nebola uložená. Chcete ju uložiť teraz?';
$messages['errnotfound'] = 'Súbor sa nenašiel';
$messages['errnotfoundexplain'] = 'Požadovaný zdroj nebol nájdený!';
$messages['errfailedrequest'] = 'Neúspešná požiadavka';
$messages['errauthorizationfailed'] = 'Autorizácia bola neúspešná';
$messages['errunauthorizedexplain'] = 'Nebolo možné overiť vašu autorizáciu na prístup k tejto službe!';
$messages['errrequestcheckfailed'] = 'Kontrola požiadavky bola neúspešná';
$messages['errcsrfprotectionexplain'] = "Kvôli vašej bezpečnosti je prístup k tomuto zdroju zabezpečený proti útokom typu CSRF.\nAk vidíte túto správu, pravdepodobne ste sa neodhlásili pred opustením webovej aplikácie.\n\nPre pokračovanie je teraz potrebný zásah človeka.";
$messages['errcontactserveradmin'] = 'Prosím kontaktujte administrátora servera.';
$messages['clicktoresumesession'] = 'Ak chcete pokračovať v predchádzajúcej relácii, prosím kliknite sem';
$messages['errcomposesession'] = 'Chyba relácie pre vytváranie správy';
$messages['errcomposesessionexplain'] = 'Požadovaná relácia pre vytvorenie správy sa nenašla';
$messages['clicktocompose'] = 'Ak chcete vytvoriť novú správu, kliknite sem';
$messages['nosupporterror'] = 'Táto funkcia nie je podporovaná vaším webovým prehliadačom.';
$messages['siginserted'] = 'Podpis bol úspešne vložený.';
$messages['responseinserted'] = 'Odpoveď bola úspešne vložená.';
$messages['noresponsesavailable'] = 'Nie sú dostupné žiadne odpovede';
$messages['listempty'] = 'Zoznam je prázdny.';
$messages['listusebutton'] = 'Na pridanie nového záznamu použite tlačidlo Vytvoriť.';
$messages['keypaircreatesuccess'] = 'Pre identitu $identity bol úspešne vytvorený nový pár kľúčov.';
$messages['emptyattachment'] = 'Zdá sa, že táto príloha je prázdna.<br>Prosím overte to u osoby, ktorá ju odoslala.';
$messages['oauthloginfailed'] = 'Prihlásenie OAuth bolo neúspešné. Prosím skúste to znovu.';
