<roundcube:object name="doctype" value="html5" />
<html>
<head>
<roundcube:include file="/includes/links.html" />
</head>
<roundcube:if condition="env:extwin" /><body class="noscroll extwin"><roundcube:else /><body class="noscroll"><roundcube:endif />

<roundcube:include file="/includes/header.html" />

<div id="mainscreen" class="offset">

<h1 class="voice"><roundcube:label name="settings" /> : <roundcube:label name="responses" /></h1>

<roundcube:include file="/includes/settingstabs.html" />

<div id="settings-right" role="main" aria-labelledby="aria-label-responseslist">

<div id="responseslist" class="uibox listbox">
<h2 class="boxtitle" id="aria-label-responseslist"><roundcube:label name="responses" /></h2>
<div class="scroller withfooter">
<roundcube:object name="responsesList" id="responses-table" class="listing" cellspacing="0" noheader="true" role="listbox" />
</div>
<div class="boxfooter">
<roundcube:button command="add" type="link" title="newresponse" class="listbutton add disabled" classAct="listbutton add" innerClass="inner" label="addresponse" /><roundcube:button command="delete" type="link" title="delete" class="listbutton delete disabled" classAct="listbutton delete" innerClass="inner" label="delete" />
</div>
</div>

<div id="response-details" class="uibox contentbox">
	<div class="iframebox">
		<roundcube:object name="contentframe" id="preferences-frame" style="width:100%; height:100%" frameborder="0" src="env:blankpage" title="arialabelresponseeditfrom" />
	</div>
</div>

</div>

</div>

<roundcube:include file="/includes/footer.html" />

</body>
</html>
