<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Здарылася памылка!';
$messages['loginfailed']  = 'Не ўдалося ўвайсці.';
$messages['cookiesdisabled'] = 'Ваш браўзер не падтрымлівае кукіс.';
$messages['sessionerror'] = 'Ваша сесія невалідная альбо састарэла.';
$messages['storageerror'] = 'Не ўдалося злучыцца з серверам-сховішчам.';
$messages['servererror'] = 'Памылка сервера!';
$messages['servererrormsg'] = 'Памылка сервера: $msg';
$messages['connerror'] = 'Памылка злучэння (не ўдалося даступіцца да сервера)!';
$messages['dberror'] = 'Памылка базы даных!';
$messages['windowopenerror'] = 'Усплыўное акно было заблакавана!';
$messages['requesttimedout'] = 'Час запросу выйшаў';
$messages['errorreadonly'] = 'Не ўдалося выканаць аперацыю. Папка даступна толькі для чытання.';
$messages['errornoperm'] = 'Не ўдалося выканаць аперацыю. Адмоўлена ў доступе.';
$messages['erroroverquota'] = 'Не ўдалося выканаць аперацыю. Няма свабоднай прасторы на дыску.';
$messages['erroroverquotadelete'] = 'Няма свабоднай прасторы на дыску. Націсніце SHIFT+DEL, каб выдаліць паведамленне.';
$messages['invalidrequest'] = 'Невалідны запрос! Дадзеныя не захаваныя.';
$messages['invalidhost'] = 'Няслушнае імя сервера.';
$messages['nomessagesfound'] = 'Паведамленняў у гэтай скрынцы не знойдзена';
$messages['mailboxempty'] = 'У паштовай скрынцы пуста';
$messages['nomessages'] = 'Няма паведамленняў';
$messages['refreshing'] = 'Абнаўляецца...';
$messages['loading'] = 'Загружаецца...';
$messages['uploading'] = 'Файл загружаецца...';
$messages['uploadingmany'] = 'Файлы загружаюцца...';
$messages['loadingdata'] = 'Загружаюцца даныя...';
$messages['checkingmail'] = 'Праверка новых паведамленняў...';
$messages['sendingmessage'] = 'Паведамленне адпраўляецца...';
$messages['messagesent'] = 'Паведамленні адпраўлены.';
$messages['savingmessage'] = 'Паведамленне захоўваецца...';
$messages['messagesaved'] = 'Паведамленне захавана ў Чарнавікі.';
$messages['successfullysaved'] = 'Захавана.';
$messages['savingresponse'] = 'Тэкст адказу захоўваецца...';
$messages['deleteresponseconfirm'] = 'Напраўду выдаліць тэкст адказу?';
$messages['addedsuccessfully'] = 'Кантакт дададзены ў адрасную кнігу.';
$messages['contactnameexists'] = 'Кантакт з такім самым імем ужо існуе.';
$messages['blockedimages'] = 'Дзеля забеспячэння вашай прыватнасці знешнія відарысы ў гэтым паведамленні заблакіраваныя.';
$messages['encryptedmessage'] = 'Гэта зашыфраванае паведамленне. Яно не можа быць адлюстравана. Выбачайце!';
$messages['nocontactsfound'] = 'Кантактаў не знойдзена.';
$messages['contactnotfound'] = 'Запытаны кантакт не знойдзены.';
$messages['sendingfailed'] = 'Не ўдалося адправіць паведамленне.';
$messages['senttooquickly'] = 'Пачакайце $sec секунд(ы) перад адпраўкай гэтага паведамлення.';
$messages['errorsavingsent'] = 'Не ўдалося захаваць адпраўленае паведамленне.';
$messages['errorsaving'] = 'Не ўдалося захаваць.';
$messages['errormoving'] = 'Не ўдалося перамясціць паведамлення(ў).';
$messages['errorcopying'] = 'Не ўдалося скапіяваць паведамлення(ў).';
$messages['errordeleting'] = 'Не ўдалося выдаліць паведамлення(ў).';
$messages['errormarking'] = 'Не ўдалося пазначыць паведамлення(ў).';
$messages['deletecontactconfirm']  = 'Напраўду выдаліць абраны(я) кантакты?';
$messages['deletegroupconfirm']  = 'Напраўду выдаліць абраную групу?';
$messages['deletemessagesconfirm'] = 'Напраўду выдаліць абранае(ыя) паведамленне?';
$messages['deletefolderconfirm']  = 'Напраўду выдаліць гэтую папку?';
$messages['purgefolderconfirm']  = 'Напраўду выдаліць усе паведамленні з гэтай папкі?';
$messages['contactdeleting'] = 'Кантакт(ы) выдаляюцца...';
$messages['groupdeleting'] = 'Група выдаляецца...';
$messages['folderdeleting'] = 'Папка выдаляецца...';
$messages['foldermoving'] = 'Папка перамяшчаецца...';
$messages['foldersubscribing'] = 'Папка падпісваецца...';
$messages['folderunsubscribing'] = 'Папка адпісваецца...';
$messages['formincomplete'] = 'Фармуляр запоўнены не да канца.';
$messages['noemailwarning'] = 'Задайце слушны адрас электроннай пошты.';
$messages['nonamewarning']  = 'Задайце імя.';
$messages['nopagesizewarning'] = 'Задайце памер старонкі.';
$messages['norecipientwarning'] = 'Задайце хаця-б аднаго атрымальніка.';
$messages['nosubjectwarning']  = 'Тэма ліста не зададзена. Ці жадаеце задаць яе зараз?';
$messages['nobodywarning'] = 'Адправіць гэта паведамленне без тэксту?';
$messages['restoresavedcomposedata'] = 'Было знойдзена ўжо складзенае, але не адпраўленае паведамленне.\n\nТэма: $subject\nЗахавана: $date\n\nЖадаеце аднавіць гэтае паведамленне?';
$messages['nosearchname'] = 'Задайце імя кантакта альбо адрас электроннай пошты.';
$messages['notuploadedwarning'] = 'Не ўсе далучэнні пакуль яшчэ зацягнутыя. Пачакайце альбо скасуйце аперацыю.';
$messages['searchsuccessful'] = 'Знойдзена $nr паведамленняў.';
$messages['contactsearchsuccessful'] = 'Знойдзена $nr кантактаў.';
$messages['searchnomatch'] = 'Пошук не даў выніку.';
$messages['searching'] = 'Ідзе пошук...';
$messages['checking'] = 'Ідзе праверка...';
$messages['stillsearching'] = 'Усё яшчэ ідзе пошук...';
$messages['nospellerrors'] = 'Памылак правапісання не выяўлена.';
$messages['folderdeleted'] = 'Папка выдалена.';
$messages['foldersubscribed'] = 'Папка падпісана.';
$messages['folderunsubscribed'] = 'Папка адпісана.';
$messages['deletedsuccessfully'] = 'Выдалена.';
$messages['converting'] = 'Фарматаванне выдаляецца...';
$messages['messageopenerror'] = 'Не ўдалося загрузіць паведамленне з сервера.';
$messages['fileuploaderror'] = 'Не ўдалося зацягнуць файл.';
$messages['filesizeerror'] = 'Зацягнуты файл перавышае максімальна дазволены памер $size.';
$messages['copysuccess'] = '$nr кантактаў скапіявана.';
$messages['movesuccess'] = '$nr кантактаў перамешчана.';
$messages['copyerror'] = 'Не ўдалося скапіяваць ніводнага кантакта.';
$messages['moveerror'] = 'Не ўдалося перамясціць ніводнага кантакта.';
$messages['sourceisreadonly'] = 'Гэтая крыніца адрасоў толькі для чытання.';
$messages['errorsavingcontact'] = 'Не ўдалося захаваць адрас кантакта.';
$messages['movingmessage'] = 'Паведамленні(е) перамяшчаюцца...';
$messages['copyingmessage'] = 'Паведамленні(е) капіююцца...';
$messages['copyingcontact'] = 'Кантакт(ы) капіююцца...';
$messages['movingcontact'] = 'Кантакт(ы) перамяшчаюцца...';
$messages['deletingmessage'] = 'Паведамленні(е) выдаляюцца...';
$messages['markingmessage'] = 'Паведамленні(е) пазначаюцца...';
$messages['addingmember'] = 'Кантакт(ы) дадаюцца ў групу...';
$messages['removingmember'] = 'Кантакт(ы) выдаляюцца з групы...';
$messages['receiptsent'] = 'Пацверджанне аб прачытанні адпраўлена.';
$messages['errorsendingreceipt'] = 'Не ўдалося адправіць пацверджання.';
$messages['deleteidentityconfirm'] = 'Напраўду выдаліць гэтую тоеснасць?';
$messages['nodeletelastidentity'] = 'Гэтую тоеснасць выдаліць няможна, бо апошняя.';
$messages['forbiddencharacter'] = 'Назва папкі змяшчае забаронены знак.';
$messages['selectimportfile'] = 'Абярыце файл да зацягвання.';
$messages['addresswriterror'] = 'Абраная адрасная кніга ёсць толькі-для-чытання.';
$messages['contactaddedtogroup'] = 'Кантакты дададзены ў групу.';
$messages['contactremovedfromgroup'] = 'Кантакты выдаленыя з групы.';
$messages['nogroupassignmentschanged'] = 'Усе прызначэнні групы засталіся без зменаў.';
$messages['importwait'] = 'Ідзе імпартаванне. Чакайце...';
$messages['importformaterror'] = 'Імпартаванне не ўдалося! Загружаны файл не ўтрымоўвае слушных даных на імпарт.';
$messages['importconfirm'] = '<b>$inserted кантактаў імпартаваныя</b>';
$messages['importconfirmskipped'] = '<b>Прапушчана $skipped існуючых запісаў</b>';
$messages['importmessagesuccess'] = '$nr паведамленняў імпартавана';
$messages['importmessageerror'] = 'Не ўдалося імпартаваць! Загружаны файл не ёсць слушным паведамленнем альбо файлам паштовай скрынкі';
$messages['opnotpermitted'] = 'Аперацыя не дазволеная!';
$messages['editorwarning'] = 'Змена тыпу рэдактара можа прывесці да страты фарматавання. Працягнуць?';
$messages['httpreceivedencrypterror'] = 'Важная памылка ў канфігурацыі. Неадкладна скантактуйцеся з адміністратарам. <b>Паведамленне не можа быць адпраўлена.</b>';
$messages['smtpconnerror'] = 'Памылка SMTP ($code): Не ўдалося злучыцца з серверам.';
$messages['smtpautherror'] = 'Памылка SMTP ($code): Аўтэтыфікацыя не ўдалася.';
$messages['smtpfromerror'] = 'Памылка SMTP ($code): Не ўдалося задаць адпраўніка "$from" ($msg).';
$messages['smtptoerror'] = 'Памылка STMP ($code): Не ўдалося задаць атрымальніка "$to" ($msg).';
$messages['smtprecipientserror'] = 'Памылка STMP: Не ўдалося прачытаць спіс атрымальнікаў.';
$messages['smtperror'] = 'Памылка SMTP: $msg';
$messages['toomanyrecipients'] = 'Замнога атрымальнікаў. Зменшыце лік атрымальнікаў да $max.';
$messages['maxgroupmembersreached'] = 'Лік сяброў групы перавышае максімум — $max.';
$messages['internalerror'] = 'Унутраная памылка. Паспрабуйце яшчэ раз.';
$messages['contactdelerror'] = 'Не ўдалося выдаліць кантакта(ў).';
$messages['contactdeleted'] = 'Кантакт(ы) выдалены.';
$messages['contactrestoreerror'] = 'Не ўдалося аднавіць выдаленыя кантакт(ы).';
$messages['contactrestored'] = 'Кантакт(ы) адноўлены.';
$messages['groupdeleted'] = 'Група выдалена.';
$messages['grouprenamed'] = 'Група перайменавана.';
$messages['groupcreated'] = 'Група створана.';
$messages['savedsearchdeleted'] = 'Захаванае запытанне выдалена.';
$messages['savedsearchdeleteerror'] = 'Не ўдалося выдаліць захаванае запытанне.';
$messages['savedsearchcreated'] = 'Захаванае запытанне створана.';
$messages['savedsearchcreateerror'] = 'Не ўдалося стварыць захаванае запытанне.';
$messages['messagedeleted'] = 'Паведамленні(е) выдалены.';
$messages['messagemoved'] = 'Паведамленні(е) перамешчаны.';
$messages['messagecopied'] = 'Паведамленні(е) скапіяваны.';
$messages['messagemarked'] = 'Паведамленні(е) пазначаны.';
$messages['autocompletechars'] = 'Увядзіце мінімум $min знакаў для аўтадапаўнення.';
$messages['autocompletemore'] = 'Больш адпаведных запісаў знойдзена. Увядзіце больш знакаў.';
$messages['namecannotbeempty'] = 'Назва не можа быць пустой.';
$messages['nametoolong'] = 'Назва задаўгая.';
$messages['folderupdated'] = 'Папка абноўлена.';
$messages['foldercreated'] = 'Папка створана.';
$messages['invalidimageformat'] = 'Няслушны фармат відарысу.';
$messages['mispellingsfound'] = 'У паведамленні выяўлены правапісныя памылкі.';
$messages['parentnotwritable'] = 'Не ўдалося стварыць/перамясціць папку ў абраным месцы. Няма доступу.';
$messages['messagetoobig'] = 'Гэтая часць паведамлення завялікая, каб яе апрацаваць.';
$messages['noscriptwarning'] = 'Увага: Служба вымагае Javascript’у! Каб карыстацца ёй, трэба ўключыць Javascript у перавагах браўзера.';
