<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<roundcube:include file="/includes/links.html" />
</head>
<body>

<roundcube:object name="logo" src="/images/roundcube_logo.png" id="logo" border="0" style="margin:0 11px" />

<roundcube:object name="message" id="message" />

<div id="login-form">
<div class="boxtitle"><roundcube:label name="welcome" /></div>
<div class="boxcontent">

<roundcube:form name="form" method="post">
<roundcube:object name="loginform" form="form" submit=true />
</form>

</div>
</div>

<noscript>
  <p id="login-noscriptwarning"><roundcube:label name="noscriptwarning" /></p>
</noscript>

<div id="login-bottomline">
  <roundcube:var name="config:product_name" condition="config:display_product_info &gt; 0"> <roundcube:object name="version" condition="config:display_product_info == 2" />
  <roundcube:if condition="config:support_url" />
    &nbsp;&#9679;&nbsp; <a href="<roundcube:var name='config:support_url' />" target="_blank" class="support-link"><roundcube:label name="support" /></a>
  <roundcube:endif />
  <roundcube:container name="loginfooter" id="bottomline" />
</div>

<roundcube:object name="preloader" images="
    /images/icons/folders.png
    /images/mail_footer.png
    /images/taskicons.gif
    /images/display/loading.gif
    /images/pagenav.gif
    /images/mail_toolbar.png
    /images/searchfield.gif
    /images/messageicons.png
    /images/icons/reset.gif
    /images/abook_toolbar.png
    /images/icons/groupactions.png
    /images/watermark.gif
" />

</body>
</html>
