<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = '$product вэб майлд тавтай морилно уу';
$labels['username'] = 'Хэрэглэгчийн нэр';
$labels['password'] = 'Нууц үг';
$labels['server'] = 'Сервер';
$labels['login'] = 'Нэвтрэх';
$labels['logout'] = 'Гарах';
$labels['mail'] = 'Захиа';
$labels['settings'] = 'Тохиргоо';
$labels['addressbook'] = 'Хаягийн дэвтэр';
$labels['inbox'] = 'Ирэх хайрцаг';
$labels['drafts'] = 'Ноорог';
$labels['sent'] = 'Илгээсэн';
$labels['trash'] = 'Хогийн сав';
$labels['junk'] = 'Спам';
$labels['show_real_foldernames'] = 'Тусгай хавтасны жинхэнэ нэрийг харуулна';
$labels['subject'] = 'Гарчиг';
$labels['from'] = 'Хэнээс';
$labels['sender'] = 'Илгээгч';
$labels['to'] = 'Хэнд';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Хариулах-Хэнд: ';
$labels['date'] = 'Огноо';
$labels['size'] = 'Хэмжээ';
$labels['priority'] = 'Ээлж';
$labels['organization'] = 'Байгууллага';
$labels['readstatus'] = 'Уншсан төлөв';
$labels['listoptions'] = 'Жагсаалтын тохиргоо...';
$labels['mailboxlist'] = 'Хавтас';
$labels['messagesfromto'] = 'Нийт $count захианы from-с $to';
$labels['showattachment'] = 'Харах';
$labels['deletemessage'] = 'Захиа устгах';
$labels['isread'] = 'Унших';
$labels['unknown'] = 'мэдэгдэхгүй';
$labels['other'] = 'Бусад';
$labels['typeother'] = 'Бусад';
$labels['delete'] = 'Устгах';
$labels['about'] = 'Танилцуулга';
$labels['folders'] = 'Хавтас';
$labels['license'] = 'Лиценз';
