<roundcube:object name="doctype" value="html5" />
<html>
<head>
<roundcube:include file="/includes/links.html" />
</head>
<roundcube:if condition="env:action != 'show'" />
<body class="iframe fullheight">

<div id="mainscreen" class="watermark" style="top:0"></div>

<roundcube:else />
<body class="<roundcube:exp expression="env:extwin ? 'extwin' : ''" />">

<roundcube:include file="/includes/header.html" />

<div id="mainscreen">

<h1 class="voice"><roundcube:label name="messageopenerror" /></h1>

<!-- toolbar -->
<h2 id="aria-label-toolbar" class="voice"><roundcube:label name="arialabeltoolbar" /></h2>
<div id="messagetoolbar" class="toolbar fullwidth" role="toolbar" aria-labelledby="aria-label-toolbar">
	<roundcube:button command="list" type="link" class="button back disabled" classAct="button back" classSel="button back pressed" label="back" />
</div>

<div id="mainscreencontent">

<div id="mailview-left">

<!-- folders list -->
<div id="mailboxcontainer" class="uibox listbox" role="navigation" aria-labelledby="aria-label-folderlist">
<h2 id="aria-label-folderlist" class="voice"><roundcube:label name="arialabelfolderlist" /></h2>
<div class="scroller">
	<roundcube:object name="mailboxlist" id="mailboxlist" class="treelist listing" folder_filter="mail" unreadwrap="%s" />
</div>
</div>

</div>

<div id="mailview-right" class="uibox">

<div id="messagecontent" class="watermark" style="top:0"></div>

</div><!-- end mailview-right -->

</div><!-- end mainscreencontent -->

</div><!-- end mainscreen -->

<roundcube:include file="/includes/footer.html" />

<roundcube:endif />

</body>
</html>
