<?php

/*
 +-----------------------------------------------------------------------+
 | localization/it_IT/csv2vcard.inc                                      |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2014, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Aleksander Machniak <alec@alec.pl>                            |
 +-----------------------------------------------------------------------+
*/
$map = array();
$map['anniversary'] = "Anniversary";
$map['assistants_name'] = "Assistant's Name";
$map['assistants_phone'] = "Assistant's Phone";
$map['birthday'] = "Birthday";
$map['business_city'] = "Città di lavoro";
$map['business_countryregion'] = "Business Country/Region";
$map['business_fax'] = "Business Fax";
$map['business_phone'] = "Business Phone";
$map['business_phone_2'] = "Business Phone 2";
$map['business_postal_code'] = "Business Postal Code";
$map['business_state'] = "Provincia di lavoro";
$map['business_street'] = "Indirizzo di lavoro";
$map['car_phone'] = "Car Phone";
$map['categories'] = "Categories";
$map['company'] = "Company";
$map['department'] = "Reparto";
$map['email_address'] = "E-mail Address";
$map['first_name'] = "Nome";
$map['gender'] = "Gender";
$map['home_city'] = "Città di residenza";
$map['home_countryregion'] = "Home Country/Region";
$map['home_fax'] = "Home Fax";
$map['home_phone'] = "Telefono casa";
$map['home_phone_2'] = "Home Phone 2";
$map['home_postal_code'] = "Home Postal Code";
$map['home_state'] = "Provincia di residenza";
$map['home_street'] = "Indirizzo di casa";
$map['job_title'] = "Qualifica";
$map['last_name'] = "Cognome";
$map['managers_name'] = "Manager's Name";
$map['middle_name'] = "Middle Name";
$map['mobile_phone'] = "Mobile Phone";
$map['notes'] = "Note";
$map['other_city'] = "Other City";
$map['other_countryregion'] = "Other Country/Region";
$map['other_fax'] = "Other Fax";
$map['other_phone'] = "Other Phone";
$map['other_postal_code'] = "Other Postal Code";
$map['other_state'] = "Other State";
$map['other_street'] = "Other Street";
$map['pager'] = "Numero cercapersone";
$map['primary_phone'] = "Primary Phone";
$map['spouse'] = "Spouse";
$map['suffix'] = "Suffix";
$map['title'] = "Title";
$map['web_page'] = "Web Page";
$map['birth_day'] = "Giorno di nascita";
$map['birth_month'] = "Mese di nascita";
$map['birth_year'] = "Anno di nascita";
$map['display_name'] = "Nome visualizzato";
$map['fax_number'] = "Numero fax";
$map['home_address'] = "Indirizzo di casa 2";
$map['home_country'] = "Nazione di residenza";
$map['home_zipcode'] = "CAP di residenza";
$map['mobile_number'] = "Numero cellulare";
$map['nickname'] = "Soprannome";
$map['organization'] = "Organizzazione";
$map['pager_number'] = "Pager Namber";
$map['primary_email'] = "Email primaria";
$map['secondary_email'] = "Email secondaria";
$map['web_page_1'] = "Pagina web 1";
$map['web_page_2'] = "Pagina web 2";
$map['work_phone'] = "Telefono lavoro";
$map['work_address'] = "Indirizzo di lavoro 2";
$map['work_country'] = "Nazione di lavoro";
$map['work_zipcode'] = "CAP di lavoro";
$map['date_of_birth'] = "Date of Birth";
$map['email'] = "Email";
$map['home_mobile'] = "Home Mobile";
$map['home_zip'] = "Home Zip";
$map['info'] = "Info";
$map['user_photo'] = "User Photo";
$map['url'] = "URL";
$map['work_city'] = "Work City";
$map['work_company'] = "Work Company";
$map['work_dept'] = "Work Dept";
$map['work_fax'] = "Work Fax";
$map['work_mobile'] = "Work Mobile";
$map['work_state'] = "Work State";
$map['work_title'] = "Work Title";
$map['work_zip'] = "Work Zip";
