<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Üdvözli a $product';
$labels['username'] = 'Felhasználónév';
$labels['password'] = 'Jelszó';
$labels['server'] = 'Szerver';
$labels['login'] = 'Bejelentkezés';
$labels['oauthlogin'] = 'Bejelentkezni a következővel $provider';
$labels['menu'] = 'Menű';
$labels['logout'] = 'Kijelentkezés';
$labels['mail'] = 'E-mail';
$labels['settings'] = 'Beállítások';
$labels['addressbook'] = 'Címjegyzék';
$labels['darkmode'] = 'Sötét mód';
$labels['lightmode'] = 'Világos mód';
$labels['inbox'] = 'Érkezettek';
$labels['drafts'] = 'Piszkozatok';
$labels['sent'] = 'Küldöttek';
$labels['trash'] = 'Kuka';
$labels['junk'] = 'Kéretlen';
$labels['show_real_foldernames'] = 'Valódi nevek megjelenítése a speciális mappáknál';
$labels['subject'] = 'Tárgy';
$labels['from'] = 'Feladó';
$labels['sender'] = 'Feladó';
$labels['to'] = 'Címzett';
$labels['cc'] = 'Másolat';
$labels['bcc'] = 'Titkos másolat';
$labels['replyto'] = 'Válaszcím';
$labels['followupto'] = 'Hírcsoport válasz';
$labels['date'] = 'Dátum';
$labels['size'] = 'Méret';
$labels['priority'] = 'Sürgősség';
$labels['organization'] = 'Szervezet';
$labels['readstatus'] = 'Olvasott';
$labels['listoptions'] = 'Üzenetlista beállítások...';
$labels['listoptionstitle'] = 'Üzenetlista beállítások.';
$labels['mailboxlist'] = 'Mappák';
$labels['messagesfromto'] = 'Üzenetek: $from - $to / $count';
$labels['threadsfromto'] = 'Témák: $from - $to / $count';
$labels['messagenrof'] = '$nr / $count üzenet';
$labels['fromtoshort'] = '$from – $to / $count';
$labels['copy'] = 'Másolás';
$labels['move'] = 'Áthelyezés';
$labels['moveto'] = 'Áthelyezés...';
$labels['copyto'] = 'Másolás..';
$labels['download'] = 'letöltés';
$labels['open'] = 'Megnyitás';
$labels['showattachment'] = 'Megjelenítés';
$labels['showanyway'] = 'Megjelnítés mindenképpen';
$labels['filename'] = 'Fájl neve';
$labels['filesize'] = 'Fájl mérete';
$labels['addtoaddressbook'] = 'Hozzáadás a címjegyzékhez';
$labels['sun'] = 'Vas';
$labels['mon'] = 'Hét';
$labels['tue'] = 'Kedd';
$labels['wed'] = 'Szer';
$labels['thu'] = 'Csüt';
$labels['fri'] = 'Pén';
$labels['sat'] = 'Szom';
$labels['sunday'] = 'Vasárnap';
$labels['monday'] = 'Hétfő';
$labels['tuesday'] = 'Kedd';
$labels['wednesday'] = 'Szerda';
$labels['thursday'] = 'Csütörtök';
$labels['friday'] = 'Péntek';
$labels['saturday'] = 'Szombat';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Febr';
$labels['mar'] = 'Márc';
$labels['apr'] = 'Ápr';
$labels['may'] = 'Május';
$labels['jun'] = 'Jún';
$labels['jul'] = 'Júl';
$labels['aug'] = 'Aug';
$labels['sep'] = 'Szept';
$labels['oct'] = 'Okt';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Dec';
$labels['longjan'] = 'Január';
$labels['longfeb'] = 'Február';
$labels['longmar'] = 'Március';
$labels['longapr'] = 'Április';
$labels['longmay'] = 'Május';
$labels['longjun'] = 'Június';
$labels['longjul'] = 'Július';
$labels['longaug'] = 'Augusztus';
$labels['longsep'] = 'Szeptember';
$labels['longoct'] = 'Október';
$labels['longnov'] = 'November';
$labels['longdec'] = 'December';
$labels['today'] = 'Ma';
$labels['refresh'] = 'Frissítés';
$labels['checkmail'] = 'Új üzenetek ellenőrzése';
$labels['compose'] = 'Új üzenet';
$labels['writenewmessage'] = 'Új üzenet';
$labels['reply'] = 'Válasz';
$labels['replytomessage'] = 'Válasz';
$labels['replytoallmessage'] = 'Válasz a listának vagy a feladónak és az összes címzettnek';
$labels['replyall'] = 'Válasz mindenkinek';
$labels['replylist'] = 'Válasz a listának';
$labels['forward'] = 'Továbbítás';
$labels['forwardinline'] = 'Továbbítás beágyazva';
$labels['forwardattachment'] = 'Továbbítás csatolmányként';
$labels['forwardmessage'] = 'Továbbítás';
$labels['bouncemsg'] = 'Újraküldés (visszapattanás)';
$labels['bounce'] = 'Újraküldés';
$labels['deletemessage'] = 'Törlés';
$labels['movemessagetotrash'] = 'Üzenet törlése';
$labels['printmessage'] = 'Nyomtatás';
$labels['previousmessage'] = 'Előző levél mutatása';
$labels['firstmessage'] = 'Első levél mutatása';
$labels['nextmessage'] = 'Következő levél mutatása';
$labels['lastmessage'] = 'Utolsó levél mutatása';
$labels['backtolist'] = 'Vissza az üzenetekhez';
$labels['viewsource'] = 'Forrás megtekintése';
$labels['mark'] = 'Jelölés';
$labels['markmessages'] = 'Üzenetek megjelölése';
$labels['markread'] = 'Olvasottként';
$labels['markunread'] = 'Olvasatlanként';
$labels['markflagged'] = 'Jelöltként';
$labels['markunflagged'] = 'Jelöletlenként';
$labels['moreactions'] = 'További műveletek...';
$labels['markallread'] = 'Mind megjelölése olvasottként';
$labels['folders-cur'] = 'Csak a kiválasztott mappa';
$labels['folders-sub'] = 'Kiválasztott mappák és almappák';
$labels['folders-all'] = 'Összes mappa';
$labels['more'] = 'Még...';
$labels['back'] = 'Vissza';
$labels['options'] = 'Beállítások';
$labels['composeoptions'] = 'Levélírás opciói';
$labels['optionsandattachments'] = 'Opciók és csatolmányok';
$labels['actions'] = 'Műveletek';
$labels['first'] = 'Első';
$labels['last'] = 'Utolsó';
$labels['previous'] = 'Előző';
$labels['next'] = 'Következő';
$labels['select'] = 'Kijelölés';
$labels['selection'] = 'Kijelölés';
$labels['all'] = 'Összes';
$labels['none'] = 'Nincs';
$labels['currpage'] = 'Aktuális oldal';
$labels['isread'] = 'Olvasás';
$labels['unread'] = 'Olvasatlan';
$labels['flagged'] = 'Megjelölt';
$labels['unflagged'] = 'Nem megjelölt';
$labels['unanswered'] = 'Megválaszolatlan';
$labels['withattachment'] = 'Csatolmánnyal';
$labels['deleted'] = 'Törölt';
$labels['undeleted'] = 'Nem lett törölve';
$labels['replied'] = 'Megválaszolva';
$labels['forwarded'] = 'Továbbítva';
$labels['invert'] = 'Invertálás';
$labels['filter'] = 'Szűrés';
$labels['list'] = 'Lista';
$labels['threads'] = 'Téma csoportok';
$labels['expand-all'] = 'Összes kibontása';
$labels['expand-unread'] = 'Olvasatlanok kibontása';
$labels['collapse-all'] = 'Összes összecsukása';
$labels['threaded'] = 'Témák szerinti csoportosítás';
$labels['showunread'] = 'Olvasatlan üzenetek megjelenítése';
$labels['autoexpand_threads'] = 'Témacsoportok kibontása';
$labels['do_expand'] = 'minden téma';
$labels['expand_only_unread'] = 'csak ahol van olvasatlan üzenet';
$labels['fromto'] = 'Feladó/Címzett';
$labels['flag'] = 'Megjelölés';
$labels['attachment'] = 'Csatolmány';
$labels['nonesort'] = 'Nincs';
$labels['sentdate'] = 'Feladva';
$labels['arrival'] = 'Kézbesítve';
$labels['asc'] = 'Emelkedő';
$labels['desc'] = 'Csökkenő';
$labels['listcolumns'] = 'Oszlopok listája';
$labels['listsorting'] = 'Rendezés oszlopa';
$labels['listorder'] = 'Rendezés sorrendje';
$labels['listmode'] = 'Megjelenítési mód';
$labels['lmode'] = 'Megjelenítési mód';
$labels['layout'] = 'Elrendezés';
$labels['layoutwidescreen'] = 'Szélesképernyő';
$labels['layoutdesktop'] = 'Asztal';
$labels['layoutlist'] = 'Lista';
$labels['layoutwidescreendesc'] = 'Szélesvásznú (3-oszlopos nézet)';
$labels['layoutdesktopdesc'] = 'Asztali ( széles üzenetlista és alatta betekintő a levélbe)';
$labels['layoutlistdesc'] = 'Lista (nincs a levélbe betekintő)';
$labels['folderactions'] = 'Mappaműveletek...';
$labels['compact'] = 'Tömörítés';
$labels['empty'] = 'Kiürítés';
$labels['importmessages'] = 'Üzenetek importálása';
$labels['mailimportdesc'] = 'Feltölthetsz leveleket a <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> vagy <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a> formátumban.';
$labels['mailimportzip'] = 'Több file-t lehet összetömöríteni egy a zip fileba.';
$labels['quota'] = 'Helyfoglalás';
$labels['unknown'] = 'ismeretlen';
$labels['unlimited'] = 'korlátlan';
$labels['quotatype'] = 'Kvóta típus';
$labels['quotatotal'] = 'Limit';
$labels['quotaused'] = 'Használt';
$labels['quotastorage'] = 'Lemez méret';
$labels['quotamessage'] = 'Üzenet darab';
$labels['shortheaderdate'] = '$date';
$labels['shortheaderto'] = '$to címzettnek $date';
$labels['shortheaderfrom'] = '$from küldőtől $date';
$labels['quicksearch'] = 'Gyorskeresés';
$labels['searchplaceholder'] = 'Keresés...';
$labels['resetsearch'] = 'Alapállapot';
$labels['searchmod'] = 'Keresési opciók';
$labels['msgtext'] = 'Teljes üzenet';
$labels['body'] = 'Törzs';
$labels['type'] = 'Típus';
$labels['namex'] = 'Név';
$labels['searchscope'] = 'Hatókör';
$labels['currentfolder'] = 'Aktuális mappa';
$labels['subfolders'] = 'Ez és az almappák';
$labels['allfolders'] = 'Minden mappa';
$labels['searchinterval-1W'] = 'egy hétnél régebbi';
$labels['searchinterval-1M'] = 'egy hónapnál régebbi';
$labels['searchinterval-1Y'] = 'több mint egy éves';
$labels['searchinterval1W'] = 'egy hétnél korábbi';
$labels['searchinterval1M'] = 'egy hónapnál korábbi';
$labels['searchinterval1Y'] = 'egy évnél korábbi';
$labels['openinextwin'] = 'Megnyitás új ablakban';
$labels['emlsave'] = 'Letöltés (.eml)';
$labels['changeformattext'] = 'Megjelenítés sima szöveges formátumban';
$labels['changeformathtml'] = 'Megjelenítés HTML formátumban';
$labels['editasnew'] = 'Szerkesztés újként';
$labels['send'] = 'Küldés';
$labels['sendmessage'] = 'Üzenet küldése';
$labels['savemessage'] = 'Vázlat mentése';
$labels['addattachment'] = 'Fájl csatolása';
$labels['charset'] = 'Karakterkészlet';
$labels['editortype'] = 'Szerkesztő típusa';
$labels['returnreceipt'] = 'Olvasási visszaigazolás';
$labels['dsn'] = 'Kézbesítési visszaigazolás';
$labels['mailreplyintro'] = '$date időpontban $sender ezt írta:';
$labels['originalmessage'] = 'Eredeti üzenet';
$labels['selectimage'] = 'Kép kijelőlés';
$labels['addimage'] = 'Kép hozzáadás';
$labels['selectmedia'] = 'Film kijelölés';
$labels['addmedia'] = 'Film hozzáadás';
$labels['encrypt'] = 'Titkosítás';
$labels['encryptmessage'] = 'Üzenet titkosítása';
$labels['encryptmessagemailvelope'] = 'Üzenet titkosítása Mailvelope-vel';
$labels['importpubkeys'] = 'Nyilvános kulcsok importálása';
$labels['encryptedsendialog'] = 'Titkosított üzenet küldése';
$labels['encryptandsign'] = 'Titkosítás és aláírás';
$labels['keyid'] = 'Kulcs ID';
$labels['keylength'] = 'Bitek';
$labels['keyexpired'] = 'Lejárt';
$labels['keyrevoked'] = 'Visszvont';
$labels['bccinstead'] = 'Titkos másolat használata';
$labels['addheader'] = 'Címzett (fejléc) hozzáadása ';
$labels['insert'] = 'Beszúrás';
$labels['insertcontact'] = 'Kapcsolat(ok) beszúrása';
$labels['recipient'] = 'Címzett';
$labels['recipientedit'] = 'A címzett szerkesztése';
$labels['editidents'] = 'Azonosítók szerkesztése';
$labels['spellcheck'] = 'Helyesírás-ellenőrzés';
$labels['checkspelling'] = 'Helyesírás-ellenőrzés';
$labels['resumeediting'] = 'Helyesírás-ellenőrzés vége';
$labels['revertto'] = 'Visszaállítás erre';
$labels['restore'] = 'Visszaállítás';
$labels['restoremessage'] = 'Üzenet visszaállítás';
$labels['ignore'] = 'figyelmen kivül hagy';
$labels['responses'] = 'Válaszok';
$labels['insertresponse'] = 'Egy válasz beillesztése';
$labels['manageresponses'] = 'Válaszok kezelése';
$labels['newresponse'] = 'Új válasz létrehozása';
$labels['addresponse'] = 'Válasz hozzáadása';
$labels['editresponse'] = 'Válasz szerkesztése';
$labels['editresponses'] = 'Válaszok szerkesztése';
$labels['responsename'] = 'Név';
$labels['responsetext'] = 'Válasz Szöveg';
$labels['attach'] = 'Csatolás';
$labels['attachments'] = 'Csatolmányok';
$labels['upload'] = 'Feltöltés';
$labels['uploadprogress'] = '$percent ($current / $total)';
$labels['close'] = 'Bezárás';
$labels['messageoptions'] = 'Üzenetbeállítások...';
$labels['togglecomposeoptions'] = 'Levélírás beállítások kapcsolása';
$labels['attachmentrename'] = 'Csatolmány átnevezése';
$labels['low'] = 'Alacsony';
$labels['lowest'] = 'Legkisebb';
$labels['normal'] = 'Normál';
$labels['high'] = 'Magas';
$labels['highest'] = 'Legmagasabb';
$labels['nosubject'] = '(nincs tárgy)';
$labels['showimages'] = 'Képek megjelenítése';
$labels['allow'] = 'Engedélyezve';
$labels['alwaysshow'] = 'Képek megjelenítése mindig, ha a feladó $sender';
$labels['alwaysallow'] = 'Minding engedélyezve ha a feladó $sender ';
$labels['isdraft'] = 'Ez egy piszkozat.';
$labels['andnmore'] = 'további $nr...';
$labels['details'] = 'Részletek';
$labels['summary'] = 'Összegzés';
$labels['headers'] = 'Fejlécek';
$labels['allheaders'] = 'Fejlécek...';
$labels['togglemoreheaders'] = 'Több üzenet fejrész(header) megjelenítése';
$labels['togglefullheaders'] = 'Nyers üzenet fejléc megjelenítés- elrejtés';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Egyszerű szöveg';
$labels['savesentmessagein'] = 'Elküldött üzenet mentése ide';
$labels['dontsave'] = 'nincs mentés';
$labels['maxuploadsize'] = 'A maximális feltölthető fájl mérete $size';
$labels['addcc'] = 'Cc (Másolati cím) hozzáadása';
$labels['addbcc'] = 'Bcc (titkos másolati cím) hozzáadása';
$labels['addreplyto'] = 'Válaszcím hozzáadása';
$labels['addfollowupto'] = 'Hírcsoport válasz hozzáadása';
$labels['sendreceipt'] = 'Elküldi az olvasási visszaigazolást?';
$labels['mdnrequest'] = 'Az üzenet küldője értesítést kér arról, hogy elolvasta a levelet. El legyen küldve az olvasási visszaigazolás?';
$labels['receiptread'] = 'Olvasási visszaigazolás (olvasott)';
$labels['yourmessage'] = 'Ez az üzenete olvasási visszaigazolása';
$labels['receiptnote'] = 'Megjegyzés: Ez az olvasási visszaigazolás csak azt igazolja, hogy az üzenet megjelenítésre került a címzett számítógépén. Nincs rá garancia, hogy a címzett elolvasta volna az üzenetet illetve megértette volna annak tartalmát.';
$labels['sendalwaysto'] = 'Mindig küldjön ide $email';
$labels['zoomin'] = 'Nagyítás';
$labels['zoomout'] = 'Kicsinyítés';
$labels['rotate'] = 'Elforgatás';
$labels['increaseimage'] = 'Kép méretének növelése';
$labels['decreaseimage'] = 'Kép méretének csökkentése';
$labels['rotateimage'] = 'Kép elforgatás';
$labels['showtools'] = 'Kép eszközök megjelenítése';
$labels['hidetools'] = 'Kép eszközök elrejtése';
$labels['name'] = 'Megjelenített név';
$labels['firstname'] = 'Keresztnév';
$labels['surname'] = 'Vezetéknév';
$labels['middlename'] = 'Második keresztnév';
$labels['nameprefix'] = 'Név-előtag';
$labels['namesuffix'] = 'Név-utótag';
$labels['nickname'] = 'Becenév';
$labels['jobtitle'] = 'Beosztás';
$labels['department'] = 'Részleg';
$labels['gender'] = 'Nem';
$labels['maidenname'] = 'Leánykori név';
$labels['email'] = 'E-mail cím';
$labels['phone'] = 'Telefonszám';
$labels['address'] = 'Lakcím';
$labels['street'] = 'Utca';
$labels['locality'] = 'Város';
$labels['zipcode'] = 'Irányítószám';
$labels['region'] = 'Régió';
$labels['country'] = 'Ország';
$labels['birthday'] = 'Születésnap';
$labels['anniversary'] = 'Évforduló';
$labels['website'] = 'Weboldal';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Megjegyzések';
$labels['male'] = 'férfi';
$labels['female'] = 'nő';
$labels['manager'] = 'Menedzser';
$labels['assistant'] = 'Asszisztens';
$labels['spouse'] = 'Házastárs';
$labels['allfields'] = 'Összes mező';
$labels['search'] = 'Keresés';
$labels['searchresult'] = 'Keresés eredménye';
$labels['advsearch'] = 'Részletes keresés';
$labels['advanced'] = 'Haladó';
$labels['other'] = 'Egyéb';
$labels['printcontact'] = 'A kapcsolat nyomtatása';
$labels['qrcode'] = 'QR Kód';
$labels['typehome'] = 'Otthon';
$labels['typework'] = 'Munkahely';
$labels['typeother'] = 'Egyéb';
$labels['typemobile'] = 'Mobil';
$labels['typemain'] = 'Vezetékes';
$labels['typehomefax'] = 'Otthoni fax';
$labels['typeworkfax'] = 'Munkahelyi fax';
$labels['typecar'] = 'Gépkocsi';
$labels['typepager'] = 'Személyhívó';
$labels['typevideo'] = 'Videó';
$labels['typeassistant'] = 'Asszisztens';
$labels['typehomepage'] = 'Weboldal';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Új mező hozzáadása...';
$labels['addcontact'] = 'Kapcsolat hozzáadása';
$labels['editcontact'] = 'Kapcsolat szerkesztése';
$labels['contacts'] = 'Kapcsolatok';
$labels['contactproperties'] = 'Kapcsolat tulajdonságai';
$labels['contactnameandorg'] = 'Név és szervezet';
$labels['personalinfo'] = 'Személyes adatok';
$labels['personal'] = 'Személyes';
$labels['contactphoto'] = 'Kapcsolat fotója';
$labels['edit'] = 'Szerkesztés';
$labels['cancel'] = 'Mégsem';
$labels['save'] = 'Mentés';
$labels['delete'] = 'Törlés';
$labels['discard'] = 'Érvénytelenít';
$labels['continue'] = 'Tovább';
$labels['ok'] = 'OK';
$labels['rename'] = 'Átnevezés';
$labels['addphoto'] = 'Kép hozzáadása';
$labels['replacephoto'] = 'Kép cseréje';
$labels['uploadphoto'] = 'Fotó feltöltése';
$labels['choosefile'] = 'File kiválasztása...';
$labels['choosefiles'] = 'Fileok kiválasztása...';
$labels['browse'] = 'Böngészés';
$labels['newcontact'] = 'Új kapcsolat létrehozása';
$labels['deletecontact'] = 'Kijelölt kapcsolatok törlése';
$labels['composeto'] = 'E-mail küldése erre a címre';
$labels['contactsfromto'] = 'Kapcsolatok: $from - $to / $count';
$labels['print'] = 'Nyomtatás';
$labels['export'] = 'Exportálás';
$labels['exportall'] = 'Összes exportálása';
$labels['exportsel'] = 'Kijelöltek exportálása';
$labels['exportvcards'] = 'Kapcsolatok exportálása vCard formátumban';
$labels['newgroup'] = 'Új csoport létrehozása';
$labels['addgroup'] = 'Csoport hozzáadása';
$labels['grouprename'] = 'Csoport átnevezése';
$labels['groupdelete'] = 'Csoport törlése';
$labels['groupassign'] = 'Csoporthoz rendelés...';
$labels['groupremove'] = 'Csoportból eltávolítás';
$labels['groupremoveselected'] = 'A kijelölt partnerek törlése a csoportból';
$labels['uponelevel'] = 'Egy szinttel feljebb';
$labels['previouspage'] = 'Előző oldal';
$labels['firstpage'] = 'Első oldal';
$labels['nextpage'] = 'Következő oldal';
$labels['lastpage'] = 'Utolsó oldal';
$labels['group'] = 'Csoport';
$labels['groups'] = 'Csoportok';
$labels['listgroup'] = 'Csoport tagjainak listája';
$labels['personaladrbook'] = 'Személyes címjegyzék';
$labels['searchsave'] = 'Keresés mentése';
$labels['searchdelete'] = 'Keresés törlése';
$labels['import'] = 'Importálás';
$labels['importcontacts'] = 'Kapcsolatok importálása';
$labels['importfromfile'] = 'Importálás fájlból';
$labels['importtarget'] = 'Kapcsolatok hozzáadása ';
$labels['importreplace'] = 'A teljes címjegyzék cseréje';
$labels['importgroups'] = 'Csoport hozzárendelések importálása';
$labels['importgroupsall'] = 'Mind(csoport létrehozása amennyiben szükséges)';
$labels['importgroupsexisting'] = 'Csak már létező csoportoknak';
$labels['importdesc'] = 'Feltölthetsz partnereket már létező címjegyzékből.<br/>Jelenleg a címeket importálni vagy <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> vagy CSV(vesszővel-tagolt) formátumból lehet.';
$labels['importmapdesc'] = 'Erősítse meg, hogy a mező megfeleltetések megfelelőek, mielőtt folytatnánk a CSV (vesszővel elválasztott) adatok importálását.';
$labels['fieldnotmapped'] = 'A mező nem hozzárendelve (nem importálandó)';
$labels['skipheader'] = 'Nem importálja az első sort (fejlécek)';
$labels['done'] = 'Kész';
$labels['settingsfor'] = 'Beállítás';
$labels['about'] = 'Névjegy';
$labels['preferences'] = 'Beállítások';
$labels['userpreferences'] = 'Felhasználói beállítások';
$labels['editpreferences'] = 'Felhasználói beállítások szerkesztése';
$labels['identities'] = 'Azonosítók';
$labels['manageidentities'] = 'Azonosítók kezelése';
$labels['newidentity'] = 'Új azonosító létrehozása';
$labels['addidentity'] = 'Azonosító hozzáadása';
$labels['editidentity'] = 'Azonosító szerkesztése';
$labels['identityencryption'] = 'Titkosítás';
$labels['preferhtml'] = 'HTML megjelenítés';
$labels['defaultcharset'] = 'Alapértelmezett karakterkódolás';
$labels['htmlmessage'] = 'HTML üzenet';
$labels['messagepart'] = 'Rész';
$labels['digitalsig'] = 'Digitális aláírás';
$labels['dateformat'] = 'Dátumformátum';
$labels['timeformat'] = 'Időformátum';
$labels['prettydate'] = 'Rövid dátumok';
$labels['setdefault'] = 'Beállítás alapértelmezettnek';
$labels['autodetect'] = 'Automatikus';
$labels['language'] = 'Nyelv';
$labels['timezone'] = 'Időzóna';
$labels['pagesize'] = 'Sorok száma egy oldalon';
$labels['signature'] = 'Aláírás';
$labels['dstactive'] = 'Nyári időszámítás';
$labels['showinextwin'] = 'Az üzenet megnyitása egy új ablakban';
$labels['composeextwin'] = 'Űzenet írása új ablakban';
$labels['htmleditor'] = 'HTML üzenet írása';
$labels['htmlonreply'] = 'csak HTML üzenetre válaszolva';
$labels['htmlonreplyandforward'] = 'HTML üzenet továbbításakor vagy az arra való válaszoláskor';
$labels['htmlsignature'] = 'HTML aláírás';
$labels['showemail'] = 'Az email címek megjelenítése a partner nevével';
$labels['previewpane'] = 'Előnézeti kép';
$labels['skin'] = 'Kinézet';
$labels['logoutclear'] = 'Törölt elemek mappa ürítése kilépéskor';
$labels['logoutcompact'] = 'Beérkezett üzenetek mappa tömörítése kilépéskor';
$labels['uisettings'] = 'Felhasználói felület';
$labels['serversettings'] = 'Szerverbeállítások';
$labels['mailboxview'] = 'Postafiók nézet';
$labels['mdnrequests'] = 'Olvasási visszaigazolás küldése';
$labels['askuser'] = 'kérdezzen rá';
$labels['autosend'] = 'automatikus küldés';
$labels['autosendknown'] = 'küldés csak a címjegyzékben lévő kapcsolataimnak, egyéb esetben kérdezzen rá';
$labels['autosendknownignore'] = 'küldés csak a címjegyzékben lévő kapcsolataimnak, egyéb esetben nem';
$labels['autosendtrusted'] = 'küldjön visszaigazolást a megbízható feladóknak, máskülönben kérdezzen rá';
$labels['autosendtrustedignore'] = 'küldjön visszaigazolást a megbízható feladóknak, máskülönben hagyja figyelmen kívül';
$labels['ignorerequest'] = 'a kérés figyelmen kivül hagyása';
$labels['readwhendeleted'] = 'Üzenet olvasottként jelölése törléskor';
$labels['flagfordeletion'] = 'Üzenet törlendőnek jelölése törlés helyett';
$labels['skipdeleted'] = 'Törölt üzenetek ne legyenek megjelenítve';
$labels['deletealways'] = 'Üzenet törlése, ha nem sikerül áthelyezni a törölt elemek mappába';
$labels['deletejunk'] = 'Üzenetek közvetlen törlése a levélszemét mappából';
$labels['showremoteimages'] = 'Távoli beágyazott képek megjelenítése';
$labels['allowremoteresources'] = 'Távoli erőforrások engedélyezve (képek, stílusok)';
$labels['fromknownsenders'] = 'csak ismert feladóktól';
$labels['fromtrustedsenders'] = 'a megbízható feladóktól';
$labels['frommycontacts'] = 'a partnereimtől';
$labels['always'] = 'mindig';
$labels['alwaysbutplain'] = 'mindig, kivéve ha sima szöveg levélre válaszolunk';
$labels['showinlineimages'] = 'Csatolt képek megjelenítése az üzenet alatt';
$labels['autosavedraft'] = 'Piszkozat automatikus mentése';
$labels['everynminutes'] = 'minden $n percben';
$labels['refreshinterval'] = 'Frissítés ( új üzenetek keresése, stb )';
$labels['never'] = 'soha';
$labels['immediately'] = 'azonnal';
$labels['messagesdisplaying'] = 'Üzenetek megjelenítése';
$labels['messagescomposition'] = 'Üzenetek írása';
$labels['mimeparamfolding'] = 'Csatolt állományok nevei';
$labels['2231folding'] = 'Teljes RFC 2231 ( pl. Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (egyéb)';
$labels['force7bit'] = 'MIME kódolás használata 8 bites karakterekhez';
$labels['savelocalstorage'] = "Mentse a böngésző helyi adattárolóba (ideiglenes)";
$labels['advancedoptions'] = 'Haladó beállítások';
$labels['toggleadvancedoptions'] = 'Haladó beállítások kapcsolása';
$labels['focusonnewmessage'] = 'Beérkező új üzenet ablakának fókuszba hozása';
$labels['checkallfolders'] = 'Új üzenetek ellenőrzése minden mappában';
$labels['displaynext'] = 'A következő elem megjelenítése törlés/áthelyezés után';
$labels['defaultfont'] = 'HTML üzenet alap karakterkészlete';
$labels['mainoptions'] = 'Általános beállítások';
$labels['browseroptions'] = 'Böngésző beállításai';
$labels['section'] = 'Beállítások';
$labels['maintenance'] = 'Karbantartás';
$labels['newmessage'] = 'Új üzenet';
$labels['signatureoptions'] = 'Aláírás beállításai';
$labels['whenreplying'] = 'Válasznál';
$labels['replyempty'] = 'ne idézze az eredeti üzenetet';
$labels['replytopposting'] = 'üzenet írása az eredeti felett';
$labels['replytoppostingnoindent'] = 'üzenet írása az eredeti felett (behúzások nélkül)';
$labels['replybottomposting'] = 'üzenet írása az eredeti alatt';
$labels['replyremovesignature'] = 'Válasznál az eredeti aláírás eltávolítása';
$labels['autoaddsignature'] = 'Aláírás automatikus hozzáadása';
$labels['newmessageonly'] = 'csak új üzenetnél';
$labels['replyandforwardonly'] = 'válasznál és továbbításnál';
$labels['insertsignature'] = 'Aláírás beillesztése';
$labels['sigbelow'] = 'Az aláírás az idézett üzenet alatt';
$labels['sigseparator'] = 'Az aláírásokban a szabványos elválasztok használatának kényszerítése';
$labels['automarkread'] = 'Üzenetek megjelölése olvasottként';
$labels['afternseconds'] = '$n másodperc elteltével';
$labels['reqmdn'] = 'Olvasási visszaigazolás megkövetelése';
$labels['reqdsn'] = 'Kézbesítési visszaigazolás megkövetelése';
$labels['replysamefolder'] = 'Válaszok azonos mappába helyezése';
$labels['defaultabook'] = 'Alapértelmezett címjegyzék';
$labels['autocompletesingle'] = 'Alternatív e-mail címek kihagyása automatikus kiegészítéskor';
$labels['listnamedisplay'] = 'Névjegyek listázása';
$labels['contactformmode'] = 'Kapcsolat űrlap mód';
$labels['privatemode'] = 'Magán (Otthoni)';
$labels['businessmode'] = 'Üzleti (Munkahely)';
$labels['collectedaddresses'] = 'Begyűjtött címek';
$labels['collectedrecipients'] = 'Begyűjtött Címzettek';
$labels['collectedrecipientsopt'] = 'Kimenő emailek címzetjeinek tárolása a kövezkezőben';
$labels['collectedsendersopt'] = 'Megbízható feladókat tárolása a következőben';
$labels['trustedsenders'] = 'Megbízható Feladók';
$labels['spellcheckbeforesend'] = 'Helyesírás-ellenőrzés az üzenet elküldése előtt';
$labels['spellcheckoptions'] = 'Helyesírás-ellenőrzés opciók';
$labels['spellcheckignoresyms'] = 'Speciális karaktereket tartalmazó szavak kihagyása';
$labels['spellcheckignorenums'] = 'Számot tartalmazó szavak kihagyása';
$labels['spellcheckignorecaps'] = 'Csak nagybetűt tartalmazó szavak kihagyása';
$labels['addtodict'] = 'Hozzáadás a szótárhoz';
$labels['mailtoprotohandler'] = 'Beállítás a mailto: linkek kezelőjeként';
$labels['standardwindows'] = 'A felugró ablakok használata szokásos ablakként';
$labels['forwardmode'] = 'Üzenet továbbítás';
$labels['inline'] = 'beágyazott';
$labels['asattachment'] = 'csatolmányként';
$labels['replyallmode'] = 'Alapértelemezett művelete a [Válasz mindenkinek] gombnak';
$labels['replyalldefault'] = 'válasz mindenkinek';
$labels['replyalllist'] = 'válasz a csak a levelező listára(ha levelezőlista)';
$labels['folder'] = 'Mappa';
$labels['folders'] = 'Mappák';
$labels['foldername'] = 'Mappa neve';
$labels['subscribed'] = 'Feliratkozva';
$labels['messagecount'] = 'Üzenet';
$labels['create'] = 'Létrehozás';
$labels['createfolder'] = 'Új mappa létrehozása';
$labels['managefolders'] = 'Mappák kezelése';
$labels['specialfolders'] = 'Különleges mappák';
$labels['properties'] = 'Tulajdonságok';
$labels['folderproperties'] = 'Mappa tulajdonságai';
$labels['parentfolder'] = 'Szülőmappa';
$labels['location'] = 'Hely';
$labels['info'] = 'Információk';
$labels['getfoldersize'] = 'Mappa mérete';
$labels['changesubscription'] = 'Feliratkozás megváltoztatása';
$labels['foldertype'] = 'Mappa típusa';
$labels['personalfolder'] = 'Privát mappa';
$labels['otherfolder'] = 'Más felhasználó(k) mappája';
$labels['sharedfolder'] = 'Megosztott mappa';
$labels['findfolders'] = 'Mappa keresése';
$labels['findcontacts'] = 'Kapcsolat keresés';
$labels['findmail'] = 'Levél keresés';
$labels['namespace.personal'] = 'Személyes';
$labels['namespace.other'] = 'Más felhasználók';
$labels['namespace.shared'] = 'Megosztva';
$labels['dualuselabel'] = 'Csak a következőt tartalmazhatja';
$labels['dualusemail'] = 'üzenetek';
$labels['dualusefolder'] = 'mappák';
$labels['generate'] = 'Generálás';
$labels['encryptioncreatekey'] = 'Új kulcs pár létrehozása';
$labels['openmailvelopesettings'] = 'Open Mailvelope Beállítások';
$labels['encryptionprivkeysinmailvelope'] = '$nr egyező privát kulcs van a Mailvelope kulcskarikádon: ';
$labels['encryptionnoprivkeysinmailvelope'] = 'Ennek küldőnek még nincs meg a PGP prívát kulcsa a Mailvelope kiterjesztésedben. Szeretnél létrehozni egyet, hogy engedélyezzed a titkositott üzenetváltást?';
$labels['encryption'] = 'Titkosítás';
$labels['mailvelopeoptions'] = 'Mailvelope opciók';
$labels['mailvelopemainkeyring'] = 'Mailvelop fő kulcskarikájának használata';
$labels['mailvelopenotfound'] = 'A Mailvelope bővítmény nincs engedélyezva/telepítve a böngésződben.';
$labels['sortby'] = 'Rendezés';
$labels['sortasc'] = 'növekvő';
$labels['sortdesc'] = 'csökkenő';
$labels['undo'] = 'Visszavonás';
$labels['installedplugins'] = 'Telepített bővítmények';
$labels['plugin'] = 'Bővítmény';
$labels['version'] = 'Verzió';
$labels['source'] = 'Forrás';
$labels['destination'] = 'Cél';
$labels['license'] = 'Licensz';
$labels['support'] = 'Támogatás';
$labels['savedsearches'] = 'Elmentett keresések';
$labels['dateformatY'] = 'ÉÉÉÉ';
$labels['dateformaty'] = 'ÉÉ';
$labels['dateformatm'] = 'HH';
$labels['dateformatd'] = 'NN';
$labels['dateformatj'] = 'N';
$labels['dateformatn'] = 'H';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Angol';
$labels['westerneuropean'] = 'Nyugat-európai';
$labels['easterneuropean'] = 'Kelet-európai';
$labels['southeasterneuropean'] = 'Délkelet-európai';
$labels['baltic'] = 'Balti';
$labels['cyrillic'] = 'Cirill';
$labels['arabic'] = 'Arab';
$labels['greek'] = 'Görög';
$labels['hebrew'] = 'Héber';
$labels['turkish'] = 'Török';
$labels['nordic'] = 'Skandináv';
$labels['thai'] = 'Thai';
$labels['celtic'] = 'Kelta';
$labels['vietnamese'] = 'Vietnámi';
$labels['japanese'] = 'Japán';
$labels['korean'] = 'Koreai';
$labels['chinese'] = 'Kínai';
$labels['arialabeltopnav'] = 'Ablak beállítás';
$labels['arialabeltasknav'] = 'Alkalmazás feladatok';
$labels['arialabeltoolbar'] = 'Alkamazás eszközsor';
$labels['arialabellistnav'] = 'Lista navigáció';
$labels['arialabelactivetask'] = 'Aktiv feladat';
$labels['arialabelmessagessearchfilter'] = 'Email lista szűrő';
$labels['arialabelmailsearchform'] = 'Email üzenet kereső űrlap';
$labels['arialabelcontactsearchform'] = 'Kapcsolat kereső űrlap';
$labels['arialabelmailquicksearchbox'] = 'Email kereső mező';
$labels['arialabelquicksearchbox'] = 'Kereső mező';
$labels['arialabelfoldersearchfilter'] = 'Mappa lista szűrő';
$labels['arialabelfoldersearchform'] = 'Mappa kereső űrlap';
$labels['arialabelfolderlist'] = 'Email mappa kiválasztás';
$labels['arialabelmessagelist'] = 'Email üzenetek listázása';
$labels['arialabelmailpreviewframe'] = 'Üzenet betekintő';
$labels['arialabelmailboxmenu'] = 'Mappa műveletek menü';
$labels['arialabellistselectmenu'] = 'Lista választék menü';
$labels['arialabelthreadselectmenu'] = 'Témák szerinti listázás menü';
$labels['arialabelmessagelistoptions'] = 'Üzenet lista megjelenítési és rendezési opciók';
$labels['arialabelmailimportdialog'] = 'Üzenet importáls';
$labels['arialabelmessagenav'] = 'Üzenet navigálás';
$labels['arialabelmessagebody'] = 'Üzenet főrész';
$labels['arialabelmessageactions'] = 'Üzenet műveletek';
$labels['arialabelcontactquicksearch'] = 'Kapcsolat kereső űrlap';
$labels['arialabelcontactsearchbox'] = 'Kapcsolat kereső beviteli mező';
$labels['arialabelmessageheaders'] = 'Üzenet fejlécek';
$labels['arialabelforwardingoptions'] = 'Továbbítási beállítások';
$labels['arialabelreplyalloptions'] = 'Válasz mindenkinek beállítások';
$labels['arialabelmoremessageactions'] = 'További műveletek az üzenettel...';
$labels['arialabelmorecontactactions'] = 'További műveletek a kapcsolatokkal...';
$labels['arialabelmarkmessagesas'] = 'A kiválasztott üzenetek megjelölése mint...';
$labels['arialabelcomposeoptions'] = 'Levélírás opciók';
$labels['arialabelresponsesmenu'] = 'Sablon válaszok menű';
$labels['arialabelattachmentuploadform'] = 'Csatolmány feltöltő űrlap';
$labels['arialabelattachmentmenu'] = 'Csatolmány beállítások';
$labels['arialabelmailtomenu'] = 'Email cím beállítások';
$labels['arialabelattachmentpreview'] = 'Csatolmány előnézet';
$labels['ariasummarycomposecontacts'] = 'A kapcsolatoknak és csoportoknak a listája a címzettek kiválasztásához';
$labels['arialabelcontactexportoptions'] = 'Kapcsolat exportálásának opciói';
$labels['arialabelabookgroupoptions'] = 'Címjegyzék/csoportjegyzék opciói';
$labels['arialabelpreferencesform'] = 'Beállítások űrlap';
$labels['arialabelidentityeditfrom'] = 'Identitás szerkesztő űrlap';
$labels['arialabelresponseeditfrom'] = 'Válasz szerkesztő űrlap';
$labels['arialabelsearchterms'] = 'Kereső kifejezések';
$labels['arialabeldropactionmenu'] = 'Drag-n-Drop műveletek menü';
$labels['arialabelheadersmenu'] = 'Címzett (fejléc) hozzáadása menűhöz';
$labels['arialabelimagetools'] = 'Kép eszközök';
$labels['helplistnavigation'] = 'A navigálásra használt billentyűk listája';
$labels['helplistkeyboardnavigation'] = "Nyilak fel/le: A sor fókusz/kiválasztás mozgatása.
Szóköz: A fókuszban lévő sor kiválasztása.
Shift + fel/le: Több sor kiválasztása az aktuális sor alatt/felett.
Ctrl + Szóköz: A fókuszban levő sor hozzáadása vagy törlése a kiválasztásból.";
$labels['helplistkeyboardnavmessages'] = "Jobbra/Balra nyilak: kibontja/becsukja az üzenet szálakat (csak a beszélgető/szálas módban).
Enter: Kinyitja a kiválasztott/fókuszban levő üzenetet.
Delete: A kiválaszott üzenet áthelyezése a Kukába.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Megnyitja a kiválasztott/fókuszban levő kapcsolatot.";
