<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Виникла помилка!';
$messages['loginfailed']  = 'Невдала спроба входу';
$messages['cookiesdisabled'] = 'Ваш переглядач не приймає cookie';
$messages['sessionerror'] = 'Ваша сесія застаріла';
$messages['storageerror'] = 'Невдале з\'єднання з IMAP сервером';
$messages['servererror'] = 'Помилка сервера!';
$messages['servererrormsg'] = 'Помилка сервера: $msg';
$messages['accountlocked'] = 'Забагато невдалих спроб входу в систему. Спробуйте пізніше. ';
$messages['connerror'] = 'Помилка з\'єднання (не вдалося зв\'язатися з сервером)!';
$messages['dberror'] = 'Помилка бази даних!';
$messages['windowopenerror'] = 'Спливне вікно було заблоковано!';
$messages['requesttimedout'] = 'Час запиту вийшов';
$messages['errorreadonly'] = 'Неможливо виконати операцію. Тека доступна тільки для читання.';
$messages['errornoperm'] = 'Неможливо виконати операцію. Доступ заборонено';
$messages['erroroverquota'] = 'Неможливо виконати операцію. Немає вільного місця на диску.';
$messages['erroroverquotadelete'] = 'Недостатньо вільного місця на диску. Скористайтесь  SHIFT+DEL для видалення повідомлення.';
$messages['invalidrequest'] = 'Недійсний запит! Дані не збережено.';
$messages['invalidhost'] = 'Недійсне ім\'я сервера.';
$messages['nomessagesfound'] = 'Листів не знайдено';
$messages['mailboxempty'] = 'Поштова скринька порожня';
$messages['nomessages'] = 'Повідомлень немає';
$messages['refreshing'] = 'Оновлення...';
$messages['loading'] = 'Завантаження...';
$messages['uploading'] = 'Файл завантажується...';
$messages['attaching'] = 'Прикріплення файлу…';
$messages['uploadingmany'] = 'Завантаження файлів...';
$messages['loadingdata'] = 'Завантаження даних...';
$messages['checkingmail'] = 'Перевірка нових листів...';
$messages['sendingmessage'] = 'Відправка листа...';
$messages['messagesent'] = 'Лист успішно відправлено';
$messages['savingmessage'] = 'Збереження листа...';
$messages['messagesaved'] = 'Збережено в Чернетках';
$messages['successfullysaved'] = 'Збережено';
$messages['savingresponse'] = 'Збереження тексту відповіді...';
$messages['deleteresponseconfirm'] = 'Справді бажаєте видалити цей текст відповіді?';
$messages['addedsuccessfully'] = 'Контакт успішно доданий до адресної книги.';
$messages['contactexists'] = 'Контакт з такою самою адресою електронної пошти вже існує.';
$messages['contactnameexists'] = 'Контакт з таким самим іменем вже існує.';
$messages['blockedimages'] = 'Задля захисту Вашої приватності, зображення з зовнішніх джерел заблоковано у цьому листі.';
$messages['encryptedmessage'] = 'Лист зашифровано і не може бути відображено. Перепрошуємо!';
$messages['externalmessagedecryption'] = 'Лист зашифровано і не може бути розшифровано розширенням Вашого браузера.';
$messages['nopubkeyfor'] = 'Не знайдено дійсного публічного ключа для $email';
$messages['nopubkeyforsender'] = 'Не знайдено дійсного публічного ключа для профіля Вашого відправника. Ви хочете зашифрувати повідомлення лише для отримувачів?';
$messages['encryptnoattachments'] = 'Уже завантажені прикріплення не можна зашифрувати. Будь ласка, додайте їх заново у редакторі шифрування.';
$messages['searchpubkeyservers'] = 'Хочете пошукати ключі, яких бракує, на серверах публічних ключів?';
$messages['encryptpubkeysfound'] = 'Було знайдено такі публічні ключі: ';
$messages['nocontactsfound'] = 'Контакти не знайдені';
$messages['contactnotfound'] = 'Запитаний контакт не знайдений';
$messages['sendingfailed'] = 'Не вдалося відправити листа';
$messages['senttooquickly'] = 'Будь ласка, зачекайте $sec секунд для відправки листа';
$messages['errorsavingsent'] = 'Помилка при збереженні відправленого повідомлення.';
$messages['errorsaving'] = 'Помилка при збереженні.';
$messages['errormoving'] = 'Не вдалося перемістити лист(и).';
$messages['errorcopying'] = 'Не вдалося скопіювати лист(и).';
$messages['errordeleting'] = 'Не вдалося видалити лист(и).';
$messages['errormarking'] = 'Не вдалося позначити лист(и).';
$messages['deletecontactconfirm']  = 'Ви дійсно бажаєте видалити вибрані контакти?';
$messages['deletegroupconfirm']  = 'Ви дійсно хочете видалити обрану групу?';
$messages['deletemessagesconfirm'] = 'Ви дійсно бажаєте видалити вибрані листи?';
$messages['deletefolderconfirm']  = 'Ви дійсно бажаєте видалити цю теку?';
$messages['purgefolderconfirm']  = 'Справді бажаєте видалити усі листи у цій теці?';
$messages['contactdeleting'] = 'Видалення контакту(ів)...';
$messages['groupdeleting'] = 'Видалення групи...';
$messages['folderdeleting'] = 'Видалення теки...';
$messages['foldermoving'] = 'Переміщення теки...';
$messages['foldersubscribing'] = 'Підписати теку...';
$messages['folderunsubscribing'] = 'Відписати теку...';
$messages['formincomplete'] = 'Заповнено не всі поля';
$messages['noemailwarning'] = 'Будь ласка, введіть коректну адресу електронної пошти';
$messages['nonamewarning']  = 'Будь ласка, введіть ім\'я';
$messages['nopagesizewarning'] = 'Будь ласка, введіть розмір сторінки';
$messages['nosenderwarning'] = 'Будь ласка, введіть адресу електронної пошти відправника';
$messages['norecipientwarning'] = 'Будь ласка, вкажіть принаймні одного отримувача';
$messages['nosubjectwarning']  = 'Не вказано тему листа. Бажаєте вказати її зараз?';
$messages['nobodywarning'] = 'Відправити листа без тексту?';
$messages['restoresavedcomposedata'] = 'Знайдено написаного раніше, але не надісланого листа.\n\nТема: $subject\nЗбережено: $date\n\nХочете відновити це повідомлення?';
$messages['nosearchname'] = 'Будь ласка, введіть ім\'я чи електронну адресу';
$messages['notuploadedwarning'] = 'Деякі вкладення не було завантажено. Будь ласка, зачекайте або скасуйте завантаження.';
$messages['searchsuccessful'] = 'Зайдено $nr листів';
$messages['contactsearchsuccessful'] = '$nr контактів знайдено.';
$messages['searchnomatch'] = 'Пошук не дав результатів.';
$messages['searching'] = 'Пошук...';
$messages['checking'] = 'Перевірка...';
$messages['stillsearching'] = 'Пошук триває…';
$messages['nospellerrors'] = 'Орфографічних помилок не знайдено';
$messages['folderdeleted'] = 'Тека видалена';
$messages['foldersubscribed'] = 'Тека підписана';
$messages['folderunsubscribed'] = 'Тека відписана';
$messages['deletedsuccessfully'] = 'Видалено успішно';
$messages['converting'] = 'Видалення форматування...';
$messages['messageopenerror'] = 'Не вдалося завантажити повідомлення з сервера';
$messages['filelinkerror'] = 'Не вдалося прикріпити файл.';
$messages['fileuploaderror'] = 'Не вдалося вкласти файл';
$messages['filesizeerror'] = 'Розмір вибраного файлу перевищує максимально дозволений ($size)';
$messages['msgsizeerror'] = 'Помилка при додаванні вкладення. Максимальний розмір повідомлення файлу ($size).';
$messages['copysuccess'] = 'Успішно скопійовано $nr контактів';
$messages['movesuccess'] = 'Успішно переміщено $nr контактів';
$messages['copyerror'] = 'Не вдалося скопіювати жодного контакту.';
$messages['moveerror'] = 'Не вдалося перемістити контакти.';
$messages['sourceisreadonly'] = 'Дане джерело адрес доступне лише для читання';
$messages['errorsavingcontact'] = 'Неможливо зберегти адресу контакту';
$messages['movingmessage'] = 'Переміщення листа...';
$messages['copyingmessage'] = 'Копіювання листа...';
$messages['copyingcontact'] = 'Копіювання контакту(ів)...';
$messages['movingcontact'] = 'Перенесення контакту(ів)...';
$messages['deletingmessage'] = 'Видалення листа (ів)';
$messages['markingmessage'] = 'Позначення листа (ів)';
$messages['addingmember'] = 'Додання контакту(ів) до групи...';
$messages['removingmember'] = 'Видалення контакту(ів) з групи...';
$messages['receiptsent'] = 'Повідомлення про прочитання відправлено';
$messages['errorsendingreceipt'] = 'Не вдалося відправити повідомлення про прочитання';
$messages['deleteidentityconfirm'] = 'Ви дійсно бажаєте видалити цей профіль?';
$messages['nodeletelastidentity'] = 'Ви не можете видалити цей профіль, він у Вас останній.';
$messages['forbiddencharacter'] = 'Назва теки містить заборонені символи';
$messages['selectimportfile'] = 'Виберіть файл для завантаження';
$messages['addresswriterror'] = 'Обрана адресна книга недоступна для запису';
$messages['contactaddedtogroup'] = 'Контакти успішно додано до цієї групи';
$messages['contactremovedfromgroup'] = 'Контакти успішно видалено з цієї групи';
$messages['nogroupassignmentschanged'] = 'Розподіл за групами не змінено.';
$messages['importwait'] = 'Імпортування, будь ласка, зачекайте...';
$messages['importformaterror'] = 'Помилка імпорту! Завантажений файл має невідомий формат даних.';
$messages['importconfirm'] = '<b>Успішно імпортовано $inserted контактів</b>';
$messages['importconfirmskipped'] = '<b>Пропущені $skipped наявні записи</b>';
$messages['importmessagesuccess'] = 'Успішно імпортовано $nr повідомлень';
$messages['importmessageerror'] = 'Імпорт не вдався! Завантажений файл не є припустимим повідомленням чи файлом поштової скриньки';
$messages['opnotpermitted'] = 'Дія заборонена!';
$messages['nofromaddress'] = 'Відсутня адреса електронної пошти в обраному профілі';
$messages['editorwarning'] = 'Перемикання типу редактора може призвести до втрати форматування тексту. Хочете продовжити?';
$messages['httpreceivedencrypterror'] = 'Помилка конфігурації. Негайно зверніться до адміністратора. <b>Ваше повідомлення може бути відправлено.</b>';
$messages['smtpconnerror'] = 'Помилка SMTP-сервера ($code): Не вдалося з\'єднатися з сервером';
$messages['smtpautherror'] = 'Помилка SMTP-сервера ($code): Невдала спроба автентифікації';
$messages['smtpfromerror'] = 'Помилка SMTP-сервера ($code): Не вдалося вказати відправника "$from" ($msg)';
$messages['smtptoerror'] = 'Помилка SMTP-сервера ($code): Не вдалося додати отримувача "$to" ($msg)';
$messages['smtprecipientserror'] = 'Помилка SMTP: Не вдалося обробити список отримувачів';
$messages['smtperror'] = 'Помилка SMTP: $msg';
$messages['emailformaterror'] = 'Некоректна адреса електронної пошти: $email';
$messages['toomanyrecipients'] = 'Забагато отримувачів. Зменшіть їх число до $max.';
$messages['maxgroupmembersreached'] = 'Число адрес у групі перевищило максимальні $max.';
$messages['internalerror'] = 'Виникла внутрішня помилка. Будь ласка, спробуйте ще раз.';
$messages['contactdelerror'] = 'Неможливо видалити контакт(и)';
$messages['contactdeleted'] = 'Контакт(и) видалено успішно';
$messages['contactrestoreerror'] = 'Неможливо відновити видалений(і) контакт(и).';
$messages['contactrestored'] = 'Контакт(и) вдало відновлено.';
$messages['groupdeleted'] = 'Група видалена успішно';
$messages['grouprenamed'] = 'Група перейменована успішно';
$messages['groupcreated'] = 'Група створена успішно';
$messages['savedsearchdeleted'] = 'Збережений пошук вдало видалено.';
$messages['savedsearchdeleteerror'] = 'Неможливо видалити збережений пошук.';
$messages['savedsearchcreated'] = 'Збережений пошук вдало створено.';
$messages['savedsearchcreateerror'] = 'Не вдалось створити збережений пошук.';
$messages['messagedeleted'] = 'Лист(и) видалено успішно';
$messages['messagemoved'] = 'Лист(и) переміщено успішно';
$messages['messagemovedtotrash'] = 'Лист(и) переміщено в Корзину успішно';
$messages['messagecopied'] = 'Лист(и) скопійовано успішно';
$messages['messagemarked'] = 'Лист(и) помічено успішно';
$messages['autocompletechars'] = 'Введіть щонайменше $min символів для автозаповнення';
$messages['autocompletemore'] = 'Знайдено багато відповідних записів. Будь ласка, введіть більше символів.';
$messages['namecannotbeempty'] = 'Ім\'я не може бути пустим';
$messages['nametoolong'] = 'Занадто довге ім\'я';
$messages['namedotforbidden'] = 'Назва теки не може починатися з крапки.';
$messages['folderupdated'] = 'Тека успішно оновлена';
$messages['foldercreated'] = 'Тека створена';
$messages['invalidimageformat'] = 'Недійсний формат зображення';
$messages['mispellingsfound'] = 'Знайдено орфографічні помилки у повідомленні.';
$messages['parentnotwritable'] = 'Неможливо створити/перемістити теку до обраної батьківської теки. Нема прав доступу.';
$messages['messagetoobig'] = 'Частина повідомлення занадто велика для опрацювання.';
$messages['noscriptwarning'] = 'Увага: Даний клієнт електронної пошти потрібує Javascript! Щоб використовувати його, необхідно включити підтримку Javascript у налаштуваннях Вашого браузера.';
$messages['messageissent'] = 'Повідомлення уже надіслане, але ще не збережене. Хочете зберегти його зараз?';
$messages['errnotfound'] = 'Файл не знайдено';
$messages['errnotfoundexplain'] = 'Запитане джерело не знайдено!';
$messages['errfailedrequest'] = 'Запит не вдався';
$messages['errauthorizationfailed'] = 'Авторизація не вдалася';
$messages['errunauthorizedexplain'] = 'Не вдалося перевірити, що Ви авторизовані для доступу до цього ресурсу!';
$messages['errrequestcheckfailed'] = 'Перевірка запиту не вдалася';
$messages['errcsrfprotectionexplain'] = "Для Вашого захисту, доступ на цей ресурс убезпечується через CSRF.\nЯкщо Ви бачите це, Ви, напевно, не вийшли з системи перед тим, як залишити веб-аплікацію.\n\nЩоб продовжити, потрібна людська взаємодія.";
$messages['errcontactserveradmin'] = 'Будь ласка, зв\'яжіться зі своїм адміністратором сервера.';
$messages['clicktoresumesession'] = 'Натисніть тут, щоб відновити свою попередню сесію.';
$messages['errcomposesession'] = 'Помилка сесії створення листа';
$messages['errcomposesessionexplain'] = 'Запитана сесія створення не знайдена.';
$messages['clicktocompose'] = 'Натисніть тут, щоб створити нове повідомлення';
