<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Fehlermeldung';
$messages['loginfailed']  = 'Login fehlgeschlagen';
$messages['cookiesdisabled'] = 'Ihr Browser akzeptiert keine Cookies';
$messages['sessionerror'] = 'Ihre Session ist ungültig oder abgelaufen';
$messages['cookiesmismatch'] = 'Cookiefehler erkannt. Bitte im Browser Cookies löschen.';
$messages['storageerror'] = 'Keine Verbindung zum IMAP Server';
$messages['servererror'] = 'Serverfehler!';
$messages['servererrormsg'] = 'Serverfehler: $msg';
$messages['accountlocked'] = 'Zuviele fehlgeschlagene Login-Versuche. Bitte versuchen Sie es später wieder.';
$messages['connerror'] = 'Verbindungsfehler (Server nicht erreichbar)!';
$messages['dberror'] = 'Datenbankfehler!';
$messages['windowopenerror'] = 'Das Popup-Fenster wurde blockiert!';
$messages['requesttimedout'] = 'Zeitlimit überschritten';
$messages['errorreadonly'] = 'Die Aktion kann nicht ausgeführt werden. Der Ordner ist schreibgeschützt.';
$messages['errornoperm'] = 'Die Aktion kann nicht ausgeführt werden. Zugriff verweigert.';
$messages['erroroverquota'] = 'Die Aktion kann nicht ausgeführt werden. Keine freier Speicherplatz.';
$messages['erroroverquotadelete'] = 'Kein freier Speicherplatz. Drücken Sie SHIFT+DEL um die Nachricht zu löschen.';
$messages['invalidrequest'] = 'Ungültige Anfrage! Es wurden keine Daten gespeichert.';
$messages['invalidhost'] = 'Ungültiger Servername';
$messages['nomessagesfound'] = 'Keine Nachrichten in diesem Ordner';
$messages['loggedout'] = 'Sie haben die Sitzung erfolgreich beendet. Auf Wiedersehen!';
$messages['mailboxempty'] = 'Ordner ist leer';
$messages['nomessages'] = 'Keine Nachrichten';
$messages['refreshing'] = 'Aktualisiere...';
$messages['loading'] = 'Daten werden geladen...';
$messages['uploading'] = 'Datei wird hochgeladen...';
$messages['attaching'] = 'Datei wird angehängt...';
$messages['uploadingmany'] = 'Dateien werden hochgeladen...';
$messages['loadingdata'] = 'Daten werden geladen...';
$messages['checkingmail'] = 'Überprüfung auf neue Nachrichten...';
$messages['sendingmessage'] = 'Nachricht wird gesendet...';
$messages['messagesent'] = 'Nachricht erfolgreich gesendet';
$messages['savingmessage'] = 'Nachricht wird gespeichert...';
$messages['messagesaved'] = 'Nachricht als Entwurf gespeichert';
$messages['successfullysaved'] = 'Erfolgreich gespeichert';
$messages['savingresponse'] = 'Antwort wird gespeichert...';
$messages['deleteresponseconfirm'] = 'Wollen Sie diese Antwort wirklich löschen?';
$messages['nocontactselected'] = 'Sie haben noch keinen Kontakt ausgewählt.';
$messages['addedsuccessfully'] = 'Kontakt zum Adressbuch hinzugefügt';
$messages['contactexists'] = 'Es existiert bereits ein Kontakt mit dieser E-Mail-Adresse.';
$messages['contactnameexists'] = 'Es existiert bereits ein Kontakt mit diesem Namen';
$messages['blockedimages'] = 'Um Ihre Privatsphäre zu schützen, wurden externe Bilder blockiert.';
$messages['blockedresources'] = 'Um Ihre Privatsphäre zu schützen, wurden externe Ressourcen blockiert.';
$messages['encryptedmessage'] = 'Dies ist eine verschlüsselte Nachricht und kann leider nicht angezeigt werden.';
$messages['externalmessagedecryption'] = 'Dies ist eine verschlüsselte Nachricht und kann mit Ihrer Browser-Erweiterung entschlüsselt werden.';
$messages['nopubkeyfor'] = 'Kein gültiger öffentlicher Schlüssel für $email gefunden';
$messages['nopubkeyforsender'] = 'Kein gültiger öffentlicher Schlüssel für Ihre Absenderidentität gefunden. Möchten Sie die Nachricht nur für die Empfänger verschlüsseln?';
$messages['encryptnoattachments'] = 'Bereits hochgeladene Anhänge können nicht nachträglich verschlüsselt werden. Bitte fügen Sie sie erneut im Verschlüsselungs-Editor hinzu.';
$messages['searchpubkeyservers'] = 'Möchten Sie öffentliche Schlüsselserver nach den fehlenden Schlüsseln durchsuchen?';
$messages['encryptpubkeysfound'] = 'Die folgenden öffentlichen Schlüssel wurden gefunden:';
$messages['keyservererror'] = 'Fehler bei der Abfrage des Schlüssels vom Schlüsselserver.';
$messages['keyimportsuccess'] = 'Öffentlicher Schlüssel $key erfolgreich in den Schlüsselbund importiert.';
$messages['nocontactsfound'] = 'Keine Kontakte gefunden';
$messages['contactnotfound'] = 'Die gewählte Adresse wurde nicht gefunden';
$messages['contactsearchonly'] = 'Sie müssen das Suchformular nutzen, um die Kontakte vom ausgewählten Adressbuch zu sehen.';
$messages['sendingfailed'] = 'Versand der Nachricht fehlgeschlagen';
$messages['senttooquickly'] = 'Bitte warten Sie $sec Sekunde(n) vor dem Senden dieser Nachricht';
$messages['errorsavingsent'] = 'Beim Speichern der gesendeten Nachricht ist ein Fehler aufgetreten.';
$messages['errorsaving'] = 'Beim Speichern ist ein Fehler aufgetreten.';
$messages['errormoving'] = 'Nachricht(en) konnte(n) nicht verschoben werden.';
$messages['errorcopying'] = 'Nachticht(en) konnte(n) nicht kopiert werden.';
$messages['errordeleting'] = 'Nachricht(en) konnte(n) nicht gelöscht werden.';
$messages['errormarking'] = 'Nachricht(en) konnte(n) nicht markiert werden.';
$messages['alerttitle'] = 'Achtung';
$messages['confirmationtitle'] = 'Sind Sie sicher...';
$messages['deletecontactconfirm']  = 'Wollen Sie die ausgewählten Kontakte wirklich löschen?';
$messages['deletegroupconfirm']  = 'Wollen Sie die gewählte Gruppe wirklich löschen?';
$messages['deletemessagesconfirm'] = 'Wollen Sie die ausgewählten Nachrichten wirklich löschen?';
$messages['deletefolderconfirm']  = 'Wollen Sie diesen Ordner wirklich löschen?';
$messages['movefolderconfirm']  = 'Wollen Sie diesen Ordner wirklich verschieben?';
$messages['purgefolderconfirm']  = 'Wollen Sie diesen Ordner wirklich leeren?';
$messages['contactdeleting'] = 'Kontakte werden gelöscht...';
$messages['groupdeleting'] = 'Gruppe wird gelöscht...';
$messages['folderdeleting'] = 'Order wird gelöscht...';
$messages['foldermoving'] = 'Ordner wird verschoben...';
$messages['foldersubscribing'] = 'Ordner wird abonniert...';
$messages['folderunsubscribing'] = 'Ordner wird abbestellt...';
$messages['formincomplete'] = 'Das Formular wurde nicht vollständig ausgefüllt.';
$messages['noemailwarning'] = 'Bitte geben Sie eine gültige E-Mail-Adresse ein.';
$messages['nonamewarning']  = 'Bitte geben Sie einen Namen ein.';
$messages['nopagesizewarning'] = 'Bitte geben Sie die Einträge pro Seite an.';
$messages['nosenderwarning'] = 'Bitte geben Sie die E-Mail-Adresse des Senders an.';
$messages['recipientsadded'] = 'Empfänger erfolgreich hinzugefügt.';
$messages['norecipientwarning'] = 'Bitte geben Sie mindestens einen Empfänger an.';
$messages['disclosedrecipwarning'] = 'Alle Empfänger sehen die E-Mail Adressen der anderen Empfänger. Um deren Privatsphäre zu schützen, können Sie das Bcc-Feld verwenden.';
$messages['disclosedreciptitle'] = 'Zu viele öffentliche Empfänger';
$messages['nosubjectwarning']  = 'Die Betreffzeile ist leer. Möchten Sie jetzt einen Betreff eingeben?';
$messages['nosubjecttitle']  = 'Kein Betreff';
$messages['nobodywarning'] = 'Wollen Sie diese Nachricht ohne Inhalt senden?';
$messages['notsentwarning'] = 'Die Nachricht wurde noch nicht gesendet und hat nicht gespeicherte Änderungen. Möchten Sie die Änderungen verwerfen?';
$messages['restoresavedcomposedata'] = 'Eine zuvor verfasste aber nicht gesendete Nachricht wurde gefunden.\n\nBetreff: $subject\nGespeichert: $date\n\nWollen Sie diese Nachricht wiederherstellen?';
$messages['nosearchname'] = 'Bitte geben Sie einen Namen oder eine E-Mail-Adresse ein.';
$messages['notuploadedwarning'] = 'Es wurden noch nicht alle Dateien hochgeladen. Bitte warten oder Upload abbrechen.';
$messages['searchsuccessful'] = '$nr Nachrichten gefunden.';
$messages['contactsearchsuccessful'] = '$nr Kontakte gefunden.';
$messages['searchnomatch'] = 'Die Suche lieferte keine Treffer.';
$messages['searching'] = 'Suche...';
$messages['checking'] = 'Überprüfung...';
$messages['stillsearching'] = 'Suche läuft...';
$messages['nospellerrors'] = 'Keine Rechtschreibfehler gefunden.';
$messages['folderdeleted'] = 'Der Ordner wurde erfolgreich gelöscht.';
$messages['foldersubscribed'] = 'Der Ordner wurde erfolgreich abonniert.';
$messages['folderunsubscribed'] = 'Der Ordner wurde erfolgreich abbestellt.';
$messages['deletedsuccessfully'] = 'Erfolgreich gelöscht.';
$messages['converting'] = 'Formatierung wird entfernt...';
$messages['messageopenerror'] = 'Die Nachricht konnte nicht vom Server geladen werden.';
$messages['filelinkerror'] = 'Datei konnte nicht angehängt werden';
$messages['fileuploaderror'] = 'Der Dateiupload ist fehlgeschlagen.';
$messages['csvfilemismatch'] = 'Der Import von mehreren CSV-Dateien mit unterschiedlichen Spalten wird nicht unterstützt.';
$messages['filesizeerror'] = 'Die Datei überschreitet die maximale Grösse von $size.';
$messages['filecounterror'] = 'Sie können maximal $count Dateien auf einmal hochladen.';
$messages['msgsizeerror'] = 'Datei konnte nicht angehängt werden. Die maximale Grösse einer Nachricht ($size) wird damit überschritten.';
$messages['msgsizeerrorfwd'] = ' Maximalgrösse einer Nachricht ($size) überschritten. $num Nachricht(en) wurde nicht angehängt.';
$messages['copysuccess'] = '$nr Kontakt(e) erfolgreich kopiert.';
$messages['movesuccess'] = '$nr Kontakt(e) erfolgreich verschoben.';
$messages['copyerror'] = 'Kontakte konnten nicht kopiert werden.';
$messages['moveerror'] = 'Kontakte konnten nicht verschoben werden.';
$messages['sourceisreadonly'] = 'Das Adressverzeichnis kann nicht verändert werden.';
$messages['errorsavingcontact'] = 'Die Änderungen konnten nicht gespeichert werden.';
$messages['movingmessage'] = 'Nachrichten werden verschoben...';
$messages['copyingmessage'] = 'Nachrichten werden kopiert...';
$messages['copyingcontact'] = 'Kontakte werden kopiert...';
$messages['movingcontact'] = 'Kontakt(e) werden verschoben...';
$messages['deletingmessage'] = 'Nachrichten werden gelöscht...';
$messages['markingmessage'] = 'Nachrichten werden markiert...';
$messages['addingmember'] = 'Kontakte werden der Gruppe hinzugefügt...';
$messages['removingmember'] = 'Kontakte werden von der Gruppe entfernt...';
$messages['receiptsent'] = 'Lesebestätigung erfolgreich gesendet.';
$messages['errorsendingreceipt'] = 'Bestätigung konnte nicht gesendet werden.';
$messages['deleteidentityconfirm'] = 'Möchten Sie diese Identität wirklich löschen?';
$messages['nodeletelastidentity'] = 'Diese Identität kann nicht gelöscht werden, da dies die letzte ist.';
$messages['forbiddencharacter'] = 'Der Ordnername enthält ein ungültiges Zeichen.';
$messages['selectimportfile'] = 'Bitte wählen Sie eine Datei zum Importieren aus.';
$messages['addresswriterror'] = 'Das gewählte Adressbuch kann nicht verändert werden.';
$messages['contactaddedtogroup'] = 'Kontakte wurden dieser Gruppe hinzugefügt.';
$messages['contactremovedfromgroup'] = 'Kontakte wurden aus dieser Gruppe entfernt.';
$messages['nogroupassignmentschanged'] = 'Es wurde keine Gruppenzuweisung verändert.';
$messages['importwait'] = 'Daten werden importiert, bitte warten...';
$messages['importformaterror'] = 'Import fehlgeschlagen! Die hochgeladene Datei enthält keines der unterstützten Datenformate.';
$messages['importconfirm'] = '<b>Es wurden $inserted Adressen erfolgreich importiert</b>';
$messages['importconfirmskipped'] = '<b>$skipped bestehende Einträge wurden übersprungen</b>';
$messages['importmessagesuccess'] = '$nr Nachricht(n) erfolgreich importiert';
$messages['importmessageerror'] = 'Import fehlgeschlagen! Die hochgeladene Datei ist keine E-Mail-Nachricht oder Mailbox-Datei.';
$messages['opnotpermitted'] = 'Operation nicht erlaubt!';
$messages['nofromaddress'] = 'Fehlende E-Mail-Adresse in ausgewählter Identität.';
$messages['editorwarning'] = 'Ein Wechsel des Editors kann zu Verlust der Textformatierungen führen. Wollen Sie fortfahren?';
$messages['httpreceivedencrypterror'] = 'Ein gravierender Konfigurationsfehler ist aufgetreten. Kontaktieren Sie den Server-Administrator. <b>Die Nachricht wurde nicht gesendet!</b>';
$messages['smtpconnerror'] = 'SMTP Fehler ($code): Die Verbindung ist fehlgeschlagen.';
$messages['smtpautherror'] = 'SMTP Fehler ($code): Die Authentisierung ist fehlgeschlagen.';
$messages['smtpfromerror'] = 'SMTP Fehler ($code): Der Absender "$from" konnte nicht gesetzt werden ($msg).';
$messages['smtptoerror'] = 'SMTP Fehler ($code): Der Empfänger "$to" konnte nicht gesetzt werden ($msg).';
$messages['smtprecipientserror'] = 'SMTP Fehler: Die Empfängerliste konnte nicht verarbeitet werden.';
$messages['smtputf8error'] = 'SMTP Fehler: Der Server unterstützt keine Unicode-Zeichen in E-Mail-Adressen.';
$messages['smtpsizeerror'] = 'SMTP Fehler: Nachrichtengrösse übersteigt die Servergrenze ($limit)';
$messages['smtperror'] = 'SMTP Fehler: $msg';
$messages['emailformaterror'] = 'Ungültige E-Mail-Adresse: $email';
$messages['toomanyrecipients'] = 'Zuviele Empfänger angegeben. Reduzieren Sie die Empfängeradressen auf $max.';
$messages['maxgroupmembersreached'] = 'Die Anzahl Adressen in dieser Gruppe überschreitet das Maximum von $max.';
$messages['internalerror'] = 'Ein interner Fehler ist aufgetreten. Bitte versuchen Sie den Vorgang erneut.';
$messages['contactdelerror'] = 'Fehler beim Löschen.';
$messages['contactdeleted'] = 'Kontakt(e) erfolgreich gelöscht.';
$messages['contactrestoreerror'] = 'Die gelöschten Kontakte konnten nicht wiederhergestellt werden.';
$messages['contactrestored'] = 'Kontakte erfolgreich wiederhergestellt.';
$messages['groupdeleted'] = 'Gruppe erfolgreich gelöscht.';
$messages['grouprenamed'] = 'Gruppe erfolgreich umbenannt.';
$messages['groupcreated'] = 'Gruppe erfolgreich erstellt.';
$messages['savedsearchdeleted'] = 'Suche erfolgreich gelöscht.';
$messages['savedsearchdeleteerror'] = 'Suche konnte nicht gelöscht werden.';
$messages['savedsearchcreated'] = 'Suche erfolgreich gespeichert.';
$messages['savedsearchcreateerror'] = 'Suche konnte nicht gespeichert werden.';
$messages['messagedeleted'] = 'Nachricht(en) erfolgreich gelöscht.';
$messages['messagemoved'] = 'Nachricht(en) erfolgreich verschoben.';
$messages['messagemovedtotrash'] = 'Nachricht(en) erfolgreich in den Papierkorb verschoben.';
$messages['messagecopied'] = 'Nachricht(en) erfolgreich kopiert.';
$messages['messagemarked'] = 'Nachricht(en) erfolgreich markiert.';
$messages['autocompletechars'] = 'Geben Sie mind. $min Zeichen für die Auto-Vervollständigung ein.';
$messages['autocompletemore'] = 'Mehrere Treffer. Bitte geben Sie mehr Buchstaben ein.';
$messages['namecannotbeempty'] = 'Der Name darf nicht leer sein.';
$messages['nametoolong'] = 'Der Name ist zu lang.';
$messages['namedotforbidden'] = 'Ordnername darf nicht mit einem Punkt beginnen.';
$messages['folderupdated'] = 'Der Ordner wurde erfolgreich aktualisiert.';
$messages['foldercreated'] = 'Der Ordner wurde erfolgreich erstellt.';
$messages['invalidimageformat'] = 'Kein gültiges Bildformat.';
$messages['mispellingsfound'] = 'Es wurden noch Rechtschreibfehler in der Nachricht gefunden.';
$messages['parentnotwritable'] = 'Konnte den Ordner nicht erstellen/verschieben. Keine Berechtigung.';
$messages['messagetoobig'] = 'Die Nachricht ist zu gross und kann nicht verarbeitet werden.';
$messages['attachmentvalidationerror'] = 'Dieser Anhang ist verdächtig, weil sein Dateityp nicht mit dem in der Nachricht angegebenen Dateityp übereinstimmt. Wenn Sie dem Absender nicht vertrauen, sollten Sie ihn nicht im Browser öffnen, da er bösartige Inhalte enthalten kann. Erwartet: $expected; gefunden: $detected</em>';
$messages['noscriptwarning'] = 'Achtung! Dieser Webmail-Service erfordert Javascript. Um ihn zu benutzten aktivieren Sie Javascript in ihren Browser-Einstellungen.';
$messages['messageissent'] = 'Die Nachricht wurde bereits gesendet, aber noch nicht gespeichert. Jetzt speichern?';
$messages['errnotfound'] = 'Datei nicht gefunden';
$messages['errnotfoundexplain'] = 'Die angeforderte Ressource wurde nicht gefunden!';
$messages['errfailedrequest'] = 'Anfrage fehlgeschlagen';
$messages['errauthorizationfailed'] = 'Autorisierung fehlgeschlagen';
$messages['errunauthorizedexplain'] = 'Es konnte nicht bestätigt werden, dass Sie berechtigt sind, auf diesen Dienst zuzugreifen!';
$messages['errrequestcheckfailed'] = 'Anfrageprüfung fehlgeschlagen';
$messages['errcsrfprotectionexplain'] = "Zu Ihrer Sicherheit wird der Zugriff auf diese Ressource gegen CSRF geschützt.\nWenn Sie dies sehen, haben Sie sich wahrscheinlich vor dem Verlassen der Anwendung nicht abgemeldet.\n\nUm fortzufahren ist eine menschliche Interaktion erforderlich.";
$messages['errcontactserveradmin'] = 'Bitte kontaktieren Sie Ihren Server-Administrator.';
$messages['clicktoresumesession'] = 'Klicken Sie hier, um Ihre vorherige Sitzung fortzusetzen';
$messages['errcomposesession'] = 'Sitzungsfehler';
$messages['errcomposesessionexplain'] = 'Sitzungsdaten für den Nachrichtenentwurf nicht gefunden.';
$messages['clicktocompose'] = 'Klicken Sie hier, um eine neue Nachricht zu verfassen';
$messages['nosupporterror'] = 'Diese Funktion wird von Ihrem Webbrowser nicht unterstützt.';
$messages['siginserted'] = 'Signatur erfolgreich eingefügt.';
$messages['responseinserted'] = 'Antwort erfolgreich eingefügt.';
$messages['listempty'] = 'Die Liste ist leer.';
$messages['listusebutton'] = 'Benutzen Sie den Erstellen-Button, um einen neuen Eintrag zu erfassen.';
$messages['keypaircreatesuccess'] = 'Neues Schlüsselpaar für $identity erfolgreich erstellt.';
$messages['emptyattachment'] = 'Dieser Anhang scheint leer zu sein.
Bitte erkundigen Sie sich bei der Person, die diesen gesendet hat.';
$messages['oauthloginfailed'] = ' OAuth-Anmeldung fehlgeschlagen. Bitte versuchen Sie es erneut.';
