<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/csv2vcard.inc                                     |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Pekka Nurmi <peknur@gmail.com>                                |
 +-----------------------------------------------------------------------+
*/
$map = array();
$map['display_name'] = "Näyttönimi";
$map['first_name'] = "Etunimi";
$map['last_name'] = "Sukunimi";
$map['home_phone'] = "Kotipuhelin";
$map['home_city'] = "Kotikaupunki";
$map['home_state'] = "Kodin lääni";
$map['business_city'] = "Työpaikan kaupunki";
$map['business_state'] = "Työpaikan lääni";
$map['job_title'] = "Ammattinimi";
$map['department'] = "Osasto";
$map['notes'] = "Muistiinpanot";
$map['birth_day'] = "Syntymäpäivä";
$map['birth_month'] = "Syntymäkuukausi";
$map['birth_year'] = "Syntymävuosi";
$map['display_name'] = "Näytettävä nimi";
$map['fax_number'] = "Faksin numero";
$map['nickname'] = "Lempinimi";
$map['primary_email'] = "Ensisijainen sähköposti";
$map['secondary_email'] = "Toissijainen sähköposti";
$map['work_phone'] = "Työpuhelin";
$map['pager_number'] = "Hakulaitteen numero";
$map['mobile_number'] = "Matkapuhelinnumero";
$map['home_address'] = "Kotiosoite";
$map['home_zipcode'] = "Kodin postinumero";
$map['home_country'] = "Kotimaa";
$map['work_address'] = "Työosoite";
$map['work_zipcode'] = "Työpaikan postinumero";
$map['work_country'] = "Työpaikan maa";
$map['organization'] = "Järjestö";
$map['web_page_1'] = "Verkkosivu 1";
$map['web_page_2'] = "Verkkosivu 2";
