<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-newmail_notifier/
*/

$labels['basic'] = 'Mostrar notificaciones del navegador en nuevos mensajes';
$labels['desktop'] = 'Mostrar notificaciones de escritorio en nuevos mensajes';
$labels['sound'] = 'Ejecutar sonido en nuevos mensajes';
$labels['test'] = 'Probar';
$labels['title'] = '¡Nuevo correo electrónico!';
$labels['body'] = 'Has recibido un nuevo correo electrónico.';
$labels['testbody'] = 'Esta es una notificación de prueba.';
$labels['desktopdisabled'] = 'Notificaciones de escritorio está deshabilitado en tu navegador.';
$labels['desktopunsupported'] = 'Tu navegador no soporta notificaciones de escritorio.';
$labels['desktoptimeout'] = 'Cerrar notificaciones de escritorio';
