<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Filtre';
$labels['managefilters'] = 'Rediger filter for innkommende e-post';
$labels['filtername'] = 'Filternavn';
$labels['newfilter'] = 'Nytt filter';
$labels['filteradd'] = 'Legg til filter';
$labels['filterdel'] = 'Slett filter';
$labels['rules'] = 'Regler';
$labels['actions'] = 'Handlinger';
$labels['scope'] = 'Omfanget';
$labels['moveup'] = 'Flytt opp';
$labels['movedown'] = 'Flytt ned';
$labels['filterallof'] = 'som treffer alle følgende regler';
$labels['filteranyof'] = 'som treffer en av følgende regler';
$labels['filterany'] = 'alle meldinger';
$labels['filtercontains'] = 'inneholder';
$labels['filternotcontains'] = 'ikke inneholder';
$labels['filteris'] = 'er lik';
$labels['filterisnot'] = 'er ulik';
$labels['filterexists'] = 'eksisterer';
$labels['filternotexists'] = 'ikke eksisterer';
$labels['filtermatches'] = 'treffer uttrykk';
$labels['filternotmatches'] = 'ikke treffer uttrykk';
$labels['filterregex'] = 'treffer regulært uttrykk';
$labels['filternotregex'] = 'ikke treffer regulært uttrykk';
$labels['filterunder'] = 'under';
$labels['filterover'] = 'over';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'MIME del:';
$labels['mime-message'] = 'melding';
$labels['mime-type'] = 'type';
$labels['mime-subtype'] = 'undertype';
$labels['mime-param'] = 'parameter';
$labels['addrule'] = 'Legg til regel';
$labels['delrule'] = 'Slett regel';
$labels['messagemoveto'] = 'Flytt meldingen til';
$labels['messageredirect'] = 'Videresend meldingen til';
$labels['messagecopyto'] = 'Kopier meldingen til';
$labels['messagesendcopy'] = 'Send en kopi av meldingen til';
$labels['messagereply'] = 'Svar med melding';
$labels['messagedelete'] = 'Slett melding';
$labels['messagediscard'] = 'Avvis med melding';
$labels['messagekeep'] = 'Behold melding i innboks';
$labels['messagesrules'] = 'For innkommende e-post';
$labels['messagesactions'] = '... gjør følgende:';
$labels['add'] = 'Legg til';
$labels['del'] = 'Slett';
$labels['sender'] = 'Avsender';
$labels['recipient'] = 'Mottaker';
$labels['vacationaddr'] = 'Mine epost-adresser:';
$labels['vacationdays'] = 'Periode mellom meldinger (i dager):';
$labels['vacationinterval'] = 'Periode mellom meldinger:';
$labels['vacationreason'] = 'Innhold (begrunnelse for fravær)';
$labels['vacationsubject'] = 'Meldingsemne:';
$labels['days'] = 'dager';
$labels['seconds'] = 'sekunder';
$labels['rulestop'] = 'Stopp evaluering av regler';
$labels['enable'] = 'Aktiver/Deaktiver';
$labels['filterset'] = 'Filtersett';
$labels['filtersets'] = 'Filtersett';
$labels['filtersetadd'] = 'Legg til filtersett';
$labels['filtersetdel'] = 'Slett filtersett';
$labels['filtersetact'] = 'Aktiver gjeldende filtersett';
$labels['filtersetdeact'] = 'Deaktiver gjeldende filtersett';
$labels['filterseteditraw'] = 'Rediger filtersett';
$labels['filtersetswitch'] = 'Aktiver/deaktiver filtersett';
$labels['filterdef'] = 'Filterdefinisjon';
$labels['filtersetname'] = 'Navn på filtersett';
$labels['newfilterset'] = 'Nytt filtersett';
$labels['active'] = 'aktiv';
$labels['none'] = 'ingen';
$labels['fromset'] = 'fra sett';
$labels['fromfile'] = 'fra fil';
$labels['filterdisabled'] = 'Filter deaktivert';
$labels['filterenabled'] = 'Filter aktivert';
$labels['countisgreaterthan'] = 'antall er flere enn';
$labels['countisgreaterthanequal'] = 'antall er flere enn eller lik';
$labels['countislessthan'] = 'antall er færre enn';
$labels['countislessthanequal'] = 'antall er færre enn eller lik';
$labels['countequals'] = 'antall er lik';
$labels['countnotequals'] = 'tallet er ikke det samme som';
$labels['valueisgreaterthan'] = 'verdien er høyrere enn';
$labels['valueisgreaterthanequal'] = 'verdien er høyere eller lik';
$labels['valueislessthan'] = 'verdien er lavere enn';
$labels['valueislessthanequal'] = 'verdien er lavere eller lik';
$labels['valueequals'] = 'verdien er lik';
$labels['valuenotequals'] = 'verdien er ikke den samme som';
$labels['setflags'] = 'Sett meldingsflagg';
$labels['addflags'] = 'Legg til flagg på meldingen';
$labels['removeflags'] = 'Fjern flagg fra meldingen';
$labels['flagread'] = 'Lese';
$labels['flagdeleted'] = 'Slettet';
$labels['flaganswered'] = 'Besvart';
$labels['flagflagged'] = 'Flagget';
$labels['flagdraft'] = 'Utkast';
$labels['addheader'] = 'Legg til meldingshode til melding';
$labels['deleteheader'] = 'Fjern meldingshode fra melding';
$labels['headername'] = 'Navn til meldingshode';
$labels['headervalue'] = 'Verdi til meldingshode';
$labels['headerpos'] = 'Posisjon for meldingshode';
$labels['headeratstart'] = 'på begynnelsen';
$labels['headeratend'] = 'på slutten';
$labels['headerfromstart'] = 'fra start';
$labels['headerfromend'] = 'fra slutt';
$labels['setvariable'] = 'Set variabel';
$labels['setvarname'] = 'Variabelnavn:';
$labels['setvarvalue'] = 'Variabel verdi:';
$labels['setvarmodifiers'] = 'Modifikator:';
$labels['varlower'] = 'med små bokstaver';
$labels['varupper'] = 'med store bokstaver';
$labels['varlowerfirst'] = 'første tegn liten bokstav';
$labels['varupperfirst'] = 'første tegn stor bokstav';
$labels['varquotewildcard'] = 'sitér spesialtegn';
$labels['varlength'] = 'lengde';
$labels['notify'] = 'Send melding';
$labels['notifyimportance'] = 'Viktighet:';
$labels['notifyimportancelow'] = 'lav';
$labels['notifyimportancenormal'] = 'normal';
$labels['notifyimportancehigh'] = 'høy';
$labels['notifymethodmailto'] = 'E-post';
$labels['notifymethodtel'] = 'Telefon';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Opprett filter';
$labels['usedata'] = 'Bruk følgende data i filteret:';
$labels['nextstep'] = 'Neste steg';
$labels['...'] = '…';
$labels['string'] = 'Tekststreng';
$labels['currdate'] = 'Nåværende dato';
$labels['datetest'] = 'Dato';
$labels['dateheader'] = 'header:';
$labels['year'] = 'år';
$labels['month'] = 'måned';
$labels['day'] = 'dag';
$labels['date'] = 'dato (yyyy-mm-dd)';
$labels['julian'] = 'dato (juliansk)';
$labels['hour'] = 'time';
$labels['minute'] = 'minutt';
$labels['second'] = 'sekund';
$labels['time'] = 'tid (hh:mm:ss)';
$labels['iso8601'] = 'dato (ISO8601)';
$labels['std11'] = 'dato (RFC2822)';
$labels['zone'] = 'tidssone';
$labels['weekday'] = 'ukedag (0-6)';
$labels['advancedopts'] = 'Avanserte alternativer';
$labels['body'] = 'Meldingstekst';
$labels['address'] = 'adresse';
$labels['envelope'] = 'konvolutt';
$labels['modifier'] = 'modifikator:';
$labels['text'] = 'tekst';
$labels['undecoded'] = 'ikke dekodet (rå)';
$labels['contenttype'] = 'innholdstype';
$labels['modtype'] = 'type:';
$labels['allparts'] = 'alle';
$labels['domain'] = 'domene';
$labels['localpart'] = 'lokal del (local part)';
$labels['user'] = 'bruker';
$labels['detail'] = 'detalj';
$labels['comparator'] = 'sammenligning:';
$labels['default'] = 'standard';
$labels['octet'] = 'streng (oktett)';
$labels['asciicasemap'] = 'ikke skill store og små bokstaver (ascii-casemap)';
$labels['asciinumeric'] = 'numerisk (ascii-numeric)';
$labels['index'] = 'index:';
$labels['indexlast'] = 'baklengs';
$labels['spamtest'] = 'Spamnivå';
$labels['spamtestisgreaterthan'] = 'er større enn';
$labels['spamtestisgreaterthanequal'] = 'er større enn eller lik';
$labels['spamtestislessthan'] = 'er mindre enn';
$labels['spamtestislessthanequal'] = 'er mindre enn eller lik';
$labels['spamtestequals'] = 'er lik';
$labels['spamtestnotequals'] = 'er ulik';
$labels['spamtestisunknown'] = 'er ukjent';
$labels['vacation'] = 'Fravær';
$labels['vacation.reply'] = 'Svar melding';
$labels['vacation.advanced'] = 'Avanserte innstillinger';
$labels['vacation.subject'] = 'Emne';
$labels['vacation.body'] = 'Meldingstekst';
$labels['vacation.start'] = 'Start tid';
$labels['vacation.end'] = 'Slutt tid';
$labels['vacation.status'] = 'Status';
$labels['vacation.on'] = 'På';
$labels['vacation.off'] = 'Av';
$labels['vacation.addresses'] = 'Min epost-adresse';
$labels['vacation.saving'] = 'Lagrer data...';
$labels['vacation.action'] = 'Handling for innkommende melding';
$labels['vacation.keep'] = 'Behold';
$labels['vacation.discard'] = 'Forkast';
$labels['vacation.redirect'] = 'Videresend til';
$labels['vacation.copy'] = 'Send kopi til';
$labels['forward'] = 'Videresending';
$labels['forward.redirect'] = 'Videresend til';
$labels['forward.copy'] = 'Send kopi til';
$labels['forward.on'] = 'På';
$labels['forward.off'] = 'Av';
$labels['forward.status'] = 'Status:';
$labels['forward.saving'] = 'Lagrer data...';
$labels['arialabelfiltersetactions'] = 'Filtersetthandlinger';
$labels['arialabelfilteractions'] = 'Filterhandling';
$labels['arialabelfilterform'] = 'Filteregenskaper';
$labels['ariasummaryfilterslist'] = 'Liste over filtre';
$labels['ariasummaryfiltersetslist'] = 'Liste over filtersett';
$labels['filterstitle'] = 'Rediger innkommende mailfiltre';
$labels['forwardtitle'] = 'Rediger videresendingsregel';
$labels['message'] = 'Melding';
$labels['duplicate'] = 'er duplikat';
$labels['notduplicate'] = 'er ikke duplikat';
$labels['duplicate.header'] = 'header:';
$labels['duplicate.uniqueid'] = 'identifikator:';
$labels['duplicate.seconds'] = 'tidsavbrudd (sekunder):';
$labels['duplicate.last'] = 'relativ til siste utførelse';
$messages['filterunknownerror'] = 'Ukjent problem med tjener.';
$messages['filterconnerror'] = 'Kunne ikke koble til tjeneren.';
$messages['filterdeleteerror'] = 'Kunne ikke slette filter. Fikk feilmelding fra server.';
$messages['filterdeleted'] = 'Filteret er blitt slettet.';
$messages['filtersaved'] = 'Filteret er blitt lagret.';
$messages['filtersaveerror'] = 'Kunne ikke lagre filter. Fikk feilmelding fra server.';
$messages['filterformerror'] = 'Filterskjemaet inneholder feil.';
$messages['filterdeleteconfirm'] = 'Vil du virkelig slette det valgte filteret?';
$messages['ruledeleteconfirm'] = 'Er du sikker på at du vil slette valgte regel?';
$messages['actiondeleteconfirm'] = 'Er du sikker på at du vil slette valgte hendelse?';
$messages['forbiddenchars'] = 'Ugyldige tegn i felt.';
$messages['cannotbeempty'] = 'Feltet kan ikke stå tomt.';
$messages['ruleexist'] = 'Det finnes allerede et filter med dette navnet.';
$messages['setactivateerror'] = 'Kunne ikke aktivere valgte filtersett. Fikk feilmelding fra server.';
$messages['setdeactivateerror'] = 'Kunne ikke deaktivere valgte filtersett. Fikk feilmelding fra server.';
$messages['setdeleteerror'] = 'Kunne ikke slette valgte filtersett. Fikk feilmelding fra server.';
$messages['setactivated'] = 'Filtersett aktivert.';
$messages['setdeactivated'] = 'Filtersett deaktivert.';
$messages['setdeleted'] = 'Filtersett slettet.';
$messages['setupdated'] = 'Filtersett oppdatert.';
$messages['setdeleteconfirm'] = 'Er du sikker på at du vil slette de valgte filtersettene?';
$messages['setcreateerror'] = 'Kunne ikke opprette filtersett. Fikk feilmelding fra server.';
$messages['setcreated'] = 'Filtersett opprettet.';
$messages['activateerror'] = 'Kunne ikke aktivere valgte filter(e). Fikk feilmelding fra server.';
$messages['deactivateerror'] = 'Kunne ikke deaktivere valgte filter(e). Fikk feilmelding fra server.';
$messages['deactivated'] = 'Filter deaktivert.';
$messages['activated'] = 'Filter aktivert.';
$messages['moved'] = 'Filter flyttet.';
$messages['moveerror'] = 'Kunne ikke flytte valgte filter. Fikk feilmelding fra server.';
$messages['nametoolong'] = 'Navnet er for langt.';
$messages['namereserved'] = 'Navnet er reservert.';
$messages['setexist'] = 'Settet eksisterer allerede.';
$messages['nodata'] = 'Du må velge minst én posisjon!';
$messages['invaliddateformat'] = 'Ugyldig dato eller datoformat';
$messages['saveerror'] = 'Kunne ikke lagre data. Fikk feilmelding fra server.';
$messages['disabledaction'] = 'Handling ikke tillatt.';
$messages['noflagset'] = 'Minst ett flagg må være valgt.';
