<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Добродошли на $product';
$labels['username'] = 'Корисничко име';
$labels['password'] = 'Лозинка';
$labels['server'] = 'Сервер';
$labels['login'] = 'Пријава';
$labels['menu'] = 'Мени';
$labels['logout'] = 'Одјава';
$labels['mail'] = 'Пошта';
$labels['settings'] = 'Поставке';
$labels['addressbook'] = 'Адресар';
$labels['inbox'] = 'Примљене';
$labels['drafts'] = 'Нацрти';
$labels['sent'] = 'Послате';
$labels['trash'] = 'Смеће';
$labels['junk'] = 'Отпад';
$labels['show_real_foldernames'] = 'Прикажи права имена за специјалне фасцикле';
$labels['subject'] = 'Наслов';
$labels['from'] = 'Од';
$labels['sender'] = 'Пошиљалац';
$labels['to'] = 'За';
$labels['cc'] = 'Цц';
$labels['bcc'] = 'Бцц';
$labels['replyto'] = 'Одговори';
$labels['date'] = 'Датум';
$labels['size'] = 'Величина';
$labels['priority'] = 'Приоритет';
$labels['organization'] = 'Организација';
$labels['readstatus'] = 'Стање читања';
$labels['listoptions'] = 'Опције листе...';
$labels['listoptionstitle'] = 'Опције листе';
$labels['mailboxlist'] = 'Фасцикле';
$labels['messagesfromto'] = 'Порука $from за $to од $count';
$labels['threadsfromto'] = 'Нити $from за $to од $count';
$labels['messagenrof'] = 'Порука $nr од $count';
$labels['fromtoshort'] = '$from – $to од $count';
$labels['copy'] = 'Копирај';
$labels['move'] = 'Премести';
$labels['moveto'] = 'Премести у...';
$labels['copyto'] = 'Копирај у...';
$labels['download'] = 'Преузми';
$labels['open'] = 'Отвори';
$labels['showattachment'] = 'Прикажи';
$labels['showanyway'] = 'Свеједно прикажи';
$labels['filename'] = 'Назив фајла';
$labels['filesize'] = 'Величина фајла';
$labels['addtoaddressbook'] = 'Додај у адресар';
$labels['sun'] = 'нед';
$labels['mon'] = 'пон';
$labels['tue'] = 'уто';
$labels['wed'] = 'сре';
$labels['thu'] = 'чет';
$labels['fri'] = 'пет';
$labels['sat'] = 'суб';
$labels['sunday'] = 'недеља';
$labels['monday'] = 'понедељак';
$labels['tuesday'] = 'уторак';
$labels['wednesday'] = 'среда';
$labels['thursday'] = 'четвртак';
$labels['friday'] = 'петак';
$labels['saturday'] = 'субота';
$labels['jan'] = 'јан';
$labels['feb'] = 'феб';
$labels['mar'] = 'мар';
$labels['apr'] = 'апр';
$labels['may'] = 'мај';
$labels['jun'] = 'јун';
$labels['jul'] = 'јул';
$labels['aug'] = 'авг';
$labels['sep'] = 'сеп';
$labels['oct'] = 'окт';
$labels['nov'] = 'нов';
$labels['dec'] = 'дец';
$labels['longjan'] = 'јануар';
$labels['longfeb'] = 'фебруар';
$labels['longmar'] = 'март';
$labels['longapr'] = 'април';
$labels['longmay'] = 'мај';
$labels['longjun'] = 'јун';
$labels['longjul'] = 'јул';
$labels['longaug'] = 'август';
$labels['longsep'] = 'септембар';
$labels['longoct'] = 'октобар';
$labels['longnov'] = 'новембар';
$labels['longdec'] = 'децембар';
$labels['today'] = 'данас';
$labels['refresh'] = 'Освежи';
$labels['checkmail'] = 'Провера нових порука';
$labels['compose'] = 'Нова порука';
$labels['writenewmessage'] = 'Напиши нову поруку';
$labels['reply'] = 'Одговори';
$labels['replytomessage'] = 'Одговори пошиљаоцу';
$labels['replytoallmessage'] = 'Одговори на листу или пошиљаоцу и свим примаоцима';
$labels['replyall'] = 'Одговори свима';
$labels['replylist'] = 'Одговори на листу';
$labels['forward'] = 'Проследи';
$labels['forwardinline'] = 'Проследи у тексту';
$labels['forwardattachment'] = 'Проследи као прилог';
$labels['forwardmessage'] = 'Проследи поруку';
$labels['deletemessage'] = 'Избриши поруку';
$labels['movemessagetotrash'] = 'Премести поруку у смеће';
$labels['printmessage'] = 'Одштампај поруку';
$labels['previousmessage'] = 'Прикажи претходну поруку';
$labels['firstmessage'] = 'Прикажи прву поруку';
$labels['nextmessage'] = 'Прикажи следећу поруку';
$labels['lastmessage'] = 'Прикажи последњу поруку';
$labels['backtolist'] = 'Повратак на листу порука';
$labels['viewsource'] = 'Прикажи изворни облик';
$labels['mark'] = 'Означи';
$labels['markmessages'] = 'Обележи поруке';
$labels['markread'] = 'као прочитано';
$labels['markunread'] = 'као непрочитано';
$labels['markflagged'] = 'као обележено';
$labels['markunflagged'] = 'као необележено';
$labels['moreactions'] = 'Остале радње...';
$labels['markallread'] = 'Означи све као прочитано';
$labels['folders-cur'] = 'Само изабрана фасцикла';
$labels['folders-sub'] = 'Изабрана фасцикла и потфасцикле';
$labels['folders-all'] = 'Све фасцикле';
$labels['more'] = 'Још';
$labels['back'] = 'Назад';
$labels['options'] = 'Опције';
$labels['actions'] = 'Радње';
$labels['first'] = 'Прво';
$labels['last'] = 'Последње';
$labels['previous'] = 'Претходно';
$labels['next'] = 'Следеће';
$labels['select'] = 'Изабери';
$labels['all'] = 'Све';
$labels['none'] = 'Ништа';
$labels['currpage'] = 'Тренутна страница';
$labels['isread'] = 'Прочитана';
$labels['unread'] = 'Непрочитана';
$labels['flagged'] = 'Обележено';
$labels['unflagged'] = 'Необележена';
$labels['unanswered'] = 'Неодговорена';
$labels['withattachment'] = 'Са прилогом';
$labels['deleted'] = 'Обрисано';
$labels['undeleted'] = 'Необрисано';
$labels['replied'] = 'Одговорено';
$labels['forwarded'] = 'Прослеђено';
$labels['invert'] = 'Обрни';
$labels['filter'] = 'Филтер';
$labels['list'] = 'Листа';
$labels['threads'] = 'Нити';
$labels['expand-all'] = 'Рашири све';
$labels['expand-unread'] = 'Рашири непрочитане';
$labels['collapse-all'] = 'Сажми све';
$labels['threaded'] = 'Разгранато';
$labels['autoexpand_threads'] = 'Рашири гране порука';
$labels['do_expand'] = 'све гране';
$labels['expand_only_unread'] = 'само са непрочитаним порукама';
$labels['fromto'] = 'од/за';
$labels['flag'] = 'Обележено';
$labels['attachment'] = 'Прилог';
$labels['nonesort'] = 'Ништа';
$labels['sentdate'] = 'Датум слања';
$labels['arrival'] = 'Датум пријема';
$labels['asc'] = 'растуће';
$labels['desc'] = 'опадајуће';
$labels['listcolumns'] = 'Колоне листе';
$labels['listsorting'] = 'Колона сортирања';
$labels['listorder'] = 'Ређање';
$labels['listmode'] = 'Режим приказа листе';
$labels['layout'] = 'Распоред';
$labels['layoutwidescreen'] = 'Широк екран';
$labels['layoutdesktop'] = 'Радна површ';
$labels['layoutlist'] = 'Листа';
$labels['folderactions'] = 'Радње фасцикле...';
$labels['compact'] = 'Сажми';
$labels['empty'] = 'Испразни';
$labels['importmessages'] = 'Увези поруке';
$labels['quota'] = 'Заузеће';
$labels['unknown'] = 'непознато';
$labels['unlimited'] = 'неограничено';
$labels['quotatype'] = 'Врста квоте';
$labels['quotatotal'] = 'Ограничење';
$labels['quotaused'] = 'Коришћено';
$labels['quotastorage'] = 'Заузеће диска';
$labels['quotamessage'] = 'Број порука';
$labels['quicksearch'] = 'Брза претрага';
$labels['resetsearch'] = 'Ресетуј претрагу';
$labels['searchmod'] = 'Модификатори претраге';
$labels['msgtext'] = 'Цела порука';
$labels['body'] = 'Тело';
$labels['type'] = 'Тип';
$labels['namex'] = 'Име';
$labels['searchscope'] = 'Распон';
$labels['currentfolder'] = 'Текућа фасцикла';
$labels['subfolders'] = 'Ова и потфасцикле';
$labels['allfolders'] = 'Све фасцикле';
$labels['searchinterval-1W'] = 'старије од седмице';
$labels['searchinterval-1M'] = 'старије од месеца';
$labels['searchinterval-1Y'] = 'старије од године';
$labels['searchinterval1W'] = 'млађе од седмице';
$labels['searchinterval1M'] = 'млађе од месеца';
$labels['searchinterval1Y'] = 'млађе од године';
$labels['openinextwin'] = 'Отвори у новом прозору';
$labels['emlsave'] = 'Преузимање (.eml)';
$labels['changeformattext'] = 'Прикажи у обичном текстуалном формату';
$labels['changeformathtml'] = 'Прикажи у ХТМЛ формату';
$labels['editasnew'] = 'Уреди као ново';
$labels['send'] = 'Пошаљи';
$labels['sendmessage'] = 'Пошаљи поруку';
$labels['savemessage'] = 'Сачувај као нацрт';
$labels['addattachment'] = 'Приложи фајл';
$labels['charset'] = 'Кодирање';
$labels['editortype'] = 'Тип уређивача';
$labels['returnreceipt'] = 'Потврда о приспећу';
$labels['dsn'] = 'Обавештење о статусу испоруке';
$labels['mailreplyintro'] = 'Дана $date, $sender написа:';
$labels['originalmessage'] = 'Оригинална порука';
$labels['selectimage'] = 'Изабери слику';
$labels['addimage'] = 'Додај слику';
$labels['selectmedia'] = 'Изабери видео';
$labels['addmedia'] = 'Додај видео';
$labels['encrypt'] = 'Шифруј';
$labels['encryptmessage'] = 'Шифруј поруку';
$labels['importpubkeys'] = 'Увези јавне кључеве';
$labels['encryptedsendialog'] = 'Шаљем шифровану поруку';
$labels['keyid'] = 'ИД кључа';
$labels['keyexpired'] = 'Истекао';
$labels['keyrevoked'] = 'Опозван';
$labels['bccinstead'] = 'Користи БЦЦ';
$labels['insert'] = 'Убаци';
$labels['editidents'] = 'Уреди идентитете';
$labels['spellcheck'] = 'Правопис';
$labels['checkspelling'] = 'Провера правописа';
$labels['resumeediting'] = 'Настави уређивање';
$labels['revertto'] = 'Врати на';
$labels['restore'] = 'Врати';
$labels['restoremessage'] = 'Да вратим поруку?';
$labels['ignore'] = 'Игнориши';
$labels['responses'] = 'Одговори';
$labels['insertresponse'] = 'Уметни одговор';
$labels['manageresponses'] = 'Управљај одговорима';
$labels['newresponse'] = 'Направи нови одговор';
$labels['addresponse'] = 'Додај одговор';
$labels['editresponse'] = 'Уреди одговор';
$labels['editresponses'] = 'Уреди одговоре';
$labels['responsename'] = 'Назив';
$labels['responsetext'] = 'Текст одговора';
$labels['attach'] = 'Приложи';
$labels['attachments'] = 'Прилози';
$labels['upload'] = 'Отпреми';
$labels['uploadprogress'] = '$percent ($current од $total)';
$labels['close'] = 'Затвори';
$labels['messageoptions'] = 'Опције поруке...';
$labels['attachmentrename'] = 'Преименуј прилог';
$labels['low'] = 'низак';
$labels['lowest'] = 'најнижи';
$labels['normal'] = 'средњи';
$labels['high'] = 'висок';
$labels['highest'] = 'највиши';
$labels['nosubject'] = '(без наслова)';
$labels['showimages'] = 'Прикажи слике';
$labels['alwaysshow'] = 'Увек прикажи слике од $sender';
$labels['isdraft'] = 'Ово је нацрт поруке.';
$labels['andnmore'] = 'још $nr...';
$labels['togglemoreheaders'] = 'Прикажи још заглавља поруке';
$labels['htmltoggle'] = 'ХТМЛ';
$labels['plaintoggle'] = 'Обичан текст';
$labels['savesentmessagein'] = 'Послате поруке сачувај у';
$labels['dontsave'] = 'не чувај';
$labels['maxuploadsize'] = 'Максимална величина фајла је $size';
$labels['addcc'] = 'Додај Цц';
$labels['addbcc'] = 'Додај Бцц';
$labels['addreplyto'] = 'Додај Одговор-на';
$labels['mdnrequest'] = 'Пошиљалац ове поруке је замолио да буде обавештен када прочитате ову поруку. Да ли желите да обавестите пошиљаоца?';
$labels['receiptread'] = 'Обавештење о приспећу (прочитано)';
$labels['yourmessage'] = 'Ово је обавештење о приспећу за вашу поруку';
$labels['receiptnote'] = 'Пажња: Ово обавештење само потврђује да је порука приказана на рачунару примаоца. Не постоји гаранција да је прималац прочитао или разумео садржај поруке.';
$labels['name'] = 'Приказано име';
$labels['firstname'] = 'Име';
$labels['surname'] = 'Презиме';
$labels['middlename'] = 'Средње име';
$labels['nameprefix'] = 'Префикс';
$labels['namesuffix'] = 'Суфикс';
$labels['nickname'] = 'Надимак';
$labels['jobtitle'] = 'Пословна титула';
$labels['department'] = 'Одељење';
$labels['gender'] = 'Пол';
$labels['maidenname'] = 'Девојачко презиме';
$labels['email'] = 'Е-пошта';
$labels['phone'] = 'Телефон';
$labels['address'] = 'Адреса';
$labels['street'] = 'Улица';
$labels['locality'] = 'Град';
$labels['zipcode'] = 'Поштански број';
$labels['region'] = 'Покрајина/Провинција';
$labels['country'] = 'Држава';
$labels['birthday'] = 'Датум рођења';
$labels['anniversary'] = 'Годишњица';
$labels['website'] = 'Веб сајт';
$labels['instantmessenger'] = 'ИМ';
$labels['notes'] = 'Белешке';
$labels['male'] = 'мушко';
$labels['female'] = 'женско';
$labels['manager'] = 'Менаџер';
$labels['assistant'] = 'Асистент';
$labels['spouse'] = 'Супружник';
$labels['allfields'] = 'Сва поља';
$labels['search'] = 'Тражи';
$labels['searchresult'] = 'Резултат претраге';
$labels['advsearch'] = 'Напредна претрага';
$labels['advanced'] = 'Напредно';
$labels['other'] = 'Остало';
$labels['printcontact'] = 'Штампај контакт';
$labels['qrcode'] = 'КуЕР код';
$labels['typehome'] = 'Кућа';
$labels['typework'] = 'Посао';
$labels['typeother'] = 'Остало';
$labels['typemobile'] = 'Мобилни';
$labels['typemain'] = 'Главно';
$labels['typehomefax'] = 'Кућни факс';
$labels['typeworkfax'] = 'Пословни факс';
$labels['typecar'] = 'Ауто';
$labels['typepager'] = 'Пејџер';
$labels['typevideo'] = 'Видео';
$labels['typeassistant'] = 'Асистент';
$labels['typehomepage'] = 'Почетна страница';
$labels['typeblog'] = 'Блог';
$labels['typeprofile'] = 'Профил';
$labels['addfield'] = 'Додај поље...';
$labels['addcontact'] = 'Додај контакт';
$labels['editcontact'] = 'Измени контакт';
$labels['contacts'] = 'Конакти';
$labels['contactproperties'] = 'Својства контакта';
$labels['contactnameandorg'] = 'Име и организација';
$labels['personalinfo'] = 'Лични подаци';
$labels['personal'] = 'Лично';
$labels['contactphoto'] = 'Фоографија контакта';
$labels['edit'] = 'Измени';
$labels['cancel'] = 'Одустани';
$labels['save'] = 'Сачувај';
$labels['delete'] = 'Обриши';
$labels['rename'] = 'Преименуј';
$labels['addphoto'] = 'Додај';
$labels['replacephoto'] = 'Замени';
$labels['uploadphoto'] = 'Отпреми слику';
$labels['newcontact'] = 'Направи нови контакт';
$labels['deletecontact'] = 'Обриши изаабране контакте';
$labels['composeto'] = 'Напиши поруку';
$labels['contactsfromto'] = 'Контакти $from до $to од $count';
$labels['print'] = 'Штампај';
$labels['export'] = 'Извези';
$labels['exportall'] = 'Извези све';
$labels['exportsel'] = 'Извези изабрано';
$labels['exportvcards'] = 'Извези конакте у формату в-картице';
$labels['newgroup'] = 'Направи нову групу';
$labels['addgroup'] = 'Додај групу';
$labels['grouprename'] = 'Преименуј групу';
$labels['groupdelete'] = 'Обриши групу';
$labels['groupremoveselected'] = 'Избриши изабране контакте из групе';
$labels['uponelevel'] = 'Горе један ниво';
$labels['previouspage'] = 'Прикажи претходну страну';
$labels['firstpage'] = 'Прикажи прву страну';
$labels['nextpage'] = 'Прикажи следећу страну';
$labels['lastpage'] = 'Прикажи последњу страну';
$labels['group'] = 'Група';
$labels['groups'] = 'Групе';
$labels['listgroup'] = 'Излистај чланове групе';
$labels['personaladrbook'] = 'Личне адресе';
$labels['searchsave'] = 'Сачувај претрагу';
$labels['searchdelete'] = 'Избриши претрагу';
$labels['import'] = 'Увези';
$labels['importcontacts'] = 'Увези контакте';
$labels['importtarget'] = 'Додај контакте у';
$labels['importreplace'] = 'Замени цео адресар';
$labels['importgroupsexisting'] = 'Само за постојеће групе';
$labels['done'] = 'Готово';
$labels['settingsfor'] = 'Поставке за';
$labels['about'] = 'О програму';
$labels['preferences'] = 'Подешавања';
$labels['userpreferences'] = 'Корисничка подешавања';
$labels['editpreferences'] = 'Измена корисничких подешавања';
$labels['identities'] = 'Идентитети';
$labels['manageidentities'] = 'Управљај идентитетима';
$labels['newidentity'] = 'Направи нови идентитет';
$labels['addidentity'] = 'Додај идентитет';
$labels['editidentity'] = 'Уреди идентитет';
$labels['preferhtml'] = 'Прикажи ХТМЛ';
$labels['defaultcharset'] = 'Подразумевани сет знакова';
$labels['htmlmessage'] = 'ХТМЛ порука';
$labels['messagepart'] = 'Део';
$labels['digitalsig'] = 'Дигитални потпис';
$labels['dateformat'] = 'Формат датума';
$labels['timeformat'] = 'Формат времена';
$labels['prettydate'] = 'Лепи датуми';
$labels['setdefault'] = 'Постави подразумевано';
$labels['autodetect'] = 'Аутоматски';
$labels['language'] = 'Језик';
$labels['timezone'] = 'Временска зона';
$labels['pagesize'] = 'Редова по страни';
$labels['signature'] = 'Потпис';
$labels['dstactive'] = 'Летње време';
$labels['showinextwin'] = 'Отвори поруку у новом прозору';
$labels['composeextwin'] = 'Састави у новом прозору';
$labels['htmleditor'] = 'Састави ХТМЛ поруке';
$labels['htmlonreply'] = 'само при одговору на ХТМЛ поруку';
$labels['htmlsignature'] = 'ХТМЛ потпис';
$labels['previewpane'] = 'Прикажи панел за преглед';
$labels['skin'] = 'Маска сучеља';
$labels['logoutclear'] = 'Испразни смеће при одјављивању';
$labels['logoutcompact'] = 'Сажми долазне при одјављивању';
$labels['uisettings'] = 'Сучеље';
$labels['serversettings'] = 'Поставке сервера';
$labels['mailboxview'] = 'Приказ сандучета';
$labels['askuser'] = 'питај ме';
$labels['autosend'] = 'шаљи потврду';
$labels['autosendknown'] = 'шаљи потврду мојим контактима, иначе питај';
$labels['autosendknownignore'] = 'шаљи потврду мојим контактима, иначе игнориши';
$labels['ignorerequest'] = 'игнориши захтев';
$labels['readwhendeleted'] = 'Означи као прочитано при брисању';
$labels['skipdeleted'] = 'Не приказуј избрисане поруке';
$labels['deletealways'] = 'Ако премештање порука у смеће не успе, обриши их';
$labels['deletejunk'] = 'Директно брисање порука у отпаду';
$labels['fromknownsenders'] = 'од знаних пошиљалаца';
$labels['always'] = 'увек';
$labels['alwaysbutplain'] = 'увек, осим кад се одговара на обичан текст';
$labels['showinlineimages'] = 'Покажи приложене слике испод поруке';
$labels['autosavedraft'] = 'Аутоматски сачувај нацрте';
$labels['everynminutes'] = 'сваких $n минута';
$labels['refreshinterval'] = 'Освежи (проверава нове поруке итд.)';
$labels['never'] = 'никад';
$labels['immediately'] = 'одмах';
$labels['messagesdisplaying'] = 'Приказ порука';
$labels['messagescomposition'] = 'Састављање порука';
$labels['mimeparamfolding'] = 'Називи прилога';
$labels['2231folding'] = 'Пун РФЦ 2231 (Тандерберд )';
$labels['miscfolding'] = 'РФЦ 2047/2231 (МС Аутлук)';
$labels['2047folding'] = 'Пун РФЦ 2047 (остали)';
$labels['force7bit'] = 'МИМЕ кодирање за 8-битне знакове';
$labels['advancedoptions'] = 'Напредне опције';
$labels['toggleadvancedoptions'] = 'Напредне опције';
$labels['focusonnewmessage'] = 'Фокусирај прозор претраживача на новој поруци';
$labels['checkallfolders'] = 'Провери све фасцикле за нове поруке';
$labels['defaultfont'] = 'Подразумевани фонт за ХТМЛ поруке';
$labels['mainoptions'] = 'Главне опције';
$labels['browseroptions'] = 'Опције претраживача';
$labels['section'] = 'Одељак';
$labels['maintenance'] = 'Одржавање';
$labels['newmessage'] = 'Нова порука';
$labels['signatureoptions'] = 'Опције потписа';
$labels['whenreplying'] = 'При одговору';
$labels['replytopposting'] = 'почни нову поруку изнад цитата';
$labels['replybottomposting'] = 'почни нову поруку испод цитата';
$labels['replyremovesignature'] = 'При одговору одстрани оригинални потпис из поруке';
$labels['autoaddsignature'] = 'Аутоматски додај потпис';
$labels['newmessageonly'] = 'само нове поруке';
$labels['replyandforwardonly'] = 'само одговори и прослеђивања';
$labels['insertsignature'] = 'Убаци потпис';
$labels['sigbelow'] = 'Потпис испод цитиране поруке';
$labels['afternseconds'] = 'након $n сек.';
$labels['reqmdn'] = 'Увек затражи потврду пријема';
$labels['reqdsn'] = 'Увек затражи обавештење о статусу слања поруке';
$labels['replysamefolder'] = 'Сачувај одговоре у фасцикли поруке на коју се одговара';
$labels['defaultabook'] = 'Подразумевани адресар';
$labels['listnamedisplay'] = 'Листа контаката као';
$labels['spellcheckbeforesend'] = 'Проверите правопис пре слања поруке';
$labels['spellcheckoptions'] = 'Опције провере правописа';
$labels['spellcheckignoresyms'] = 'Игнориши речи са симболима';
$labels['spellcheckignorenums'] = 'Игнориши речи са бројевима';
$labels['addtodict'] = 'Додај у речник';
$labels['forwardmode'] = 'Прослеђивање порука';
$labels['inline'] = 'уткано';
$labels['asattachment'] = 'као прилог';
$labels['replyallmode'] = 'Подразумевана радња за дугме [Одговори свима]';
$labels['replyalldefault'] = 'одговори свима';
$labels['folder'] = 'Фасцикла';
$labels['folders'] = 'Фасцикле';
$labels['foldername'] = 'Назив фасцикле';
$labels['subscribed'] = 'Претплаћено';
$labels['messagecount'] = 'Поруке';
$labels['create'] = 'Направи';
$labels['createfolder'] = 'Направи нову фасциклу';
$labels['managefolders'] = 'Управљај фасциклама';
$labels['specialfolders'] = 'Посебне фасцикле';
$labels['properties'] = 'Својства';
$labels['folderproperties'] = 'Својства фасцикле';
$labels['parentfolder'] = 'Над-фасцикла';
$labels['location'] = 'Локација';
$labels['info'] = 'Подаци';
$labels['getfoldersize'] = 'Кликните да добијете величину фасцикле';
$labels['changesubscription'] = 'Кликните да промените претплату';
$labels['foldertype'] = 'Тип фасцикле';
$labels['personalfolder'] = 'Лична фасцикла';
$labels['otherfolder'] = 'Фасцикла других корисникa';
$labels['sharedfolder'] = 'Јавна фасцикла';
$labels['findfolders'] = 'Нађи фасцикле';
$labels['findcontacts'] = 'Пронађи контакте';
$labels['namespace.personal'] = 'Лично';
$labels['namespace.other'] = 'Остали корисници';
$labels['sortby'] = 'Поређај';
$labels['sortasc'] = 'растуће';
$labels['sortdesc'] = 'опадајуће';
$labels['undo'] = 'Поништи';
$labels['installedplugins'] = 'Инсталирани прикључци';
$labels['plugin'] = 'Прикључак';
$labels['version'] = 'Верзија';
$labels['source'] = 'Изворни код';
$labels['license'] = 'Лиценца';
$labels['support'] = 'Подршка';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Уникод';
$labels['english'] = 'енглески';
$labels['westerneuropean'] = 'западноевропски';
$labels['easterneuropean'] = 'источноевропски';
$labels['southeasterneuropean'] = 'југоисточна Европа';
$labels['baltic'] = 'балтички';
$labels['cyrillic'] = 'Ћирилица';
$labels['arabic'] = 'арапски';
$labels['greek'] = 'грчки';
$labels['hebrew'] = 'хебрејски';
$labels['turkish'] = 'турски';
$labels['nordic'] = 'нордијски';
$labels['thai'] = 'тајландски';
$labels['celtic'] = 'келтски';
$labels['vietnamese'] = 'вијетнамски';
$labels['japanese'] = 'јапански';
$labels['korean'] = 'корејски';
$labels['chinese'] = 'кинески';
$labels['arialabelquicksearchbox'] = 'Унос претраге';
$labels['arialabelmailpreviewframe'] = 'Преглед поруке';
$labels['arialabelmailimportdialog'] = 'Дијалог увоза поруке';
$labels['arialabelmessagenav'] = 'Навигација поруке';
$labels['arialabelmessagebody'] = 'Тело поруке';
$labels['arialabelmessageactions'] = 'Радње поруке';
$labels['arialabelmessageheaders'] = 'Заглавља поруке';
$labels['arialabelforwardingoptions'] = 'Опције прослеђивања';
$labels['arialabelreplyalloptions'] = 'Опције одговора свима';
$labels['arialabelmoremessageactions'] = 'Још радњи за поруку';
$labels['arialabelmarkmessagesas'] = 'Означи изабране поруке као...';
$labels['arialabelcomposeoptions'] = 'Опције састављања';
$labels['arialabelattachmentpreview'] = 'Преглед прилога';
$labels['arialabelcontactexportoptions'] = 'Опције извоза контакта';
$labels['arialabelabookgroupoptions'] = 'Опције адресара/групе';
$labels['arialabelsearchterms'] = 'Појмови претраге';
$labels['helplistkeyboardnavmessages'] = "Стрелице лево/десно: скупљају/шире нит порука (само у нитном режиму).
Ентер: отвара означену поруку.
Delete: премешта изабране поруке у смеће.";
