<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = '필터';
$labels['managefilters'] = '수신 메일 필터 관리';
$labels['filtername'] = '필터명';
$labels['newfilter'] = '새로운 필터';
$labels['filteradd'] = '필터 추가';
$labels['filterdel'] = '필터 삭제';
$labels['rules'] = '규칙';
$labels['actions'] = '행동';
$labels['scope'] = '범위';
$labels['moveup'] = '위로 이동';
$labels['movedown'] = '아래로 이동';
$labels['filterallof'] = '다음 모든 규칙과 일치함';
$labels['filteranyof'] = '다음 규칙 중 하나라도 일치함';
$labels['filterany'] = '모든 메시지';
$labels['filtercontains'] = '다음을 포함함';
$labels['filternotcontains'] = '다음을 포함하지 않음';
$labels['filteris'] = '다음과 일치함';
$labels['filterisnot'] = '다음과 일치하지 않음';
$labels['filterexists'] = '다음이 존재함';
$labels['filternotexists'] = '다음이 존재하지 않음';
$labels['filtermatches'] = '다음 표현식과 일치함';
$labels['filternotmatches'] = '다음 표현식과 일치하지 않음';
$labels['filterregex'] = '다음 정규 표현식과 일치함';
$labels['filternotregex'] = '다음 정규 표현식과 일치하지 않음';
$labels['filterunder'] = '다음보다 아래임';
$labels['filterover'] = '다음보다 위임';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'MIME 일부:';
$labels['mime-message'] = '메시지';
$labels['mime-anychild'] = '모두';
$labels['mime-type'] = '유형';
$labels['mime-subtype'] = '하위 유형';
$labels['mime-contenttype'] = '내용 유형';
$labels['mime-param'] = '매개변수';
$labels['addrule'] = '규칙 추가';
$labels['delrule'] = '규칙 삭제';
$labels['messagemoveto'] = '메시지를 다음 위치로 이동';
$labels['messageredirect'] = '메시지를 다음 주소로 재전송';
$labels['messagecopyto'] = '메시지를 다음 위치로 복사';
$labels['messagesendcopy'] = '메시지 사본을 다음 대상에게 보내기';
$labels['messagereply'] = '다음 메시지로 회신';
$labels['messagedelete'] = '메시지 삭제';
$labels['messagediscard'] = '다음 메시지와 함께 폐기';
$labels['messagekeep'] = '메시지를 받은 편지함에 보관';
$labels['messagesrules'] = '해당 받은 메일:';
$labels['messagesactions'] = '...다음 동작을 실행:';
$labels['add'] = '추가';
$labels['del'] = '삭제';
$labels['sender'] = '발송자';
$labels['recipient'] = '수신자';
$labels['vacationaddr'] = '내 이메일 주소:';
$labels['vacationdays'] = '메시지 발신 주기 (일):';
$labels['vacationinterval'] = '메시지 발신 주기:';
$labels['vacationreason'] = '메시지 본문 (휴가 사유):';
$labels['vacationfrom'] = '회신 시 보내는 사람 주소:';
$labels['vacationsubject'] = '메시지 제목:';
$labels['days'] = '일';
$labels['seconds'] = '초';
$labels['rulestop'] = '규칙 평가를 중단';
$labels['enable'] = '활성화/비활성화';
$labels['filterset'] = '필터 세트';
$labels['filtersets'] = '필터 세트';
$labels['filtersetadd'] = '필터 세트 추가';
$labels['filtersetdel'] = '필터 세트 삭제';
$labels['filtersetact'] = '현재 필터 세트 활성화';
$labels['filtersetdeact'] = '현재 필터 세트 비활성화';
$labels['filterseteditraw'] = '필터 세트 편집';
$labels['filtersetswitch'] = '필터 세트 활성화/비활성화';
$labels['filterdef'] = '필터 정의';
$labels['filtersetname'] = '필터 세트 이름';
$labels['newfilterset'] = '새 필터 세트';
$labels['active'] = '활성화됨';
$labels['none'] = '없음';
$labels['fromset'] = '세트로부터';
$labels['fromfile'] = '파일로부터';
$labels['filterdisabled'] = '필터가 비활성화됨';
$labels['filterenabled'] = '필터 활성화됨';
$labels['countisgreaterthan'] = '개수가 다음보다 큼';
$labels['countisgreaterthanequal'] = '개수가 다음보다 크거나 같음';
$labels['countislessthan'] = '개수가 다음보다 작음';
$labels['countislessthanequal'] = '개수가 작거나 같음';
$labels['countequals'] = '개수가 다음과 같음';
$labels['countnotequals'] = '개수가 다음과 일치하지 않음';
$labels['valueisgreaterthan'] = '값이 다음보다 큼';
$labels['valueisgreaterthanequal'] = '값이 다음보다 크거나 같음';
$labels['valueislessthan'] = '값이 다음보다 작음';
$labels['valueislessthanequal'] = '값이 다음보다 작거나 같음';
$labels['valueequals'] = '값이 다음과 같음';
$labels['valuenotequals'] = '값이 다음과 일치하지 않음';
$labels['setflags'] = '메시지를 깃발로 표시';
$labels['addflags'] = '메시지에 깃발을 추가';
$labels['removeflags'] = '메시지에서 깃발을 제거';
$labels['flagread'] = '읽음';
$labels['flagdeleted'] = '삭제됨';
$labels['flaganswered'] = '응답함';
$labels['flagflagged'] = '깃발로 표시함';
$labels['flagdraft'] = '임시 보관함';
$labels['addheader'] = '메시지에 머리글 추가';
$labels['deleteheader'] = '메시지에서 머리글 제거';
$labels['headername'] = '머리글 이름';
$labels['headervalue'] = '머리글 값';
$labels['headerpos'] = '머리글 위치';
$labels['headeratstart'] = '시작 지점에';
$labels['headeratend'] = '끝 지점에';
$labels['headeroccurrence'] = '머리글 존재/위치';
$labels['headerfromstart'] = '시작부터';
$labels['headerfromend'] = '끝부터';
$labels['headerpatterns'] = '머리글 값 패턴';
$labels['headermatchtype'] = '일치 유형:';
$labels['setvariable'] = '변수 설정';
$labels['setvarname'] = '변수명:';
$labels['setvarvalue'] = '변수 값:';
$labels['setvarmodifiers'] = '수식자:';
$labels['varlower'] = '소문자';
$labels['varupper'] = '대문자';
$labels['varlowerfirst'] = '첫 문자를 소문자로';
$labels['varupperfirst'] = '첫 문자를 대문자로';
$labels['varquotewildcard'] = '특수 기호를 인용';
$labels['varlength'] = '길이';
$labels['notify'] = '알림 메시지 보내기';
$labels['notifytarget'] = '알림 대상:';
$labels['notifymessage'] = '알림 메시지(옵션):';
$labels['notifyoptions'] = '알림 옵션(옵션):';
$labels['notifyfrom'] = '알림 발송자(옵션):';
$labels['notifyimportance'] = '중요도:';
$labels['notifyimportancelow'] = '낮음';
$labels['notifyimportancenormal'] = '보통';
$labels['notifyimportancehigh'] = '높음';
$labels['notifymethodmailto'] = '이메일';
$labels['notifymethodtel'] = '전화';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = '필터 생성';
$labels['usedata'] = '필터에서 다음 데이터를 사용:';
$labels['nextstep'] = '다음 단계';
$labels['...'] = '...';
$labels['string'] = '스티링';
$labels['currdate'] = '오늘 날짜';
$labels['datetest'] = '날짜';
$labels['dateheader'] = '머리글:';
$labels['year'] = '년';
$labels['month'] = '월';
$labels['day'] = '일';
$labels['date'] = '날짜 (yyyy-mm-dd)';
$labels['julian'] = '날짜 (율리우스력)';
$labels['hour'] = '시';
$labels['minute'] = '분';
$labels['second'] = '초';
$labels['time'] = '시간 (hh:mm:ss)';
$labels['iso8601'] = '날짜 (ISO8601)';
$labels['std11'] = '날짜 (RFC2822)';
$labels['zone'] = '시간대';
$labels['weekday'] = '주중 (0-6)';
$labels['advancedopts'] = '고급 설정';
$labels['body'] = '본문';
$labels['address'] = '주소';
$labels['envelope'] = '봉투';
$labels['modifier'] = '수식자:';
$labels['text'] = '텍스트';
$labels['undecoded'] = '암호화되지 않음(원상태)';
$labels['contenttype'] = '내용 유형';
$labels['modtype'] = '유형:';
$labels['allparts'] = '모두';
$labels['domain'] = '도메인';
$labels['localpart'] = '로컬 부분';
$labels['user'] = '사용자';
$labels['detail'] = '세부사항';
$labels['comparator'] = '비교기:';
$labels['default'] = '기본';
$labels['octet'] = '엄격 (8진수)';
$labels['asciicasemap'] = '대/소문자 구분 (ascii-casemap)';
$labels['asciinumeric'] = '숫자 (ascii-numeric)';
$labels['index'] = '색인:';
$labels['indexlast'] = '역방향';
$labels['spamtest'] = '스팸 수준';
$labels['spamtestisgreaterthan'] = '다음보다 큼';
$labels['spamtestisgreaterthanequal'] = '다음보다 크거나 같음';
$labels['spamtestislessthan'] = '다음보다 작음';
$labels['spamtestislessthanequal'] = '다음보다 작거나 같음';
$labels['spamtestequals'] = '다음과 일치함';
$labels['spamtestnotequals'] = '다음과 일치하지 않음';
$labels['spamtestisunknown'] = '알 수 없음';
$labels['vacation'] = '자리비움';
$labels['vacation.reply'] = '메시지 회신';
$labels['vacation.advanced'] = '고급 설정';
$labels['vacation.from'] = '회신 시 보내는 사람 주소';
$labels['vacation.subject'] = '제목';
$labels['vacation.body'] = '본문';
$labels['vacation.start'] = '시작 시간';
$labels['vacation.end'] = '종료 시간';
$labels['vacation.status'] = '상태';
$labels['vacation.on'] = '켬';
$labels['vacation.off'] = '끔';
$labels['vacation.addresses'] = '내 이메일 주소';
$labels['vacation.interval'] = '회신 주기';
$labels['vacation.after'] = '다음 이후에 자리비움 규칙 두기';
$labels['vacation.saving'] = '데이터를 저장하는 중...';
$labels['vacation.action'] = '수신 메시지 동작';
$labels['vacation.keep'] = '보관';
$labels['vacation.discard'] = '폐기';
$labels['vacation.redirect'] = '재전송';
$labels['vacation.copy'] = '사본을 다음 대상에게 전송';
$labels['forward'] = '전달';
$labels['forward.redirect'] = '재전송';
$labels['forward.copy'] = '사본을 다음 대상에게 전송';
$labels['forward.on'] = '켬';
$labels['forward.off'] = '끔';
$labels['forward.status'] = '상태:';
$labels['forward.action'] = '받은 메일에 대해 다음 동작을 실행:';
$labels['forward.saving'] = '데이터를 저장하는 중...';
$labels['filladdresses'] = '내 이메일 주소로 모두 채우기';
$labels['arialabelfiltersetactions'] = '필터 세트 동작';
$labels['arialabelfilteractions'] = '필터 동작';
$labels['arialabelfilterform'] = '필터 속성';
$labels['ariasummaryfilterslist'] = '필터 목록';
$labels['ariasummaryfiltersetslist'] = '필터 세트 목록';
$labels['filterstitle'] = '수신 메일 필터 편집';
$labels['vacationtitle'] = '자리비움 규칙 편집';
$labels['forwardtitle'] = '메일 전달 규칙 편집';
$labels['message'] = '메시지';
$labels['duplicate'] = '중복임';
$labels['notduplicate'] = '중복 아님';
$labels['duplicate.handle'] = '취급';
$labels['duplicate.header'] = '머리글:';
$labels['duplicate.uniqueid'] = '식별자:';
$labels['duplicate.seconds'] = '타임아웃 (초):';
$labels['duplicate.last'] = '마지막 실행과 관련';
$messages['filterunknownerror'] = '알수 없는 서버 오류.';
$messages['filterconnerror'] = '서버에 연결할 수 없습니다.';
$messages['filterdeleteerror'] = '필터를 삭제할 수 없습니다. 서버 오류가 발생했습니다.';
$messages['filterdeleted'] = '필터가 성공적으로 삭제되었습니다.';
$messages['filtersaved'] = '필터가 성공적으로 저장되었습니다.';
$messages['filtersaveerror'] = '필터를 저장할 수 없습니다. 서버 오류가 발생했습니다.';
$messages['filterformerror'] = '필터 양식에 오류가 포함되어 있음.';
$messages['filterdeleteconfirm'] = '정말로 선택한 필터를 삭제하시겠습니까?';
$messages['ruledeleteconfirm'] = '정말로 선택한 규칙을 삭제하시겠습니까?';
$messages['actiondeleteconfirm'] = '정말로 선택한 동작을 삭제하시겠습니까?';
$messages['forbiddenchars'] = '필드에 금지된 문자가 존재합니다.';
$messages['cannotbeempty'] = '필드는 비어둘 수 없습니다.';
$messages['ruleexist'] = '지정한 이름의 필터가 이미 존재합니다.';
$messages['setactivateerror'] = '선택한 필터 세트를 활성화할 수 없습니다. 서버 오류가 발생했습니다.';
$messages['setdeactivateerror'] = '선택한 필터 세트를 비활성화할 수 없습니다. 서버 오류가 발생했습니다.';
$messages['setdeleteerror'] = '선택한 필터 세트를 삭제할 수 없습니다. 서버 오류가 발생했습니다.';
$messages['setactivated'] = '필터 세트가 성공적으로 활성화되었습니다.';
$messages['setdeactivated'] = '필터 세트가 성공적으로 비활성화되었습니다.';
$messages['setdeleted'] = '필터 세트가 성공적으로 삭제되었습니다.';
$messages['setupdated'] = '필터 세트가 성공적으로 업데이트되었습니다.';
$messages['setdeleteconfirm'] = '정말 선택한 필터 세트를 삭제하시겠습니까?';
$messages['setcreateerror'] = '필터 세트를 생성하지 못했습니다. 서버 오류가 발생했습니다.';
$messages['setcreated'] = '필터 세트를 성공적으로 생성했습니다.';
$messages['activateerror'] = '선택한 필터를 활성화할 수 없습니다. 서버 오류가 발생했습니다.';
$messages['deactivateerror'] = '선택한 필터를 비활성화할 수 없습니다. 서버 오류가 발생했습니다.';
$messages['deactivated'] = '필터가 성공적으로 비활성화되었습니다.';
$messages['activated'] = '필터가 성공적으로 활성화되었습니다.';
$messages['moved'] = '필터가 성공적으로 이동되었습니다.';
$messages['moveerror'] = '선택한 필터를 이동할 수 없습니다. 서버 오류가 발생했습니다.';
$messages['nametoolong'] = '이름이 너무 깁니다.';
$messages['namereserved'] = '예약된 이름입니다.';
$messages['setexist'] = '세트가 이미 존재합니다.';
$messages['nodata'] = '최소 하나의 위치가 선택되어야 합니다!';
$messages['invaliddateformat'] = '유효하지 않은 날짜 또는 날짜 일부 형식';
$messages['saveerror'] = '데이터를 저장할 수 없습니다.. 서버 오류가 발생했습니다.';
$messages['vacationsaved'] = '자리비움 데이터를 성공적으로 저장했습니다.';
$messages['forwardsaved'] = '전달 데이터를 성공적으로 저장했습니다.';
$messages['emptyvacationbody'] = '휴가 메시지의 본문이 필요합니다!';
$messages['duplicate.conflict.err'] = '머리글 및 유일 식별자가 허용되지 않음.';
$messages['disabledaction'] = '동작이 허용되지 않았습니다.';
$messages['lastindexempty'] = '끝에서부터 세려면 인덱스 숫자가 필요합니다';
$messages['noflagset'] = '최소 하나의 깃발이 선택되어야 합니다.';
