<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<roundcube:include file="/includes/links.html" />
<script type="text/javascript" src="/functions.js"></script>
</head>
<body class="iframe">

<div class="boxcontent">
  <roundcube:object name="searchform" id="advsearchform" size=30 />
</div>
<script type="text/javascript">rcube_init_tabs('advsearchform')</script>

</body>
</html>
