<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'Cuir sa chartlann';
$labels['buttontitle'] = 'Cuir an teachtaireacht seo sa chartlann';
$labels['archived'] = 'Curtha go ráthúil sa chartlann';
$labels['archivedreload'] = 'Curtha go ráthúil sa chartlann. Athluchtaigh an leathanach chun na fillteáin chartlainne nua a fheiceáil.';
$labels['archiveerror'] = 'Níorbh fhéidir roinnt teachtaireachtaí a chur sa chartlann';
$labels['archivefolder'] = 'An Chartlann';
$labels['settingstitle'] = 'Cartlann';
$labels['archivetype'] = 'Roinn an chartlann de réir';
$labels['archivetypeyear'] = 'Biiain (m.sh. Cartlann/2012)';
$labels['archivetypemonth'] = 'Mí (m.sh. Cartlann/2012/06)';
$labels['archivetypetbmonth'] = 'Mí - comhoiriúnach le Thunderbird (m.sh. Cartlann/2012/2012-06)';
$labels['archivetypefolder'] = 'An fillteán bunaidh';
$labels['archivetypesender'] = 'Seoladh ríomhphoist an tseoltóra';
$labels['unkownsender'] = 'anaithnid';
$labels['readonarchive'] = 'Rianaigh an teachtaireacht mar léite sa chartlann';
