<roundcube:object name="doctype" value="html5" />
<html>
<head>
<roundcube:object name="meta" />
<roundcube:object name="links" />
<link rel="stylesheet" type="text/css" href="/print.css" />
</head>
<body>

<div id="header"><roundcube:object name="logo" src="/images/roundcube_logo.png" id="toplogo" border="0" alt="Logo" logo-type="print" logo-match="all" /></div>

<div id="contact-details" class="boxcontent">
	<div id="contactphoto"><roundcube:object name="contactphoto" id="contactpic" placeholder="/images/contactpic.png" placeholderGroup="/images/contactgroup.png" /></div>
	<roundcube:object name="contacthead" id="contacthead" />
	<br style="clear:both" />
	<roundcube:object name="contactdetails" />
</div>

</body>
</html>
