/* This file contains the CSS data for the editable area(iframe) of TinyMCE */

body, td, pre {
	font-family: "Lucida Grande", Verdana,  Arial, Helvetica, sans-serif;
	font-size: 12px;
}

body {
	background-color: #fff;
	margin: 4px;
}

div.pre {
	margin: 0;
	padding: 0;
	font-family: monospace;
}

blockquote
{
	border-left: #1010ff 2px solid;
	margin: 0;
	padding: 0 0.4em;
}
