<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Chia sẻ';
$labels['myrights'] = 'Quyền truy cập';
$labels['username'] = 'Người dùng:';
$labels['advanced'] = 'Chế độ tính năng cao hơn';
$labels['add'] = 'Thêm';
$labels['newuser'] = 'Thêm bài viết';
$labels['editperms'] = 'Sửa đổi quyền sử dụng';
$labels['actions'] = 'Các thao tác quyền truy cập';
$labels['anyone'] = 'Tất cả người dùng (bất kỳ ai)';
$labels['anonymous'] = 'Khách (nặc danh)';
$labels['identifier'] = 'Định danh';
$labels['acll'] = 'Tìm kiếm';
$labels['aclr'] = 'Đọc thư';
$labels['acls'] = 'Giữ trạng thái đã xem qua';
$labels['aclw'] = 'Cờ đánh dấu cho mục viết';
$labels['acli'] = 'Chèn thêm (sao chép vào)';
$labels['aclp'] = 'Đăng bài';
$labels['aclc'] = 'Tạo giữ liệu con';
$labels['aclk'] = 'Tạo giữ liệu con';
$labels['acld'] = 'Xóa thư';
$labels['aclt'] = 'Xóa thư';
$labels['acle'] = 'Thải bỏ';
$labels['aclx'] = 'Xóa giữ liệu';
$labels['acla'] = 'Quản lý';
$labels['acln'] = 'Thông tin chú thích';
$labels['aclfull'] = 'Quản lý toàn bộ';
$labels['aclother'] = 'Loại khác';
$labels['aclread'] = 'Đọc';
$labels['aclwrite'] = 'Viết';
$labels['acldelete'] = 'Xoá';
$labels['shortacll'] = 'Tìm kiếm';
$labels['shortaclr'] = 'Đọc';
$labels['shortacls'] = 'Giữ';
$labels['shortaclw'] = 'Viết';
$labels['shortacli'] = 'Chèn';
$labels['shortaclp'] = 'Đăng bài';
$labels['shortaclc'] = 'Tạo mới';
$labels['shortaclk'] = 'Tạo mới';
$labels['shortacld'] = 'Xoá';
$labels['shortaclt'] = 'Xoá';
$labels['shortacle'] = 'Thải bỏ';
$labels['shortaclx'] = 'Giữ liệu được xóa';
$labels['shortacla'] = 'Quản lý';
$labels['shortacln'] = 'Chú thích';
$labels['shortaclother'] = 'Loại khác';
$labels['shortaclread'] = 'Đọc';
$labels['shortaclwrite'] = 'Viết';
$labels['shortacldelete'] = 'Xoá';
$labels['longacll'] = 'Thư mục đã được hiển thị và có thể đăng ký sử dụng';
$labels['longaclr'] = 'Thư mục có thể được mở để đọc';
$labels['longacls'] = 'Cờ đánh dấu thư đã xem qua có thể thay đổi';
$labels['longaclw'] = 'Cờ thư và từ khóa có thể thay đổi, ngoại trừ đã xem qua và bị xóa';
$labels['longacli'] = 'Thư có thể được ghi hoặc sao chép vào giữ liệu';
$labels['longaclp'] = 'Thư có thể bỏ vào trong giữ liệu này';
$labels['longaclc'] = 'Các giữ liệu có thể được tạo (hoặc đặt lại tên) trực tiếp dưới giữ liệu này';
$labels['longaclk'] = 'Các giữ liệu có thể được tạo (hoặc đặt lại tên) trực tiếp dưới giữ liệu này';
$labels['longacld'] = 'Cờ đánh dấu thư xóa có thể thay đổi';
$labels['longaclt'] = 'Cờ đánh dấu thư xóa có thể thay đổi';
$labels['longacle'] = 'Thư có thể thải bỏ';
$labels['longaclx'] = 'Giữ liệu có thể xóa được hoặc đặt lại tên';
$labels['longacla'] = 'Quyên truy cập giữ liệu có thể thay đổi';
$labels['longacln'] = 'Dữ liệu thông tin (chú thích) của thư có thể thay đổi';
$labels['longaclfull'] = 'Quản lý toàn bộ bao gồm cả sự thi hành giữ liệu';
$labels['longaclread'] = 'Giữ liệu có thể được mở để đọc';
$labels['longaclwrite'] = 'Thư có thể được đánh dấu, ghi hoăc sao chép vào giữ liệu';
$labels['longacldelete'] = 'Thư có thể bị xóa';
$labels['longaclother'] = 'Quyền truy cập khác';
$labels['ariasummaryacltable'] = 'Danh sách quyền truy cập';
$labels['arialabelaclactions'] = 'Danh sách hành động';
$labels['arialabelaclform'] = 'Bảng khai quyền truy cập';
$messages['deleting'] = 'Xóa quyền truy cập...';
$messages['saving'] = 'Lưu quyền truy cập...';
$messages['updatesuccess'] = 'Thay đổi quyền truy cập thành công...';
$messages['deletesuccess'] = 'Xóa quyền truy cập thành công...';
$messages['createsuccess'] = 'Thêm quyền truy cập thành công...';
$messages['updateerror'] = 'Không thể cập nhật quyền truy cập';
$messages['deleteerror'] = 'Khôngthể xóa quyền truy cập';
$messages['createerror'] = 'Không thể thêm quyền truy cập';
$messages['deleteconfirm'] = 'Bạn có chắc là muốn xóa bỏ quyền truy cập của người dùng được chọn?';
$messages['norights'] = 'Chưa có quyền nào được chỉ định!';
$messages['nouser'] = 'Chưa có tên truy nhập được chỉ định!';
