<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<roundcube:include file="/includes/links.html" />
</head>
<body class="iframe">

<div id="filter-title" class="boxtitle"><roundcube:label name="managesieve.newfilterset" /></div>

<div id="filter-form" class="boxcontent">
<roundcube:object name="filtersetform" />

<p>
<roundcube:button command="plugin.managesieve-save" type="input" class="button mainaction" label="save" />
</p>

</form>
</div>


</body>
</html>
