<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Willkommen bei $product';
$labels['username'] = 'Benutzername';
$labels['password'] = 'Passwort';
$labels['server'] = 'Server';
$labels['login'] = 'Login';
$labels['oauthlogin'] = 'Anmelden mit $provider';
$labels['menu'] = 'Menü';
$labels['logout'] = 'Logout';
$labels['mail'] = 'E-Mail';
$labels['settings'] = 'Einstellungen';
$labels['addressbook'] = 'Adressbuch';
$labels['darkmode'] = 'Dunkler Modus';
$labels['lightmode'] = 'Heller Modus';
$labels['inbox'] = 'Posteingang';
$labels['drafts'] = 'Entwürfe';
$labels['sent'] = 'Gesendet';
$labels['trash'] = 'Gelöscht';
$labels['junk'] = 'Spam';
$labels['show_real_foldernames'] = 'Spezialordner nicht übersetzen';
$labels['subject'] = 'Betreff';
$labels['from'] = 'Von';
$labels['sender'] = 'Absender';
$labels['to'] = 'An';
$labels['cc'] = 'Kopie (CC)';
$labels['bcc'] = 'Blind-Kopie';
$labels['replyto'] = 'Antwort an';
$labels['followupto'] = 'Followup-To';
$labels['date'] = 'Datum';
$labels['size'] = 'Grösse';
$labels['priority'] = 'Priorität';
$labels['organization'] = 'Organisation';
$labels['readstatus'] = 'Gelesen/Ungelesen';
$labels['listoptions'] = 'Listenoptionen...';
$labels['listoptionstitle'] = 'Listeneinstellungen';
$labels['mailboxlist'] = 'Ordner';
$labels['messagesfromto'] = 'Nachrichten $from bis $to von $count';
$labels['threadsfromto'] = 'Konversationen $from bis $to von $count';
$labels['messagenrof'] = 'Nachricht $nr von $count';
$labels['fromtoshort'] = '$from – $to von $count';
$labels['copy'] = 'Kopieren';
$labels['move'] = 'Verschieben';
$labels['moveto'] = 'Verschieben nach...';
$labels['copyto'] = 'Kopieren nach...';
$labels['download'] = 'Download';
$labels['open'] = 'Öffnen';
$labels['showattachment'] = 'Anzeigen';
$labels['showanyway'] = 'Trotzdem anzeigen';
$labels['filename'] = 'Dateiname';
$labels['filesize'] = 'Dateigrösse';
$labels['addtoaddressbook'] = 'Ins Adressbuch übernehmen';
$labels['sun'] = 'So';
$labels['mon'] = 'Mo';
$labels['tue'] = 'Di';
$labels['wed'] = 'Mi';
$labels['thu'] = 'Do';
$labels['fri'] = 'Fr';
$labels['sat'] = 'Sa';
$labels['sunday'] = 'Sonntag';
$labels['monday'] = 'Montag';
$labels['tuesday'] = 'Dienstag';
$labels['wednesday'] = 'Mittwoch';
$labels['thursday'] = 'Donnerstag';
$labels['friday'] = 'Freitag';
$labels['saturday'] = 'Samstag';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Feb';
$labels['mar'] = 'Mär';
$labels['apr'] = 'Apr';
$labels['may'] = 'Mai';
$labels['jun'] = 'Jun';
$labels['jul'] = 'Jul';
$labels['aug'] = 'Aug';
$labels['sep'] = 'Sep';
$labels['oct'] = 'Okt';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Dez';
$labels['longjan'] = 'Januar';
$labels['longfeb'] = 'Februar';
$labels['longmar'] = 'März';
$labels['longapr'] = 'April';
$labels['longmay'] = 'Mai';
$labels['longjun'] = 'Juni';
$labels['longjul'] = 'Juli';
$labels['longaug'] = 'August';
$labels['longsep'] = 'September';
$labels['longoct'] = 'Oktober';
$labels['longnov'] = 'November';
$labels['longdec'] = 'Dezember';
$labels['today'] = 'Heute';
$labels['refresh'] = 'Aktualisieren';
$labels['checkmail'] = 'Auf neue Nachrichten prüfen';
$labels['compose'] = 'Schreiben';
$labels['writenewmessage'] = 'Neue Nachricht schreiben';
$labels['reply'] = 'Antworten';
$labels['replytomessage'] = 'Antwort verfassen';
$labels['replytoallmessage'] = 'Antwort an Absender und alle Empfänger verfassen';
$labels['replyall'] = 'Allen antworten';
$labels['replylist'] = 'Liste antworten';
$labels['forward'] = 'Weiterleiten';
$labels['forwardinline'] = 'Eingebunden weiterleiten';
$labels['forwardattachment'] = 'Als Anhang weiterleiten';
$labels['forwardmessage'] = 'Nachricht weiterleiten';
$labels['bouncemsg'] = 'Erneut senden (Bounce)';
$labels['bounce'] = 'Erneut senden';
$labels['deletemessage'] = 'Nachricht löschen';
$labels['movemessagetotrash'] = 'Nachricht in den Papierkorb verschieben';
$labels['printmessage'] = 'Nachricht drucken';
$labels['previousmessage'] = 'Vorherige Nachricht anzeigen';
$labels['firstmessage'] = 'Die erste Nachricht anzeigen';
$labels['nextmessage'] = 'Nächste Nachricht anzeigen';
$labels['lastmessage'] = 'Die letzte Nachricht anzeigen';
$labels['backtolist'] = 'Zurück zur Liste';
$labels['viewsource'] = 'Quelltext anzeigen';
$labels['mark'] = 'Markieren';
$labels['markmessages'] = 'Nachrichten markieren';
$labels['markread'] = 'Als gelesen';
$labels['markunread'] = 'Als ungelesen';
$labels['markflagged'] = 'Markierung hinzufügen';
$labels['markunflagged'] = 'Markierung entfernen';
$labels['moreactions'] = 'Mehr ...';
$labels['markallread'] = 'Alle als gelesen markieren';
$labels['folders-cur'] = 'Nur ausgewählten Ordner';
$labels['folders-sub'] = 'Ausgewählter Ordner und seine Unterordner';
$labels['folders-all'] = 'Alle Ordner';
$labels['more'] = 'Mehr';
$labels['back'] = 'Zurück';
$labels['options'] = 'Optionen';
$labels['composeoptions'] = 'Optionen für die neue Nachrichten';
$labels['optionsandattachments'] = 'Optionen und Anhänge';
$labels['actions'] = 'Aktionen';
$labels['first'] = 'Erste';
$labels['last'] = 'Letzte';
$labels['previous'] = 'Vorherige';
$labels['next'] = 'Nächste';
$labels['select'] = 'Auswählen';
$labels['selection'] = 'Auswahl';
$labels['all'] = 'Alle';
$labels['none'] = 'Keine';
$labels['currpage'] = 'Aktuelle Seite';
$labels['isread'] = 'Gelesen';
$labels['unread'] = 'Ungelesene';
$labels['flagged'] = 'Markierte';
$labels['unflagged'] = 'Nicht markiert';
$labels['unanswered'] = 'Unbeantwortete';
$labels['withattachment'] = 'Mit Anhang';
$labels['deleted'] = 'Gelöschte';
$labels['undeleted'] = 'Nicht gelöscht';
$labels['replied'] = 'Beantwortet';
$labels['forwarded'] = 'Weitergeleitet';
$labels['invert'] = 'Umkehren';
$labels['filter'] = 'Filter';
$labels['list'] = 'Liste';
$labels['threads'] = 'Konversationen';
$labels['expand-all'] = 'Alle aufklappen';
$labels['expand-unread'] = 'Ungelesene aufklappen';
$labels['collapse-all'] = 'Alle zuklappen';
$labels['threaded'] = 'Gruppiert';
$labels['showunread'] = ' Ungelesene Nachrichten anzeigen';
$labels['autoexpand_threads'] = 'Konversationen aufklappen';
$labels['do_expand'] = 'alle';
$labels['expand_only_unread'] = 'nur ungelesene';
$labels['fromto'] = 'Von/An';
$labels['flag'] = 'Markierung';
$labels['attachment'] = 'Anhang';
$labels['nonesort'] = 'Keine';
$labels['sentdate'] = 'Sendedatum';
$labels['arrival'] = 'Empfangsdatum';
$labels['asc'] = 'aufsteigend';
$labels['desc'] = 'absteigend';
$labels['listcolumns'] = 'Spalten';
$labels['listsorting'] = 'Sortierung';
$labels['listorder'] = 'Ordnung';
$labels['listmode'] = 'Anzeigemodus';
$labels['lmode'] = 'Listen-Modus';
$labels['layout'] = 'Layout';
$labels['layoutwidescreen'] = 'Breitbild';
$labels['layoutdesktop'] = 'Desktop';
$labels['layoutlist'] = 'Liste';
$labels['layoutwidescreendesc'] = 'Breitbild (3-Spalten-Ansicht)';
$labels['layoutdesktopdesc'] = 'Desktop (breite Liste mit Vorschau unterhalb)';
$labels['layoutlistdesc'] = 'Liste (keine Vorschau)';
$labels['folderactions'] = 'Ordneraktionen...';
$labels['compact'] = 'Packen';
$labels['empty'] = 'Leeren';
$labels['importmessages'] = 'Nachrichten importieren';
$labels['mailimportdesc'] = 'Sie können E-Mails im <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a>- oder <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>-Format hochladen.';
$labels['mailimportzip'] = 'Mehrere Dateien können in ein Zip-Archiv gepackt werden.';
$labels['quota'] = 'Kapazität';
$labels['unknown'] = 'unbekannt';
$labels['unlimited'] = 'unlimitiert';
$labels['quotatype'] = 'Kapazitätstyp';
$labels['quotatotal'] = 'Limit';
$labels['quotaused'] = 'Verwendet';
$labels['quotastorage'] = 'Speicherplatz';
$labels['quotamessage'] = 'Anzahl Nachrichten';
$labels['shortheaderdate'] = 'Am $date';
$labels['shortheaderto'] = 'An $to am $date';
$labels['shortheaderfrom'] = 'Von $from am $date';
$labels['quicksearch'] = 'Schnellsuche';
$labels['searchplaceholder'] = 'Suche...';
$labels['resetsearch'] = 'Löschen';
$labels['searchmod'] = 'Suchkriterien ändern';
$labels['msgtext'] = 'Ganze Nachricht';
$labels['body'] = 'Inhalt';
$labels['type'] = 'Typ';
$labels['namex'] = 'Name';
$labels['searchscope'] = 'Suchbereich';
$labels['currentfolder'] = 'Aktueller Ordner';
$labels['subfolders'] = 'Aktueller und Unterordner';
$labels['allfolders'] = 'Alle Ordner';
$labels['searchinterval-1W'] = 'älter als eine Woche';
$labels['searchinterval-1M'] = 'älter als ein Monat';
$labels['searchinterval-1Y'] = 'älter als ein Jahr';
$labels['searchinterval1W'] = 'jünger als eine Woche';
$labels['searchinterval1M'] = 'jünger als ein Monat';
$labels['searchinterval1Y'] = 'jünger als ein Jahr';
$labels['openinextwin'] = 'In neuem Fenster öffnen';
$labels['emlsave'] = 'Herunterladen (.eml)';
$labels['changeformattext'] = 'Als reiner Text anzeigen';
$labels['changeformathtml'] = 'Als original HTML anzeigen';
$labels['editasnew'] = 'Als neue Nachricht öffnen';
$labels['send'] = 'Senden';
$labels['sendmessage'] = 'Nachricht jetzt senden';
$labels['savemessage'] = 'Nachricht speichern';
$labels['addattachment'] = 'Datei anfügen';
$labels['charset'] = 'Zeichensatz';
$labels['editortype'] = 'Editor-Typ';
$labels['returnreceipt'] = 'Empfangsbestätigung (MDN)';
$labels['dsn'] = 'Übermittlungsbestätigung (DSN)';
$labels['mailreplyintro'] = 'Am $date, schrieb $sender:';
$labels['originalmessage'] = 'Originalnachricht';
$labels['selectimage'] = 'Bild auswählen';
$labels['addimage'] = 'Bild hinzufügen';
$labels['selectmedia'] = 'Video auswählen';
$labels['addmedia'] = 'Video hinzufügen';
$labels['encrypt'] = 'Verschlüsseln';
$labels['encryptmessage'] = 'Nachricht verschlüsseln';
$labels['encryptmessagemailvelope'] = 'Nachricht verschlüsseln mit Mailvelope';
$labels['importpubkeys'] = 'Öffentliche Schlüssel importieren';
$labels['encryptedsendialog'] = 'Verschlüsselte Nachricht senden';
$labels['encryptandsign'] = 'Verschlüsseln & signieren';
$labels['keyid'] = 'Schlüsselkennung';
$labels['keylength'] = 'Bits';
$labels['keyexpired'] = 'Abgelaufen';
$labels['keyrevoked'] = 'Widerrufen';
$labels['bccinstead'] = 'Bcc verwenden';
$labels['addheader'] = 'Empfänger hinzufügen (Kopfzeile)';
$labels['insert'] = 'Hinzufügen';
$labels['insertcontact'] = 'Kontakt(e) einfügen';
$labels['recipient'] = 'Empfänger';
$labels['recipientedit'] = 'Empfänger bearbeiten';
$labels['editidents'] = 'Absender bearbeiten';
$labels['spellcheck'] = 'Rechtschreibung';
$labels['checkspelling'] = 'Rechtschreibung prüfen';
$labels['resumeediting'] = 'Bearbeitung fortsetzen';
$labels['revertto'] = 'Zurück zu';
$labels['restore'] = 'Wiederherstellen';
$labels['restoremessage'] = 'Nachricht wiederherstellen?';
$labels['ignore'] = 'Ignorieren';
$labels['responses'] = 'Antworten';
$labels['insertresponse'] = 'Antwort einfügen';
$labels['manageresponses'] = 'Antworten verwalten';
$labels['newresponse'] = 'Neue Antwort erstellen';
$labels['addresponse'] = 'Antwort hinzufügen';
$labels['editresponse'] = 'Antwort bearbeiten';
$labels['editresponses'] = 'Antworten bearbeiten';
$labels['responsename'] = 'Name';
$labels['responsetext'] = 'Antworttext';
$labels['attach'] = 'Anhängen';
$labels['attachments'] = 'Anhänge';
$labels['upload'] = 'Hochladen';
$labels['uploadprogress'] = '$percent ($current von $total)';
$labels['close'] = 'Schliessen';
$labels['messageoptions'] = 'Optionen...';
$labels['togglecomposeoptions'] = 'Nachrichten-Optionen ein-/ausblenden';
$labels['attachmentrename'] = 'Anhang umbenennen';
$labels['low'] = 'Niedrig';
$labels['lowest'] = 'Niedrigste';
$labels['normal'] = 'Normal';
$labels['high'] = 'Hoch';
$labels['highest'] = 'Höchste';
$labels['nosubject'] = '(kein Betreff)';
$labels['showimages'] = 'Bilder anzeigen';
$labels['allow'] = 'Erlauben';
$labels['alwaysshow'] = 'Bilder von $sender immer zeigen';
$labels['alwaysallow'] = 'Von $sender immer erlauben';
$labels['isdraft'] = 'Dies ist ein Entwurf';
$labels['andnmore'] = '$nr weitere...';
$labels['details'] = 'Details';
$labels['summary'] = 'Zusammenfassung';
$labels['headers'] = 'Kopfzeilen';
$labels['allheaders'] = 'Alle Kopfzeilen...';
$labels['togglemoreheaders'] = 'Weitere Kopfzeilen anzeigen';
$labels['togglefullheaders'] = 'Original-Kopfzeilen ein-/ausblenden';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Klartext';
$labels['savesentmessagein'] = 'Nachricht speichern in';
$labels['dontsave'] = 'nicht speichern';
$labels['maxuploadsize'] = 'Maximal erlaubte Dateigrösse ist $size';
$labels['addcc'] = 'Cc hinzufügen';
$labels['addbcc'] = 'Bcc hinzufügen';
$labels['addreplyto'] = 'Antwortadresse hinzufügen';
$labels['addfollowupto'] = 'Followup-To hinzufügen';
$labels['sendreceipt'] = 'Lesebestätigung senden?';
$labels['mdnrequest'] = 'Der Sender dieser Nachricht hat eine Empfangsbestätigung angefordert. Möchten Sie diese jetzt senden?';
$labels['receiptread'] = 'Empfangsbestätigung (gelesen)';
$labels['yourmessage'] = 'Dieses ist eine Empfangsbestätigung für Ihre Nachricht';
$labels['receiptnote'] = 'Hinweis: Der Empfänger hat den Empfang der Nachricht bestätigt. Dieses ist keine Garantie, dass die Nachricht gelesen und verstanden wurde.';
$labels['sendalwaysto'] = 'Immer an $email senden';
$labels['zoomin'] = 'Vergrössern';
$labels['zoomout'] = 'Verkleinern';
$labels['rotate'] = 'Drehen';
$labels['increaseimage'] = 'Bild vergrössern';
$labels['decreaseimage'] = 'Bild verkleinern';
$labels['rotateimage'] = 'Bild drehen';
$labels['showtools'] = 'Bildwerkzeuge einblenden';
$labels['hidetools'] = 'Bildwerkzeuge ausblenden';
$labels['name'] = 'Anzeigename';
$labels['firstname'] = 'Vorname';
$labels['surname'] = 'Nachname';
$labels['middlename'] = '2. Vorname';
$labels['nameprefix'] = 'Präfix';
$labels['namesuffix'] = 'Suffix';
$labels['nickname'] = 'Spitzname';
$labels['jobtitle'] = 'Titel';
$labels['department'] = 'Abteilung';
$labels['gender'] = 'Geschlecht';
$labels['maidenname'] = 'Mädchenname';
$labels['email'] = 'E-Mail';
$labels['phone'] = 'Telefon';
$labels['address'] = 'Adresse';
$labels['street'] = 'Strasse';
$labels['locality'] = 'Ort';
$labels['zipcode'] = 'PLZ';
$labels['region'] = 'Region';
$labels['country'] = 'Land';
$labels['birthday'] = 'Geburtstag';
$labels['anniversary'] = 'Jahrestag';
$labels['website'] = 'Website';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Notizen';
$labels['male'] = 'männlich';
$labels['female'] = 'weiblich';
$labels['manager'] = 'Vorgesetzte/r';
$labels['assistant'] = 'Assistent';
$labels['spouse'] = 'Partner/in';
$labels['allfields'] = 'Alle Felder';
$labels['search'] = 'Suche';
$labels['searchresult'] = 'Suchresultat';
$labels['advsearch'] = 'Erweiterte Suche';
$labels['advanced'] = 'Erweitert';
$labels['other'] = 'Andere';
$labels['printcontact'] = 'Kontakt drucken';
$labels['qrcode'] = 'QR-Code';
$labels['typehome'] = 'Zuhause';
$labels['typework'] = 'Arbeit';
$labels['typeother'] = 'Andere';
$labels['typemobile'] = 'Mobiltelefon';
$labels['typemain'] = 'Hauptnummer';
$labels['typehomefax'] = 'Fax Zuhause';
$labels['typeworkfax'] = 'Fax Arbeit';
$labels['typecar'] = 'Auto';
$labels['typepager'] = 'Pager';
$labels['typevideo'] = 'Video';
$labels['typeassistant'] = 'Assistent';
$labels['typehomepage'] = 'Homepage';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Feld hinzufügen...';
$labels['addcontact'] = 'Kontakt hinzufügen';
$labels['editcontact'] = 'Kontakt bearbeiten';
$labels['contacts'] = 'Kontakte';
$labels['contactproperties'] = 'Kontaktdaten';
$labels['contactnameandorg'] = 'Name und Organisation';
$labels['personalinfo'] = 'Persönliche Informationen';
$labels['personal'] = 'Persönlich';
$labels['contactphoto'] = 'Kontakt-Bild';
$labels['edit'] = 'Bearbeiten';
$labels['cancel'] = 'Abbrechen';
$labels['save'] = 'Speichern';
$labels['delete'] = 'Löschen';
$labels['discard'] = 'Verwerfen';
$labels['continue'] = 'Weiter';
$labels['ok'] = 'OK';
$labels['rename'] = 'Umbenennen';
$labels['addphoto'] = 'Hinzufügen';
$labels['replacephoto'] = 'Ersetzen';
$labels['uploadphoto'] = 'Bild hochladen';
$labels['choosefile'] = 'Datei auswählen...';
$labels['choosefiles'] = 'Dateien auswählen...';
$labels['browse'] = 'Durchsuchen';
$labels['newcontact'] = 'Neuen Kontakt erfassen';
$labels['deletecontact'] = 'Gewählte Kontakte löschen';
$labels['composeto'] = 'Nachricht verfassen';
$labels['contactsfromto'] = 'Kontakte $from bis $to von $count';
$labels['print'] = 'Drucken';
$labels['export'] = 'Exportieren';
$labels['exportall'] = 'Alle exportieren';
$labels['exportsel'] = 'Ausgewählte exportieren';
$labels['exportvcards'] = 'Kontakte im vCard-Format exportieren';
$labels['newgroup'] = 'Neue Addressgruppe erstellen';
$labels['addgroup'] = 'Gruppe hinzufügen';
$labels['grouprename'] = 'Gruppe umbenennen';
$labels['groupdelete'] = 'Gruppe löschen';
$labels['groupassign'] = 'Zur Gruppe hinzufügen...';
$labels['groupremove'] = 'Aus Gruppe entfernen';
$labels['groupremoveselected'] = 'Gewählte Kontakte aus Gruppe entfernen';
$labels['uponelevel'] = 'Eine Ebene nach oben';
$labels['previouspage'] = 'Eine Seite zurück';
$labels['firstpage'] = 'Erste Seite';
$labels['nextpage'] = 'Nächste Seite';
$labels['lastpage'] = 'Letzte Seite';
$labels['group'] = 'Gruppe';
$labels['groups'] = 'Gruppen';
$labels['listgroup'] = 'Gruppenmitglieder anzeigen';
$labels['personaladrbook'] = 'Persönliches Adressbuch';
$labels['searchsave'] = 'Suche speichern';
$labels['searchdelete'] = 'Suche löschen';
$labels['import'] = 'Importieren';
$labels['importcontacts'] = 'Adressen importieren';
$labels['importfromfile'] = 'Aus Datei importieren';
$labels['importtarget'] = 'Importieren nach';
$labels['importreplace'] = 'Bestehendes Adressbuch komplett ersetzen';
$labels['importgroups'] = 'Gruppenzuweisungen importieren';
$labels['importgroupsall'] = 'Alle (nicht vorhandene Gruppen erstellen)';
$labels['importgroupsexisting'] = 'Für existierende Gruppen';
$labels['importdesc'] = 'Sie können Kontakte aus einem bestehenden Adressbuch hochladen.<br/>Unterstützt werden aktuell <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> oder CSV (comma-separated) Dateiformate.';
$labels['importmapdesc'] = 'Prüfen Sie die unten stehende Spaltenzuweisung bevor der Import der CSV-Daten (komma-getrennt) fortgesetzt wird.';
$labels['fieldnotmapped'] = 'Feld nicht zugewiesen (nicht importieren)';
$labels['skipheader'] = 'Die erste Zeile nicht importieren (Kopfzeile)';
$labels['done'] = 'Fertig';
$labels['settingsfor'] = 'Einstellungen für';
$labels['about'] = 'Über';
$labels['preferences'] = 'Einstellungen';
$labels['userpreferences'] = 'Benutzereinstellungen';
$labels['editpreferences'] = 'Einstellungen bearbeiten';
$labels['identities'] = 'Absender';
$labels['manageidentities'] = 'Absender verwalten';
$labels['newidentity'] = 'Neuen Absender erfassen';
$labels['addidentity'] = 'Absender hinzufügen';
$labels['editidentity'] = 'Absender bearbeiten';
$labels['identityencryption'] = 'Verschlüsselung';
$labels['preferhtml'] = 'HTML bevorzugen';
$labels['defaultcharset'] = 'Standard-Zeichensatz';
$labels['htmlmessage'] = 'HTML Nachricht';
$labels['messagepart'] = 'Abschnitt';
$labels['digitalsig'] = 'Digitale Signatur';
$labels['dateformat'] = 'Datumsformat';
$labels['timeformat'] = 'Zeitformat';
$labels['prettydate'] = 'Kurze Datumsanzeige';
$labels['setdefault'] = 'Als Standard';
$labels['autodetect'] = 'Automatisch';
$labels['language'] = 'Sprache';
$labels['timezone'] = 'Zeitzone';
$labels['pagesize'] = 'Einträge pro Seite';
$labels['signature'] = 'Signatur';
$labels['dstactive'] = 'Sommerzeit';
$labels['showinextwin'] = 'Nachrichten in neuem Fenster öffnen';
$labels['composeextwin'] = 'Nachrichten in neuem Fenster verfassen';
$labels['htmleditor'] = 'HTML-Nachrichten verfassen';
$labels['htmlonreply'] = 'nur Antworten auf HTML-Nachrichten';
$labels['htmlonreplyandforward'] = 'Antworten oder Weiterleiten einer HTML-Nachricht';
$labels['htmlsignature'] = 'HTML-Signatur';
$labels['showemail'] = 'E-Mail-Adresse und Namen anzeigen';
$labels['previewpane'] = 'Nachrichtenvorschau anzeigen';
$labels['skin'] = 'Oberflächendesign';
$labels['logoutclear'] = 'Papierkorb beim Abmelden leeren';
$labels['logoutcompact'] = 'Posteingang beim Abmelden packen';
$labels['uisettings'] = 'Benutzeroberfläche';
$labels['serversettings'] = 'Server-Einstellungen';
$labels['mailboxview'] = 'Mailbox-Ansicht';
$labels['mdnrequests'] = 'Empfangsbestätigung senden';
$labels['askuser'] = 'immer fragen';
$labels['autosend'] = 'automatisch senden';
$labels['autosendknown'] = 'für bekannte Absender, sonst fragen';
$labels['autosendknownignore'] = 'für bekannte Absender, sonst ignorieren';
$labels['autosendtrusted'] = 'Bestätigung an vertrauenswürdige Absender senden, sonst nachfragen';
$labels['autosendtrustedignore'] = 'Bestätigung an vertrauenswürdige Absender senden, sonst ignorieren';
$labels['ignorerequest'] = 'Anfrage ignorieren';
$labels['readwhendeleted'] = 'Beim Löschen als gelesen markieren';
$labels['flagfordeletion'] = 'Als gelöscht markieren anstatt in den Papierkorb verschieben';
$labels['skipdeleted'] = 'Zeige keine gelöschten Nachrichten an';
$labels['deletealways'] = 'Löschen wenn Verschieben in den Papierkorb nicht möglich';
$labels['deletejunk'] = 'Nachrichten in Spam direkt löschen';
$labels['showremoteimages'] = 'Eingebettete Bilder vom Internet laden';
$labels['allowremoteresources'] = 'Externe Ressourcen erlauben (Bilder, Styles)';
$labels['fromknownsenders'] = 'bei bekannten Absendern';
$labels['fromtrustedsenders'] = 'von vertrauenswürdigen Absendern';
$labels['frommycontacts'] = 'aus meinen Kontakten';
$labels['always'] = 'immer';
$labels['alwaysbutplain'] = 'immer, ausser beim Antworten auf Klartext';
$labels['showinlineimages'] = 'Angehängte Bilder unter der Nachricht anzeigen';
$labels['autosavedraft'] = 'Entwurf autom. speichern';
$labels['everynminutes'] = '$n Minute(n)';
$labels['refreshinterval'] = 'Refresh (auf neue Nachrichten prüfen, etc.)';
$labels['never'] = 'nie';
$labels['immediately'] = 'sofort';
$labels['messagesdisplaying'] = 'Nachrichtendarstellung';
$labels['messagescomposition'] = 'Nachrichtenerstellung';
$labels['mimeparamfolding'] = 'Namen der Dateianhänge';
$labels['2231folding'] = 'Vollständig RFC 2231 kompatibel (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 kompatibel (Microsoft Outlook)';
$labels['2047folding'] = 'Vollständig RFC 2047 kompatibel (andere)';
$labels['force7bit'] = 'MIME-Kodierung für 8-bit Zeichen';
$labels['savelocalstorage'] = "Im Browser speichern (temporär)";
$labels['advancedoptions'] = 'Erweiterte Einstellungen';
$labels['toggleadvancedoptions'] = 'Erweiterte Einstellungen ein-/ausblenden';
$labels['focusonnewmessage'] = 'Fokussiere Browserfenster bei neuen Nachrichten';
$labels['checkallfolders'] = 'Alle Ordner auf neue Nachrichten prüfen';
$labels['displaynext'] = 'Nach Verschieben/Löschen den nächsten Listeneintrag anzeigen';
$labels['defaultfont'] = 'Standardschrift in HTML-Nachrichten';
$labels['mainoptions'] = 'Allgemein';
$labels['browseroptions'] = 'Browsereinstellungen';
$labels['section'] = 'Bereich';
$labels['maintenance'] = 'Wartung';
$labels['newmessage'] = 'Neue Nachrichten';
$labels['signatureoptions'] = 'Signatur';
$labels['whenreplying'] = 'Beantworten einer Nachricht';
$labels['replyempty'] = 'Antwort ohne Zitat der Originalnachricht';
$labels['replytopposting'] = 'Antwort über der Originalnachricht';
$labels['replytoppostingnoindent'] = 'Antwort über der Originalnachricht (ohne Einrückung)';
$labels['replybottomposting'] = 'Antwort unter der Originalnachricht';
$labels['replyremovesignature'] = 'Beim Antworten die Signatur der Originalnachricht entfernen';
$labels['autoaddsignature'] = 'Signatur automatisch einfügen';
$labels['newmessageonly'] = 'nur bei neuen Nachrichten';
$labels['replyandforwardonly'] = 'nur bei Antworten und Weiterleitungen';
$labels['insertsignature'] = 'Signatur einfügen';
$labels['sigbelow'] = 'Signatur unter der zitierten Nachricht platzieren';
$labels['sigseparator'] = 'Standardtrennzeichen in Signaturen erzwingen';
$labels['automarkread'] = 'Nachrichten als gelesen markieren';
$labels['afternseconds'] = 'nach $n Sekunden';
$labels['reqmdn'] = 'Empfangsbestätigung (MSN) immer anfordern';
$labels['reqdsn'] = 'Übermittlungsbestätigung (DSN) immer anfordern';
$labels['replysamefolder'] = 'Antworten im selben Ordner wie Original speichern';
$labels['defaultabook'] = 'Standard-Adressbuch';
$labels['autocompletesingle'] = 'Keine alternativen E-Mail-Adressen in Autovervollständigung';
$labels['listnamedisplay'] = 'Kontakte auflisten als';
$labels['contactformmode'] = 'Formularmodus';
$labels['privatemode'] = 'Privat (Home)';
$labels['businessmode'] = 'Geschäftlich (Work)';
$labels['collectedaddresses'] = 'Gesammelte Adressen';
$labels['collectedrecipients'] = 'Gesammelte Empfänger';
$labels['collectedrecipientsopt'] = 'Empfänger gesendeter Nachrichten speichern in';
$labels['collectedsendersopt'] = ' Vertrauenswürdige Absender speichern in';
$labels['trustedsenders'] = ' Vertrauenswürdige Absender';
$labels['spellcheckbeforesend'] = 'Rechtscheibung vor dem Senden prüfen';
$labels['spellcheckoptions'] = 'Rechtschreibprüfungsoptionen';
$labels['spellcheckignoresyms'] = 'Wörter mit Symbolen überspringen';
$labels['spellcheckignorenums'] = 'Wörter mit Ziffern überspringen';
$labels['spellcheckignorecaps'] = 'Wörter überspringen, die nur aus Grossbuchstaben bestehen';
$labels['addtodict'] = 'Zum Wörterbuch hinzufügen';
$labels['mailtoprotohandler'] = 'Als Empfänger für mailto: Links einrichten';
$labels['standardwindows'] = 'Popups als normale Browserfenster öffnen';
$labels['forwardmode'] = 'Weiterleiten einer Nachricht';
$labels['inline'] = 'eingebettet';
$labels['asattachment'] = 'als Anhang';
$labels['replyallmode'] = 'Standard Funktion für [Allen antworten]';
$labels['replyalldefault'] = 'Allen antworten';
$labels['replyalllist'] = 'Nur der Mailing-Liste antworten (falls vorhanden)';
$labels['folder'] = 'Ordner';
$labels['folders'] = 'Ordner';
$labels['foldername'] = 'Ordnername';
$labels['subscribed'] = 'Abonniert';
$labels['messagecount'] = 'Nachrichten';
$labels['create'] = 'Erstellen';
$labels['createfolder'] = 'Neuen Ordner erstellen';
$labels['managefolders'] = 'Ordner verwalten';
$labels['specialfolders'] = 'Spezialordner';
$labels['properties'] = 'Eigenschaften';
$labels['folderproperties'] = 'Ordnereigenschaften';
$labels['parentfolder'] = 'Eltern';
$labels['location'] = 'Speicherort';
$labels['info'] = 'Informationen';
$labels['getfoldersize'] = 'Ordnergrösse anzeigen';
$labels['changesubscription'] = 'Abonnieren';
$labels['foldertype'] = 'Ordnertyp';
$labels['personalfolder'] = 'Privater Ordner';
$labels['otherfolder'] = 'Order eines anderen Benutzers';
$labels['sharedfolder'] = 'Öffentlicher Ordner';
$labels['findfolders'] = 'Ordner suchen';
$labels['findcontacts'] = 'Kontakte durchsuchen';
$labels['findmail'] = 'Nachrichten durchsuchen';
$labels['namespace.personal'] = 'Persönlich';
$labels['namespace.other'] = 'Andere Benutzer';
$labels['namespace.shared'] = 'Freigegeben';
$labels['dualuselabel'] = 'Enthält ausschliesslich';
$labels['dualusemail'] = 'Nachrichten';
$labels['dualusefolder'] = 'Ordner';
$labels['generate'] = 'Generieren';
$labels['encryptioncreatekey'] = 'Neues Schlüsselpaar erstellen';
$labels['openmailvelopesettings'] = 'Mailvelope-Einstellungen öffnen';
$labels['encryptionprivkeysinmailvelope'] = 'Für diesen Absender sind $nr private Schlüssel in Ihrem Mailvelope Schlüsselbund gespeichert:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Für diesen Absender existiert noch kein PGP Schlüsselpaar in Ihrem Mailvelope Schlüsselbund. Möchten Sie jetzt eines erstellen, um E-Mail-Verschlüsselung zu ermöglichen?';
$labels['encryption'] = 'Verschlüsselung';
$labels['mailvelopeoptions'] = 'Mailvelope-Optionen';
$labels['mailvelopemainkeyring'] = 'Mailvelope-Hauptschlüsselbund verwenden';
$labels['mailvelopenotfound'] = 'Die Mailvelope-Erweiterung ist in Ihrem Browser nicht aktiviert/installiert.';
$labels['sortby'] = 'Sortieren nach';
$labels['sortasc'] = 'aufsteigend sortieren';
$labels['sortdesc'] = 'absteigend sortieren';
$labels['undo'] = 'Rückgängig';
$labels['installedplugins'] = 'Installierte Plugins';
$labels['plugin'] = 'Plugin';
$labels['version'] = 'Version';
$labels['source'] = 'Quellcode';
$labels['destination'] = 'Ziel';
$labels['license'] = 'Lizenz';
$labels['support'] = 'Support';
$labels['savedsearches'] = 'Gespeicherte Suchen';
$labels['dateformatY'] = 'JJJJ';
$labels['dateformaty'] = 'JJ';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'TT';
$labels['dateformatj'] = 'T';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Englisch';
$labels['westerneuropean'] = 'Westeuropäisch';
$labels['easterneuropean'] = 'Osteuropäisch';
$labels['southeasterneuropean'] = 'Südosteuropäisch';
$labels['baltic'] = 'Baltisch';
$labels['cyrillic'] = 'Kyrillisch';
$labels['arabic'] = 'Arabisch';
$labels['greek'] = 'Griechisch';
$labels['hebrew'] = 'Hebräisch';
$labels['turkish'] = 'Türkisch';
$labels['nordic'] = 'Skandinavisch';
$labels['thai'] = 'Thailändisch';
$labels['celtic'] = 'Keltisch';
$labels['vietnamese'] = 'Vietnamesisch';
$labels['japanese'] = 'Japanisch';
$labels['korean'] = 'Koreanisch';
$labels['chinese'] = 'Chinesisch';
$labels['arialabeltopnav'] = 'Fensterkontrolle';
$labels['arialabeltasknav'] = 'Anwendungsbereiche';
$labels['arialabeltoolbar'] = 'Funktionsleiste';
$labels['arialabellistnav'] = 'Listen-Navigation';
$labels['arialabelactivetask'] = 'Aktive Anwendung';
$labels['arialabelmessagessearchfilter'] = 'Nachrichtenfilter';
$labels['arialabelmailsearchform'] = 'Nachrichtensuche';
$labels['arialabelcontactsearchform'] = 'Kontaktsuche';
$labels['arialabelmailquicksearchbox'] = 'Nachrichten-Sucheingabe';
$labels['arialabelquicksearchbox'] = 'Sucheingabe';
$labels['arialabelfoldersearchfilter'] = 'Ordnerfilter';
$labels['arialabelfoldersearchform'] = 'Ordnersuche';
$labels['arialabelfolderlist'] = 'Ordner-Auswahl';
$labels['arialabelmessagelist'] = 'Nachrichtenliste';
$labels['arialabelmailpreviewframe'] = 'Nachrichtenvorschau';
$labels['arialabelmailboxmenu'] = 'Ordneraktionen-Menü';
$labels['arialabellistselectmenu'] = 'Nachrichtenauswahl-Menü';
$labels['arialabelthreadselectmenu'] = 'Konversationsauswahl-Menü';
$labels['arialabelmessagelistoptions'] = 'Einstellungen zur Nachrichten-Anzeige und -sortierung';
$labels['arialabelmailimportdialog'] = 'Nachrichten-Import Dialog';
$labels['arialabelmessagenav'] = 'Nachrichten-Navigation';
$labels['arialabelmessagebody'] = 'Nachrichtentext';
$labels['arialabelmessageactions'] = 'Nachrichten-Aktionen';
$labels['arialabelcontactquicksearch'] = 'Kontaktsuche';
$labels['arialabelcontactsearchbox'] = 'Sucheingabe';
$labels['arialabelmessageheaders'] = 'Nachrichten-Kopfzeilen';
$labels['arialabelforwardingoptions'] = 'Weiterleitungsoptionen';
$labels['arialabelreplyalloptions'] = 'Beantwortungsoptionen';
$labels['arialabelmoremessageactions'] = 'Weitere Nachricht-Aktionen';
$labels['arialabelmorecontactactions'] = 'Weitere Kontakt-Aktionen';
$labels['arialabelmarkmessagesas'] = 'Ausgewählte Nachrichten markieren als...';
$labels['arialabelcomposeoptions'] = 'Nachrichten-Verfassungs-Optionen';
$labels['arialabelresponsesmenu'] = 'Gespeicherte Antworten Menü';
$labels['arialabelattachmentuploadform'] = 'Anhang hochladen (Dateiauswahl)';
$labels['arialabelattachmentmenu'] = 'Anhangsoptionen';
$labels['arialabelmailtomenu'] = 'Optionen für E-Mail-Adressen';
$labels['arialabelattachmentpreview'] = 'Dateivorschau';
$labels['ariasummarycomposecontacts'] = 'Kontakte und Adressgruppen zur Auswahl als Empfänger';
$labels['arialabelcontactexportoptions'] = 'Export-Optionen';
$labels['arialabelabookgroupoptions'] = 'Adressbuch/Adressgruppen-Optionen';
$labels['arialabelpreferencesform'] = 'Einstellungen (Formular)';
$labels['arialabelidentityeditfrom'] = 'Absender bearbeiten (Formular)';
$labels['arialabelresponseeditfrom'] = 'Antwort bearbeiten (Formular)';
$labels['arialabelsearchterms'] = 'Suchbegriffe';
$labels['arialabeldropactionmenu'] = 'Drag & Drop Aktionsmenü';
$labels['arialabelheadersmenu'] = 'Menü zum Hinzufügen von Empfängern (Kopfzeile) ';
$labels['arialabelimagetools'] = 'Bildwerkzeuge';
$labels['helplistnavigation'] = 'Tastatur-Navigation in der Liste';
$labels['helplistkeyboardnavigation'] = "Pfeiltasten Auf/Ab: Bewege Zeilenauswahl/Fokus.
Leertaste: Fokussierte Zeile auswählen.
Shift + Auf/Ab: Zeile darüber/darunter auswählen.
Ctrl + Leertaste: Fokussierte Zeile der Auswahl hinzufügen/entfernen.";
$labels['helplistkeyboardnavmessages'] = "Pfeiltasten Rechts/Links: Konversation auf-/zuklappen.
Eingabe: Ausgewählte/fokussierte Nachricht öffnen.
Löschen: Ausgewählte Nachricht in den Papierkorb verschieben resp. löschen.";
$labels['helplistkeyboardnavcontacts'] = "Eingabe: Ausgewählten Kontakt öffnen.";
