<?php

/*
 +-----------------------------------------------------------------------+
 | language/pl_PL/csv2vcard.inc                                          |
 |                                                                       |
 | Language file of the Roundcube Webmail client                         |
 | Copyright (C) 2005-2012, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Aleksander Machniak <alec@alec.pl>                            |
 +-----------------------------------------------------------------------+
*/
$map = array();
$map['anniversary'] = "Rocznica";
$map['assistants_name'] = "Asystent";
$map['assistants_phone'] = "Telefon asystenta";
$map['birthday'] = "Urodziny";
$map['business_city'] = "Miasto (biuro)";
$map['business_countryregion'] = "Kraj/region (biuro)";
$map['business_fax'] = "Faks służbowy";
$map['business_phone'] = "Telefon służbowy";
$map['business_phone_2'] = "Telefon służbowy 2";
$map['business_postal_code'] = "Kod pocztowy (biuro)";
$map['business_state'] = "Województwo (biuro)";
$map['business_street'] = "Ulica (biuro)";
$map['categories'] = "Kategorie";
$map['company'] = "Firma";
$map['department'] = "Oddział";
$map['email_address'] = "Adres e-mail";
$map['first_name'] = "Imię";
$map['gender'] = "Płeć";
$map['home_city'] = "Miasto (dom)";
$map['home_countryregion'] = "Kraj/region (dom)";
$map['home_fax'] = "Faks domowy";
$map['home_phone'] = "Telefon domowy";
$map['home_phone_2'] = "Home Phone 2";
$map['home_postal_code'] = "Kod pocztowy (dom)";
$map['home_state'] = "Województwo (dom)";
$map['home_street'] = "Ulica (dom)";
$map['job_title'] = "Stanowisko";
$map['last_name'] = "Nazwisko";
$map['managers_name'] = "Menadżer";
$map['middle_name'] = "Drugie imię";
$map['mobile_phone'] = "Telefon komórkowy";
$map['notes'] = "Notatki";
$map['pager'] = "Pager";
$map['primary_phone'] = "Telefon główny";
$map['title'] = "Tytuł";
$map['web_page'] = "Osobista strona sieci Web";
$map['nickname'] = "Przydomek";
