<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Berbagi';
$labels['myrights'] = 'Hak Akses';
$labels['username'] = 'Pengguna:';
$labels['advanced'] = 'Mode Lanjut';
$labels['add'] = 'Tambah';
$labels['newuser'] = 'Tambahkan entri';
$labels['editperms'] = 'Ubah izin';
$labels['actions'] = 'Aksi hak akses...';
$labels['anyone'] = 'Semua pengguna (siapa saja)';
$labels['anonymous'] = 'Para tamu (anonim)';
$labels['identifier'] = 'Yang mengidentifikasi';
$labels['acll'] = 'Cari';
$labels['aclr'] = 'Baca pesan';
$labels['acls'] = 'Jaga status terbaca';
$labels['aclw'] = 'Membuat tanda';
$labels['acli'] = 'Sisipkan (Salin kedalam)';
$labels['aclp'] = 'Tulisan';
$labels['aclc'] = 'Buat subfolder';
$labels['aclk'] = 'Buat subfolder';
$labels['acld'] = 'Hapus pesan';
$labels['aclt'] = 'Hapus pesan';
$labels['acle'] = 'Menghapus';
$labels['aclx'] = 'Hapus folder';
$labels['acla'] = 'Kelola';
$labels['acln'] = 'Berikan keterangan pesan';
$labels['aclfull'] = 'Kendali penuh';
$labels['aclother'] = 'Lainnya';
$labels['aclread'] = 'Baca';
$labels['aclwrite'] = 'Tulis';
$labels['acldelete'] = 'Hapus';
$labels['shortacll'] = 'Cari';
$labels['shortaclr'] = 'Baca';
$labels['shortacls'] = 'Simpan';
$labels['shortaclw'] = 'Tulis';
$labels['shortacli'] = 'Sisipkan';
$labels['shortaclp'] = 'Tulisan';
$labels['shortaclc'] = 'Buat';
$labels['shortaclk'] = 'Buat';
$labels['shortacld'] = 'Hapus';
$labels['shortaclt'] = 'Hapus';
$labels['shortacle'] = 'Buang';
$labels['shortaclx'] = 'Hapus folder';
$labels['shortacla'] = 'Kelola';
$labels['shortacln'] = 'Berikan keterangan';
$labels['shortaclother'] = 'Lainnya';
$labels['shortaclread'] = 'Baca';
$labels['shortaclwrite'] = 'Tulis';
$labels['shortacldelete'] = 'Hapus';
$labels['longacll'] = 'Folder terlihat di daftar dan dapat dijadikan langganan';
$labels['longaclr'] = 'Folder dapat dibuka untuk dibaca';
$labels['longacls'] = 'Tanda pesan terbaca dapat diubah';
$labels['longaclw'] = 'Tanda pesan dan kata kunci dapat diubah, kecuali Terbaca dan Terhapus';
$labels['longacli'] = 'Pesan dapat ditulis atau disalin kedalam folder';
$labels['longaclp'] = 'Pesan dapat dikirim ke folder ini';
$labels['longaclc'] = 'Folder dapat dibuat (atau diubah namanya) langsung dari folder ini';
$labels['longaclk'] = 'Folder dapat dibuat (atau diubah namanya) langsung dari folder ini';
$labels['longacld'] = 'Tanda hapus pesan dapat diubah';
$labels['longaclt'] = 'Tanda hapus pesan dapat diubah';
$labels['longacle'] = 'Pesan dapat dibuang';
$labels['longaclx'] = 'Folder dapat dihapus atau diubah namanya';
$labels['longacla'] = 'Hak akses folder dapat diubah';
$labels['longacln'] = 'Metadata pesan bersama (penjelasan) dapat diubah';
$labels['longaclfull'] = 'Kendali penuh penuh termasuk administrasi';
$labels['longaclread'] = 'Folder dapat dibuka untuk dibaca';
$labels['longaclwrite'] = 'Pesan dapat ditandai, ditulis atau disalin kedalam folder';
$labels['longacldelete'] = 'Pesan dapat dihapus';
$labels['longaclother'] = 'Hak akses lainnya';
$labels['ariasummaryacltable'] = 'Daftar hak akses';
$labels['arialabelaclactions'] = 'Aksi daftar';
$labels['arialabelaclform'] = 'Formulir hak akses';
$messages['deleting'] = 'Menghapus hak akses...';
$messages['saving'] = 'Menyimpan hak akses...';
$messages['updatesuccess'] = 'Hak akses berhasil diubah';
$messages['deletesuccess'] = 'Hak akses berhasil dihapus';
$messages['createsuccess'] = 'Hak akses berhasil ditambahkan';
$messages['updateerror'] = 'Tidak dapat memperbaharui hak akses';
$messages['deleteerror'] = 'Tidak dapat menghapus hak akses';
$messages['createerror'] = 'Tidak dapat menambah hak akses';
$messages['deleteconfirm'] = 'Apakah Anda yakin ingin menghapus hak akses dari user terpilih?';
$messages['norights'] = 'Hak belum ditentukan!';
$messages['nouser'] = 'Username belum ditentukan!';
