<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Paylaşım';
$labels['myrights'] = 'Erişim İzinleri';
$labels['username'] = 'Kullanıcı:';
$labels['advanced'] = 'Gelişmiş kip';
$labels['add'] = 'Ekle';
$labels['newuser'] = 'Kayıt ekle';
$labels['editperms'] = 'İzinleri düzenle';
$labels['actions'] = 'Erişim izinleri işlemleri...';
$labels['anyone'] = 'Tüm kullanıcılar (kim olursa)';
$labels['anonymous'] = 'Ziyaretçiler (isimsiz)';
$labels['identifier'] = 'Tanımlayıcı';
$labels['acll'] = 'Arama';
$labels['aclr'] = 'İletileri oku';
$labels['acls'] = 'Okundu durumu korunsun';
$labels['aclw'] = 'Yazma işaretleri';
$labels['acli'] = 'Ekle (kopyala)';
$labels['aclp'] = 'Gönder';
$labels['aclc'] = 'Alt klasörler ekle';
$labels['aclk'] = 'Alt klasörler ekle';
$labels['acld'] = 'İletileri sil';
$labels['aclt'] = 'İletileri sil';
$labels['acle'] = 'Sil';
$labels['aclx'] = 'Klasörü sil';
$labels['acla'] = 'Yönet';
$labels['acln'] = 'İletilere not ekle';
$labels['aclfull'] = 'Tam denetim';
$labels['aclother'] = 'Diğer';
$labels['aclread'] = 'Oku';
$labels['aclwrite'] = 'Yaz';
$labels['acldelete'] = 'Sil';
$labels['shortacll'] = 'Arama';
$labels['shortaclr'] = 'Oku';
$labels['shortacls'] = 'Koru';
$labels['shortaclw'] = 'Yaz';
$labels['shortacli'] = 'Ekle';
$labels['shortaclp'] = 'Gönder';
$labels['shortaclc'] = 'Ekle';
$labels['shortaclk'] = 'Ekle';
$labels['shortacld'] = 'Sil';
$labels['shortaclt'] = 'Sil';
$labels['shortacle'] = 'Sil';
$labels['shortaclx'] = 'Klasörü sil';
$labels['shortacla'] = 'Yönet';
$labels['shortacln'] = 'Not ekle';
$labels['shortaclother'] = 'Diğer';
$labels['shortaclread'] = 'Oku';
$labels['shortaclwrite'] = 'Yaz';
$labels['shortacldelete'] = 'Sil';
$labels['longacll'] = 'Klasör listesinde görülebilir ve abone olunabilir';
$labels['longaclr'] = 'Klasör okunmak üzere açılabilir';
$labels['longacls'] = 'İletilerin Okundu işareti değiştirilebilir';
$labels['longaclw'] = 'Okundu ve Silindi işaretleri dışındaki işaret ve anahtar sözcükler değiştirilebilir';
$labels['longacli'] = 'Klasöre iletiler yazılabilir ya da kopyalanabilir';
$labels['longaclp'] = 'İletiler bu klasöre gönderilebilir';
$labels['longaclc'] = 'Klasörler doğrudan bu klasör altına eklenebilir (ya da yeniden adlandırılabilir).';
$labels['longaclk'] = 'Klasörler doğrudan bu klasör altına eklenebilir (ya da yeniden adlandırılabilir).';
$labels['longacld'] = 'İleti Silindi işareti değiştirilebilir';
$labels['longaclt'] = 'İleti Silindi işareti değiştirilebilir';
$labels['longacle'] = 'İletiler silinebilir';
$labels['longaclx'] = 'Klasör silinebilir ya da yeniden adlandırılabilir';
$labels['longacla'] = 'Klasör erişim izinleri değiştirilebilir';
$labels['longacln'] = 'İletilerin paylaşılan üst verileri (notlar) değiştirilebilir';
$labels['longaclfull'] = 'Klasör yönetimi dahil tam denetim';
$labels['longaclread'] = 'Klasör okunmak üzere açılabilir';
$labels['longaclwrite'] = 'Klasöre iletiler işaretlenebilir, yazılabilir ya da kopyalanabilir';
$labels['longacldelete'] = 'İletiler silinebilir';
$labels['longaclother'] = 'Diğer erişim izinleri';
$labels['ariasummaryacltable'] = 'Erişim izinleri listesi';
$labels['arialabelaclactions'] = 'İşlem listesi';
$labels['arialabelaclform'] = 'Erişim izinleri formu';
$messages['deleting'] = 'Erişim izinleri siliniyor...';
$messages['saving'] = 'Erişim izinleri kaydediliyor...';
$messages['updatesuccess'] = 'Erişim izinleri değiştirildi';
$messages['deletesuccess'] = 'Erişim izinleri silindi';
$messages['createsuccess'] = 'Erişim izinleri eklendi';
$messages['updateerror'] = 'Erişim izinleri güncellenemedi';
$messages['deleteerror'] = 'Erişim izinleri silinemedi';
$messages['createerror'] = 'Erişim izinleri eklenemedi';
$messages['deleteconfirm'] = 'Seçilmiş kullanıcılar için erişim izinlerini silmek istediğinize emin misiniz?';
$messages['norights'] = 'Herhangi bir izin belirtilmemiş!';
$messages['nouser'] = 'Herhangi bir kullanıcı belirtilmemiş!';
