<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Wystąpił błąd!';
$messages['loginfailed']  = 'Błąd logowania!';
$messages['cookiesdisabled'] = 'Twoja przeglądarka nie obsługuje ciasteczek!';
$messages['sessionerror'] = 'Błąd sesji bądź sesja wygasła!';
$messages['cookiesmismatch'] = 'Niezgodność ciasteczek. Proszę usunąć ciasteczka zapisane w przeglądarce.';
$messages['storageerror'] = 'Błąd połączenia z serwerem!';
$messages['servererror'] = 'Błąd serwera!';
$messages['servererrormsg'] = 'Błąd serwera: $msg';
$messages['accountlocked'] = 'Przekroczono maksymalną dozwoloną liczbę prób logowania. Proszę spróbować później.';
$messages['connerror'] = 'Błąd połączenia (brak odpowiedzi serwera)!';
$messages['dberror'] = 'Błąd bazy danych!';
$messages['dbconnerror'] = 'Nie można nawiązać połączenia z bazą danych!';
$messages['windowopenerror'] = 'Wyskakujące okno zostało zablokowane!';
$messages['requesttimedout'] = 'Upłynął limit czasu żądania';
$messages['errorreadonly'] = 'Nie można wykonać operacji. Folder tylko do odczytu.';
$messages['errornoperm'] = 'Nie można wykonać operacji. Brak uprawnień.';
$messages['erroroverquota'] = 'Nie można wykonać operacji. Brak miejsca na dysku.';
$messages['erroroverquotadelete'] = 'Brak miejsca na dysku. Użyj SHIFT+DEL aby usunąć wiadomość.';
$messages['invalidrequest'] = 'Błędne żądanie! Nie zapisano danych.';
$messages['invalidhost'] = 'Błędna nazwa serwera.';
$messages['nomessagesfound'] = 'Brak wiadomości w skrzynce.';
$messages['loggedout'] = 'Sesja została zakończona poprawnie. Do widzenia!';
$messages['mailboxempty'] = 'Folder jest pusty';
$messages['nomessages'] = 'Brak wiadomości';
$messages['refreshing'] = 'Odświeżanie...';
$messages['loading'] = 'Ładowanie...';
$messages['uploading'] = 'Zapisywanie pliku...';
$messages['attaching'] = 'Dołączanie pliku...';
$messages['uploadingmany'] = 'Zapisywanie plików...';
$messages['loadingdata'] = 'Ładowanie danych...';
$messages['checkingmail'] = 'Sprawdzanie nowych wiadomości...';
$messages['sendingmessage'] = 'Wysyłanie wiadomości...';
$messages['messagesent'] = 'Wiadomość została wysłana.';
$messages['savingmessage'] = 'Zapisywanie wiadomości...';
$messages['messagesaved'] = 'Wiadomość została zapisana w folderze Kopie robocze.';
$messages['successfullysaved'] = 'Zapisano pomyślnie.';
$messages['savingresponse'] = 'Zapisywanie tekstu odpowiedzi...';
$messages['deleteresponseconfirm'] = 'Czy na pewno chcesz usunąć tą odpowiedź?';
$messages['nocontactselected'] = 'Nie wybrałeś jeszcze kontaktu.';
$messages['addedsuccessfully'] = 'Kontakt został dodany.';
$messages['contactexists'] = 'Kontakt o podanym adresie e-mail już istnieje!';
$messages['contactnameexists'] = 'Kontakt z podaną nazwą już istnieje!';
$messages['blockedimages'] = 'Ze względów bezpieczeństwa zewnętrzne obrazki zostały zablokowane.';
$messages['blockedresources'] = 'W celu ochrony prywatności zablokowano zdalne zasoby.';
$messages['suspiciousemail'] = 'Ta wiadomość może być próbą oszustwa, gdyż zawiera podejrzane adresy email.';
$messages['bccemail'] = 'Przekazywane wiadomości zawierają poufnych odbiorców (Bcc).';
$messages['bouncehint'] = 'Wiadomość zostanie wysłana bez żadnych modyfikacji, tzn. przy użyciu oryginalnej treści, nagłówków i odbiorców.';
$messages['encryptedmessage'] = 'Przepraszamy, nie można wyświetlić zaszyfrowanej wiadomości!';
$messages['externalmessagedecryption'] = 'Ta wiadomość jest zaszyfrowana i może zostać odszyfrowana za pomocą rozszerzenia przeglądarki.';
$messages['nopubkeyfor'] = 'Nie znaleziono klucza publicznego dla $email';
$messages['nopubkeyforsender'] = 'Nie znaleziono klucza publicznego dla używanej tożsamości. Czy chcesz zaszyfrować wiadomość tylko dla adresatów?';
$messages['encryptnoattachments'] = 'Załączniki, które zostały poprzednio przesłane na serwer nie mogą zostać zaszyfrowane. Należy przesłać je ponownie poprzez dodanie do edytora szyfrowania.';
$messages['searchpubkeyservers'] = 'Czy wyszukać brakujące klucze na serwerach kluczy?';
$messages['encryptpubkeysfound'] = 'Znaleziono następujące klucze:';
$messages['keyservererror'] = 'Pobieranie klucza z serwera nie powiodło się.';
$messages['keyimportsuccess'] = 'Klucz $key został pomyślnie zaimportowany do bazy kluczy.';
$messages['nocontactsfound'] = 'Nie znaleziono kontaktu!';
$messages['contactnotfound'] = 'Szukany kontakt nie został odnaleziony.';
$messages['contactsearchonly'] = 'Dostęp do kontaktów z wybranej książki adresowej możliwy jedynie poprzez formularz wyszukiwania.';
$messages['sendingfailed'] = 'Nie udało się wysłać wiadomości!';
$messages['senttooquickly'] = 'Musisz poczekać $sec sek. aby móc wysłać tą wiadomość!';
$messages['errorsavingsent'] = 'Wystąpił błąd podczas zapisu wysłanej wiadomości!';
$messages['errorsaving'] = 'Wystąpił błąd podczas zapisu!';
$messages['errormoving'] = 'Nie można przenieść wiadomości!';
$messages['errorcopying'] = 'Nie można skopiować wiadomości!';
$messages['errordeleting'] = 'Nie można usunąć wiadomości!';
$messages['errormarking'] = 'Nie można oznaczyć wiadomości!';
$messages['alerttitle'] = 'Uwaga';
$messages['confirmationtitle'] = 'Czy jesteś pewien...';
$messages['deletecontactconfirm']  = 'Czy na pewno chcesz usunąć wybrane kontakty?';
$messages['deletegroupconfirm']  = 'Czy na pewno chcesz usunąć wybraną grupę?';
$messages['deletemessagesconfirm'] = 'Czy na pewno chcesz usunąć wybrane wiadomości?';
$messages['deletefolderconfirm']  = 'Czy na pewno chcesz usunąć wybrany folder?';
$messages['movefolderconfirm']  = 'Czy na pewno chcesz przenieść ten folder?';
$messages['purgefolderconfirm']  = 'Czy na pewno chcesz usunąć wszystkie wiadomości w tym folderze?';
$messages['contactdeleting'] = 'Usuwanie kontaktów...';
$messages['groupdeleting'] = 'Usuwanie grupy...';
$messages['folderdeleting'] = 'Usuwanie folderu...';
$messages['foldermoving'] = 'Przenoszenie folderu...';
$messages['foldersubscribing'] = 'Subskrybowanie folderu...';
$messages['folderunsubscribing'] = 'Odsubskrybowanie folderu...';
$messages['formincomplete'] = 'Uzupełnij formularz!';
$messages['noemailwarning'] = 'Podaj poprawny adres e-mail!';
$messages['nonamewarning']  = 'Podaj nazwę!';
$messages['nopagesizewarning'] = 'Podaj poprawną wartość!';
$messages['nosenderwarning'] = 'Podaj adres e-mail nadawcy!';
$messages['recipientsadded'] = 'Odbiorcy zostali dodani pomyślnie.';
$messages['norecipientwarning'] = 'Podaj co najmniej jednego odbiorcę!';
$messages['disclosedrecipwarning'] = 'Wszyscy odbiorcy będą widzieć adresy e-mail innych. Aby temu zapobiec i chronić ich prywatność możesz użyć pola Bcc.';
$messages['disclosedreciptitle'] = 'Zbyt wielu publicznych odbiorców';
$messages['nosubjectwarning']  = 'Nie podano tematu wiadomości. Czy chcesz go teraz uzupełnić?';
$messages['nosubjecttitle']  = 'Brak tematu';
$messages['nobodywarning'] = 'Ta wiadomość jest pusta, czy mimo to chcesz ją wysłać?';
$messages['notsentwarning'] = 'Wiadomość została zmieniona i nie została jeszcze wysłana. Czy chcesz porzucić zmiany?';
$messages['restoresavedcomposedata'] = 'Wykryto poprzednio tworzoną ale nie wysłaną wiadomość.\n\nTemat: $subject\nZapisano: $date\n\nCzy przywrócić tą wiadomość?';
$messages['nosearchname'] = 'Podaj nazwę kontaktu lub jego adres e-mail.';
$messages['notuploadedwarning'] = 'Nie wszystkie załączniki zostały pobrane. Poczekaj lub anuluj pobieranie.';
$messages['searchsuccessful'] = 'Liczba znalezionych wiadomości: $nr.';
$messages['contactsearchsuccessful'] = 'Znaleziono $nr kontaktów.';
$messages['searchnomatch'] = 'Nic nie znaleziono.';
$messages['searching'] = 'Wyszukiwanie...';
$messages['checking'] = 'Sprawdzanie...';
$messages['stillsearching'] = 'Dalsze wyszukiwanie...';
$messages['nospellerrors'] = 'Nie znaleziono błędów w pisowni.';
$messages['folderdeleted'] = 'Folder został pomyślnie usunięty.';
$messages['foldersubscribed'] = 'Folder został pomyślnie zasubskrybowany.';
$messages['folderunsubscribed'] = 'Folder został pomyślnie odsubskrybowany.';
$messages['folderpurged'] = 'Folder został pomyślnie opróżniony.';
$messages['folderexpunged'] = 'Folder został pomyślnie uporządkowany.';
$messages['deletedsuccessfully'] = 'Usunięto.';
$messages['converting'] = 'Konwertowanie tekstu...';
$messages['messageopenerror'] = 'Nie udało się pobrać treści wiadomości.';
$messages['filelinkerror'] = 'Dołączanie pliku nie powiodło się.';
$messages['fileuploaderror'] = 'Załączanie pliku nie powiodło się.';
$messages['csvfilemismatch'] = 'Import wielu plików CSV z różnymi definicjami pól nie jest możliwy.';
$messages['filesizeerror'] = 'Plik przekracza maksymalną wielkość $size.';
$messages['filecounterror'] = 'Możesz wysłać tylko $count plików jednocześnie.';
$messages['msgsizeerror'] = 'Załączanie pliku nie powiodło się. Przekroczony maksymalny rozmiar wiadomości ($size).';
$messages['msgsizeerrorfwd'] = 'Maksymalny rozmiar wiadomości ($size) został przekroczony. $num wiadomości nie zostało załączonych.';
$messages['copysuccess'] = 'Pomyślnie skopiowano $nr kontaktów.';
$messages['movesuccess'] = 'Pomyślnie przeniesiono $nr kontaktów.';
$messages['copyerror'] = 'Nie udało się skopiować żadnego kontaktu.';
$messages['moveerror'] = 'Nie udało się przenieść żadnego kontaktu.';
$messages['sourceisreadonly'] = 'Źródło adresu jest tylko do odczytu.';
$messages['errorsavingcontact'] = 'Nie można było zapisać adresu kontaktu.';
$messages['movingmessage'] = 'Przenoszenie wiadomości...';
$messages['copyingmessage'] = 'Kopiowanie wiadomości...';
$messages['copyingcontact'] = 'Kopiowanie kontaktów...';
$messages['movingcontact'] = 'Przenoszenie kontaktów...';
$messages['deletingmessage'] = 'Usuwanie wiadomości...';
$messages['markingmessage'] = 'Oznaczanie wiadomości...';
$messages['addingmember'] = 'Dodawanie kontaktów do grupy...';
$messages['removingmember'] = 'Usuwanie kontaktów z grupy...';
$messages['receiptsent'] = 'Pomyślnie wysłano potwierdzenie dostarczenia.';
$messages['errorsendingreceipt'] = 'Nie można wysłać potwierdzenia.';
$messages['deleteidentityconfirm'] = 'Czy na pewno chcesz usunąć tą tożsamość?';
$messages['nodeletelastidentity'] = 'Nie można skasować tej tożsamości, ponieważ jest ostatnią.';
$messages['forbiddencharacter'] = 'Nazwa folderu zawiera niedozwolony znak.';
$messages['selectimportfile'] = 'Proszę wybrać plik do wysłania.';
$messages['addresswriterror'] = 'Wybrana książka adresowa jest tylko-do-odczytu.';
$messages['contactaddedtogroup'] = 'Kontakty zostały pomyślnie dodane do grupy.';
$messages['contactremovedfromgroup'] = 'Kontakty zostały pomyślnie usunięte z grupy.';
$messages['nogroupassignmentschanged'] = 'Nie zmieniono żadnych powiązań z grupą.';
$messages['importwait'] = 'Importowanie, proszę czekać...';
$messages['importformaterror'] = 'Import nieudany! Użyty plik nie jest poprawnym plikiem importu danych.';
$messages['importconfirm'] = '<b>Pomyślnie dodano $inserted kontaktów.</b>';
$messages['importconfirmskipped'] = '<b>Pominięto $skipped istniejących wpisów.</b>';
$messages['importmessagesuccess'] = 'Pomyślnie zaimportowano następującą liczbę wiadomości: $nr';
$messages['importmessageerror'] = 'Import nieudany! Wgrywany plik nie jest poprawną wiadomością lub plikiem skrzynki pocztowej';
$messages['opnotpermitted'] = 'Niedozwolona operacja!';
$messages['nofromaddress'] = 'Brak adresu e-mail w wybranej tożsamości.';
$messages['editorwarning'] = 'Zmiana typu editora może spowodować utratę formatowania. Czy chcesz kontynuować?';
$messages['httpreceivedencrypterror'] = 'Wystąpił błąd krytyczny. Skontaktuj się z administratorem. <b>Nie można wysłać wiadomości.</b>';
$messages['smtpconnerror'] = 'Błąd SMTP ($code): Nie można nawiązać połączenia z serwerem.';
$messages['smtpautherror'] = 'Błąd SMTP ($code): Uwierzytelnianie nie powiodło się.';
$messages['smtpfromerror'] = 'Błąd SMTP ($code): Nie można ustawić nadawcy "$from" ($msg).';
$messages['smtptoerror'] = 'Błąd SMTP ($code): Nie można dodać odbiorcy "$to" ($msg).';
$messages['smtprecipientserror'] = 'Błąd SMTP: Parsowanie listy odbiorców nie powiodło się.';
$messages['smtputf8error'] = 'Błąd SMTP: Serwer nie obsługuje znaków Unicode w adresach email.';
$messages['smtpsizeerror'] = 'Błąd SMTP: Rozmiar wiadomości przekracza limit ($limit)';
$messages['smtperror'] = 'Błąd SMTP: $msg';
$messages['emailformaterror'] = 'Błędny adres e-mail: $email';
$messages['toomanyrecipients'] = 'Zbyt wielu odbiorców. Zmniejsz ich liczbę do $max.';
$messages['maxgroupmembersreached'] = 'Liczba członków grupy nie może być większa niż $max.';
$messages['internalerror'] = 'Wystąpił wewnętrzny błąd systemu. Spróbuj jeszcze raz.';
$messages['contactdelerror'] = 'Usuwanie kontaktów nie powiodło się.';
$messages['contactdeleted'] = 'Kontakt(y) został(y) usunięte.';
$messages['contactrestoreerror'] = 'Przywracanie kontaktów nie powiodło się.';
$messages['contactrestored'] = 'Kontakt(y) zostały przywrócone.';
$messages['groupdeleted'] = 'Grupa została usunięta.';
$messages['grouprenamed'] = 'Nazwa grupy została zmieniona.';
$messages['groupcreated'] = 'Grupa została utworzona.';
$messages['savedsearchdeleted'] = 'Wyszukiwanie usunięto pomyślnie.';
$messages['savedsearchdeleteerror'] = 'Nie można usunąć wyszukiwania.';
$messages['savedsearchcreated'] = 'Wyszukiwanie zapisano pomyślnie.';
$messages['savedsearchcreateerror'] = 'Nie można zapisać wyszukiwania.';
$messages['messagedeleted'] = 'Wiadomości zostały usunięte.';
$messages['messagemoved'] = 'Wiadomości zostały przeniesione.';
$messages['messagemovedtotrash'] = 'Wiadomości zostały przeniesione do Kosza.';
$messages['messagecopied'] = 'Wiadomości zostały skopiowane.';
$messages['messagemarked'] = 'Wiadomości zostały oznaczone.';
$messages['autocompletechars'] = 'Wprowadź co najmniej $min znak(ów) aby skorzystać z autouzupełniania.';
$messages['autocompletemore'] = 'Znaleziono więcej pasujących wpisów. Wprowadź więcej znaków.';
$messages['namecannotbeempty'] = 'Nazwa nie może być pusta.';
$messages['nametoolong'] = 'Nazwa jest zbyt długa.';
$messages['namedotforbidden'] = 'Nazwa folderu nie może rozpoczynać się od kropki.';
$messages['folderupdated'] = 'Folder został pomyślnie zaktualizowany.';
$messages['foldercreated'] = 'Folder został pomyślnie utworzony.';
$messages['invalidimageformat'] = 'Niepoprawny format obrazka.';
$messages['mispellingsfound'] = 'Wykryto błędy pisowni w tej wiadomości.';
$messages['parentnotwritable'] = 'Nie można utworzyć/przenieść folderu w wybrane miejsce. Brak upranień.';
$messages['messagetoobig'] = 'Ta część wiadomości jest zbyt duża aby ją przetworzyć.';
$messages['attachmentvalidationerror'] = 'UWAGA! Ten załącznik jest podejrzany ponieważ jego typ nie jest zgodny z typem zadeklarownym w wiadomości. Jeśli nie ufasz temu nadawcy nie powinieneś otwierać go w przeglądarce, gdyż może zawierać złośliwe oprogramowanie.<br/><br/><em>Zadeklarowano: $expected; wykryto: $detected</em>';
$messages['noscriptwarning'] = 'Uwaga: Usługa wymaga Javascriptu! Aby z niej skorzystać proszę włączyć obsługę języka Javascript w ustawieniach przeglądarki.';
$messages['messageissent'] = 'Wiadomość została już wysłana, jednak nie została zapisana. Czy chcesz ją zapisać teraz?';
$messages['errnotfound'] = 'Nie znaleziono pliku';
$messages['errnotfoundexplain'] = 'Żądany zasób nie został odnaleziony!';
$messages['errfailedrequest'] = 'Błędne żądanie';
$messages['errauthorizationfailed'] = 'Błąd autoryzacji';
$messages['errunauthorizedexplain'] = 'Nie można zweryfikować czy jesteś upoważniony do dostępu dla tej usługi!';
$messages['errrequestcheckfailed'] = 'Sprawdzanie żądania nie powiodło się';
$messages['errcsrfprotectionexplain'] = "Dla twojego bezpieczeństwa, dostęp do tego zasobu jest zabezpieczony przeciw atakom typu CSRF.\nJeśli widzisz ten komunikat, prawdopodobnie nie wylogowałeś się przed opuszczeniem aplikacji.\n\nTwoje działanie jest wymagane aby kontynuować.";
$messages['errcontactserveradmin'] = 'Skontaktuj się z administratorem serwera.';
$messages['clicktoresumesession'] = 'Kliknij tutaj aby przywrócić poprzednią sesję';
$messages['errcomposesession'] = 'Błąd sesji tworzenia';
$messages['errcomposesessionexplain'] = 'Wywoływana sesja nie została odnaleziona';
$messages['clicktocompose'] = 'Kliknij tutaj aby stworzyć nową wiadomość';
$messages['nosupporterror'] = 'Ta funkcja nie jest obsługiwana w twojej przeglądarce.';
$messages['siginserted'] = 'Podpis został dodany pomyślnie.';
$messages['responseinserted'] = 'Odpowiedź została dodana pomyślnie.';
$messages['noresponsesavailable'] = 'Brak odpowiedzi';
$messages['listempty'] = 'Lista jest pusta.';
$messages['listusebutton'] = 'Aby dodać nowy wpis użyj przycisk Utwórz.';
$messages['keypaircreatesuccess'] = 'Pomyślnie utworzono parę kluczy dla $identity.';
$messages['emptyattachment'] = 'Wybrany załącznik wygląda na pusty.<br>Zweryfikuj to z nadawcą wiadomości.';
$messages['oauthloginfailed'] = 'Nieudane logowanie OAuth, Spróbuj ponownie.';
