<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = '$product ലേയ്ക്ക് സ്വാഗതം';
$labels['username'] = 'ഉപയോക്തൃനാമം';
$labels['password'] = 'രഹസ്യവാക്ക്';
$labels['server'] = 'സേവകന്‍';
$labels['login'] = 'പ്രവേശിക്കുക';
$labels['logout'] = 'പുറത്ത് കടക്കുക';
$labels['mail'] = 'തപാല്‍';
$labels['settings'] = 'ക്രമീകരണങ്ങള്‍';
$labels['addressbook'] = 'വിലാസ പുസ്തകം';
$labels['inbox'] = 'ഇന്‍ബോക്സ്';
$labels['drafts'] = 'പൂര്‍ത്തിയാകാത്തവ';
$labels['sent'] = 'അയച്ചവ';
$labels['trash'] = 'ചവറ്റുകുട്ട';
$labels['junk'] = 'ആവശ്യമില്ലാത്തവ';
$labels['subject'] = 'വിഷയം';
$labels['from'] = 'പ്രേഷിതന്‍';
$labels['sender'] = 'അയചയാള്‍';
$labels['to'] = 'സ്വീകര്‍ത്താവ്';
$labels['date'] = 'തീയതി';
$labels['size'] = 'വലിപ്പം';
$labels['priority'] = 'മുന്‍ഗണന';
$labels['readstatus'] = 'അവസ്ഥ വായിക്കുക';
$labels['mailboxlist'] = 'ഫോള്‍ഡറുകള്‍';
$labels['copy'] = 'പകര്‍ത്തുക';
$labels['move'] = 'നീക്കുക';
$labels['download'] = 'ഡൗണ്‍ലോഡ്';
$labels['showattachment'] = 'പ്രദർശിപ്പിക്കുക';
$labels['filename'] = 'ഫയല്‍ നാമം';
$labels['filesize'] = 'ഫയലിന്റെ വലിപ്പം';
$labels['addtoaddressbook'] = 'മേല്‍വിലാസങ്ങളില്‍ ചേര്‍ക്കുക.';
$labels['sun'] = 'ഞാ';
$labels['mon'] = 'തി';
$labels['tue'] = 'ചൊ';
$labels['wed'] = 'ബു';
$labels['thu'] = 'വ്യാ';
$labels['fri'] = 'വെ';
$labels['sat'] = 'ശ';
$labels['sunday'] = 'ഞായര്‍';
$labels['monday'] = 'തിങ്കള്‍';
$labels['tuesday'] = 'ചൊവ്വ';
$labels['wednesday'] = 'ബുധന്‍';
$labels['thursday'] = 'വ്യാഴം';
$labels['friday'] = 'വെള്ളി';
$labels['saturday'] = 'ശനി';
$labels['jan'] = 'ജനു';
$labels['feb'] = 'ഫെബ്';
$labels['mar'] = 'മാര്‍';
$labels['apr'] = 'ഏപ്ര';
$labels['may'] = 'മെ';
$labels['jun'] = 'ജൂണ്‍';
$labels['jul'] = 'ജൂലൈ';
$labels['aug'] = 'ആഗസ്റ്റ്';
$labels['sep'] = 'സെപ്റ്റംബര്‍';
$labels['oct'] = 'ഒക്ടോബര്‍';
$labels['nov'] = 'നവംബര്‍';
$labels['dec'] = 'ഡിസംബര്‍';
$labels['longjan'] = 'ജനുവരി';
$labels['longfeb'] = 'ഫെബ്രുവരി';
$labels['longmar'] = 'മാര്‍ച്ച്';
$labels['longapr'] = 'ഏപ്രില്‍';
$labels['longmay'] = 'മെ';
$labels['longjun'] = 'ജൂണ്‍';
$labels['longjul'] = 'ജൂലൈ';
$labels['longaug'] = 'ആഗസ്റ്റ്';
$labels['longsep'] = 'സെപ്തംബ‌ര്‍';
$labels['longoct'] = 'ഒക്ടോബര്‍';
$labels['longnov'] = 'നവംബ‌ര്‍';
$labels['longdec'] = 'ഡിസംബ‌ര്‍';
$labels['today'] = 'ഇന്ന്';
$labels['refresh'] = 'പുതുക്കുക';
$labels['checkmail'] = 'പുതിയ സന്ദേശത്തിനായി തിരയുക';
$labels['compose'] = 'രചന';
$labels['reply'] = 'മറുപടി';
$labels['forward'] = 'കൈമാറുക';
$labels['forwardmessage'] = 'സന്ദേശം കൈമാറുക';
$labels['deletemessage'] = 'സന്ദേശം മായ്ക്കുക';
$labels['movemessagetotrash'] = 'സന്ദേശം ചവറ്റുകുട്ടയിലേക്ക് നീക്കുക';
$labels['printmessage'] = 'ഈ സന്ദേശം അച്ചടിക്കുക';
$labels['previousmessage'] = 'മുന്‍പുളള സന്ദേശം കാണിക്കുക.';
$labels['firstmessage'] = 'ആദ്യത്തെ സന്ദേശം കാണിക്കുക.';
$labels['nextmessage'] = 'അടുത്ത സന്ദേശം കാണിക്കുക.';
$labels['lastmessage'] = 'അവസാനത്തെ സന്ദേശം കാണിക്കുക.';
$labels['viewsource'] = 'ഉറവിടം കാണിക്കുക.';
$labels['mark'] = 'അടയാളപ്പെടുത്തു';
$labels['markmessages'] = 'സന്തേശങ്ങള്‍ അടയാളപ്പെടുത്തു';
$labels['markread'] = 'വായിച്ചതായി';
$labels['markunread'] = 'വായിക്കാത്തതായി';
$labels['moreactions'] = 'കൂടുതല്‍ ചെയ്തികള്‍...';
$labels['more'] = 'കൂടുതല്‍';
$labels['back'] = 'പിന്നോട്ട്';
$labels['options'] = 'ഐച്ഛികങ്ങള്‍‌';
$labels['select'] = 'തെരഞ്ഞെടുക്കുക';
$labels['all'] = 'എല്ലാം';
$labels['none'] = 'ഒന്നുമില്ല';
$labels['currpage'] = 'നിലവിലുളള പേജ്';
$labels['isread'] = 'വായിച്ചവ';
$labels['unread'] = 'വായിക്കാത്തത്';
$labels['flagged'] = 'അടയാളപ്പെടുത്തിയവ';
$labels['unanswered'] = 'മറുപടി കൊടുക്കാത്ത';
$labels['deleted'] = 'മായ്ച്ചവ';
$labels['invert'] = 'തലതിരിക്കുക';
$labels['filter'] = 'അരിപ്പ';
$labels['list'] = 'പട്ടിക';
$labels['expand-all'] = 'എല്ലാം വികസിപ്പിക്കുക';
$labels['expand-unread'] = 'വായിക്കാത്തവ വികസിപ്പിക്കുക';
$labels['collapse-all'] = 'എല്ലാം അടയ്ക്കുക';
$labels['fromto'] = 'എവിടുന്ന് /എങ്ങൊട്ടു';
$labels['nonesort'] = 'ഒന്നുമില്ല';
$labels['sentdate'] = 'അയച്ച തീയതി';
$labels['arrival'] = 'വന്ന തീയതി';
$labels['asc'] = 'ആരോഹണം';
$labels['desc'] = 'അവരോഹണം';
$labels['listorder'] = 'തരംതിരിക്കണ്ട രീതി';
$labels['layoutlist'] = 'പട്ടിക';
$labels['compact'] = 'ചുരുക്കു';
$labels['empty'] = 'ശൂന്യം';
$labels['quota'] = 'ഡിസ്ക്ക് ഉപയോഗം';
$labels['unknown'] = 'അറിയാത്ത';
$labels['unlimited'] = 'പരിമിതികളില്ലാത്ത';
$labels['quicksearch'] = 'പെട്ടെന്ന് തെരയു';
$labels['msgtext'] = 'മുഴുവന്‍ സന്ദേശവും';
$labels['body'] = 'ഉള്ളടക്കം';
$labels['openinextwin'] = 'പുതിയ വിന്‍ഡോയില്‍ തുറക്കുക';
$labels['editasnew'] = 'പുതിയതായി തിരുത്തുക';
$labels['sendmessage'] = 'സന്ദേശം അയയ്ക്കുക';
$labels['savemessage'] = 'പൂര്‍ത്തിയാകാത്തവ ആയി സൂക്ഷിക്കുക';
$labels['addattachment'] = 'ഒരു ഫയല്‍ മെയിലിനൊപ്പം ചേര്‍ക്കുക';
$labels['editortype'] = 'തിരുത്തല്‍ രീതി';
$labels['originalmessage'] = 'യഥാര്‍ഥ സന്ദേശം';
$labels['recipient'] = 'സ്വീകര്‍ത്താവ്';
$labels['checkspelling'] = 'അക്ഷരത്തെറ്റു് പരിശോധിക്കുക';
$labels['resumeediting'] = 'തിരുത്തല്‍ തുടരുക';
$labels['attach'] = 'സംയോജിപ്പിക്കു';
$labels['attachments'] = 'അറ്റാച്ച്മെന്റുകള്‍';
$labels['upload'] = 'അപ്‌ലോഡ് ചെയ്യുക';
$labels['close'] = 'അടയ്ക്കുക';
$labels['messageoptions'] = 'സന്ദേശ ​ഐച്ഛികങ്ങള്‍...';
$labels['low'] = 'കുറഞ്ഞ';
$labels['lowest'] = 'ഏറ്റവും കുറഞ്ഞ';
$labels['normal'] = 'സാധാരണ';
$labels['high'] = 'കൂടിയ';
$labels['highest'] = 'ഏറ്റവും കൂടിയത്';
$labels['nosubject'] = '(വിഷയം ഇല്ല)';
$labels['showimages'] = 'ചിത്രങ്ങള്‍ കാണിക്കുക';
$labels['isdraft'] = 'ഇതൊരു കരടുരൂപമാണ്.';
$labels['htmltoggle'] = 'HTML';
$labels['dontsave'] = 'സുക്ഷിക്കരുത്';
$labels['maxuploadsize'] = '$size ആണ് പരമാവധി  ഫയല്‍ വലിപ്പം';
$labels['firstname'] = 'ആദ്യ നാമം';
$labels['surname'] = 'അവസാന നാമം';
$labels['nickname'] = 'ചെല്ലപേര്';
$labels['jobtitle'] = 'ജോലിയുടെ പേര്';
$labels['department'] = 'വകുപ്പ്';
$labels['gender'] = 'ലിംഗം';
$labels['maidenname'] = 'കന്യകാനാമം';
$labels['email'] = 'ഇമെയില്‍';
$labels['phone'] = 'ഫോണ്‍';
$labels['address'] = 'മേല്‍വിലാസം';
$labels['street'] = 'തെരുവ്';
$labels['locality'] = 'നഗരം';
$labels['zipcode'] = 'പിന്‍ കോഡ്';
$labels['region'] = 'സംസ്ഥാനം / പ്രദേശം';
$labels['country'] = 'രാജ്യം';
$labels['birthday'] = 'പിറന്നാള്‍';
$labels['anniversary'] = 'വാര്‍ഷികം';
$labels['website'] = 'വെബ്സൈറ്റ്';
$labels['notes'] = 'കുറിപ്പുകള്‍';
$labels['male'] = 'പുരുഷന്‍';
$labels['female'] = 'സ്‌ത്രീ';
$labels['manager'] = 'പരിപാലകന്‍';
$labels['assistant'] = 'സഹായി';
$labels['spouse'] = 'ഭാര്യ/ഭര്‍ത്താവ്';
$labels['search'] = 'തെരയുക';
$labels['advsearch'] = 'വിപുലമായ തിരച്ചില്‍';
$labels['advanced'] = 'സങ്കീര്‍ണ്ണം';
$labels['other'] = 'മറ്റുള്ളത്';
$labels['typehome'] = 'ആസ്ഥാനം';
$labels['typework'] = 'ജോലി';
$labels['typeother'] = 'മറ്റുള്ളത്';
$labels['typemobile'] = 'മോബൈല്‍';
$labels['typemain'] = 'പ്രധാനപ്പെട്ട';
$labels['typehomefax'] = 'വീട്ടിലെ ഫാക്സ്';
$labels['typeworkfax'] = 'കാര്യാലയത്തിലെ ഫാക്സ്';
$labels['typecar'] = 'കാര്‍';
$labels['typepager'] = 'പേജര്‍';
$labels['typevideo'] = 'ചലച്ചിത്രം';
$labels['typeassistant'] = 'സഹായി';
$labels['typehomepage'] = 'ഹോം പേജ്';
$labels['typeblog'] = 'ബ്ലോഗ്';
$labels['typeprofile'] = 'പ്രൊഫൈല്‍';
$labels['personalinfo'] = 'സ്വകാര്യ വിവരങ്ങള്‍';
$labels['edit'] = 'തിരുത്തുക';
$labels['cancel'] = 'റദ്ദാക്കുക';
$labels['save'] = 'സൂക്ഷിക്കുക';
$labels['delete'] = 'നീക്കം ചെയ്യുക';
$labels['rename'] = 'പേരുമാറ്റുക';
$labels['addphoto'] = 'ചേര്‍ക്കുക';
$labels['replacephoto'] = 'പകരം വയ്ക്കുക';
$labels['print'] = 'അച്ചടി';
$labels['export'] = 'പുറത്തെടുക്കുക';
$labels['grouprename'] = 'കുട്ടത്തിന്റെ പേര് മാറ്റുക';
$labels['groupdelete'] = 'കൂട്ടം മായ്ക്കുക';
$labels['previouspage'] = 'മുമ്പുളള താള്‍ കാണിയ്ക്കുക';
$labels['group'] = 'കൂട്ടം';
$labels['groups'] = 'കൂട്ടങ്ങള്‍';
$labels['personaladrbook'] = 'സ്വകാര്യ വിലാസങ്ങള്‍';
$labels['searchsave'] = 'തിരയല്‍ സൂക്ഷിക്കുക';
$labels['searchdelete'] = 'തിരയല്‍ നീക്കംചെയ്യുക';
$labels['import'] = 'പ്രോഗ്രമ്മിലേക്ക് എടുക്കുക';
$labels['done'] = 'പൂര്‍ത്തീകരിച്ചു';
$labels['about'] = 'വിവരം';
$labels['userpreferences'] = 'ഉപയൊക്ത മുന്‍ഗണനകള്‍';
$labels['preferhtml'] = 'HTML കാണിക്കുക';
$labels['language'] = 'ഭാഷ';
$labels['timezone'] = 'സമയ മേഖല';
$labels['pagesize'] = 'ഒരു താളിലെ വരികള്‍';
$labels['signature'] = 'ഒപ്പ്';
$labels['htmleditor'] = 'HTML സന്ദേശങ്ങള്‍ രചിക്കുക';
$labels['serversettings'] = 'സേവകന്റെ ക്രമീകരണങ്ങള്‍';
$labels['askuser'] = 'എന്നൊടു ചോദിക്കുക';
$labels['always'] = 'എപ്പോഴും';
$labels['never'] = 'ഒരിക്കലുമില്ല';
$labels['immediately'] = 'ഉടനടി';
$labels['2231folding'] = 'Full RFC 2231 (തണ്ടര്‍ബേട് )';
$labels['miscfolding'] = 'Full RFC 2231 ( മൈക്രൊസൊഫ്റ്റ് ഔട്ട്ലൂക്കു് )';
$labels['2047folding'] = 'Full RFC 2047 (മറ്റുള്ളവ)';
$labels['force7bit'] = '8-bit അക്ഷരങ്ങള്‍ക്കു "MIME encoding" ഉപയോഗിക്കുക';
$labels['advancedoptions'] = 'വിപുലീക്രിതമായ ക്രമീകരണങ്ങള്‍';
$labels['defaultfont'] = 'HTML സന്ദേശത്തിന്റെ തനതായ ലിപി';
$labels['section'] = 'വിഭാഗം';
$labels['newmessage'] = 'പുതിയ സന്ദേശം';
$labels['newmessageonly'] = 'പുതിയ സന്ദേശം മാത്രം';
$labels['afternseconds'] = '$n നിമിഷങ്ങള്‍ കഴിഞ്ഞു്';
$labels['spellcheckignorenums'] = 'അക്കങ്ങള്‍ ഉള്ള വാക്കുകളെ അവഗണിക്കുക';
$labels['addtodict'] = 'നിഘണ്ടുവില്‍ ചേര്‍ക്കുക';
$labels['folders'] = 'ഫോള്‍ഡറുകള്‍';
$labels['properties'] = 'സവിശേഷതകള്‍';
$labels['info'] = 'വിവരം';
$labels['getfoldersize'] = 'അറയുടെ വലുപ്പം അരിയാന്‍ ക്ലിക്ക് ചെയ്യുക';
$labels['personalfolder'] = 'സ്വകാര്യ അറ';
$labels['sharedfolder'] = 'പൊതു - അറ';
$labels['license'] = 'അനുമതി';
$labels['support'] = 'സഹായം തേടുക';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'യൂണിക്കോഡ്';
$labels['english'] = 'ഇംഗ്ലീഷ്';
$labels['westerneuropean'] = 'പടിഞ്ഞാറന്‍ യൂറോപ്യന്‍';
$labels['easterneuropean'] = 'കിഴക്കന്‍ യൂറോപ്യന്‍';
$labels['baltic'] = 'ബാള്‍ട്ടിക്ക്';
$labels['cyrillic'] = 'സിറില്ലിക്ക്';
$labels['arabic'] = 'അറബിക്ക്';
$labels['greek'] = 'ഗ്രീക്ക്';
$labels['hebrew'] = 'ഹീബ്രു';
$labels['turkish'] = 'ടര്‍ക്കിഷ്';
$labels['nordic'] = 'നോര്‍ഡിക്ക്';
$labels['thai'] = 'തായ്';
$labels['celtic'] = 'സെല്‍റ്റിക്ക്';
$labels['vietnamese'] = 'വിയറ്റ്നാമീസ്';
$labels['japanese'] = 'ജാപ്പനീസ്';
$labels['korean'] = 'കൊറിയന്‍';
$labels['chinese'] = 'ചൈനീസ്‌';
