/***** Roundcube|Mail message print styles *****/

body
{
  font-family: "Lucida Grande", Verdana, Arial, Helvetica, sans-serif;
  background-color: #ffffff;
  color: #000000;
  margin: 2mm;
}

body, td, th, div, p
{
  font-size: 9pt;
  color: #000000;
}

h3
{
  font-size: 18px;
  color: #000000;
}

a, a:active, a:visited
{
  color: #000000;
}

body > #logo
{
  float: right;
  margin: 0 5mm 3mm 5mm;
}

table.headers-table
{
  table-layout: fixed;
  margin-top: 14px;
}

table.headers-table tr td
{
  font-size: 9pt;
}

table.headers-table td.header-title
{
  color: #666666;
  font-weight: bold;
  text-align: right;
  vertical-align: top;
  padding-right: 4mm;
  white-space: nowrap;
}

table.headers-table tr td.subject
{
  width: 90%;
  font-weight: bold;
}

#attachment-list
{
  margin-top: 3mm;
  padding-top: 3mm;
  border-top: 1pt solid #cccccc;
}

#attachment-list li
{
  font-size: 9pt;
}

#attachment-list li a
{
  text-decoration: none;
}

#attachment-list li a:hover
{
  text-decoration: underline;
}

#messagebody
{
  position: relative;
  margin-top: 5mm;
  border-top: none;
}

div.message-part
{
  padding: 2mm;
  margin-top: 5mm;
  margin-bottom: 5mm;
  border-top: 1pt solid #cccccc;
}

div.message-part a
{
  color: #0000CC;
}

div.message-part div.pre
{
  margin: 0;
  padding: 0;
  font-family: monospace;
  font-size: 12px;
}

div.message-part blockquote
{
  color: blue;
  border-left: 2px solid blue;
  border-right: 2px solid blue;
  background-color: #F6F6F6;
  margin: 2px 0;
  padding: 0 0.4em;
}

div.message-part blockquote blockquote
{
  color: green;
  border-left: 2px solid green;
  border-right: 2px solid green;
}

div.message-part blockquote blockquote blockquote
{
  color: #990000;
  border-left: 2px solid #bb0000;
  border-right: 2px solid #bb0000;
}

p.image-attachment
{
  position: relative;
  padding: 1em;
  border-top: 1px solid #ccc;
}

p.image-attachment a.image-link
{
  float: left;
  display: block;
  margin-right: 2em;
  min-width: 160px;
  min-height: 60px;
  text-align: center;
}

p.image-attachment .image-filename
{
  display: block;
  line-height: 1.6em;
}

p.image-attachment .attachment-links
{
  display: none;
}

/* contact print */
#contact-details fieldset {
	color: #666;
	border: 1px solid #999;
	margin-top: 5px;
}

#contact-details fieldset.contactfieldgroup {
	border: 0;
	padding: 0;
	margin: 0;
}

#contact-details div.row {
	padding: 2px 0;
}

#contact-details .contactfieldlabel {
	display: inline-block;
	vertical-align: top;
	width: 150px;
	overflow: hidden;
	text-overflow: ellipsis;
}

#contact-details .contactfieldcontent {
	display: inline-block;
	vertical-align: top;
	font-weight: bold;
}

#contact-details #contactphoto {
	float: left;
	margin: 5px 15px 5px 3px;
	width: 112px;
	border: 0;
	padding: 0;
}

#contact-details #contactpic {
	width: 112px;
	background: white;
}

#contact-details #contactpic img {
	max-width: 112px;
	visibility: inherit;
}

#contact-details #contacthead {
	border: 0;
	margin: 0 16em 0 0;
	padding: 0;
}

#contact-details #contacthead > legend {
	display: none;
}

#contact-details #contacthead .names span.namefield {
	font-size: 140%;
	font-weight: bold;
}
