#aclmanager
{
  position: relative;
  border: 1px solid #999;
  min-height: 302px;
}

#aclcontainer
{
  overflow-x: auto;
}

#acltable
{
  width: 100%;
  border-collapse: collapse;
  background-color: #F9F9F9;
}

#acltable td
{
  width: 1%;
  white-space: nowrap;
}

#acltable thead td
{
  padding: 0 4px 0 2px;
}

#acltable tbody td
{
  text-align: center;
  padding: 2px;
  border-bottom: 1px solid #999999;
  cursor: default;
}

#acltable tbody td.user
{
  width: 96%;
  text-align: left;
  overflow: hidden;
  text-overflow: ellipsis;
  -o-text-overflow: ellipsis;
}

#acltable tbody td.partial
{
  background: url(images/partial.png) center no-repeat;
}

#acltable tbody td.enabled
{
  background: url(images/enabled.png) center no-repeat;
}

#acltable tr.selected td
{
  color: #FFFFFF;
  background-color: #CC3333;
}

#acltable tr.unfocused td
{
  color: #FFFFFF;
  background-color: #929292;
}

#acladvswitch
{
  position: absolute;
  right: 4px;
  text-align: right;
  line-height: 22px;
}

#acladvswitch input
{
  vertical-align: middle;
}

#acladvswitch span
{
  display: block;
}

#aclform
{
  display: none;
}

#aclform div
{
  padding: 0;
  text-align: center;
  clear: both;
}
