<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = '¡Ha ocurrido un error!';
$messages['loginfailed']  = 'Falló el Login.';
$messages['cookiesdisabled'] = 'Su navegador no acepta cookies.';
$messages['sessionerror'] = 'Su sesión no es válida o ha expirado.';
$messages['storageerror'] = 'Ha fallado la conexión al servidor de almacenamiento.';
$messages['servererror'] = '¡Error del servidor!';
$messages['servererrormsg'] = 'Error del servidor: $msg';
$messages['connerror'] = '¡Error de conexión (no se puede contactar con el servidor)!';
$messages['dberror'] = '¡Error en la base de datos!';
$messages['windowopenerror'] = '¡La ventana emergente ha sido bloqueada!';
$messages['requesttimedout'] = 'Tiempo de espera expirado';
$messages['errorreadonly'] = 'No es posible realizar la operación. La carpeta es de solo lectura';
$messages['errornoperm'] = 'No es posible realizar la operación. Permiso denegado.';
$messages['erroroverquota'] = 'No es posible realizar la operación. No hay espacio en disco.';
$messages['erroroverquotadelete'] = 'No hay espacio libre en disco. Use Mayúsculas+Eliminar para borrar mensajes.';
$messages['invalidrequest'] = '¡Solicitud no válida! No se ha guardado la información.';
$messages['invalidhost'] = 'Nombre de servidor no válido.';
$messages['nomessagesfound'] = 'No se encontraron mensajes en esta casilla.';
$messages['mailboxempty'] = 'Casilla vacía';
$messages['nomessages'] = 'Ningún mensaje';
$messages['refreshing'] = 'Actualizando...';
$messages['loading'] = 'Cargando...';
$messages['uploading'] = 'Subiendo archivo...';
$messages['uploadingmany'] = 'Subiendo archivos...';
$messages['loadingdata'] = 'Cargando información...';
$messages['checkingmail'] = 'Revisando por nuevos mensajes...';
$messages['sendingmessage'] = 'Enviando mensaje...';
$messages['messagesent'] = 'Mensaje enviado exitosamente.';
$messages['savingmessage'] = 'Guardando mensaje...';
$messages['messagesaved'] = 'Mensaje guardado en Borrador.';
$messages['successfullysaved'] = 'Guardado exitosamente.';
$messages['savingresponse'] = 'Guardando texto de respuesta...';
$messages['deleteresponseconfirm'] = '¿Estás seguro que quieres eliminar este texto de respuesta?';
$messages['addedsuccessfully'] = 'Contacto agregado exitosamente a la libreta de direcciones.';
$messages['contactnameexists'] = 'Un contacto con el mismo nombre ya existe.';
$messages['blockedimages'] = 'Para proteger su privacidad, las imágenes remotas están bloqueadas en este mensaje.';
$messages['encryptedmessage'] = 'Este es un mensaje encriptado y no se puede mostrar. ¡Lo lamento!';
$messages['nocontactsfound'] = 'No se encontraron contactos.';
$messages['contactnotfound'] = 'El contacto solicitado no fue encontrado.';
$messages['sendingfailed'] = 'Error al enviar mensaje.';
$messages['senttooquickly'] = 'Por favor espera $sec seg(s). antes de enviar este mensaje.';
$messages['errorsavingsent'] = 'Ha ocurrido un error grabando el mensaje enviado.';
$messages['errorsaving'] = 'Ha ocurrido un error grabando.';
$messages['errormoving'] = 'No se pudo mover el/los mensaje(s).';
$messages['errorcopying'] = 'No se pudo copiar el/los mensaje(s).';
$messages['errordeleting'] = 'No se pudo eliminar el/los mensaje(s).';
$messages['errormarking'] = 'No se pudo marcar el/los mensaje(s).';
$messages['deletecontactconfirm']  = '¿Estás seguro que quieres eliminar el/los contacto(s) seleccionado(s)?';
$messages['deletegroupconfirm']  = '¿Estás seguro que quieres eliminar el grupo seleccionado?';
$messages['deletemessagesconfirm'] = '¿Estás seguro que quieres eliminar el/los mensaje(s) seleccionado(s)?';
$messages['deletefolderconfirm']  = '¿Estás seguro que quieres eliminar esta carpeta?';
$messages['purgefolderconfirm']  = '¿Estás seguro que quieres eliminar todos los mensajes en esta carpeta?';
$messages['contactdeleting'] = 'Eliminando contacto(s)...';
$messages['groupdeleting'] = 'Eliminando grupo...';
$messages['folderdeleting'] = 'Eliminando carpeta...';
$messages['foldermoving'] = 'Moviendo carpeta...';
$messages['foldersubscribing'] = 'Suscribiendo carpeta...';
$messages['folderunsubscribing'] = 'Desuscribiendo carpeta...';
$messages['formincomplete'] = 'El formulario no se ha completado en su totalidad.';
$messages['noemailwarning'] = 'Por favor ingresa una dirección de correo electrónico válida.';
$messages['nonamewarning']  = 'Por favor ingresa un nombre.';
$messages['nopagesizewarning'] = 'Por favor ingresa un tamaño de página.';
$messages['norecipientwarning'] = 'Por favor ingresa al menos un destinatario.';
$messages['nosubjectwarning']  = 'El campo "Asunto" está vacio. ¿Deseas ingresar uno ahora?';
$messages['nobodywarning'] = '¿Enviar este mensaje sin texto?';
$messages['restoresavedcomposedata'] = 'Se ha encontrado un mensaje escrito pero no enviado\n\nAsunto: $subject\nGuardado: $date\n\n¿Desea restaurar este mensaje?';
$messages['nosearchname'] = 'Por favor ingresa un nombre de contacto o dirección de correo electrónico.';
$messages['notuploadedwarning'] = 'Aún no se han subido todos los archivos adjuntos. Por favor espera o cancela la subida.';
$messages['searchsuccessful'] = '$nr mensajes encontrados.';
$messages['contactsearchsuccessful'] = '$nr contactos encontrados.';
$messages['searchnomatch'] = 'La búsqueda no retornó resultados.';
$messages['searching'] = 'Buscando...';
$messages['checking'] = 'Verificando...';
$messages['stillsearching'] = 'Todavía buscando...';
$messages['nospellerrors'] = 'No se han encontrado errores gramaticales.';
$messages['folderdeleted'] = 'Carpeta eliminada exitosamente.';
$messages['foldersubscribed'] = 'Carpeta suscripta exitosamente';
$messages['folderunsubscribed'] = 'Carpeta desuscripta exitosamente';
$messages['deletedsuccessfully'] = 'Eliminado exitosamente.';
$messages['converting'] = 'Quitando el formato...';
$messages['messageopenerror'] = 'No se pudo cargar el mensaje desde el servidor.';
$messages['fileuploaderror'] = 'Subida de archivo falló.';
$messages['filesizeerror'] = 'El archivo subido excede el tamaño máxmo de $size.';
$messages['copysuccess'] = 'Copiados $nr contactos exitosamente.';
$messages['movesuccess'] = 'Movidos $nr contactos exitosamente.';
$messages['copyerror'] = 'No se pudo copiar ninguno de los contactos.';
$messages['moveerror'] = 'No se pudo mover ninguno de los contactos.';
$messages['sourceisreadonly'] = 'Esta dirección fuente es de solo lectura.';
$messages['errorsavingcontact'] = 'No se puedo guardar la dirección del contacto.';
$messages['movingmessage'] = 'Moviendo mensaje(s)...';
$messages['copyingmessage'] = 'Copiando mensaje(s)...';
$messages['copyingcontact'] = 'Copiando contacto(s)...';
$messages['movingcontact'] = 'Moviendo contacto(s)...';
$messages['deletingmessage'] = 'Eliminando mensaje(s)...';
$messages['markingmessage'] = 'Marcando mensaje(s)...';
$messages['addingmember'] = 'Agregando contacto(s) al grupo...';
$messages['removingmember'] = 'Eliminando contacto(s) del grupo...';
$messages['receiptsent'] = 'Se ha enviado con éxito una confirmación de lectura.';
$messages['errorsendingreceipt'] = 'No se pudo enviar el aviso de retorno.';
$messages['deleteidentityconfirm'] = '¿Estás seguro que quieres eliminar esta identidad?';
$messages['nodeletelastidentity'] = 'No puedes eliminar esta identidad, es tu última.';
$messages['forbiddencharacter'] = 'Lo nombre de la carpeta contiene un caracter no permitido.';
$messages['selectimportfile'] = 'Por favor selecciona un archivo para subir.';
$messages['addresswriterror'] = 'La libreta de direcciones seleccionada no se puede escribir.';
$messages['contactaddedtogroup'] = 'Se han eliminado los contactos a este grupo exitosamente';
$messages['contactremovedfromgroup'] = 'Se han eliminado los contactos de este grupo exitosamente';
$messages['nogroupassignmentschanged'] = 'No se han cambiado las asignaciones de grupo.';
$messages['importwait'] = 'Importando, por favor espera...';
$messages['importformaterror'] = '¡Ha fallado la importación! El archivo subido no tiene un formato válido.';
$messages['importconfirm'] = '<b>Se han importado $inserted contactos exitosamente</b>';
$messages['importconfirmskipped'] = '<b>Salteadas $skipped entradas existentes</b>';
$messages['importmessagesuccess'] = 'Importados $nr mensajes exitosamente.';
$messages['importmessageerror'] = '¡Ha fallado la importación! El archivo subido no tiene un formato válido.';
$messages['opnotpermitted'] = '¡Operación no permitida!';
$messages['editorwarning'] = 'Cambiar el tipo de editor puede causar que el formato de texto se pierda. ¿Desea continuar?';
$messages['httpreceivedencrypterror'] = 'Ha ocurrido un error fatal de configuración. Contacte a su administrador de inmediato. <b>Su mensaje no puede ser enviado.</b>';
$messages['smtpconnerror'] = 'Error SMTP ($code): Ha fallado la conexión con el servidor.';
$messages['smtpautherror'] = 'Error SMTP ($code): Error de autenticación.';
$messages['smtpfromerror'] = 'Error SMTP ($code): Fallo en establecer remitente "$from" ($msg).';
$messages['smtptoerror'] = 'Error SMTP ($code): Fallo al agregar destinatario "$to" ($msg).';
$messages['smtprecipientserror'] = 'Error SMTP: No es posible obtener la lista de destinatarios.';
$messages['smtperror'] = 'Error SMTP: $msg';
$messages['toomanyrecipients'] = 'Demasiados destinatarios. Reduzca el número de destinatarios a $max.';
$messages['maxgroupmembersreached'] = 'El número de miembros del grupo excede el máximo de $max.';
$messages['internalerror'] = 'Ha ocurrido un error interno. Por favor intenta de nuevo.';
$messages['contactdelerror'] = 'No se pudo eliminar el/los contacto(s).';
$messages['contactdeleted'] = 'Contacto(s) eliminados exitosamente';
$messages['contactrestoreerror'] = 'No se pudo restaurar los contacto(s) eliminados.';
$messages['contactrestored'] = 'Contacto(s) restaurados exitosamente.';
$messages['groupdeleted'] = 'Grupo eliminado exitosamente.';
$messages['grouprenamed'] = 'Grupo renombrado exitosamente.';
$messages['groupcreated'] = 'Grupo creado exitosamente.';
$messages['savedsearchdeleted'] = 'Búsqueda guardada eliminada exitosamente.';
$messages['savedsearchdeleteerror'] = 'No se pudo eliminar la búsqueda guardada.';
$messages['savedsearchcreated'] = 'Búsqueda guardada creada exitosamente.';
$messages['savedsearchcreateerror'] = 'No se puedo crear la búsqueda guardada.';
$messages['messagedeleted'] = 'Mensaje(s) eliminado(s) exitosamente.';
$messages['messagemoved'] = 'Mensaje(s) movido(s) exitosamente.';
$messages['messagecopied'] = 'Mensaje(s) copiado(s) exitosamente.';
$messages['messagemarked'] = 'Mensaje(s) marcado(s) exitosamente.';
$messages['autocompletechars'] = 'Ingrese al menos $min caracteres para el autocompletado.';
$messages['autocompletemore'] = 'No se han encontrado resultados. Por favor ingrese más caracteres.';
$messages['namecannotbeempty'] = 'El nombre no puede estar vacio.';
$messages['nametoolong'] = 'El nombre es demasiado largo.';
$messages['folderupdated'] = 'Carpeta actualizada exitosamente.';
$messages['foldercreated'] = 'Carpeta creada exitosamente.';
$messages['invalidimageformat'] = 'Formato de imagen no válido.';
$messages['mispellingsfound'] = 'Errores de gramática detectados en el mensaje.';
$messages['parentnotwritable'] = 'No se puede mover/crear la carpeta en la carpeta pariente seleccionada. No tiene derechos de acceso.';
$messages['messagetoobig'] = 'La parte del mensaje es demasiado grande para ser procesada.';
$messages['noscriptwarning'] = 'Atención: ¡Este servicio de Webmail requiere Javascript! Para usarlo por favor habilite Javascript en las opciones de su navegador.';
