<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Suodattimet';
$labels['managefilters'] = 'Hallitse saapuvan sähköpostin suodattimia';
$labels['filtername'] = 'Suodattimen nimi';
$labels['newfilter'] = 'Uusi suodatin';
$labels['filteradd'] = 'Lisää suodatin';
$labels['filterdel'] = 'Poista suodatin';
$labels['rules'] = 'Säännöt';
$labels['actions'] = 'Toiminnot';
$labels['scope'] = 'Rajaus';
$labels['moveup'] = 'Siirrä ylös';
$labels['movedown'] = 'Siirrä alas';
$labels['filterallof'] = 'Täsmää kaikkiin seuraaviin sääntöihin';
$labels['filteranyof'] = 'Täsmää mihin tahansa seuraavista säännöistä';
$labels['filterany'] = 'Kaikki viestit';
$labels['filtercontains'] = 'Sisältää';
$labels['filternotcontains'] = 'Ei sisällä';
$labels['filteris'] = 'on samanlainen kuin';
$labels['filterisnot'] = 'ei ole samanlainen kuin';
$labels['filterexists'] = 'on olemassa';
$labels['filternotexists'] = 'ei ole olemassa';
$labels['filtermatches'] = 'vastaa lauseketta';
$labels['filternotmatches'] = 'ei vastaa lauseketta';
$labels['filterregex'] = 'vastaa säännöllistä lauseketta';
$labels['filternotregex'] = 'ei vastaa säännöllistä lauseketta';
$labels['filterunder'] = 'alle';
$labels['filterover'] = 'yli';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'MIME-osio:';
$labels['mime-message'] = 'viesti';
$labels['mime-anychild'] = 'mikä tahansa';
$labels['mime-type'] = 'tyyppi';
$labels['mime-subtype'] = 'alatyyppi';
$labels['mime-contenttype'] = 'sisällön tyyppi';
$labels['mime-param'] = 'parametri';
$labels['addrule'] = 'Lisää sääntö';
$labels['delrule'] = 'Poista sääntö';
$labels['messagemoveto'] = 'Siirrä viesti';
$labels['messageredirect'] = 'Lähetä viesti edelleen';
$labels['messagecopyto'] = 'Kopioi viesti';
$labels['messagesendcopy'] = 'Lähetä kopio viestistä';
$labels['messagereply'] = 'Vastaa viestillä';
$labels['messagedelete'] = 'Poista viesti';
$labels['messagediscard'] = 'Hylkää viestillä';
$labels['messagekeep'] = 'Säilytä viesti saapuneissa';
$labels['messagesrules'] = 'Saapuville viesteille:';
$labels['messagesactions'] = '...suorita seuraavat toiminnot:';
$labels['add'] = 'Lisää';
$labels['del'] = 'Poista';
$labels['sender'] = 'Lähettäjä';
$labels['recipient'] = 'Vastaanottaja';
$labels['vacationaddr'] = 'Sähköpostiosoitteeni:';
$labels['vacationdays'] = 'Viestien lähetysväli (päivissä):';
$labels['vacationinterval'] = 'Viestien lähetysväli:';
$labels['vacationreason'] = 'Viestin runko (loman syy):';
$labels['vacationfrom'] = 'Vastauksen lähetysosoite:';
$labels['vacationsubject'] = 'Viestin aihe:';
$labels['days'] = 'päivää';
$labels['seconds'] = 'sekuntia';
$labels['rulestop'] = 'Lopeta sääntöjen arviointi';
$labels['enable'] = 'Ota käyttöön/poista käytöstä';
$labels['filterset'] = 'Suodatinasetus';
$labels['filtersets'] = 'Suodattimen asetus';
$labels['filtersetadd'] = 'Lisää suodatinasetus';
$labels['filtersetdel'] = 'Poista suodatinasetus';
$labels['filtersetact'] = 'Ota käyttöön nykyinen suodatinasetus';
$labels['filtersetdeact'] = 'Poista nykyinen suodatinasetus käytöstä';
$labels['filterseteditraw'] = 'Muokkaa suodatinasetusta';
$labels['filtersetswitch'] = 'Ota käyttöön/poista käytöstä suodatinasetukset';
$labels['filterdef'] = 'Suodattimen määrittely';
$labels['filtersetname'] = 'Suodatinasetuksen nimi';
$labels['newfilterset'] = 'Uusi suodatinasetus';
$labels['active'] = 'aktiivinen';
$labels['none'] = 'Ei mikään';
$labels['fromset'] = 'sarjasta';
$labels['fromfile'] = 'tiedostosta';
$labels['filterdisabled'] = 'Suodatin poistettu käytöstä';
$labels['filterenabled'] = 'Suodatin käytössä';
$labels['countisgreaterthan'] = 'määrä on suurempi kuin';
$labels['countisgreaterthanequal'] = 'määrä on suurempi tai yhtä suuri kuin';
$labels['countislessthan'] = 'määrä on vähemmän kuin';
$labels['countislessthanequal'] = 'määrä on vähemmän tai yhtä suuri kuin';
$labels['countequals'] = 'määrä on yhtä suuri kuin';
$labels['countnotequals'] = 'määrä ei ole yhtä suuri kuin';
$labels['valueisgreaterthan'] = 'arvo on suurempi kuin';
$labels['valueisgreaterthanequal'] = 'arvo on suurempi kuin tai yhtä suuri kuin';
$labels['valueislessthan'] = 'arvo on vähemmän kuin';
$labels['valueislessthanequal'] = 'määrä on vähemmän tai yhtä suuri kuin';
$labels['valueequals'] = 'arvo on yhtä suuri kuin';
$labels['valuenotequals'] = 'arvo ei ole yhtä suuri kuin';
$labels['setflags'] = 'Aseta liput viestiin';
$labels['addflags'] = 'Lisää liput viestiin';
$labels['removeflags'] = 'Poista liput viestistä';
$labels['flagread'] = 'Lue';
$labels['flagdeleted'] = 'Poistettu';
$labels['flaganswered'] = 'Vastattu';
$labels['flagflagged'] = 'Liputettu';
$labels['flagdraft'] = 'Luonnos';
$labels['addheader'] = 'Lisää otsake viestiin';
$labels['deleteheader'] = 'Poista otsake viestistä';
$labels['headername'] = 'Otsakkeen nimi';
$labels['headervalue'] = 'Otsakkeen arvo';
$labels['headerpos'] = 'Otsakkeen sijainti';
$labels['headeratstart'] = 'alussa';
$labels['headeratend'] = 'lopussa';
$labels['headeroccurrence'] = 'Otsakkeen esiintyminen/sijainti';
$labels['headerfromstart'] = 'alusta';
$labels['headerfromend'] = 'lopusta';
$labels['headerpatterns'] = 'Otsakearvon kaava';
$labels['headermatchtype'] = 'täsmää tyyppiin:';
$labels['setvariable'] = 'Aseta muuttuja';
$labels['setvarname'] = 'Muuttujan nimi:';
$labels['setvarvalue'] = 'Muuttujan arvo:';
$labels['setvarmodifiers'] = 'Muuntimet:';
$labels['varlower'] = 'pienellä kirjoitettu';
$labels['varupper'] = 'isolla kirjoitettu';
$labels['varlowerfirst'] = 'ensimmäinen merkki pienellä kirjoitettuna';
$labels['varupperfirst'] = 'ensimmäinen merkki isolla kirjoitettuna';
$labels['varquotewildcard'] = 'lainaa erikoismerkit';
$labels['varlength'] = 'pituus';
$labels['notify'] = 'Lähetä ilmoitus';
$labels['notifytarget'] = 'Ilmoituksen kohde:';
$labels['notifymessage'] = 'Ilmoituksen viesti (valinnainen):';
$labels['notifyoptions'] = 'Ilmoituksen valinnat (valinnainen)';
$labels['notifyfrom'] = 'Ilmoituksen lähettäjä (valinnainen):';
$labels['notifyimportance'] = 'Tärkeysaste:';
$labels['notifyimportancelow'] = 'matala';
$labels['notifyimportancenormal'] = 'normaali';
$labels['notifyimportancehigh'] = 'korkea';
$labels['notifymethodmailto'] = 'Sähköposti';
$labels['notifymethodtel'] = 'Puhelin';
$labels['notifymethodsms'] = 'Tekstiviesti';
$labels['filtercreate'] = 'Luo suodatin';
$labels['usedata'] = 'Käytä seuraavaa dataa suodattimessa:';
$labels['nextstep'] = 'Seuraava vaihe';
$labels['...'] = '...';
$labels['string'] = 'Merkkijono';
$labels['currdate'] = 'Nykyinen päivämäärä';
$labels['datetest'] = 'Päivämäärä';
$labels['dateheader'] = 'otsikko:';
$labels['year'] = 'vuosi';
$labels['month'] = 'kuukausi';
$labels['day'] = 'päivä';
$labels['date'] = 'päivämäärä (vvvv-kk-pp)';
$labels['julian'] = 'päivämäärä (juliaaninen)';
$labels['hour'] = 'tunti';
$labels['minute'] = 'minuutti';
$labels['second'] = 'sekunti';
$labels['time'] = 'aika (hh:mm:ss)';
$labels['iso8601'] = 'päivämäärä (ISO8601)';
$labels['std11'] = 'päivämäärä (RFC2882)';
$labels['zone'] = 'aikavyöhyke';
$labels['weekday'] = 'viikonpäivä (0-6)';
$labels['advancedopts'] = 'Lisävalinnat';
$labels['body'] = 'Runko';
$labels['address'] = 'osoite';
$labels['envelope'] = 'kirjekuori';
$labels['modifier'] = 'muuntaja:';
$labels['text'] = 'teksti';
$labels['undecoded'] = 'dekoodaamaton (raaka)';
$labels['contenttype'] = 'sisällön tyyppi';
$labels['modtype'] = 'tyyppi:';
$labels['allparts'] = 'kaikki';
$labels['domain'] = 'domain';
$labels['localpart'] = 'paikallinen osa';
$labels['user'] = 'käyttäjä';
$labels['detail'] = 'yksityiskohta';
$labels['comparator'] = 'vertailija:';
$labels['default'] = 'oletus';
$labels['octet'] = 'tarkka (tavuina)';
$labels['asciicasemap'] = 'kirjainkoosta riippumaton (ascii-merkistö)';
$labels['asciinumeric'] = 'numeerinen (ascii-numerot)';
$labels['index'] = 'indeksi:';
$labels['indexlast'] = 'taaksepäin';
$labels['spamtest'] = 'Roskapostitaso';
$labels['spamtestisgreaterthan'] = 'on suurempi kuin';
$labels['spamtestisgreaterthanequal'] = 'on suurempi tai yhtä suuri kuin';
$labels['spamtestislessthan'] = 'on vähemmän kuin';
$labels['spamtestislessthanequal'] = 'on vähemmän tai yhtä suuri kuin';
$labels['spamtestequals'] = 'on samanlainen kuin';
$labels['spamtestnotequals'] = 'ei ole samanlainen kuin';
$labels['spamtestisunknown'] = 'on tuntematon';
$labels['vacation'] = 'Lomavastaaja';
$labels['vacation.reply'] = 'Vastausviesti';
$labels['vacation.advanced'] = 'Lisäasetukset';
$labels['vacation.from'] = 'Vastauksen lähetysosoite';
$labels['vacation.subject'] = 'Aihe';
$labels['vacation.body'] = 'Sisältö';
$labels['vacation.start'] = 'Aloitusaika';
$labels['vacation.end'] = 'Päättymisaika';
$labels['vacation.status'] = 'Tila';
$labels['vacation.on'] = 'Päällä';
$labels['vacation.off'] = 'Pois';
$labels['vacation.addresses'] = 'Omat osoitteeni';
$labels['vacation.interval'] = 'Vastausväli';
$labels['vacation.after'] = 'Lisää lomavastaaja tämän säännön jälkeen';
$labels['vacation.saving'] = 'Tallennetaan tietoja...';
$labels['vacation.action'] = 'Toiminto saapuvalle viestille';
$labels['vacation.keep'] = 'Säilytä';
$labels['vacation.discard'] = 'Hylkää';
$labels['vacation.redirect'] = 'Ohjaa uudelleen osoitteeseen';
$labels['vacation.copy'] = 'Lähetä kopio osoitteeseen';
$labels['forward'] = 'Uudelleenohjaus';
$labels['forward.redirect'] = 'Ohjaa uudelleen osoitteeseen';
$labels['forward.copy'] = 'Lähetä kopio osoitteeseen';
$labels['forward.on'] = 'Päällä';
$labels['forward.off'] = 'Pois';
$labels['forward.status'] = 'Tila:';
$labels['forward.action'] = 'Suorita seuraava sääntö saapuville viesteille:';
$labels['forward.saving'] = 'Tallennetaan tietoja...';
$labels['filladdresses'] = 'Lisää kaikki osoitteeni';
$labels['arialabelfiltersetactions'] = 'Suodatinasetuksen toiminnot';
$labels['arialabelfilteractions'] = 'Suodattimen toiminnot';
$labels['arialabelfilterform'] = 'Suodattimen asetukset';
$labels['ariasummaryfilterslist'] = 'Suodatinlista';
$labels['ariasummaryfiltersetslist'] = 'Suodatinasetuslista';
$labels['filterstitle'] = 'Muokkaa saapuvan postin suodattimia';
$labels['vacationtitle'] = 'Muokkaa poissaolosääntöä';
$labels['forwardtitle'] = 'Muokkaa viestien vältyssääntöä';
$labels['message'] = 'Viesti';
$labels['duplicate'] = 'on kopio';
$labels['notduplicate'] = 'ei ole kopio';
$labels['duplicate.handle'] = 'käsittele:';
$labels['duplicate.header'] = 'otsikko:';
$labels['duplicate.uniqueid'] = 'tunniste:';
$labels['duplicate.seconds'] = 'aikakatkaisu (sekuntia):';
$labels['duplicate.last'] = 'suhteellinen viimeiseen suoritukseen';
$messages['filterunknownerror'] = 'Tuntematon palvelinvirhe.';
$messages['filterconnerror'] = 'Yhteys palvelimeen epäonnistui.';
$messages['filterdeleteerror'] = 'Suodattimen poistaminen epäonnistui. Tapahtui palvelinvirhe.';
$messages['filterdeleted'] = 'Suodatin poistettu onnistuneesti.';
$messages['filtersaved'] = 'Suodatin tallennettu onnistuneesti.';
$messages['filtersaveerror'] = 'Suodattimen tallennus epäonnistui palvelinvirheen vuoksi.';
$messages['filterformerror'] = 'Suodatinlomake sisältää virheitä.';
$messages['filterdeleteconfirm'] = 'Haluatko varmasti poistaa valitun suodattimen?';
$messages['ruledeleteconfirm'] = 'Haluatko varmasti poistaa valitun säännön?';
$messages['actiondeleteconfirm'] = 'Haluatko varmasti poistaa valitun toimenpiteen?';
$messages['forbiddenchars'] = 'Virheellisiä merkkejä kentässä.';
$messages['cannotbeempty'] = 'Kenttä ei voi olla tyhjä.';
$messages['ruleexist'] = 'Suodatin samalla nimellä on jo olemassa.';
$messages['setactivateerror'] = 'Palvelinvirheestä johtuen suodatinasetuksia ei voitu ottaa käyttöön.';
$messages['setdeactivateerror'] = 'Palvelinvirheestä johtuen suodatinasetuksia ei voitu kytkeä pois päältä.';
$messages['setdeleteerror'] = 'Palvelinvirheestä johtuen suodatinasetuksia ei voitu poistaa.';
$messages['setactivated'] = 'Suodatinasetukset kytketty päälle.';
$messages['setdeactivated'] = 'Suodatinasetukset kytketty pois päältä.';
$messages['setdeleted'] = 'Suodatinasetus poistettu.';
$messages['setupdated'] = 'Suodatinasetus päivitetty.';
$messages['setdeleteconfirm'] = 'Oletko varma että haluat poistaa valitun suodatinasetuksen?';
$messages['setcreateerror'] = 'Palvelinvirheestä johtuen suodatinasetusta ei voitu luoda.';
$messages['setcreated'] = 'Suodatinasetus luotiin onnistuneesti.';
$messages['activateerror'] = 'Palvelinvirheestä johtuen valittuja suodattimia ei voitu ottaa käyttöön.';
$messages['deactivateerror'] = 'Palvelinvirheestä johtuen valittuja suodattimia ei voitu kytkeä pois käytöstä.';
$messages['deactivated'] = 'Suodattimet kytketty pois käytöstä.';
$messages['activated'] = 'Suodattimet otettu käyttöön.';
$messages['moved'] = 'Suodatin siirretty onnistuneesti.';
$messages['moveerror'] = 'Palvelinvirheestä johtuen suodatinta ei voitu siirtää.';
$messages['nametoolong'] = 'Nimi on liian pitkä.';
$messages['namereserved'] = 'Varattu nimi.';
$messages['setexist'] = 'Suodatinasetus on jo olemassa.';
$messages['nodata'] = 'Vähintään yksi sijainti täytyy valita!';
$messages['invaliddateformat'] = 'Virheellinen päivämäärämuoto.';
$messages['saveerror'] = 'Tietojen tallennus epäonnistui palvelinvirheen vuoksi.';
$messages['vacationsaved'] = 'Lomavastaaja aktivoitu.';
$messages['forwardsaved'] = 'Uudelleenohjaukset tallennettu.';
$messages['emptyvacationbody'] = 'Lomaviestin sisältö vaaditaan!';
$messages['duplicate.conflict.err'] = 'Otsaketta ja uniikkia tunnistetta ei sallita samanaikaisesti.';
$messages['disabledaction'] = 'Toiminto ei ole sallittu.';
$messages['lastindexempty'] = 'Indeksi vaaditaan lopusta laskiessa.';
$messages['noflagset'] = 'Vähintään yksi lippu täytyy valita.';
