<roundcube:object name="doctype" value="html5" />
<html>
<head>
<roundcube:include file="/includes/links.html" />
</head>
<roundcube:if condition="env:extwin" /><body class="noscroll extwin"><roundcube:else /><body class="noscroll"><roundcube:endif />

<roundcube:include file="/includes/header.html" />

<div id="mainscreen" class="offset">

<h1 class="voice"><roundcube:label name="settings" /> : <roundcube:label name="folders" /></h1>

<roundcube:include file="/includes/settingstabs.html" />

<div id="settings-right" role="main">

<div id="folderslist" class="uibox listbox">
<h2 id="folderslist-header" class="boxtitle">
	<roundcube:label name="folders" />
	<a href="#folders" class="iconbutton search" title="<roundcube:label name='findfolders' />" tabindex="0"><roundcube:label name='findfolders' /></a>
</h2>
<div class="listsearchbox">
	<roundcube:object name="folderfilter" id="folderlist-filter" />
	<div class="searchbox" role="search" aria-labelledby="aria-label-foldersearchform">
		<h3 id="aria-label-foldersearchform" class="voice"><roundcube:label name="arialabelfoldersearchform" /></h3>
		<label for="foldersearch" class="voice"><roundcube:label name="arialabelsearchterms" /></label>
		<input type="text" name="q" id="foldersearch" placeholder="<roundcube:label name='findfolders' />" />
		<a class="iconbutton searchicon"></a>
		<roundcube:button command="reset-foldersearch" type="link" id="folderlistsearch-reset" class="iconbutton reset" title="resetsearch" label="resetsearch" />
	</div>
</div>
<div id="folderslist-content" class="scroller withfooter">
	<roundcube:object name="foldersubscription" id="subscription-table" class="treelist listing folderlist" />
</div>
<div id="folderslist-footer" class="boxfooter">
	<roundcube:button command="create-folder" type="link" title="createfolder" class="listbutton add disabled" classAct="listbutton add" innerClass="inner" label="createfolder" /><roundcube:button name="mailboxmenulink" id="mailboxmenulink" type="link" title="folderactions" class="listbutton groupactions" onclick="return UI.toggle_popup('mailboxmenu',event)" innerClass="inner" content="&#9881;" aria-haspopup="true" aria-expanded="false" aria-owns="mailboxoptionsmenu" />
	<roundcube:if condition="env:quota" />
		<span class="voice"><roundcube:label name="quota"></span>
		<roundcube:object name="quotaDisplay" id="quotadisplay" class="countdisplay" display="text" />
	<roundcube:endif />
</div>

<div id="mailboxmenu" class="popupmenu" aria-hidden="true">
	<h3 id="aria-label-mailboxmenu" class="voice"><roundcube:label name="arialabelmailboxmenu" /></h3>
	<ul class="toolbarmenu" id="mailboxoptionsmenu" role="menu" aria-labelledby="aria-label-mailboxmenu">
		<roundcube:button command="delete-folder" type="link-menuitem" label="delete" classAct="active" />
		<roundcube:button command="purge" type="link-menuitem" label="empty" classAct="active" />
		<roundcube:container name="mailboxoptions" id="mailboxoptionsmenu" />
	</ul>
</div>

</div>

<div id="folder-details" class="uibox contentbox">
	<div class="iframebox">
		<roundcube:object name="contentframe" id="preferences-frame" style="width:100%; height:100%" frameborder="0" src="env:blankpage" />
	</div>
</div>

</div>

</div>

<roundcube:include file="/includes/footer.html" />

</body>
</html>
