<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Virhe havaittu.';
$messages['loginfailed']  = 'Sisäänkirjautuminen epäonnistui';
$messages['cookiesdisabled'] = 'Selaimesi ei hyväksy evästeitä';
$messages['sessionerror'] = 'Sessio ei kelpaa tai ei ole enää voimassa';
$messages['cookiesmismatch'] = 'Evästeiden yhteensopimattomuus havaittu. Tyhjennä selaimessasi olevat evästeet.';
$messages['storageerror'] = 'Yhteys IMAP-palvelimeen epäonnistui';
$messages['servererror'] = 'Palvelinvirhe!';
$messages['servererrormsg'] = 'Palvelinvirhe: $msg';
$messages['accountlocked'] = 'Liian monta epäonnistunutta kirjautumisyritystä. Yritä myöhemmin uudelleen.';
$messages['connerror'] = 'Yhteysvirhe, ei yhteyttä palvelimeen!';
$messages['dberror'] = 'Tietokantavirhe!';
$messages['windowopenerror'] = 'Ponnahdusikkuna estettiin!';
$messages['requesttimedout'] = 'Pyyntö aikakatkaistiin';
$messages['errorreadonly'] = 'Toiminnon suoritus ei onnistu, koska hakemisto on vain lukutilassa.';
$messages['errornoperm'] = 'Toimintoa ei voitu suorittaa. Ei oikeuksia.';
$messages['erroroverquota'] = 'Toiminnon suoritus epäonnistui. Levytila on loppu.';
$messages['erroroverquotadelete'] = 'Levytila on loppu. Paina SHIFT+DEL poistaaksesi viestin.';
$messages['invalidrequest'] = 'Virheellinen pyyntö! Tietoa ei tallennettu.';
$messages['invalidhost'] = 'Virheellinen palvelinnimi.';
$messages['nomessagesfound'] = 'Kansiossa ei ole sähköpostiviestejä';
$messages['loggedout'] = 'Lopetit istunnon onnistuneesti. Näkemiin!';
$messages['mailboxempty'] = 'Postilaatikko on tyhjä';
$messages['nomessages'] = 'Ei viestejä';
$messages['refreshing'] = 'Päivitetään...';
$messages['loading'] = 'Ladataan...';
$messages['uploading'] = 'Ladataan tiedostoa palvelimelle...';
$messages['attaching'] = 'Liitetään tiedostoa...';
$messages['uploadingmany'] = 'Ladataan tiedostoja...';
$messages['loadingdata'] = 'Ladataan tietoja...';
$messages['checkingmail'] = 'Tarkistetaan saapuneita viestejä...';
$messages['sendingmessage'] = 'Lähetetään viestiä...';
$messages['messagesent'] = 'Viesti lähetetty';
$messages['savingmessage'] = 'Tallennetaan viestiä...';
$messages['messagesaved'] = 'Viesti tallennettu "Luonnokset"-kansioon';
$messages['successfullysaved'] = 'Tallennus onnistui';
$messages['savingresponse'] = 'Tallennetaan vastaustekstiä...';
$messages['deleteresponseconfirm'] = 'Haluatko varmasti poistaa tämän vastaustekstin?';
$messages['nocontactselected'] = 'Et ole vielä valinnut yhteystietoja.';
$messages['addedsuccessfully'] = 'Yhteystieto lisätty osoitekirjaan';
$messages['contactexists'] = 'Yhteystieto samalla sähköpostiosoitteella on jo olemassa.';
$messages['contactnameexists'] = 'Yhteystieto samalla nimellä on jo olemassa';
$messages['blockedimages'] = 'Turvallisuussyistä viestin kuvia ei näytetty.';
$messages['blockedresources'] = 'Turvallisuussyistä viestin ulkoisia lähteitä ei näytetty.';
$messages['encryptedmessage'] = 'Viesti on salattu, eikä sitä voida näyttää.';
$messages['externalmessagedecryption'] = 'Tämä on salattu viesti. Viestin salaus on mahdollista purkaa selaimesi laajennuksella.';
$messages['nopubkeyfor'] = 'Sähköpostille $email ei löytynyt kelvollista julkista avainta';
$messages['nopubkeyforsender'] = 'Lähettäjäidentiteetillesi ei löytynyt kelvollista julkista avainta. Haluatko salata viestin vain vastaanottajille?';
$messages['encryptnoattachments'] = 'Entuudestaan määritettyjä liitteitä ei voi salata. Lisää liitteet uudelleen salausmuokkaimen kautta.';
$messages['searchpubkeyservers'] = 'Haluatko etsiä puuttuvia avaimia julkisten avainten palvelimilta?';
$messages['encryptpubkeysfound'] = 'Seuraavat avaimet löydettiin:';
$messages['keyservererror'] = 'Avaimen noutaminen avainpalvelimelta epäonnistui.';
$messages['keyimportsuccess'] = 'Julkinen avain $key tuotiin onnistuneesti avainnippuusi.';
$messages['nocontactsfound'] = 'Yhteystietoja ei löytynyt.';
$messages['contactnotfound'] = 'Pyydettyä yhteystietoa ei löytynyt';
$messages['contactsearchonly'] = 'Sinun on käytettävä hakulomaketta nähdäksesi yhteystiedot valitusta osoitekirjasta.';
$messages['sendingfailed'] = 'Viestin lähetys epäonnistui';
$messages['senttooquickly'] = 'Odota $sec sekunti(a) ennen viestin lähettämistä';
$messages['errorsavingsent'] = 'Virhe tallennettaessa lähetettyä viestiä.';
$messages['errorsaving'] = 'Virhe tallennettaessa.';
$messages['errormoving'] = 'Viestiä ei voitu siirtää';
$messages['errorcopying'] = 'Viestiä ei voitu kopioida';
$messages['errordeleting'] = 'Viestiä ei voitu poistaa';
$messages['errormarking'] = 'Viestiä ei voitu merkiä';
$messages['alerttitle'] = 'Huomio';
$messages['confirmationtitle'] = 'Oletko varma...';
$messages['deletecontactconfirm']  = 'Haluatko varmasti poistaa valitut yhteystiedot?';
$messages['deletegroupconfirm']  = 'Haluatko varmasti poistaa valitun ryhmän?';
$messages['deletemessagesconfirm'] = 'Haluatko varmasti poistaa valitut viestit?';
$messages['deletefolderconfirm']  = 'Haluatko varmasti poistaa kansion?';
$messages['movefolderconfirm']  = 'Haluatko varmasti siirtää tämän kansion?';
$messages['purgefolderconfirm']  = 'Haluatko varmasti poistaa kaikki viestit kansiosta?';
$messages['contactdeleting'] = 'Poistetaan yhteystietoja...';
$messages['groupdeleting'] = 'Poistetaan ryhmää...';
$messages['folderdeleting'] = 'Poistetaan kansiota...';
$messages['foldermoving'] = 'Siirretään kansiota...';
$messages['foldersubscribing'] = 'Tilataan kansio...';
$messages['folderunsubscribing'] = 'Perutaan kansio tilaus...';
$messages['formincomplete'] = 'Lomakkeen tiedot olivat puutteelliset';
$messages['noemailwarning'] = 'Anna sähköpostiosoite';
$messages['nonamewarning']  = 'Anna nimi';
$messages['nopagesizewarning'] = 'Anna sivukoko';
$messages['nosenderwarning'] = 'Anna lähettäjän sähköpostiosoite.';
$messages['recipientsadded'] = 'Vastaanottaja(t) lisätty onnistuneesti.';
$messages['norecipientwarning'] = 'Anna ainakin yksi vastaanottaja';
$messages['disclosedrecipwarning'] = 'Kaikki vastaanottajat tulevat näkemään muut vastaanottajat. Estääksesi tämän ja suojellaksesi heidän turvallisuutta käytä BCC-kenttää.';
$messages['disclosedreciptitle'] = 'Liian monta julkista vastaanottajaa';
$messages['nosubjectwarning']  = '"Aihe"-kenttä on tyhjä. Haluatko kirjoittaa viestillesi aiheen?';
$messages['nosubjecttitle']  = 'Ei aihetta';
$messages['nobodywarning'] = 'Lähetetäänkö viesti ilman tekstiä?';
$messages['notsentwarning'] = 'Viestiä ei lähetetty ja se sisältää tallentamattomia muutoksia. Haluatko hylätä muutoksesi?';
$messages['restoresavedcomposedata'] = 'Löydettiin aiemmin luotu, mutta lähettämätön viesti.\n\nAihe: $subject\nTallennettu: $date\n\nHaluatko palauttaa tämän viestin?';
$messages['nosearchname'] = 'Anna yhteystiedon nimi tai sähköpostiosoite';
$messages['notuploadedwarning'] = 'Kaikkia liitteitä ei ole vielä ladattu palvelimelle. Odota tai peruuta lataus.';
$messages['searchsuccessful'] = 'Löydetty $nr viestiä';
$messages['contactsearchsuccessful'] = 'Löydetty $nr yhteystietoa';
$messages['searchnomatch'] = 'Haku ei tuottanut tuloksia';
$messages['searching'] = 'Etsitään...';
$messages['checking'] = 'Tarkistetaan...';
$messages['stillsearching'] = 'Etsitään edelleen...';
$messages['nospellerrors'] = 'Kirjoitusvirheitä ei löytynyt.';
$messages['folderdeleted'] = 'Kansio poistettu onnistuneesti';
$messages['foldersubscribed'] = 'Kansio tilattu onnistuneesti.';
$messages['folderunsubscribed'] = 'Kansion tilaus poistettu onnistuneesti.';
$messages['deletedsuccessfully'] = 'Poistettu onnistuneesti';
$messages['converting'] = 'Poistetaan asettelu viestistä...';
$messages['messageopenerror'] = 'Virhe kopioitaessa viestiä palvelimelta';
$messages['filelinkerror'] = 'TIedoston liittäminen epäonnistui.';
$messages['fileuploaderror'] = 'Tiedoston lähettäminen epäonnistui';
$messages['filesizeerror'] = 'Lähetettävä tiedosto ylittää sallitun enimmäiskoon $size';
$messages['filecounterror'] = 'Voit lähettää maksimissaan $count tiedostoa kerralla.';
$messages['msgsizeerror'] = 'Tiedoston liittäminen epäonnistui. Viestin enimmäiskoko ($size) ylitettiin.';
$messages['msgsizeerrorfwd'] = 'Viestin suurin sallittu koko ($size) ylittyi. $num viesti(ä) jätettiin liittämättä.';
$messages['copysuccess'] = '$nr yhteystietoa kopioitiin onnistuneesti.';
$messages['movesuccess'] = '$nr yhteystietoa siirrettiin onnistuneesti.';
$messages['copyerror'] = 'Yhdenkään yhteystiedon kopiointi ei onnistunut.';
$messages['moveerror'] = 'Minkään yhteystiedon siirto ei onnistunut.';
$messages['sourceisreadonly'] = 'Tämän osoitteen lähde on kirjoitussuojattu';
$messages['errorsavingcontact'] = 'Yhteystietoa ei voitu tallentaa';
$messages['movingmessage'] = 'Siirretään viestiä...';
$messages['copyingmessage'] = 'Kopioidaan viestiä...';
$messages['copyingcontact'] = 'Kopioidaan yhteystietoja...';
$messages['movingcontact'] = 'Siirretään yhteystieto(j)a...';
$messages['deletingmessage'] = 'Poistetaan viestejä...';
$messages['markingmessage'] = 'Merkitään viestejä...';
$messages['addingmember'] = 'Lisätään yhteystietoja ryhmään...';
$messages['removingmember'] = 'Poistetaan yhteystietoja ryhmästä...';
$messages['receiptsent'] = 'Lukukuittaus lähetetty onnistuneesti';
$messages['errorsendingreceipt'] = 'Lukukuittausta ei voitu lähettää';
$messages['deleteidentityconfirm'] = 'Haluatko varmasti poistaa identiteetin?';
$messages['nodeletelastidentity'] = 'Et voi poistaa tätä identiteettiä, koska se on ainoa jäljelläoleva';
$messages['forbiddencharacter'] = 'Kansion nimessä on kiellettyjä merkkejä';
$messages['selectimportfile'] = 'Valitse lähetettävä tiedosto';
$messages['addresswriterror'] = 'Valittuun osoitekirjaan ei voi kirjoittaa';
$messages['contactaddedtogroup'] = 'Yhteystiedot lisätty ryhmään';
$messages['contactremovedfromgroup'] = 'Yhteystiedot poistettu ryhmästä';
$messages['nogroupassignmentschanged'] = 'Ryhmämäärityksiä ei muutettu.';
$messages['importwait'] = 'Tuodaan, odota...';
$messages['importformaterror'] = 'Tuonti epäonnistui! Lähetetty tiedosto ei ole kelvollinen tuontitiedosto.';
$messages['importconfirm'] = '<b>$inserted yhteystietoa tuotu onnistuneesti</b>';
$messages['importconfirmskipped'] = '<b>Ohitettu $skipped  olemassa olevaa merkintää</b>';
$messages['importmessagesuccess'] = '$nr viestiä tuotiin onnistuneesti';
$messages['importmessageerror'] = 'Tuonti epäonnistui! Lähetetty tiedosto ei ole kelvollinen viesti tai mailbox-tiedosto';
$messages['opnotpermitted'] = 'Toiminto ei ole sallittu!';
$messages['nofromaddress'] = 'Valitusta identiteetistä puuttuu sähköpostiosoite.';
$messages['editorwarning'] = 'Muokkaintyypin vaihtaminen saattaa aiheuttaa tekstin muotoilun katoamisen. Haluatko jatkaa?';
$messages['httpreceivedencrypterror'] = 'Vakava virhe asetuksissa. Ota välittömästi yhteys ylläpitoon. <b>Viestiäsi ei voida lähettää.</b>';
$messages['smtpconnerror'] = 'SMTP-virhe ($code): Palvelimelle yhdistäminen epäonnistui';
$messages['smtpautherror'] = 'SMTP-virhe ($code): Tunnistus epäonnistui';
$messages['smtpfromerror'] = 'SMTP-virhe ($code): Lähettäjän "$from" asettaminen epäonnistui ($msg)';
$messages['smtptoerror'] = 'SMTP-virhe ($code): Vastaanottajan "$to" lisääminen epäonnistui ($msg)';
$messages['smtprecipientserror'] = 'SMTP-virhe: Ei voida jäsentää vastaanottajien listaa.';
$messages['smtputf8error'] = 'SMTP-virhe: Palvelin ei tue Unicodea sähköpostiosoitteessa.';
$messages['smtpsizeerror'] = 'SMTP-virhe: Viestin koko ylittää palvleimen rajoituksen ($limit)';
$messages['smtperror'] = 'SMTP-virhe: $msg';
$messages['emailformaterror'] = 'Virheellinen sähköpostiosoite: $email';
$messages['toomanyrecipients'] = 'Liikaa vastaanottajia. Vähennä vastaanottajien määrä maksimiin $max.';
$messages['maxgroupmembersreached'] = 'Ryhmän jäsenten määrä ylittää maksimin $max';
$messages['internalerror'] = 'Sisäinen virhe. Yritä uudelleen.';
$messages['contactdelerror'] = 'Yhteystietoja ei voitu poistaa.';
$messages['contactdeleted'] = 'Yhteystiedot poistettu onnistuneesti.';
$messages['contactrestoreerror'] = 'Poistettujen yhteystietojen palautus epäonnistui.';
$messages['contactrestored'] = 'Yhteystiedot palautettu onnistuneesti.';
$messages['groupdeleted'] = 'Ryhmä poistettu onnistuneesti.';
$messages['grouprenamed'] = 'Ryhmä nimetty uudelleen onnistuneesti.';
$messages['groupcreated'] = 'Ryhmä luotu onnistuneesti.';
$messages['savedsearchdeleted'] = 'Tallennettu haku poistettu onnistuneesti.';
$messages['savedsearchdeleteerror'] = 'Tallennetun haun poisto epäonnistui.';
$messages['savedsearchcreated'] = 'Tallennettu haku luotu onnistuneesti.';
$messages['savedsearchcreateerror'] = 'Tallennetun haun tallennus epäonnistui.';
$messages['messagedeleted'] = 'Viestit poistettu onnistuneesti.';
$messages['messagemoved'] = 'Viestit siirretty onnistuneesti.';
$messages['messagemovedtotrash'] = 'Yksi tai useampi viesti siirrettiin roskakoriin onnistuneesti.';
$messages['messagecopied'] = 'Viestit kopioitu onnistuneesti.';
$messages['messagemarked'] = 'Viestit merkitty onnistuneesti.';
$messages['autocompletechars'] = 'Kirjoita vähintään $min merkkiä  ennen automaattista täydennystä.';
$messages['autocompletemore'] = 'Täsmääviä kohteita löytyi enemmän. Syötä lisää merkkejä.';
$messages['namecannotbeempty'] = 'Nimi ei voi olla tyhjä.';
$messages['nametoolong'] = 'Nimi on liian pitkä.';
$messages['namedotforbidden'] = 'Kansion nimi ei voi alkaa pisteellä.';
$messages['folderupdated'] = 'Kansio päivitetty onnistuneesti.';
$messages['foldercreated'] = 'Kansio luotu onnistuneesti.';
$messages['invalidimageformat'] = 'Virheellinen kuvamuoto.';
$messages['mispellingsfound'] = 'Viestissä havaittiin kielioppivirheitä.';
$messages['parentnotwritable'] = 'Kansiota ei voitu siirtää tai luoda valittuun yläkansioon. Ei käyttöoikeutta.';
$messages['messagetoobig'] = 'Viestiosa on liian suuri prosessoitavaksi.';
$messages['attachmentvalidationerror'] = 'Liitetiedosto on epäilyttävä, koska sen tyyppi ei ole sama kuin viestissä määritetty. Jos et luota lähettäjään, tiedostoa ei tulisi avata selaimessa, koska se voi sisältää haitallista sisältöä.<br/><br/><em>Odotettu: $expected; löytynyt: $detected</em>';
$messages['noscriptwarning'] = 'Varoitus: Tämä verkkopohjainen sähköpostipalvelu vaatii Javascriptin toimiakseen. Ota Javascript käyttöön selaimesi asetuksista.';
$messages['messageissent'] = 'Viesti lähetettiin jo, mutta sitä ei vielä tallennettu. Haluatko tallentaa sen nyt?';
$messages['errnotfound'] = 'Tiedostoa ei löytynyt';
$messages['errnotfoundexplain'] = 'Pyydettyä resurssia ei löytynyt!';
$messages['errfailedrequest'] = 'Pyyntö epäonnistui';
$messages['errauthorizationfailed'] = 'Valtuutus epäonnistui';
$messages['errunauthorizedexplain'] = 'Tämän palvelun käyttöön vaadittavan valtuutuksen tarkistaminen epäonnistui!';
$messages['errrequestcheckfailed'] = 'Pyyntötarkistus epäonnistui';
$messages['errcsrfprotectionexplain'] = "Turvallisuutesi vuoksi tämän resurssin käyttö on suojattu CSRF:ää vastaan.\nJos näet tämän viestin, et luultavasti kirjautunut ulos, ennen kuin poistuit verkkosovelluksesta.\n\nVuorovaikutustasi tarvitaan nyt, jotta voit jatkaa.";
$messages['errcontactserveradmin'] = 'Ota yhteys palvelimen ylläpitäjään.';
$messages['clicktoresumesession'] = 'Napsauta tästä palauttaaksesi edellisen istuntosi';
$messages['errcomposesession'] = 'Kirjoitusistunnon virhe';
$messages['errcomposesessionexplain'] = 'Pyydettyä kirjoitusistuntoa ei löytynyt.';
$messages['clicktocompose'] = 'Napsauta tästä kirjoittaaksesi uuden viestin';
$messages['nosupporterror'] = 'Selaimesi ei tue tätä ominaisuutta.';
$messages['siginserted'] = 'Allekirjoitus lisätty onnistuneesti.';
$messages['responseinserted'] = 'Vastaus lisätty onnistuneesti.';
$messages['listempty'] = 'Lista on tyhjä.';
$messages['listusebutton'] = 'Lisää uusi tietue Luo uusi -painikkeella.';
$messages['keypaircreatesuccess'] = 'Luotiin uusi pari onnistuneesti identiteetille $identity.';
$messages['emptyattachment'] = 'Liitetiedosto on tyhjä.<br>Tarkista asia lähettäjältä.';
$messages['oauthloginfailed'] = 'OAuth-kirjautuminen epäonnistui. Yritä myöhemmin uudelleen.';
