<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/timezones/
*/

$labels['tz:utc'] = 'التوقيت العالمي';
$labels['tz:africa'] = 'أفريقيا';
$labels['tz:africa:abidjan'] = 'أبيدجان';
$labels['tz:africa:accra'] = 'آكر';
$labels['tz:africa:addis_ababa'] = 'أديس أبابا';
$labels['tz:africa:algiers'] = 'الجزائر';
$labels['tz:africa:asmara'] = 'أسمرة';
$labels['tz:africa:bamako'] = 'باماكو';
$labels['tz:africa:bangui'] = 'بانغي';
$labels['tz:africa:banjul'] = 'بانجول';
$labels['tz:africa:bissau'] = 'بيساو';
$labels['tz:africa:blantyre'] = 'بلانتير';
$labels['tz:africa:brazzaville'] = 'برازافيل';
$labels['tz:africa:bujumbura'] = 'بوجمبورا';
$labels['tz:africa:cairo'] = 'القاهرة';
$labels['tz:africa:casablanca'] = 'الدار البيضاء';
$labels['tz:africa:ceuta'] = 'سبتة';
$labels['tz:africa:conakry'] = 'كوناكري';
$labels['tz:africa:dakar'] = 'داكار';
$labels['tz:africa:dar_es_salaam'] = 'دار السلام';
$labels['tz:africa:djibouti'] = 'جيبوتي';
$labels['tz:africa:douala'] = 'دوالا';
$labels['tz:africa:el_aaiun'] = 'العيون';
$labels['tz:africa:freetown'] = 'فريتاون';
$labels['tz:africa:gaborone'] = 'جابورون';
$labels['tz:africa:harare'] = 'هراري';
$labels['tz:africa:johannesburg'] = 'جوهانسبرج';
$labels['tz:africa:juba'] = 'جوبا';
$labels['tz:africa:kampala'] = 'كمبالا';
$labels['tz:africa:khartoum'] = 'الخرطوم';
$labels['tz:africa:kigali'] = 'كيغالي';
$labels['tz:africa:kinshasa'] = 'كينشاسا';
$labels['tz:africa:lagos'] = 'لاغوس';
$labels['tz:africa:libreville'] = 'ليبرفيل';
$labels['tz:africa:lome'] = 'لومي';
$labels['tz:africa:luanda'] = 'لواندا';
$labels['tz:africa:lubumbashi'] = 'لوبومباشي';
$labels['tz:africa:lusaka'] = 'لوساكا';
$labels['tz:africa:malabo'] = 'مالابو';
$labels['tz:africa:maputo'] = 'مابوتو';
$labels['tz:africa:maseru'] = 'ماسيرو';
$labels['tz:africa:mbabane'] = 'مبابان';
$labels['tz:africa:mogadishu'] = 'مقديشو';
$labels['tz:africa:monrovia'] = 'مونروفيا';
$labels['tz:africa:nairobi'] = 'نيروبي';
$labels['tz:africa:ndjamena'] = 'نجامينا';
$labels['tz:africa:niamey'] = 'نيامي';
$labels['tz:africa:nouakchott'] = 'نواكشوط';
$labels['tz:africa:ouagadougou'] = 'واغادوغو';
$labels['tz:africa:porto-novo'] = 'بورتو نوفو';
$labels['tz:africa:sao_tome'] = 'ساو تومي';
$labels['tz:africa:tripoli'] = 'طرابلس';
$labels['tz:africa:tunis'] = 'تونس';
$labels['tz:africa:windhoek'] = 'ويندهوك';
$labels['tz:america'] = 'أمريكا';
$labels['tz:america:adak'] = 'أداك';
$labels['tz:america:anchorage'] = 'أنكوريج';
$labels['tz:america:anguilla'] = 'أنغيلا';
$labels['tz:america:antigua'] = 'أنتيغوا';
$labels['tz:america:araguaina'] = 'أراغوينا';
$labels['tz:america:argentina'] = 'الأرجنتين';
$labels['tz:america:argentina:buenos_aires'] = 'بوينس ايرس';
$labels['tz:america:argentina:catamarca'] = 'كاتاماركا';
$labels['tz:america:argentina:cordoba'] = 'قرطبة';
$labels['tz:america:argentina:jujuy'] = 'جوجوي';
$labels['tz:america:argentina:la_rioja'] = 'لاريوخا';
$labels['tz:america:argentina:mendoza'] = 'مندوزا';
$labels['tz:pacific:gambier'] = 'غامبير';
$labels['tz:pacific:guadalcanal'] = 'غوادالكانال';
$labels['tz:pacific:guam'] = 'غوام';
$labels['tz:pacific:honolulu'] = 'هونولولو';
$labels['tz:pacific:johnston'] = 'جونستون';
$labels['tz:pacific:kiritimati'] = 'كيريتيماتي';
$labels['tz:pacific:kosrae'] = 'كسرى';
$labels['tz:pacific:kwajalein'] = 'كواجالين';
$labels['tz:pacific:majuro'] = 'ماجورو';
$labels['tz:pacific:marquesas'] = 'ماركيساس';
$labels['tz:pacific:midway'] = 'ميدواي';
$labels['tz:pacific:nauru'] = 'ناورو';
$labels['tz:pacific:niue'] = 'نيو';
$labels['tz:pacific:norfolk'] = 'نورفولك';
$labels['tz:pacific:noumea'] = 'نوميا';
$labels['tz:pacific:pago_pago'] = 'باغو باغو';
$labels['tz:pacific:palau'] = 'بالاو';
$labels['tz:pacific:pitcairn'] = 'بيتكيرن';
$labels['tz:pacific:pohnpei'] = 'بوهنباي';
$labels['tz:pacific:port_moresby'] = 'مرفئ مويسبي';
$labels['tz:pacific:rarotonga'] = 'راروتونجا';
$labels['tz:pacific:saipan'] = 'سايبان';
$labels['tz:pacific:tahiti'] = 'تاهيتي';
$labels['tz:pacific:tarawa'] = 'تاراوا';
$labels['tz:pacific:tongatapu'] = 'تونغاتابو';
$labels['tz:pacific:wake'] = 'واكه';
$labels['tz:pacific:wallis'] = 'واليس';
