/**
 * Roundcube webmail "embedded" stylesheets
 *
 * Copyright (c) The Roundcube Dev Team
 *
 * The contents are subject to the Creative Commons Attribution-ShareAlike
 * License. It is allowed to copy, distribute, transmit and to adapt the work
 * by keeping credits to the original autors in the README file.
 * See http://creativecommons.org/licenses/by-sa/3.0/ for details.
 */

.rcmail-inline-message {
	font-family: sans-serif;
	font-size: 11px;
	font-weight: bold;
	color: #996600;
	border: 1px solid #ffdf0e;
	background: url("images/messages.png") no-repeat scroll 5px -83px #fef893;
	padding: 6px 12px 4px 30px;
	margin-bottom: 0.8em;
}

.rcmail-inline-message em {
	font-size: 90%;
}

.rcmail-inline-buttons {
	margin-bottom: 0;
	display: inline;
}

.rcmail-inline-buttons > button {
	margin-left: 1em;
	vertical-align: baseline;
	line-height: 12px;
}
