<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = '$productにようこそ';
$labels['username'] = 'ユーザー名';
$labels['password'] = 'パスワード';
$labels['server'] = 'サーバー';
$labels['login'] = 'ログイン';
$labels['oauthlogin'] = '$provider でログイン';
$labels['menu'] = 'メニュー';
$labels['logout'] = 'ログアウト';
$labels['mail'] = '電子メール';
$labels['settings'] = '設定';
$labels['addressbook'] = 'アドレス帳';
$labels['darkmode'] = 'ダークモード';
$labels['lightmode'] = 'ライトモード';
$labels['inbox'] = '受信箱';
$labels['drafts'] = '下書き';
$labels['sent'] = '送信済み';
$labels['trash'] = 'ごみ箱';
$labels['junk'] = '迷惑メール';
$labels['show_real_foldernames'] = '特殊フォルダーの実際の名前を表示';
$labels['subject'] = '件名';
$labels['from'] = '発信者';
$labels['sender'] = '送信者';
$labels['to'] = '宛先';
$labels['cc'] = '写し(Cc)';
$labels['bcc'] = '隠した写し(Bcc)';
$labels['replyto'] = '返信先';
$labels['followupto'] = 'Followup-To';
$labels['date'] = '日付';
$labels['size'] = '大きさ';
$labels['priority'] = '優先度';
$labels['organization'] = '企業名';
$labels['readstatus'] = '閲覧の状態';
$labels['listoptions'] = '一覧のオプション...';
$labels['listoptionstitle'] = '一覧のオプション';
$labels['mailboxlist'] = 'フォルダー';
$labels['messagesfromto'] = '$count通の$from通目から$to通目のメッセージ';
$labels['threadsfromto'] = '$count通の$from通目から$to通目のスレッド';
$labels['messagenrof'] = '$count通の$nr通目のメッセージ';
$labels['fromtoshort'] = '$count通の$from通目から$to通目';
$labels['copy'] = 'コピー';
$labels['move'] = '移動';
$labels['moveto'] = 'フォルダーに移動';
$labels['copyto'] = 'コピー...';
$labels['download'] = 'ダウンロード';
$labels['open'] = '開く';
$labels['showattachment'] = '表示';
$labels['showanyway'] = 'とにかく表示';
$labels['filename'] = 'ファイル名';
$labels['filesize'] = 'ファイルの大きさ';
$labels['addtoaddressbook'] = 'アドレス帳に追加';
$labels['sun'] = '日';
$labels['mon'] = '月';
$labels['tue'] = '火';
$labels['wed'] = '水';
$labels['thu'] = '木';
$labels['fri'] = '金';
$labels['sat'] = '土';
$labels['sunday'] = '日曜日';
$labels['monday'] = '月曜日';
$labels['tuesday'] = '火曜日';
$labels['wednesday'] = '水曜日';
$labels['thursday'] = '木曜日';
$labels['friday'] = '金曜日';
$labels['saturday'] = '土曜日';
$labels['jan'] = '1月';
$labels['feb'] = '2月';
$labels['mar'] = '3月';
$labels['apr'] = '4月';
$labels['may'] = '5月';
$labels['jun'] = '6月';
$labels['jul'] = '7月';
$labels['aug'] = '8月';
$labels['sep'] = '9月';
$labels['oct'] = '10月';
$labels['nov'] = '11月';
$labels['dec'] = '12月';
$labels['longjan'] = '1月';
$labels['longfeb'] = '2月';
$labels['longmar'] = '3月';
$labels['longapr'] = '4月';
$labels['longmay'] = '5月';
$labels['longjun'] = '6月';
$labels['longjul'] = '7月';
$labels['longaug'] = '8月';
$labels['longsep'] = '9月';
$labels['longoct'] = '10月';
$labels['longnov'] = '11月';
$labels['longdec'] = '12月';
$labels['today'] = '今日';
$labels['refresh'] = '再読込み';
$labels['checkmail'] = '新しく届いたメッセージを確認';
$labels['compose'] = '新規作成';
$labels['writenewmessage'] = '新しいメッセージを作成';
$labels['reply'] = '返信';
$labels['replytomessage'] = '送信者に返信';
$labels['replytoallmessage'] = 'メーリングリスト、または送信者とすべての宛先に返信';
$labels['replyall'] = '全員に返信';
$labels['replylist'] = 'メーリングリストに返信';
$labels['forward'] = '転送';
$labels['forwardinline'] = '本文に挿入して転送';
$labels['forwardattachment'] = '添付ファイルとして転送';
$labels['forwardmessage'] = 'メッセージを転送';
$labels['bouncemsg'] = '再送(送り直し)';
$labels['bounce'] = '再送';
$labels['deletemessage'] = 'メッセージを削除';
$labels['movemessagetotrash'] = 'ごみ箱に移動';
$labels['printmessage'] = 'メッセージを印刷';
$labels['previousmessage'] = '前のメッセージを表示';
$labels['firstmessage'] = '最初のメッセージを表示';
$labels['nextmessage'] = '次のメッセージを表示';
$labels['lastmessage'] = '最後のメッセージを表示';
$labels['backtolist'] = 'メッセージの一覧に戻る';
$labels['viewsource'] = 'ソースを表示';
$labels['mark'] = 'マーク';
$labels['markmessages'] = 'マークを付ける';
$labels['markread'] = '既読に設定';
$labels['markunread'] = '未読に設定';
$labels['markflagged'] = 'フラグを設定';
$labels['markunflagged'] = 'フラグを解除';
$labels['moreactions'] = 'その他の操作...';
$labels['markallread'] = 'すべてを既読に設定';
$labels['folders-cur'] = '選択したフォルダーだけ';
$labels['folders-sub'] = '選択したフォルダーとその下位のフォルダー';
$labels['folders-all'] = 'すべてのフォルダー';
$labels['more'] = '続く';
$labels['back'] = '戻る';
$labels['options'] = 'オプション';
$labels['composeoptions'] = '作成のオプション';
$labels['optionsandattachments'] = 'オプションと添付ファイル';
$labels['actions'] = '動作';
$labels['first'] = '最初';
$labels['last'] = '最後';
$labels['previous'] = '前';
$labels['next'] = '次';
$labels['select'] = '選択';
$labels['selection'] = '選択範囲';
$labels['all'] = 'すべて';
$labels['none'] = 'なし';
$labels['currpage'] = '現在のページ';
$labels['isread'] = '既読';
$labels['unread'] = '未読';
$labels['flagged'] = 'フラグ付き';
$labels['unflagged'] = 'フラッグなし';
$labels['unanswered'] = '未返信';
$labels['withattachment'] = '添付ファイルあり';
$labels['deleted'] = '削除済み';
$labels['undeleted'] = '削除済みでない';
$labels['replied'] = '返信済み';
$labels['forwarded'] = '転送済み';
$labels['invert'] = '反転';
$labels['filter'] = 'フィルター';
$labels['list'] = '一覧';
$labels['threads'] = 'スレッド';
$labels['expand-all'] = 'すべて展開';
$labels['expand-unread'] = '未開封のメッセージを展開';
$labels['collapse-all'] = 'すべて折りたたむ';
$labels['threaded'] = 'スレッド化';
$labels['showunread'] = '未読のメッセージを表示';
$labels['autoexpand_threads'] = 'メッセージのスレッドを展開';
$labels['do_expand'] = 'すべてのスレッド';
$labels['expand_only_unread'] = '未読のメッセージだけ';
$labels['fromto'] = '発信者/宛先';
$labels['flag'] = 'フラグ';
$labels['attachment'] = '添付ファイル';
$labels['nonesort'] = 'なし';
$labels['sentdate'] = '送信日';
$labels['arrival'] = '受信日';
$labels['asc'] = '昇順';
$labels['desc'] = '降順';
$labels['listcolumns'] = '列を一覧';
$labels['listsorting'] = '並べ替える列';
$labels['listorder'] = '並べ替える順序';
$labels['listmode'] = '一覧表示モード';
$labels['lmode'] = '一覧モード';
$labels['layout'] = '配置';
$labels['layoutwidescreen'] = 'ワイド画面';
$labels['layoutdesktop'] = 'デスクトップ';
$labels['layoutlist'] = '一覧';
$labels['layoutwidescreendesc'] = 'ワイドスクリーン (3列の表示)';
$labels['layoutdesktopdesc'] = 'デスクトップ (広いリストと下にメールのプレビュー)';
$labels['layoutlistdesc'] = '一覧 (メールのプレビューなし)';
$labels['folderactions'] = 'フォルダーの操作...';
$labels['compact'] = '圧縮';
$labels['empty'] = '空';
$labels['importmessages'] = 'メッセージをインポート';
$labels['mailimportdesc'] = '<a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a>または<a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>形式を使用してメールをアップロードできます。';
$labels['mailimportzip'] = '複数のファイルをzipアーカイブに圧縮できます。';
$labels['quota'] = 'ディスクの使用状況';
$labels['unknown'] = '不明';
$labels['unlimited'] = '無制限';
$labels['quotatype'] = 'クォータの種類';
$labels['quotatotal'] = '限度';
$labels['quotaused'] = '使用';
$labels['quotastorage'] = 'ディスク容量';
$labels['quotamessage'] = 'メッセージ数';
$labels['shortheaderdate'] = '$date';
$labels['shortheaderto'] = '$date に $to 宛て';
$labels['shortheaderfrom'] = '$date に $from から';
$labels['quicksearch'] = '高速検索';
$labels['searchplaceholder'] = '検索...';
$labels['resetsearch'] = '検索を解除';
$labels['searchmod'] = '検索の条件';
$labels['msgtext'] = 'メッセージ全体';
$labels['body'] = '本文';
$labels['type'] = '種類';
$labels['namex'] = '名前';
$labels['searchscope'] = 'スコープ';
$labels['currentfolder'] = '現在のフォルダー';
$labels['subfolders'] = 'このフォルダーと下位のフォルダー';
$labels['allfolders'] = 'すべてのフォルダー';
$labels['searchinterval-1W'] = '1週間より前';
$labels['searchinterval-1M'] = '1か月より前';
$labels['searchinterval-1Y'] = '1年より前';
$labels['searchinterval1W'] = '1週間以内';
$labels['searchinterval1M'] = '1か月以内';
$labels['searchinterval1Y'] = '1年以内';
$labels['openinextwin'] = '新しいウィンドウで開く';
$labels['emlsave'] = 'ダウンロード(.eml形式)';
$labels['changeformattext'] = 'テキスト形式で表示';
$labels['changeformathtml'] = 'HTML形式で表示';
$labels['editasnew'] = '新しいメッセージとして編集';
$labels['send'] = '送信';
$labels['sendmessage'] = 'メッセージを送信';
$labels['savemessage'] = '下書きとして保存';
$labels['addattachment'] = 'ファイルを添付';
$labels['charset'] = '文字セット';
$labels['editortype'] = 'エディターの種類';
$labels['returnreceipt'] = '開封確認';
$labels['dsn'] = '配送状態通知';
$labels['mailreplyintro'] = '$date に $sender さんは書きました:';
$labels['originalmessage'] = '元のメッセージ';
$labels['selectimage'] = '画像を選択';
$labels['addimage'] = '画像を追加';
$labels['selectmedia'] = '動画を選択';
$labels['addmedia'] = '動画を追加';
$labels['encrypt'] = '暗号化';
$labels['encryptmessage'] = 'メッセージを暗号化';
$labels['encryptmessagemailvelope'] = 'Mailvelopeでメッセージを暗号化';
$labels['importpubkeys'] = '公開鍵をインポート';
$labels['encryptedsendialog'] = '暗号化したメッセージを送信中';
$labels['encryptandsign'] = '暗号化と署名';
$labels['keyid'] = 'キーID';
$labels['keylength'] = 'ビット';
$labels['keyexpired'] = '期限切れ';
$labels['keyrevoked'] = '取り消し済み';
$labels['bccinstead'] = 'Bccを使用';
$labels['addheader'] = '宛先を追加(ヘッダー)';
$labels['insert'] = '挿入';
$labels['insertcontact'] = '連絡先を挿入';
$labels['recipient'] = '宛先';
$labels['recipientedit'] = '宛先編集';
$labels['editidents'] = '識別情報を編集';
$labels['spellcheck'] = 'スペル';
$labels['checkspelling'] = 'スペルチェック';
$labels['resumeediting'] = '編集を再開';
$labels['revertto'] = '元に戻す';
$labels['restore'] = '回復';
$labels['restoremessage'] = 'メッセージを回復しますか?';
$labels['ignore'] = '無視';
$labels['responses'] = '回答';
$labels['insertresponse'] = '回答を挿入';
$labels['manageresponses'] = '回答を管理';
$labels['newresponse'] = '新しい回答を作成';
$labels['addresponse'] = '回答を追加';
$labels['editresponse'] = '回答を編集';
$labels['editresponses'] = '回答を編集';
$labels['responsename'] = '名前';
$labels['responsetext'] = '回答の文章';
$labels['attach'] = '添付';
$labels['attachments'] = '添付ファイル';
$labels['upload'] = 'アップロード';
$labels['uploadprogress'] = '$percent ($totalの$current)';
$labels['close'] = '閉じる';
$labels['messageoptions'] = 'メッセージのオプション...';
$labels['togglecomposeoptions'] = '作成のオプションを切り替え';
$labels['attachmentrename'] = '添付ファイルの名前を変更';
$labels['low'] = '低';
$labels['lowest'] = '最低';
$labels['normal'] = '通常';
$labels['high'] = '高';
$labels['highest'] = '最高';
$labels['nosubject'] = '(件名なし)';
$labels['showimages'] = '画像を表示';
$labels['allow'] = '許可';
$labels['alwaysshow'] = '$sender から届いた画像は常に表示';
$labels['alwaysallow'] = '$sender からは常に許可';
$labels['isdraft'] = 'これは下書きのメッセージです。';
$labels['andnmore'] = 'さらに$nr件...';
$labels['details'] = '詳細';
$labels['summary'] = '要約';
$labels['headers'] = 'ヘッダー';
$labels['allheaders'] = 'すべてのヘッダー...';
$labels['togglemoreheaders'] = 'さらにメッセージのヘッダーを表示';
$labels['togglefullheaders'] = 'メッセージヘッダーの生の表示と切り替え';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'テキスト';
$labels['savesentmessagein'] = '送信したメッセージの保存先';
$labels['dontsave'] = '保存しない';
$labels['maxuploadsize'] = '添付可能なファイルは最大で$sizeです。';
$labels['addcc'] = '写し(Cc)を追加';
$labels['addbcc'] = '隠した写し(Bcc)を追加';
$labels['addreplyto'] = '返信先(Reply-To)を追加';
$labels['addfollowupto'] = 'フォロー先(Followup-Toを追加';
$labels['sendreceipt'] = '開封確認を送信しますか?';
$labels['mdnrequest'] = 'このメッセージを読んだときに、送信者が通知を受けたいと依頼しています。開封確認の通知を送信しますか?';
$labels['receiptread'] = '開封確認(表示済み)';
$labels['yourmessage'] = 'これはあなたが送信したメッセージに対する開封確認です。';
$labels['receiptnote'] = '注意: この開封確認は、メッセージが宛先のコンピューターで表示されたことだけを知らせるものです。受信者がメッセージを読んだり、内容を理解したと保証するものではありません。';
$labels['sendalwaysto'] = '常に $emailに送信';
$labels['zoomin'] = 'ズームイン';
$labels['zoomout'] = 'ズームアウト';
$labels['rotate'] = '回転';
$labels['increaseimage'] = '画像のサイズを増やす';
$labels['decreaseimage'] = '画像のサイズを減らす';
$labels['rotateimage'] = '画像を回転';
$labels['showtools'] = '画像ツールを表示';
$labels['hidetools'] = '画像ツールを非表示';
$labels['name'] = '表示名';
$labels['firstname'] = '名';
$labels['surname'] = '姓';
$labels['middlename'] = 'ミドルネーム';
$labels['nameprefix'] = '敬称(名前の前)';
$labels['namesuffix'] = '敬称(名前の後)';
$labels['nickname'] = 'ニックネーム';
$labels['jobtitle'] = '職名';
$labels['department'] = '部署名';
$labels['gender'] = '性別';
$labels['maidenname'] = '旧姓';
$labels['email'] = '電子メール';
$labels['phone'] = '電話番号';
$labels['address'] = '住所';
$labels['street'] = '住所';
$labels['locality'] = '都市';
$labels['zipcode'] = '郵便番号';
$labels['region'] = '都道府県';
$labels['country'] = '国';
$labels['birthday'] = '誕生日';
$labels['anniversary'] = '記念日';
$labels['website'] = 'ウェブサイト';
$labels['instantmessenger'] = 'インスタントメッセージ';
$labels['notes'] = '注釈';
$labels['male'] = '男性';
$labels['female'] = '女性';
$labels['manager'] = '管理者';
$labels['assistant'] = 'アシスタント';
$labels['spouse'] = '配偶者';
$labels['allfields'] = 'すべての項目';
$labels['search'] = '検索';
$labels['searchresult'] = '検索の結果';
$labels['advsearch'] = '高度な検索';
$labels['advanced'] = '高度';
$labels['other'] = 'その他';
$labels['printcontact'] = '連絡先を印刷';
$labels['qrcode'] = 'QRコード';
$labels['typehome'] = '自宅';
$labels['typework'] = '職場';
$labels['typeother'] = 'その他';
$labels['typemobile'] = 'モバイル';
$labels['typemain'] = '主回線';
$labels['typehomefax'] = '自宅ファクス';
$labels['typeworkfax'] = '職場のFax';
$labels['typecar'] = '車';
$labels['typepager'] = 'ページャー(ポケットベル)';
$labels['typevideo'] = '動画';
$labels['typeassistant'] = 'アシスタント';
$labels['typehomepage'] = 'ホームページ';
$labels['typeblog'] = 'ブログ';
$labels['typeprofile'] = 'プロフィール';
$labels['addfield'] = '項目を追加...';
$labels['addcontact'] = '連絡先を追加';
$labels['editcontact'] = '連絡先を編集';
$labels['contacts'] = '連絡先';
$labels['contactproperties'] = '連絡先の属性';
$labels['contactnameandorg'] = '名前と組織';
$labels['personalinfo'] = '個人情報';
$labels['personal'] = '個人';
$labels['contactphoto'] = '連絡先の写真';
$labels['edit'] = '編集';
$labels['cancel'] = '取り止め';
$labels['save'] = '保存';
$labels['delete'] = '削除';
$labels['discard'] = '破棄';
$labels['continue'] = '継続';
$labels['ok'] = 'OK';
$labels['rename'] = '名前を変更';
$labels['addphoto'] = '追加';
$labels['replacephoto'] = '置き換え';
$labels['uploadphoto'] = '写真をアップロード';
$labels['choosefile'] = 'ファイルを選択...';
$labels['choosefiles'] = 'ファイルを選択...';
$labels['browse'] = '閲覧';
$labels['newcontact'] = '新しい連絡先を作成';
$labels['deletecontact'] = '選択した連絡先を削除';
$labels['composeto'] = 'この連絡先宛にメッセージを作成';
$labels['contactsfromto'] = '$count件の連絡先の$from件目から$to件目';
$labels['print'] = '印刷';
$labels['export'] = 'エクスポート';
$labels['exportall'] = 'すべてエクスポート';
$labels['exportsel'] = '選択した連絡先をエクスポート';
$labels['exportvcards'] = 'vCard形式でエクスポート';
$labels['newgroup'] = '新しいグループを作成';
$labels['addgroup'] = 'グループを追加';
$labels['grouprename'] = 'グループ名を変更';
$labels['groupdelete'] = 'グループを削除';
$labels['groupassign'] = 'グループに割り当て...';
$labels['groupremove'] = 'グループから削除';
$labels['groupremoveselected'] = '選択した連絡先をグループから削除';
$labels['uponelevel'] = '1つ上のレベル';
$labels['previouspage'] = '前のページを表示';
$labels['firstpage'] = '最初のページを表示';
$labels['nextpage'] = '次のページを表示';
$labels['lastpage'] = '最後のページを表示';
$labels['group'] = 'グループ';
$labels['groups'] = 'グループ';
$labels['listgroup'] = 'グループのメンバーを一覧';
$labels['personaladrbook'] = '個人の住所';
$labels['searchsave'] = '検索情報を保存';
$labels['searchdelete'] = '検索情報を削除';
$labels['import'] = 'インポート';
$labels['importcontacts'] = '連絡先をインポート';
$labels['importfromfile'] = 'ファイルからインポート';
$labels['importtarget'] = '次に連絡先を追加';
$labels['importreplace'] = 'アドレス帳全体と置き換え';
$labels['importgroups'] = 'グループの割り当てをインポート';
$labels['importgroupsall'] = 'すべて (必要ならグループを作成)';
$labels['importgroupsexisting'] = '存在するグループだけ';
$labels['importdesc'] = '既存のアドレス帳から連絡先をアップロードできます。<br/>現在、<a href="https://en.wikipedia.org/wiki/VCard">vCard</a>またはCSV(コンマ区切り)のデータ形式からのアドレスの取り込みをサポートしています。';
$labels['importmapdesc'] = 'CSV(コンマ区切り)のデータのインポートを進める前に、以下の列の対応情報を確認してください。';
$labels['fieldnotmapped'] = '列の対応なし(無視)';
$labels['skipheader'] = '最初の行(ヘッダー)を無視';
$labels['done'] = '完了';
$labels['settingsfor'] = '次の設定:';
$labels['about'] = 'このプログラムについて';
$labels['preferences'] = '設定';
$labels['userpreferences'] = 'ユーザー設定';
$labels['editpreferences'] = 'ユーザー設定を変更';
$labels['identities'] = '識別情報';
$labels['manageidentities'] = '識別情報を管理';
$labels['newidentity'] = '新しい識別情報を作成';
$labels['addidentity'] = '識別情報を追加';
$labels['editidentity'] = '識別情報を編集';
$labels['identityencryption'] = '暗号化';
$labels['preferhtml'] = 'HTMLを表示';
$labels['defaultcharset'] = '初期設定の文字セット';
$labels['htmlmessage'] = 'HTMLメッセージ';
$labels['messagepart'] = 'パート';
$labels['digitalsig'] = 'デジタル署名';
$labels['dateformat'] = '日付の書式';
$labels['timeformat'] = '時刻の書式';
$labels['prettydate'] = '短い日付で表示';
$labels['setdefault'] = '初期値を設定';
$labels['autodetect'] = '自動識別';
$labels['language'] = '言語';
$labels['timezone'] = 'タイムゾーン';
$labels['pagesize'] = '1ページの表示件数';
$labels['signature'] = '署名';
$labels['dstactive'] = 'サマータイムを適用';
$labels['showinextwin'] = '新しいウィンドウでメッセージを表示';
$labels['composeextwin'] = '新しいウィンドウでメッセージを作成';
$labels['htmleditor'] = '作成時にHTMLメッセージを使用';
$labels['htmlonreply'] = '返信時にHTMLメッセージを使用';
$labels['htmlonreplyandforward'] = '転送またはHTMLメッセージへの返信';
$labels['htmlsignature'] = 'HTMLの署名';
$labels['showemail'] = '電子メールアドレスを表示名と共に表示';
$labels['previewpane'] = 'プレビュー枠の表示';
$labels['skin'] = 'インターフェイスのスキン';
$labels['logoutclear'] = 'ログアウト時にごみ箱の内容を消去';
$labels['logoutcompact'] = 'ログアウト時にフォルダーを整理';
$labels['uisettings'] = 'ユーザーインターフェイス';
$labels['serversettings'] = 'サーバーの設定';
$labels['mailboxview'] = '受信箱';
$labels['mdnrequests'] = '開封確認の要求の処理';
$labels['askuser'] = '開封確認の送信を確認';
$labels['autosend'] = '開封確認を送信';
$labels['autosendknown'] = '送信者が連絡先に登録されているなら開封確認を送信、そうでなければ確認';
$labels['autosendknownignore'] = '送信者が連絡先に登録されているなら開封確認を送信、そうでなければ無視';
$labels['autosendtrusted'] = '受信確認を信頼する送信者に送信、そうでなければ確認';
$labels['autosendtrustedignore'] = '受信確認を信頼する送信者に送信、そうでなければ無視';
$labels['ignorerequest'] = '要求を無視';
$labels['readwhendeleted'] = '削除したメッセージを既読に設定';
$labels['flagfordeletion'] = '削除する代わりに削除済みフラグを設定';
$labels['skipdeleted'] = '削除済みのメッセージを表示しない';
$labels['deletealways'] = 'ごみ箱への移動できなかったメッセージは削除';
$labels['deletejunk'] = '迷惑メールのメッセージを直接削除';
$labels['showremoteimages'] = '外部のインライン画像を表示';
$labels['allowremoteresources'] = 'リモートのリソース(画像、スタイル)を許可';
$labels['fromknownsenders'] = '送信者が知人の場合';
$labels['fromtrustedsenders'] = '信頼した送信者から';
$labels['frommycontacts'] = '連絡先のアドレスから';
$labels['always'] = '常時';
$labels['alwaysbutplain'] = 'テキスト形式で返信するときを除いて常時';
$labels['showinlineimages'] = 'メッセージに添付された画像を下に表示';
$labels['autosavedraft'] = '自動的に下書きを保存';
$labels['everynminutes'] = '$n分毎';
$labels['refreshinterval'] = '再表示 (新しいメッセージの確認等)';
$labels['never'] = 'しない';
$labels['immediately'] = '即時';
$labels['messagesdisplaying'] = 'メッセージの表示';
$labels['messagescomposition'] = 'メッセージの作成';
$labels['mimeparamfolding'] = '添付ファイルの名前';
$labels['2231folding'] = 'RFC 2231に完全準拠(Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231(MS Outlook)';
$labels['2047folding'] = 'RFC 2047に完全準拠(その他)';
$labels['force7bit'] = '8ビット文字列にMIMEエンコードを使用';
$labels['savelocalstorage'] = "ブラウザのローカルストレージに(一時的に)保存";
$labels['advancedoptions'] = '高度な設定';
$labels['toggleadvancedoptions'] = '詳細なオプションの表示を切り替え';
$labels['focusonnewmessage'] = '新しいメッセージが届いたらブラウザーをアクティブ';
$labels['checkallfolders'] = 'すべてのフォルダーで新着メールを表示';
$labels['displaynext'] = '削除・移動した後で次の項目を表示';
$labels['defaultfont'] = 'HTMLメッセージの初期フォント';
$labels['mainoptions'] = '基本的な設定';
$labels['browseroptions'] = 'ブラウザーのオプション';
$labels['section'] = '設定項目';
$labels['maintenance'] = '保守';
$labels['newmessage'] = '新しいメッセージ';
$labels['signatureoptions'] = '署名の設定';
$labels['whenreplying'] = '返信時の本文';
$labels['replyempty'] = '元のメッセージを引用しない';
$labels['replytopposting'] = '元のメッセージを引用した前に本文を作成';
$labels['replytoppostingnoindent'] = '(字下げなしで)元のメッセージを引用した前に本文を作成';
$labels['replybottomposting'] = '元のメッセージを引用した後に本文を作成';
$labels['replyremovesignature'] = '返信時に元の署名をメッセージから削除';
$labels['autoaddsignature'] = '自動的に署名を付加';
$labels['newmessageonly'] = '新しいメッセージだけ';
$labels['replyandforwardonly'] = '返信と転送だけ';
$labels['insertsignature'] = '署名を挿入';
$labels['sigbelow'] = '引用したメッセージの後に署名を置く';
$labels['sigseparator'] = '強制的に署名に標準の分離記号を使用';
$labels['automarkread'] = 'メッセージを既読に設定';
$labels['afternseconds'] = '$n秒後';
$labels['reqmdn'] = '常に開封確認通知を要求';
$labels['reqdsn'] = '常に配送状態通知を要求';
$labels['replysamefolder'] = '返信したメッセージを元のメールと同じフォルダに保存';
$labels['defaultabook'] = '初期状態で使用するアドレス帳';
$labels['autocompletesingle'] = '自動補完で代替のメールアドレスを飛ばして進める';
$labels['listnamedisplay'] = '連絡先の一覧表示';
$labels['contactformmode'] = '次の連絡先から:';
$labels['privatemode'] = '私用(自宅)';
$labels['businessmode'] = '業務(仕事)';
$labels['collectedaddresses'] = '収集したアドレス';
$labels['collectedrecipients'] = '収集した宛先';
$labels['collectedrecipientsopt'] = '送信する電子メールの宛先の保存先';
$labels['collectedsendersopt'] = '信頼する送信者の保存先';
$labels['trustedsenders'] = '信頼する送信者';
$labels['spellcheckbeforesend'] = 'メッセージを送信する前にスペルチェック';
$labels['spellcheckoptions'] = 'スペルチェックのオプション';
$labels['spellcheckignoresyms'] = '記号を含む単語を無視';
$labels['spellcheckignorenums'] = '数字を含む単語を無視';
$labels['spellcheckignorecaps'] = 'すべて大文字の単語を無視';
$labels['addtodict'] = '辞書に追加';
$labels['mailtoprotohandler'] = 'mailto: のリンクを扱うプロトコル処理の登録';
$labels['standardwindows'] = 'ポップアップを通常のウィンドウとして処理';
$labels['forwardmode'] = 'メッセージの転送形式';
$labels['inline'] = 'インライン';
$labels['asattachment'] = '添付ファイル';
$labels['replyallmode'] = '「全員に返信」ボタンの既定の動作';
$labels['replyalldefault'] = '全員に返信';
$labels['replyalllist'] = 'メーリングリスト(とわかれば)だけに返信';
$labels['folder'] = 'フォルダー';
$labels['folders'] = 'フォルダー';
$labels['foldername'] = 'フォルダー名';
$labels['subscribed'] = '購読済み';
$labels['messagecount'] = 'メッセージ';
$labels['create'] = '作成';
$labels['createfolder'] = '新しいフォルダーを作成';
$labels['managefolders'] = 'フォルダーを管理';
$labels['specialfolders'] = '特殊なフォルダー';
$labels['properties'] = '属性';
$labels['folderproperties'] = 'フォルダーの属性';
$labels['parentfolder'] = '親のフォルダー';
$labels['location'] = '場所';
$labels['info'] = '情報';
$labels['getfoldersize'] = 'クリックしてフォルダーの大きさを取得';
$labels['changesubscription'] = 'クリックして購読状態を変更';
$labels['foldertype'] = 'フォルダーの種類';
$labels['personalfolder'] = '個人フォルダー';
$labels['otherfolder'] = '他のユーザーのフォルダー';
$labels['sharedfolder'] = '公開フォルダー';
$labels['findfolders'] = 'フォルダーを探す';
$labels['findcontacts'] = '連絡先を探す';
$labels['findmail'] = 'メールメッセージを探す';
$labels['namespace.personal'] = '個人';
$labels['namespace.other'] = '他のユーザー';
$labels['namespace.shared'] = '共有した';
$labels['dualuselabel'] = 'これだけ含められる';
$labels['dualusemail'] = 'メッセージ';
$labels['dualusefolder'] = 'フォルダー';
$labels['generate'] = '生成';
$labels['encryptioncreatekey'] = '新しい鍵ペアを作成';
$labels['openmailvelopesettings'] = 'Mailvelopeの設定を表示';
$labels['encryptionprivkeysinmailvelope'] = 'Mailvelopeのキーリングに$nr個の一致する秘密鍵:';
$labels['encryptionnoprivkeysinmailvelope'] = 'この送信者の識別情報へのPGP秘密鍵がMailvelope拡張にまだありません。メッセージの暗号化を有効にするためにPGP秘密鍵を作成しますか?';
$labels['encryption'] = '暗号化';
$labels['mailvelopeoptions'] = 'Mailvelopeのオプション';
$labels['mailvelopemainkeyring'] = 'Mailvelopeをメインのキーリングに使用';
$labels['mailvelopenotfound'] = 'ブラウザーでMailvelope拡張が無効またはインストールされていません。';
$labels['sortby'] = '並べ替え';
$labels['sortasc'] = '昇順で並べ替え';
$labels['sortdesc'] = '降順で並べ替え';
$labels['undo'] = '取り消し';
$labels['installedplugins'] = 'インストールしているプラグイン';
$labels['plugin'] = 'プラグイン';
$labels['version'] = 'バージョン';
$labels['source'] = 'ソース';
$labels['destination'] = '宛先';
$labels['license'] = 'ライセンス';
$labels['support'] = 'サポートを依頼';
$labels['savedsearches'] = '検索を保存';
$labels['dateformatY'] = 'YYYY';
$labels['dateformaty'] = 'YY';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'バイト';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = '英語';
$labels['westerneuropean'] = '西ヨーロッパ言語';
$labels['easterneuropean'] = '東ヨーロッパ言語';
$labels['southeasterneuropean'] = '南東ヨーロッパ言語';
$labels['baltic'] = 'バルト諸語';
$labels['cyrillic'] = 'キリル文字';
$labels['arabic'] = 'アラビア語';
$labels['greek'] = 'ギリシャ語';
$labels['hebrew'] = 'ヘブライ語';
$labels['turkish'] = 'トルコ語';
$labels['nordic'] = '北欧言語';
$labels['thai'] = 'タイ語';
$labels['celtic'] = 'ケルト語';
$labels['vietnamese'] = 'ベトナム語';
$labels['japanese'] = '日本語';
$labels['korean'] = '韓国語';
$labels['chinese'] = '中国語';
$labels['arialabeltopnav'] = 'ウィンドウ制御';
$labels['arialabeltasknav'] = 'アプリケーションのタスク';
$labels['arialabeltoolbar'] = 'アプリケーションのツールバー';
$labels['arialabellistnav'] = 'ナビゲーションを一覧';
$labels['arialabelactivetask'] = '活動中のタスク';
$labels['arialabelmessagessearchfilter'] = '電子メールの一覧のフィルター';
$labels['arialabelmailsearchform'] = '電子メールの検索欄';
$labels['arialabelcontactsearchform'] = '連絡先の検索欄';
$labels['arialabelmailquicksearchbox'] = '電子メールの検索を入力';
$labels['arialabelquicksearchbox'] = '検索を入力';
$labels['arialabelfoldersearchfilter'] = 'フォルダーの一覧のフィルター';
$labels['arialabelfoldersearchform'] = 'フォルダーの検索欄';
$labels['arialabelfolderlist'] = '電子メールのフォルダーの選択';
$labels['arialabelmessagelist'] = '電子メールのメッセージの一覧';
$labels['arialabelmailpreviewframe'] = 'メッセージのプレビュー';
$labels['arialabelmailboxmenu'] = 'フォルダーの操作メニュー';
$labels['arialabellistselectmenu'] = '一覧の選択メニュー';
$labels['arialabelthreadselectmenu'] = 'スレッドの一覧メニュー';
$labels['arialabelmessagelistoptions'] = 'メッセージの一覧の表示と並べ替えのオプション';
$labels['arialabelmailimportdialog'] = 'メッセージを取り込むダイアログ';
$labels['arialabelmessagenav'] = 'メッセージのナビゲーション';
$labels['arialabelmessagebody'] = 'メッセージの本文';
$labels['arialabelmessageactions'] = 'メッセージの操作';
$labels['arialabelcontactquicksearch'] = '連絡先の検索欄';
$labels['arialabelcontactsearchbox'] = '連絡先を入力';
$labels['arialabelmessageheaders'] = 'メッセージのヘッダー';
$labels['arialabelforwardingoptions'] = '転送のオプション';
$labels['arialabelreplyalloptions'] = '全員に返信のオプション';
$labels['arialabelmoremessageactions'] = 'さらにメッセージを操作';
$labels['arialabelmorecontactactions'] = 'さらに連絡先を操作';
$labels['arialabelmarkmessagesas'] = '選択したメッセージに次のマーク...';
$labels['arialabelcomposeoptions'] = '作成のオプション';
$labels['arialabelresponsesmenu'] = '回答テンプレートメニュー';
$labels['arialabelattachmentuploadform'] = '添付ファイルのアップロードフォーム';
$labels['arialabelattachmentmenu'] = '添付ファイルのオプション';
$labels['arialabelmailtomenu'] = '電子メールアドレスのオプション';
$labels['arialabelattachmentpreview'] = '添付ファイルのプレビュー';
$labels['ariasummarycomposecontacts'] = '宛先として選択する連絡先とグループの一覧';
$labels['arialabelcontactexportoptions'] = '連絡先のエクスポートのオプション';
$labels['arialabelabookgroupoptions'] = 'アドレス帳・グループのオプション';
$labels['arialabelpreferencesform'] = '設定のフォーム';
$labels['arialabelidentityeditfrom'] = '識別情報のフォーム';
$labels['arialabelresponseeditfrom'] = '回答のフォーム';
$labels['arialabelsearchterms'] = '検索語';
$labels['arialabeldropactionmenu'] = 'ドラッグ・アンド・ドロップの動作メニュー';
$labels['arialabelheadersmenu'] = '宛先(ヘッダー)を追加するメニュー';
$labels['arialabelimagetools'] = '画像ツール';
$labels['helplistnavigation'] = 'キーボードのナビゲーションの一覧';
$labels['helplistkeyboardnavigation'] = "上矢印・下矢印: 選択する行を移動します。
スペース: 現在の行を選択します。
シフトキーを押しながら上矢印・下矢印: 上・下の行を選択に追加します。
コントロールきーを押しながらスペース: 現在の行を選択に追加または削除します。";
$labels['helplistkeyboardnavmessages'] = "右矢印・左矢印: メッセージのスレッドを展開・折り畳みします。(スレッドモードだけ)
改行: 現在・選択しているメッセージを開きます。
削除: 選択しているメッセージをゴミ箱に移動します。";
$labels['helplistkeyboardnavcontacts'] = "改行: 現在・選択中の連絡先を開きます。";
