<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Det oppsto en feil!';
$messages['loginfailed']  = 'Pålogging mislyktes';
$messages['cookiesdisabled'] = 'Nettleseren din tillater ikke informasjonskapsler (cookies)';
$messages['sessionerror'] = 'Din nettlesertilkobling er ugyldig eller utløpt';
$messages['storageerror'] = 'Tilkobling til IMAP-tjener mislyktes.';
$messages['servererror'] = 'Tjenerfeil!';
$messages['servererrormsg'] = 'Tjenerfeil: $msg';
$messages['accountlocked'] = 'For mange feilede innloggingsforsøk. Prøv igjen senere.';
$messages['connerror'] = 'Tilkoblingsfeil (Kunne ikke nå server)!';
$messages['dberror'] = 'Databasefeil!';
$messages['windowopenerror'] = 'Popup-vinduet ble blokkert!';
$messages['requesttimedout'] = 'Forespørselen har fått et tidsavbrudd';
$messages['errorreadonly'] = 'Kunne ikke utføre handlingen. Mappen kan kun leses.';
$messages['errornoperm'] = 'Kan ikke utføre operasjon. Nektet tilgang.';
$messages['erroroverquota'] = 'Kunne ikke utføre handlingen, tomt for diskplass.';
$messages['erroroverquotadelete'] = 'Ingen ledig plass på disk. Bruk SHIFT+DEL for å slette en melding.';
$messages['invalidrequest'] = 'Ugyldig forespørsel! Ingen data ble lagret.';
$messages['invalidhost'] = 'Ugyldig servernavn.';
$messages['nomessagesfound'] = 'Det ble ikke funnet noen meldinger i denne mappen';
$messages['mailboxempty'] = 'Mappen er tom';
$messages['nomessages'] = 'Ingen meldinger';
$messages['refreshing'] = 'Oppdaterer …';
$messages['loading'] = 'Laster...';
$messages['uploading'] = 'Laster opp fil...';
$messages['attaching'] = 'Legger til vedlegg...';
$messages['uploadingmany'] = 'Laster opp filer ...';
$messages['loadingdata'] = 'Laster data...';
$messages['checkingmail'] = 'Sjekker for nye meldinger...';
$messages['sendingmessage'] = 'Sender melding...';
$messages['messagesent'] = 'Meldingen ble sendt';
$messages['savingmessage'] = 'Lagrer melding...';
$messages['messagesaved'] = 'Melding er lagret som kladd';
$messages['successfullysaved'] = 'Lagret';
$messages['savingresponse'] = 'Lagrer svartekst...';
$messages['deleteresponseconfirm'] = 'Vil du virkelig å slette denne svarteksten?';
$messages['nocontactselected'] = 'Du har ennå ikke markert en kontakt.';
$messages['addedsuccessfully'] = 'Kontakten ble lagt til i adresseboken';
$messages['contactnameexists'] = 'Det finnes allerede en kontakt med dette navnet';
$messages['blockedimages'] = 'Av sikkerhetsgrunner er bilder lagret på eksterne servere blokkert fra denne e-postmeldingen';
$messages['encryptedmessage'] = 'Dette er en kryptert melding som ikke kan vises. Beklager!';
$messages['nopubkeyfor'] = 'Ingen gyldig offentlig nøkkel ble funnet for $email';
$messages['encryptpubkeysfound'] = 'Følgende offentlige nøkler har blitt funnet:';
$messages['nocontactsfound'] = 'Ingen kontakter ble funnet';
$messages['contactnotfound'] = 'Den ønskede kontakten ble ikke funnet';
$messages['sendingfailed'] = 'Kunne ikke sende e-posten';
$messages['senttooquickly'] = 'Vennligst vent $sec sekund(er) før du sender denne meldingen';
$messages['errorsavingsent'] = 'En feil oppsto under lagring av sendt melding.';
$messages['errorsaving'] = 'En feil oppsto under lagring.';
$messages['errormoving'] = 'Kunne ikke flytte meldingen(e)';
$messages['errorcopying'] = 'Kunne ikke kopiere meldingen(e)';
$messages['errordeleting'] = 'Kunne ikke slette meldingen(e)';
$messages['errormarking'] = 'Kunne ikke markere meldingen(e)';
$messages['confirmationtitle'] = 'Er du sikker...';
$messages['deletecontactconfirm']  = 'Vil du virkelig slette valgte kontakt(er)?';
$messages['deletegroupconfirm']  = 'Vil du virkelig slette den valgte gruppa?';
$messages['deletemessagesconfirm'] = 'Vil du virkelig slette de(n) valgte meldingen(e)?';
$messages['deletefolderconfirm']  = 'Vil du virkelig slette denne mappen?';
$messages['purgefolderconfirm']  = 'Vil du virkelig slette alle meldingene i denne mappen?';
$messages['contactdeleting'] = 'Sletter kontakt(er) ...';
$messages['groupdeleting'] = 'Sletter gruppe ...';
$messages['folderdeleting'] = 'Sletter mappe...';
$messages['foldermoving'] = 'Flytter mappe...';
$messages['foldersubscribing'] = 'Abonnerer på mappe ...';
$messages['folderunsubscribing'] = 'Avslutter mappeabonnement ...';
$messages['formincomplete'] = 'Skjemaet var ikke fullstendig fylt ut';
$messages['noemailwarning'] = 'Vennligst oppgi en gyldig epostadresse.';
$messages['nonamewarning']  = 'Angi et navn';
$messages['nopagesizewarning'] = 'Angi sidestørrelsen';
$messages['norecipientwarning'] = 'Skriv inn minst én mottaker';
$messages['nosubjectwarning']  = 'Emnefeltet er tomt. Vil du skrive det inn nå?';
$messages['nosubjecttitle']  = 'Intet emne';
$messages['nobodywarning'] = 'Send denne meldingen uten tekst?';
$messages['restoresavedcomposedata'] = 'Et tidligere usendt svar ble funnet.\n\nEmne: $subject\nLagret: $date\n\nVil du gjenopprette denne meldingen?';
$messages['nosearchname'] = 'Venligst skriv inn kontaktens navn eller e-postadresse';
$messages['notuploadedwarning'] = 'Ikke alle vedlegg er ferdig opplastet. Vennligst vent eller avbryt opplastingen.';
$messages['searchsuccessful'] = '$nr meldinger funnet';
$messages['contactsearchsuccessful'] = '$nr kontakter funnet.';
$messages['searchnomatch'] = 'Søket ga ingen resultater';
$messages['searching'] = 'Søker …';
$messages['checking'] = 'Sjekker …';
$messages['stillsearching'] = 'Søker fortsatt...';
$messages['nospellerrors'] = 'Fant ingen skrivefeil.';
$messages['folderdeleted'] = 'Mappe slettet.';
$messages['foldersubscribed'] = 'Abonnerte på mappen.';
$messages['folderunsubscribed'] = 'Avsluttet mappeabonnement.';
$messages['deletedsuccessfully'] = 'Slettet';
$messages['converting'] = 'Fjerner formatering fra meldingen ...';
$messages['messageopenerror'] = 'Kunne ikke hente meldingen fra server';
$messages['fileuploaderror'] = 'Feil under opplastning.';
$messages['filesizeerror'] = 'Filen overstiger maksimum tillatt filstørrelse ($size)';
$messages['copysuccess'] = 'Kopierte $nr kontakter.';
$messages['movesuccess'] = 'Flyttet $nr kontakter.';
$messages['copyerror'] = 'Kunne ikke kopiere noen kontakter.';
$messages['moveerror'] = 'Kunne ikke flytte noen kontakter.';
$messages['sourceisreadonly'] = 'Denne adressekilden er skrivebeskyttet';
$messages['errorsavingcontact'] = 'Kunne ikke lagre kontaktadressen.';
$messages['movingmessage'] = 'Flytter e-post ...';
$messages['copyingmessage'] = 'Kopierer e-post...';
$messages['copyingcontact'] = 'Kopierer kontakt(er) …';
$messages['movingcontact'] = 'Flytter kontakt(er)...';
$messages['deletingmessage'] = 'Sletter melding(er) …';
$messages['markingmessage'] = 'Markerer melding(er) ...';
$messages['addingmember'] = 'Legger til kontakt(er) i gruppa ...';
$messages['removingmember'] = 'Fjerner kontakt(er) fra gruppa ...';
$messages['receiptsent'] = 'Kvittering er sent';
$messages['errorsendingreceipt'] = 'Kunne ikke sende til mottaker';
$messages['deleteidentityconfirm'] = 'Vil du virkelig å slette denne identiteten?';
$messages['nodeletelastidentity'] = 'Du kan ikke slette den siste identiteten din.';
$messages['forbiddencharacter'] = 'Mappenavnet inneholder tegn som ikke er tillatt';
$messages['selectimportfile'] = 'Vennligst velg en fil for opplasting';
$messages['addresswriterror'] = 'Den valgte adresseboken er ikke skrivbar';
$messages['contactaddedtogroup'] = 'Lagt til kontakter til denne gruppen.';
$messages['contactremovedfromgroup'] = 'Kontaktene ble vellykket fjernet fra denne gruppen';
$messages['nogroupassignmentschanged'] = 'Ingen gruppetilordninger ble endret.';
$messages['importwait'] = 'Importerer, vennligst vent...';
$messages['importformaterror'] = 'Import feilet! Den opplastede filen er i feil format.';
$messages['importconfirm'] = '<b>Importerte $inserted kontakter</b>';
$messages['importconfirmskipped'] = '<b>Hoppet over $skipped eksisterende oppføringer</b>';
$messages['importmessagesuccess'] = 'Kopierte $nr meldinger';
$messages['importmessageerror'] = 'Importeringen var mislykket! Den opplastede filen er ikke en gyldig melding, eller er ikke kompatibel med meldingssystemet.';
$messages['opnotpermitted'] = 'Handling ikke tillatt!';
$messages['httpreceivedencrypterror'] = 'En uopprettelig feil oppsto. Vennligst kontakt systemansvarlig umiddelbart. <b>Din melding kunne ikke sendes.</b>';
$messages['smtpconnerror'] = 'SMTP-feil ($code): Klarte ikke koble til server';
$messages['smtpautherror'] = 'SMTP-feil ($code): Pålogging feilet';
$messages['smtpfromerror'] = 'SMTP-feil ($code): Kunne ikke sette avsender "$from" ($msg)';
$messages['smtptoerror'] = 'SMTP-feil ($code): Kunne ikke legge til mottaker "$to" ($msg)';
$messages['smtprecipientserror'] = 'SMTP-feil ($code): Kunne ikke lese mottakerliste';
$messages['smtperror'] = 'SMTP-feil ($code): $msg';
$messages['toomanyrecipients'] = 'For mange mottakere. Reduser antall mottakere til $max.';
$messages['maxgroupmembersreached'] = 'Antall gruppemedlemmer overskrider maksgrensen på $max';
$messages['internalerror'] = 'En intern feil har oppstått, prøv igjen senere.';
$messages['contactdelerror'] = 'Kunne ikke slette kontakt(er)';
$messages['contactdeleted'] = 'Kontakt(er) slettet uten feil.';
$messages['contactrestoreerror'] = 'Kunne ikke gjenopprette kontakt(er).';
$messages['contactrestored'] = 'Kontakten(e) gjennomrettet uten feil.';
$messages['groupdeleted'] = 'Gruppen er slettet.';
$messages['grouprenamed'] = 'Gruppen er omdøpt uten feil.';
$messages['groupcreated'] = 'Gruppen er opprettet';
$messages['savedsearchdeleted'] = 'Lagrede søk er slettet.';
$messages['savedsearchdeleteerror'] = 'Kunne ikke slette lagrede søk.';
$messages['savedsearchcreated'] = 'Lagret søk har blitt opprettet.';
$messages['savedsearchcreateerror'] = 'Kunne ikke opprette lagret søk.';
$messages['messagedeleted'] = 'Meldingen(e) er slettet.';
$messages['messagemoved'] = 'Meldingen(e) er  flyttet.';
$messages['messagecopied'] = 'Meldingen(e) er kopiert.';
$messages['messagemarked'] = 'Meldingen(e) er markert.';
$messages['autocompletechars'] = 'Skriv inn minst $min tegn for autofullføring.';
$messages['autocompletemore'] = 'Flere like oppføring funnet. Vennligst skriv flere tegn.';
$messages['namecannotbeempty'] = 'Navn kan ikke være tomt.';
$messages['nametoolong'] = 'Navnet er for langt.';
$messages['namedotforbidden'] = 'Mappenavn kan ikke starte med punktum.';
$messages['folderupdated'] = 'Mappen er oppdatert.';
$messages['foldercreated'] = 'Mappe opprettet.';
$messages['invalidimageformat'] = 'Ikke et gyldig bildeformat.';
$messages['mispellingsfound'] = 'Fant stavefeil i meldingen.';
$messages['parentnotwritable'] = 'Kunne ikke opprette/flytte mappen i valgt overordnet mappe. Ingen tilgangsrettigheter.';
$messages['messagetoobig'] = 'Meldingsdelen er for stor til at den kan prosesseres.';
$messages['noscriptwarning'] = 'NB: Denne webmail-klienten krever Javascript! Skru på Javascript i nettleseren din for å kunne bruke den.';
$messages['errnotfound'] = 'Filen ble ikke funnet';
$messages['listempty'] = 'Listen er tom.';
