<roundcube:object name="doctype" value="html5" />
<html>
<head>
<roundcube:include file="/includes/links.html" />
</head>
<body class="iframe fullheight">

<h1 class="voice"><roundcube:label name="addressbook" /> : <roundcube:label name="advsearch" /></h1>

<div id="contact-details" class="boxcontent">
	<roundcube:object name="searchform" id="advsearchform" class="tabbed" size=30 />
</div>

<roundcube:include file="/includes/footer.html" />

</body>
</html>
