span.blockquote-link {
  font-family: "Lucida Grande", Verdana, Arial, Helvetica, sans-serif;
  top: 0;
  cursor: pointer;
  right: 5px;
  height: 14px;
  min-width: 40px;
  padding: 0 8px;
  font-size: 10px;
  font-weight: bold;
  color: #a8a8a8;
  line-height: 14px;
  text-decoration: none;
  text-shadow: 0px 1px 1px #fff;
  text-align: center;
  border: 1px solid #e8e8e8;
  border-top: none;
  border-bottom-right-radius: 6px;
  border-bottom-left-radius: 6px;
  background: #f8f8f8;
  background: -moz-linear-gradient(top, #f8f8f8 0%, #e8e8e8 100%);
  background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#f8f8f8), color-stop(100%,#e8e8e8));
  background: -o-linear-gradient(top, #f8f8f8 0%, #e8e8e8 100%);
  background: -ms-linear-gradient(top, #f8f8f8 0%, #e8e8e8 100%);
  background: linear-gradient(top, #f8f8f8 0%, #e8e8e8 100%);
}

blockquote.blockquote-header {
  text-overflow: ellipsis !important;
  padding-right: 60px !important;
}