/*** Style for Enigma plugin ***/

/***** Messages displaying *****/

#enigma-message,
#messagebody div #enigma-message
{
  margin: 0;
  margin-bottom: 5px;
  padding: 6px 12px 6px 30px;
  font-weight: bold;
}

div.enigmaerror,
#messagebody div.enigmaerror
{
  background: url(enigma_icons.png) 3px -201px no-repeat #f2cccd;
  border: 1px solid #c00005;
  color: #c00005;
}

div.enigmanotice,
#messagebody div.enigmanotice
{
  background: url(enigma_icons.png) 3px -171px no-repeat #c9e6d3;
  border: 1px solid #008a2e;
  color: #008a2e;
}

div.enigmawarning,
#messagebody div.enigmawarning
{
  background: url(enigma_icons.png) 3px -231px no-repeat #fef893;
  border: 1px solid #ffdf0e;
  color: #960;
}

#enigma-message a
{
  color: #666666;
  padding-left: 10px;
}

#enigma-message a:hover
{
  color: #333333;
}

p.enigmaattachment {
  margin: 0.5em 1em;
  width: auto;
  background: #f9f9f9;
  border: 1px solid #d3d3d3;
  border-radius: 4px;
}

p.enigmaattachment span {
  display: inline-block;
  background: url(enigma_icons.png) 8px -78px no-repeat;
  padding: 1em 0.5em 1em 46px;
}

/***** E-mail Compose Page *****/

#messagetoolbar a.button.enigma {
  background-image: url(enigma_icons.png);
  background-position: center -122px;
  background-repeat: no-repeat;
}

#enigmamenu {
  color: white;
  padding: 2px 5px;
}

#enigmamenu div.row {
  display: table-row;
}

#enigmamenu div.row > label {
  display: table-cell;
  padding: 3px;
}

#enigmamenu div.row > div {
  display: table-cell;
  padding: 3px;
}

/***** Keys/Certs Management *****/

#settings-sections .enigma.keys a {
  background-image: url(enigma_icons.png);
  background-position: 7px -345px;
  background-repeat: no-repeat;
}

#settings-sections .enigma.keys.selected a {
  background-image: url(enigma_icons.png);
  background-position: 7px -368px;
  background-repeat: no-repeat;
}

#sections-table #rcmrowenigma .section {
  background-image: url(enigma_icons.png);
  background-position: 5px -297px;
  background-repeat: no-repeat;
}

#sections-table #rcmrowenigma.selected .section {
  background-image: url(enigma_icons.png);
  background-position: 5px -321px;
  background-repeat: no-repeat;
}

#mainscreen.enigma #settings-sections,
#mainscreen.enigma #settings-right
{
  top: 44px;
}

#enigmacontent-box
{
  position: absolute;
  top: 0px;
  left: 272px;
  right: 0px;
  bottom: 0px;
}

#enigmakeyslist
{
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  width: 260px;
}

#keylistcountbar
{
  margin-top: 4px;
  margin-left: 4px;
}

#keys-table
{
  width: 100%;
  table-layout: fixed;
}

#keys-table td
{
  text-overflow: ellipsis;
}

#keyimportform fieldset div
{
  background-color: #eee;
  padding: 10px;
}

#keycreateform td > label {
  display: block;
}

#keycreateform ul.proplist li {
  border: 0;
  padding: 2px 0;
}

#keystoolbar
{
  position: absolute;
  top: -6px;
  left: 0;
  height: 40px;
  white-space: nowrap;
  z-index: 10;
}

#keystoolbar a.import {
  background: url(enigma_icons.png) center 0 no-repeat transparent;
}

#keystoolbar a.export {
  background: url(enigma_icons.png) center -40px no-repeat transparent;
}
