<roundcube:include file="includes/layout.html" />
<roundcube:include file="includes/menu.html" />
<roundcube:include file="includes/settings-menu.html" />

<h1 class="voice"><roundcube:label name="responses" /></h1>

<!-- responses list -->
<div id="layout-list" class="listbox selected" aria-labelledby="aria-label-responseslist">
	<div class="header">
		<a class="button icon back-sidebar-button" href="#sidebar"><span class="inner"><roundcube:label name="settings" /></span></a>
		<span id="aria-label-responseslist" class="header-title"><roundcube:label name="responses" /></span>
		<a class="button icon toolbar-menu-button" href="#list-menu"><span class="inner"><roundcube:label name="menu" /></span></a>
	</div>
	<div class="scroller">
		<roundcube:object name="responseslist" id="responses-table" class="listing"
			noheader="true" role="listbox" data-list="responses_list"
			data-label-msg="listempty" data-label-ext="listusebutton" data-create-command="add" />
	</div>
	<div class="footer"></div>
</div>

<!-- response details frame -->
<div id="layout-content" role="main">
	<h2 id="aria-label-toolbar" class="voice"><roundcube:label name="arialabeltoolbar" /></h2>
	<div class="header" role="toolbar" aria-labelledby="aria-label-toolbar">
		<a class="button icon back-list-button" href="#back"><span class="inner"><roundcube:label name="back" /></span></a>
		<span class="header-title"></span>
		<!-- toolbar -->
		<div id="responsestoolbar" class="toolbar menu">
			<roundcube:button command="add" type="link" class="create disabled" classAct="create"
				label="create" title="newresponse" innerClass="inner" data-fab="true" />
			<roundcube:button command="delete" type="link" class="delete disabled" classAct="delete"
				label="delete" title="delete" innerClass="inner" />
		</div>
	</div>
	<div class="iframe-wrapper">
		<roundcube:object name="contentframe" id="preferences-frame" src="env:blankpage" title="arialabelresponseeditfrom" />
	</div>
</div>

<roundcube:include file="includes/footer.html" />
