<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Scagairí';
$labels['managefilters'] = 'Bainistigh na scagairí do theachtaireachtaí isteach';
$labels['filtername'] = 'Ainm an scagaire';
$labels['newfilter'] = 'Scagaire nua';
$labels['filteradd'] = 'Cuir scagaire leis';
$labels['filterdel'] = 'Scrios an scagaire';
$labels['rules'] = 'Rialacha';
$labels['actions'] = 'Gníomhartha';
$labels['scope'] = 'Raon feidhme';
$labels['moveup'] = 'Bog suas';
$labels['movedown'] = 'Bog síos';
$labels['filterany'] = 'gach teachtaireacht';
$labels['filtercontains'] = 'ina bhfuil';
$labels['filternotcontains'] = 'níl seo ann';
$labels['filteris'] = 'cothrom le';
$labels['filterisnot'] = 'níl sé cothrom le';
$labels['filterunder'] = 'faoi';
$labels['filterover'] = 'thar';
$labels['mime-message'] = 'teachtaireacht';
$labels['mime-anychild'] = 'ceann ar bith';
$labels['mime-type'] = 'cineál';
$labels['mime-subtype'] = 'fochineál';
$labels['mime-param'] = 'paraiméadar';
$labels['addrule'] = 'Cuir rial leis';
$labels['delrule'] = 'Scrios an rial';
$labels['messagemoveto'] = 'Bog teachtaireacht chuig';
$labels['messageredirect'] = 'Atreoraigh an teachtaireacht chuig';
$labels['messagecopyto'] = 'Macasamhlaigh an teachtaireacht chuig';
$labels['messagesendcopy'] = 'Seol macasamhail den teachtaireacht chuig';
$labels['messagereply'] = 'Freagair le teachtaireacht';
$labels['messagedelete'] = 'Scrios an teachtaireacht';
$labels['messagediscard'] = 'Cuileáil leis an teachtaireacht';
$labels['messagekeep'] = 'Coinnigh an teachtaireacht sa Bhosca Isteach';
$labels['messagesrules'] = 'I gcomhair teachtaireachtaí isteach:';
$labels['messagesactions'] = '...rith na gníomhartha seo a leanas:';
$labels['add'] = 'Cuir leis';
$labels['del'] = 'Scrios';
$labels['sender'] = 'Seoltóir';
$labels['recipient'] = 'Faighteoir';
$labels['vacationaddr'] = 'Mo sheoltaí ríomhphoist:';
$labels['vacationdays'] = 'Cé chomh minic ar chóir teachtaireachtaí a sheoladh (i laetheanta):';
$labels['vacationinterval'] = 'Cé chomh minic ar chóir teachtaireachtaí a sheoladh:';
$labels['vacationfrom'] = 'Seoladh fhreagair an tseoltóra:';
$labels['vacationsubject'] = 'Ábhar na teachtaireachta:';
$labels['days'] = 'lá';
$labels['seconds'] = 'soicind';
$labels['enable'] = 'Cumasaigh/Díchumasaigh';
$labels['filtersets'] = 'Tacair scagairí';
$labels['filterdef'] = 'Sainmhíniú an fhillteáin';
$labels['active'] = 'gníomhach';
$labels['none'] = 'dada';
$labels['fromset'] = 'ón tacair';
$labels['fromfile'] = 'ón gcomhad';
$labels['filterdisabled'] = 'Díchumasaíodh an scagaire';
$labels['valueisgreaterthan'] = 'tá an luach níos mó ná';
$labels['valueisgreaterthanequal'] = 'tá an luach níos mó ná nó cothrom le';
$labels['valueislessthan'] = 'tá an luach níos lú ná';
$labels['valueequals'] = 'tá an luach cothrom le';
$labels['removeflags'] = 'Bain bratacha ón teachtaireacht';
$labels['flagread'] = 'Léite';
$labels['flagdeleted'] = 'Scriosta';
$labels['flaganswered'] = 'Freagartha';
$labels['flagflagged'] = 'Bratach curtha leis';
$labels['flagdraft'] = 'Cum teachtaireacht';
$labels['headeratstart'] = 'ag an tús';
$labels['headeratend'] = 'ag an deireadh';
$labels['headerfromstart'] = 'ón tús';
$labels['headerfromend'] = 'ón deireadh';
$labels['setvariable'] = 'Socraigh athraitheach';
$labels['setvarmodifiers'] = 'Mionathraitheoirí:';
$labels['varlower'] = 'cás íochtar';
$labels['varupper'] = 'cás uachtar';
$labels['varlength'] = 'fad';
$labels['notify'] = 'Seol fógra';
$labels['notifytarget'] = 'Sprioc an fhógra:';
$labels['notifyimportance'] = 'Tábhacht:';
$labels['notifyimportancelow'] = 'íseal';
$labels['notifyimportancenormal'] = 'gnáth';
$labels['notifyimportancehigh'] = 'ard';
$labels['notifymethodmailto'] = 'Seoladh ríomhphoist';
$labels['notifymethodtel'] = 'Guthán';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Cruthaigh scagaire';
$labels['nextstep'] = 'An chéad chéim eile';
$labels['...'] = '...';
$labels['string'] = 'Teaghrán';
$labels['currdate'] = 'An dáta reatha';
$labels['datetest'] = 'Dáta';
$labels['dateheader'] = 'ceanntásc:';
$labels['year'] = 'bliain';
$labels['month'] = 'mí';
$labels['day'] = 'lá';
$labels['date'] = 'dáta (bbbb-mm-ll)';
$labels['julian'] = 'dáta (Iúil)';
$labels['hour'] = 'uair';
$labels['minute'] = 'nóiméad';
$labels['second'] = 'soicind';
$labels['time'] = 'am (uu:nn:ss)';
$labels['iso8601'] = 'dáta (ISO8601)';
$labels['std11'] = 'dáta (RFC2822)';
$labels['zone'] = 'crios ama';
$labels['weekday'] = 'lá oibre (0-6)';
$labels['advancedopts'] = 'Ardroghanna';
$labels['body'] = 'Corp';
$labels['address'] = 'seoladh';
$labels['envelope'] = 'clúdach litreach';
$labels['modifier'] = 'mionathraitheoir:';
$labels['text'] = 'téacs';
$labels['modtype'] = 'cineál:';
$labels['allparts'] = 'uile';
$labels['domain'] = 'fearann';
$labels['localpart'] = 'páirt logánta';
$labels['user'] = 'úsáideoir';
$labels['detail'] = 'mionsonra';
$labels['default'] = 'réamhshocrú';
$labels['index'] = 'Treorán:';
$labels['indexlast'] = 'siar';
$labels['spamtestequals'] = 'cothrom le';
$labels['spamtestnotequals'] = 'níl sé cothrom le';
$labels['vacation'] = 'As Oifig';
$labels['vacation.reply'] = 'Freagair an teachtaireacht';
$labels['vacation.advanced'] = 'Ardsocruithe';
$labels['vacation.subject'] = 'Ábhar';
$labels['vacation.body'] = 'Corp';
$labels['vacation.start'] = 'Am tosaigh';
$labels['vacation.end'] = 'Am le críochnú';
$labels['vacation.status'] = 'Treo';
$labels['vacation.on'] = 'Ar siúl';
$labels['vacation.off'] = 'As';
$labels['vacation.addresses'] = 'Mo sheoltaí ríomhphoist';
$labels['vacation.interval'] = 'Eatramh an fhreagra';
$labels['vacation.keep'] = 'Coinnigh';
$labels['vacation.discard'] = 'Cuileáil';
$labels['vacation.redirect'] = 'Atreoraigh chuig';
$labels['vacation.copy'] = 'Seol macasamhail chuig';
$labels['forward'] = 'Cur ar aghaidh';
$labels['forward.redirect'] = 'Atreoraigh chuig';
$labels['forward.copy'] = 'Seol macasamhail chuig';
$labels['forward.on'] = 'Ar siúl';
$labels['forward.off'] = 'As';
$labels['forward.status'] = 'Treo:';
$labels['filladdresses'] = 'Líon le mo sheoltaí uile';
$labels['arialabelfilteractions'] = 'Gníomhartha an scagaire';
$labels['arialabelfilterform'] = 'Airíonna an fhillteáin';
$labels['ariasummaryfilterslist'] = 'Liosta de na fillteáin';
$labels['message'] = 'Teachtaireacht';
$labels['duplicate.header'] = 'ceanntásc:';
$labels['duplicate.uniqueid'] = 'aitheantóir:';
$messages['filterdeleted'] = 'Scriosadh an fillteán go ráthúil.';
$messages['filterdeleteconfirm'] = 'An bhfuil tú cinnte gur mian leat an scagaire roghnaithe a scriosadh?';
$messages['ruledeleteconfirm'] = 'An bhfuil tú cinnte gur mian leat an riail roghnaithe sin a scriosadh?';
$messages['actiondeleteconfirm'] = 'An bhfuil tú cinnte gur mian leat an gníomh roghnaithe a scriosadh?';
$messages['forbiddenchars'] = 'Tá carachtair neamhcheadaithe sa réimse.';
$messages['cannotbeempty'] = 'Ní féidir leis an réimse bheith folamh.';
$messages['ruleexist'] = 'Tá an scagaire leis an ainm sonraithe ann cheana.';
$messages['moved'] = 'Bogadh an scagaire go ráthúil.';
$messages['nametoolong'] = 'Tá an t-ainm rófhada.';
$messages['namereserved'] = 'Ainm curtha in áirithe.';
$messages['setexist'] = 'Tá an tacair sin ann cheana.';
$messages['nodata'] = 'Caithfear ar a laghad suíomh amháin a roghnú!';
$messages['disabledaction'] = 'Ní cheadaítear an gníomh sin.';
