<roundcube:object name="doctype" value="html5" />
<html>
<head>
<roundcube:include file="/includes/links.html" />
</head>
<body class="iframe fullheight">

<h1 class="voice"><roundcube:label name="enigma.importkeys" /></h1>

<div id="import-form" class="boxcontent">
    <roundcube:object name="importform" class="propform" id="keyimportform" part="search" />
</div>

<roundcube:include file="/includes/footer.html" />

</body>
</html>
