<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Bi xêr hatî $product\'ê';
$labels['username'] = 'Bikarhêner';
$labels['password'] = 'Nasnav';
$labels['server'] = 'Pêşkêşkar';
$labels['login'] = 'Têkevê';
$labels['logout'] = 'Derkeve';
$labels['mail'] = 'E-Peyam';
$labels['settings'] = 'Mîhengên Takekesî';
$labels['addressbook'] = 'Lênûska Navnîşanan';
$labels['inbox'] = 'Hatî';
$labels['drafts'] = 'Hilanînî';
$labels['sent'] = 'Şandî';
$labels['trash'] = 'Çop';
$labels['junk'] = 'Biikêrnehatî';
$labels['show_real_foldernames'] = 'Ji bo dosyeyên taybet navên rast bide nîşan';
$labels['subject'] = 'Mijar';
$labels['from'] = 'Şandyar';
$labels['sender'] = 'Şandyar';
$labels['to'] = 'Standyar';
$labels['cc'] = 'Kopiya Karbon';
$labels['bcc'] = 'Kopiya karbon a Veşartî';
$labels['replyto'] = 'Navnîşanên Standyar';
$labels['date'] = 'Dîrok';
$labels['size'] = 'Mezinahî';
$labels['priority'] = 'Girîngî';
$labels['organization'] = 'Sazî';
$labels['readstatus'] = 'Rewşê bixwîne';
$labels['listoptions'] = 'Vebijêrk tên rêzkirin...';
$labels['mailboxlist'] = 'Peldank';
$labels['messagesfromto'] = 'Peyam $count ên di navbera $from - $to';
$labels['messagenrof'] = '$nr a peyama $count';
$labels['fromtoshort'] = '$from – $to ji $count';
$labels['copy'] = 'Kopiya Karbon';
$labels['move'] = 'Bibe';
$labels['moveto'] = 'bibe...';
$labels['copyto'] = 'Kopyayek çêke li ser ...';
$labels['download'] = 'Daxîne';
$labels['open'] = 'Veke';
$labels['showattachment'] = 'Bide nîşan';
$labels['showanyway'] = 'Her çawa be nîşan bide';
$labels['filename'] = 'Navê pelê';
$labels['filesize'] = 'Mezinahiya pelê';
$labels['addtoaddressbook'] = 'Têxe lênûska navnîşanan';
$labels['sun'] = 'Yş';
$labels['mon'] = 'Dş';
$labels['tue'] = 'Sş';
$labels['wed'] = 'Çş';
$labels['thu'] = 'Pş';
$labels['fri'] = 'În';
$labels['sat'] = 'Şe';
$labels['sunday'] = 'Yekşem';
$labels['monday'] = 'Duşem';
$labels['tuesday'] = 'Sêşem';
$labels['wednesday'] = 'Çarşem';
$labels['thursday'] = 'Pêncşem';
$labels['friday'] = 'În';
$labels['saturday'] = 'Şemî';
$labels['jan'] = 'Çile';
$labels['feb'] = 'Reş';
$labels['mar'] = 'Adar';
$labels['apr'] = 'Avr';
$labels['may'] = 'Gul';
$labels['jun'] = 'Pûş';
$labels['jul'] = 'Tîr';
$labels['aug'] = 'Gel';
$labels['sep'] = 'Rez';
$labels['oct'] = 'Cotm';
$labels['nov'] = 'Serm';
$labels['dec'] = 'Berf';
$labels['longjan'] = 'Rêbendan';
$labels['longfeb'] = 'Reşemî';
$labels['longmar'] = 'Adar';
$labels['longapr'] = 'Avrêl';
$labels['longmay'] = 'Gulan';
$labels['longjun'] = 'Pûşper';
$labels['longjul'] = 'Tîrmeh';
$labels['longaug'] = 'Tebax';
$labels['longsep'] = 'Rezber';
$labels['longoct'] = 'Kewçêr';
$labels['longnov'] = 'Sermawez';
$labels['longdec'] = 'Berfanbar';
$labels['today'] = 'Îro';
$labels['refresh'] = 'Tezekirin';
$labels['checkmail'] = 'Li peyamên nû venihêre';
$labels['compose'] = 'Peyamekê biafirîne';
$labels['writenewmessage'] = 'Peyameke nû biafirîne';
$labels['reply'] = 'Bersivê bide';
$labels['replytomessage'] = 'Bersivê bide peyamê';
$labels['replytoallmessage'] = 'Bersivê ji bo hemû kesên ku ev peyan standine bişîne';
$labels['replyall'] = 'Hemûyan bibersivîne';
$labels['replylist'] = 'Lîsteyê bibersivîne';
$labels['forward'] = 'Pêşde';
$labels['forwardmessage'] = 'Bersivê bide peyamê';
$labels['deletemessage'] = 'Peyamê jê bibe';
$labels['movemessagetotrash'] = 'Peyamê dake çopê';
$labels['printmessage'] = 'Vê peyamê çap bike';
$labels['previousmessage'] = 'Peyama berê nîşan bide';
$labels['firstmessage'] = 'Peyama yekemîn nîşan bide';
$labels['nextmessage'] = 'Peyama di rêzê de nîşan bide';
$labels['lastmessage'] = 'Peyama dawî nîşan bide';
$labels['backtolist'] = 'Vegere lîsteya peyaman';
$labels['viewsource'] = 'Çavkaniyê nîşan bide';
$labels['mark'] = 'Nîşan bike';
$labels['markmessages'] = 'Peyamê nîşan bike';
$labels['markread'] = 'Wekî xwendî';
$labels['markunread'] = 'Wekî nexwendî';
$labels['markflagged'] = 'Wek alakirî';
$labels['markunflagged'] = 'Wek nealakirî';
$labels['moreactions'] = 'Bêhtir tevger...';
$labels['folders-all'] = 'Hemû dosye';
$labels['more'] = 'Bêhtir';
$labels['back'] = 'Paşve';
$labels['options'] = 'Vebijêrk';
$labels['first'] = 'Pêşîn';
$labels['last'] = 'Dawîn';
$labels['previous'] = 'Pêşde';
$labels['next'] = 'Piştde';
$labels['select'] = 'Hilbijêre';
$labels['all'] = 'Hemû';
$labels['none'] = 'Ne yek jî';
$labels['currpage'] = 'Rûpela niha';
$labels['isread'] = 'Bixwîne';
$labels['unread'] = 'Nexwendî';
$labels['flagged'] = 'Bialakirî';
$labels['unflagged'] = 'Nealakirî';
$labels['unanswered'] = 'Bersivnedayî';
$labels['withattachment'] = 'Bi pêvek';
$labels['deleted'] = 'Jêbirî';
$labels['undeleted'] = 'Nê jêbirî';
$labels['replied'] = 'Bersivdayî';
$labels['filter'] = 'Parzûn';
$labels['list'] = 'Lîste';
$labels['expand-all'] = 'Hemûyan fireh bike';
$labels['expand-unread'] = 'Ên nexwendî veke';
$labels['expand_only_unread'] = 'tenê bi peyamên nexwendî';
$labels['fromto'] = 'Ji/Jê re';
$labels['flag'] = 'Ala';
$labels['attachment'] = 'Pêvek';
$labels['nonesort'] = 'Ne yek jî';
$labels['sentdate'] = 'Dema şandinê';
$labels['arrival'] = 'Dema hatinê';
$labels['asc'] = 'ber bi jor ve';
$labels['desc'] = 'ber bi jêr ve';
$labels['listcolumns'] = 'Stûnan lîste bike';
$labels['listsorting'] = 'Stûna parzûnkirinê';
$labels['listorder'] = 'Rêza parzûnkirinê';
$labels['layoutlist'] = 'Lîste';
$labels['folderactions'] = 'Tevgerên dosyeyê...';
$labels['compact'] = 'Kompakt';
$labels['empty'] = 'Vala Bike';
$labels['quota'] = 'Bikaranîna dîskê';
$labels['unknown'] = 'nayê zanîn';
$labels['unlimited'] = 'bêsînor';
$labels['quotatotal'] = 'Lîmît';
$labels['quotaused'] = 'Bikarhatî';
$labels['quotastorage'] = 'Valahiya dîskê';
$labels['quotamessage'] = 'Hejmara peyaman';
$labels['quicksearch'] = 'Lêgerîna bilez';
$labels['resetsearch'] = 'Lêgerînê reset bike';
$labels['msgtext'] = 'Hemû peyam';
$labels['type'] = 'Cûre';
$labels['namex'] = 'Nav';
$labels['currentfolder'] = 'Dosyeya niha';
$labels['subfolders'] = 'Ev û bindosye';
$labels['allfolders'] = 'Hemû dosye';
$labels['openinextwin'] = 'Di pencereyeke nû de veke';
$labels['emlsave'] = 'Daxîne (.eml)';
$labels['changeformathtml'] = 'Di forma HTMLê de nîşan bide';
$labels['editasnew'] = 'Wek nû sererast bike';
$labels['send'] = 'Bişîne';
$labels['sendmessage'] = 'Peyamê niha bişîne';
$labels['savemessage'] = 'Hilîne';
$labels['addattachment'] = 'Pelekê lê zêde bike';
$labels['charset'] = 'Curetîp';
$labels['editortype'] = 'Cureyê serastkat';
$labels['returnreceipt'] = 'Rapora Vegerînê';
$labels['mailreplyintro'] = 'Di $date de, şandyar nivîsî:';
$labels['originalmessage'] = 'Peyama orîjînal';
$labels['selectimage'] = 'Wêne bibijêre';
$labels['addimage'] = 'Wêne tev bike';
$labels['selectmedia'] = 'Fîlmekê bibijêre';
$labels['addmedia'] = 'Fîlmekê tev bike';
$labels['insert'] = 'Tev bike';
$labels['checkspelling'] = 'Kontrola rastnivîsê';
$labels['resumeediting'] = 'Serastkirinê bidomîne';
$labels['revertto'] = 'Şûnde bîne';
$labels['responses'] = 'Bersivgel';
$labels['insertresponse'] = 'Bersivekê têxê';
$labels['manageresponses'] = 'Bersivan bi rê ve bibe';
$labels['newresponse'] = 'Bersiveke nê biafirîne';
$labels['addresponse'] = 'Bersivê tev bike';
$labels['editresponse'] = 'Bersivê sererast bike';
$labels['editresponses'] = 'Bersivan sererast bike';
$labels['responsename'] = 'Nav';
$labels['responsetext'] = 'Teksta Bersivê';
$labels['attach'] = 'Pêvek';
$labels['attachments'] = 'Pêvek';
$labels['upload'] = 'Bar bike';
$labels['uploadprogress'] = '$percent ($current ji $total)';
$labels['close'] = 'Bigire';
$labels['messageoptions'] = 'Vebijêrkên peyamê...';
$labels['low'] = 'Nizm';
$labels['lowest'] = 'Nizmtirîn';
$labels['normal'] = 'Asayî';
$labels['high'] = 'Bilind';
$labels['highest'] = 'Bilintirîn';
$labels['nosubject'] = '(bê mijar)';
$labels['showimages'] = 'Xuyakirina wêneyan';
$labels['alwaysshow'] = 'Her tim dîmenên ji $sender nîşan bide';
$labels['andnmore'] = '$nr bêhtir...';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Deqa tazî';
$labels['savesentmessagein'] = 'Peyama şandî tomar bike di ';
$labels['dontsave'] = 'tomar neke';
$labels['addcc'] = 'Cc Têxê';
$labels['addbcc'] = 'Bcc Têxê';
$labels['addreplyto'] = 'Bibersivîne têxê';
$labels['mdnrequest'] = 'Şandyarê/a vê peyamê xwest dema ku tu vê peyamê bixwînî ew were agahdarkirin. Tu dixwazî wî/ê agahdar bikî?';
$labels['receiptread'] = 'Rapora Vegerînê (xwendî)';
$labels['yourmessage'] = 'Ev rapora vegerîna peyama te ye';
$labels['receiptnote'] = 'Nîşe: Ev dide zanîn ka peyama te şand hat xwendin an na. Naveroka peyamê bi mîgogerî nayê zanîn.';
$labels['name'] = 'Navê xuya dibe';
$labels['firstname'] = 'Nav';
$labels['surname'] = 'Paşnav';
$labels['middlename'] = 'Navê navîn';
$labels['nameprefix'] = 'Pêşgir';
$labels['namesuffix'] = 'Paşgir';
$labels['nickname'] = 'Nûçik';
$labels['jobtitle'] = 'Şana Kar';
$labels['department'] = 'Beş';
$labels['gender'] = 'Zayend';
$labels['email'] = 'E-Peyam';
$labels['phone'] = 'Telefon';
$labels['address'] = 'Navnîşan';
$labels['street'] = 'Kolan';
$labels['locality'] = 'Bajar';
$labels['zipcode'] = 'ZIP Code';
$labels['region'] = 'Eyalet';
$labels['country'] = 'Welat';
$labels['birthday'] = 'Rojbûn';
$labels['anniversary'] = 'Sersal';
$labels['website'] = 'Website';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Nîşegel';
$labels['male'] = 'mêr';
$labels['female'] = 'jin';
$labels['manager'] = 'Birêvebir';
$labels['assistant'] = 'Alîkar';
$labels['spouse'] = 'Heval';
$labels['allfields'] = 'Hemû qad';
$labels['search'] = 'Lêgerîn';
$labels['searchresult'] = 'Encama lêgerînê';
$labels['advsearch'] = 'Lêgerîna pêşketî';
$labels['advanced'] = 'Pêşketî';
$labels['other'] = 'A din';
$labels['typehome'] = 'Mal';
$labels['typework'] = 'Kar';
$labels['typeother'] = 'A din';
$labels['typemobile'] = 'Mobîl';
$labels['typemain'] = 'Sereke';
$labels['typehomefax'] = 'Faksa Malê';
$labels['typeworkfax'] = 'Faksa Kar';
$labels['typecar'] = 'Otomobîl';
$labels['typevideo'] = 'Bînûdeng';
$labels['typeassistant'] = 'Alîkar';
$labels['typehomepage'] = 'Malper';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Berg';
$labels['addfield'] = 'Qadekî zêde bike';
$labels['addcontact'] = 'Kesekî zêde bike';
$labels['editcontact'] = 'Têkiliyê serast bike';
$labels['contacts'] = 'Kes';
$labels['contactproperties'] = 'Taybetmendiyên Kesan';
$labels['contactnameandorg'] = 'Nav û rêxistin';
$labels['personalinfo'] = 'Agahiyên kesane';
$labels['contactphoto'] = 'Wêneyê Kes';
$labels['edit'] = 'Serast bike';
$labels['cancel'] = 'Betal';
$labels['save'] = 'Tomar bike';
$labels['delete'] = 'Jê Bibe';
$labels['rename'] = 'Dîsa navek lê bike';
$labels['addphoto'] = 'Tev bike';
$labels['replacephoto'] = 'Dîsa bi cih bike';
$labels['uploadphoto'] = 'Fotoyek bar bike';
$labels['newcontact'] = 'Kesekî nû biafirîne';
$labels['deletecontact'] = 'Têkiliyên hilbijartî jê bibe';
$labels['composeto'] = 'Ji têkiliya hilbijartî re peyam bişîne';
$labels['contactsfromto'] = 'Têkiliyên $count ên di navbera $from - $to de';
$labels['print'] = 'çap bike';
$labels['export'] = 'Derxe';
$labels['exportall'] = 'Hemûyan derxe';
$labels['exportsel'] = 'A bijartî derxe';
$labels['newgroup'] = 'Komeke nû çêke';
$labels['addgroup'] = 'Komek tev bike';
$labels['grouprename'] = 'Dîsa navekî li komê bike';
$labels['groupdelete'] = 'Komê rake';
$labels['uponelevel'] = 'Astek jor';
$labels['previouspage'] = 'Seta berê nîşan bide';
$labels['firstpage'] = 'Seta yekemîn nîşan bide';
$labels['nextpage'] = 'Seta di rêzê de nîşan bide';
$labels['lastpage'] = 'Seta dawî nîşan bide';
$labels['group'] = 'Kom';
$labels['groups'] = 'Kom';
$labels['personaladrbook'] = 'Navnîşanên Takekesî';
$labels['searchsave'] = 'Lêgerînê tomar bike';
$labels['searchdelete'] = 'Lêgerînê jê bibe';
$labels['import'] = 'Derhîne';
$labels['done'] = 'Qediya';
$labels['settingsfor'] = 'Mîheng ji bo';
$labels['about'] = 'Derbar';
$labels['preferences'] = 'Vebijêrk';
$labels['userpreferences'] = 'Vebijêrkên bikarhêner';
$labels['editpreferences'] = 'Vebijêrkên bikarhêner serast bike';
$labels['identities'] = 'Nasname';
$labels['preferhtml'] = 'Wekî HTML nîşan bide';
$labels['htmlmessage'] = 'Peyama HTML';
$labels['messagepart'] = 'Parçe';
$labels['digitalsig'] = 'Îmzeya Dîjîtal';
$labels['prettydate'] = 'Kurtenivîsa Dîrokê';
$labels['setdefault'] = 'Wekî standard tomar bike';
$labels['language'] = 'Ziman';
$labels['timezone'] = 'Herêma demê';
$labels['pagesize'] = 'Hejmara peyamên her rûpelekê';
$labels['signature'] = 'Şanenav';
$labels['dstactive'] = 'Demjimêra havînî';
$labels['htmleditor'] = 'Peyameke HTML biafirîne';
$labels['htmlsignature'] = 'Şanenava HTML';
$labels['previewpane'] = 'Panela berê nîşan bide';
$labels['askuser'] = 'bipirse min';
$labels['skipdeleted'] = 'Peyamên jêbirî nîşan nede';
$labels['always'] = 'Her tim';
$labels['autosavedraft'] = 'Xweber hilîne';
$labels['everynminutes'] = 'Her $n saniye(yan)';
$labels['never'] = 'qet';
$labels['immediately'] = 'a niha';
$labels['folder'] = 'Peldank';
$labels['folders'] = 'Peldank';
$labels['foldername'] = 'Navê peldankê';
$labels['subscribed'] = 'Ni şanenav';
$labels['messagecount'] = 'Peyam';
$labels['create'] = 'Biafirîne';
$labels['createfolder'] = 'Peldankeke nû biafirîne';
$labels['managefolders'] = 'Rêveberiya peldankan';
$labels['sortby'] = 'Şêweyê rêzkirinê';
$labels['sortasc'] = 'Wekî zêde dibe';
$labels['sortdesc'] = 'Wekî kêm dibe';
$labels['license'] = 'Lîsans';
