<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Filter';
$labels['managefilters'] = 'Verwalte eingehende Nachrichtenfilter';
$labels['filtername'] = 'Filtername';
$labels['newfilter'] = 'Neuer Filter';
$labels['filteradd'] = 'Filter hinzufügen';
$labels['filterdel'] = 'Filter löschen';
$labels['rules'] = 'Regeln';
$labels['actions'] = 'Aktionen';
$labels['scope'] = 'Suchbereich';
$labels['moveup'] = 'Nach oben';
$labels['movedown'] = 'Nach unten';
$labels['filterallof'] = 'UND (alle Regeln müssen zutreffen)';
$labels['filteranyof'] = 'ODER (eine der Regeln muss zutreffen';
$labels['filterany'] = 'Für alle Nachrichten';
$labels['filtercontains'] = 'enthält';
$labels['filternotcontains'] = 'enthält nicht';
$labels['filteris'] = 'ist gleich';
$labels['filterisnot'] = 'ist ungleich';
$labels['filterexists'] = 'ist vorhanden';
$labels['filternotexists'] = 'nicht vorhanden';
$labels['filtermatches'] = 'entspricht Ausdruck';
$labels['filternotmatches'] = 'entspricht nicht Ausdruck';
$labels['filterregex'] = 'trifft regulären Ausdruck';
$labels['filternotregex'] = 'entspricht regulärem Ausdruck';
$labels['filterunder'] = 'unter';
$labels['filterover'] = 'über';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'MIME-Teil:';
$labels['mime-message'] = 'Nachricht';
$labels['mime-anychild'] = 'weiteres';
$labels['mime-type'] = 'Typ';
$labels['mime-subtype'] = 'Untertyp';
$labels['mime-contenttype'] = 'Inhaltstyp';
$labels['mime-param'] = 'Parameter';
$labels['addrule'] = 'Regel hinzufügen';
$labels['delrule'] = 'Regel löschen';
$labels['messagemoveto'] = 'Verschiebe Nachricht nach';
$labels['messageredirect'] = 'Leite Nachricht um nach';
$labels['messagecopyto'] = 'Kopiere Nachricht nach';
$labels['messagesendcopy'] = 'Sende Kopie an';
$labels['messagereply'] = 'Antworte mit Nachricht';
$labels['messagedelete'] = 'Nachricht löschen';
$labels['messagediscard'] = 'Discard with message';
$labels['messagekeep'] = 'Im Posteingang behalten';
$labels['messagesrules'] = 'Für eingehende Nachrichten:';
$labels['messagesactions'] = 'Führe folgende Aktionen aus:';
$labels['add'] = 'Hinzufügen';
$labels['del'] = 'Löschen';
$labels['sender'] = 'Absender';
$labels['recipient'] = 'Empfänger';
$labels['vacationaddr'] = 'Meine E-Mail-Adressen:';
$labels['vacationdays'] = 'Antwort wird erneut gesendet nach (in Tagen):';
$labels['vacationinterval'] = 'Wie oft senden:';
$labels['vacationreason'] = 'Inhalt der Nachricht (Abwesenheitsgrund):';
$labels['vacationfrom'] = 'Antwort E-Mail-Adresse:';
$labels['vacationsubject'] = 'Betreff';
$labels['days'] = 'Tage';
$labels['seconds'] = 'Sekunden';
$labels['rulestop'] = 'Regelauswertung anhalten';
$labels['enable'] = 'Aktivieren/Deaktivieren';
$labels['filtersets'] = 'Filtersätze';
$labels['filterseteditraw'] = 'Filtersatz bearbeiten';
$labels['filterdef'] = 'Filterdefinition';
$labels['active'] = 'aktiv';
$labels['none'] = 'keine';
$labels['fromset'] = 'aus Filtersatz';
$labels['fromfile'] = 'aus Datei';
$labels['filterdisabled'] = 'Filter deaktiviert';
$labels['countisgreaterthan'] = 'Anzahl ist grösser als';
$labels['countisgreaterthanequal'] = 'Anzahl ist gleich oder grösser als';
$labels['countislessthan'] = 'Anzahl ist kleiner als';
$labels['countislessthanequal'] = 'Anzahl ist gleich oder kleiner als';
$labels['countequals'] = 'Anzahl ist gleich';
$labels['countnotequals'] = 'Anzahl ist ungleich';
$labels['valueisgreaterthan'] = 'Wert ist grösser als';
$labels['valueisgreaterthanequal'] = 'Wert ist gleich oder grösser als';
$labels['valueislessthan'] = 'Wert ist kleiner';
$labels['valueislessthanequal'] = 'Wert ist gleich oder kleiner als';
$labels['valueequals'] = 'Wert ist gleich';
$labels['valuenotequals'] = 'Wert ist ungleich';
$labels['setflags'] = 'Setze Markierungen';
$labels['addflags'] = 'Füge Markierung hinzu';
$labels['removeflags'] = 'Entferne Markierung';
$labels['flagread'] = 'gelesen';
$labels['flagdeleted'] = 'Gelöscht';
$labels['flaganswered'] = 'Beantwortet';
$labels['flagflagged'] = 'Markiert';
$labels['flagdraft'] = 'Entwurf';
$labels['setvariable'] = 'Setze Variable';
$labels['setvarname'] = 'Variablenname:';
$labels['setvarvalue'] = 'Variablenwert:';
$labels['setvarmodifiers'] = 'Umwandler:';
$labels['varlower'] = 'Kleinschreibung';
$labels['varupper'] = 'Grossschreibung';
$labels['varlowerfirst'] = 'Erster Buchstabe klein';
$labels['varupperfirst'] = 'Erster Buchstabe gross';
$labels['varquotewildcard'] = 'Sonderzeichen auszeichnen';
$labels['varlength'] = 'Länge';
$labels['notify'] = 'Mitteilung senden';
$labels['notifytarget'] = 'Mitteilungsempfänger:';
$labels['notifymessage'] = 'Mitteilungstext (optional):';
$labels['notifyoptions'] = 'Mitteilungsoptionen (optional):';
$labels['notifyfrom'] = 'Absender (optional):';
$labels['notifyimportance'] = 'Wichtigkeit:';
$labels['notifyimportancelow'] = 'tief';
$labels['notifyimportancenormal'] = 'normal';
$labels['notifyimportancehigh'] = 'hoch';
$labels['notifymethodmailto'] = 'E-Mail';
$labels['notifymethodtel'] = 'Telefon';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Filter erstellen';
$labels['usedata'] = 'Die folgenden Daten im Filter benutzen:';
$labels['nextstep'] = 'Nächster Schritt';
$labels['...'] = '...';
$labels['string'] = 'Zeichenkette';
$labels['currdate'] = 'Aktuelles Datum';
$labels['datetest'] = 'Datum';
$labels['dateheader'] = 'Kopfzeile:';
$labels['year'] = 'Jahr';
$labels['month'] = 'Monat';
$labels['day'] = 'Tag';
$labels['date'] = 'Datum (JJJJ-MM-TT)';
$labels['julian'] = 'Datum (julianisch)';
$labels['hour'] = 'Stunde';
$labels['minute'] = 'Minute';
$labels['second'] = 'Sekunde';
$labels['time'] = 'Zeit (hh:mm:ss)';
$labels['iso8601'] = 'Datum (ISO-8601)';
$labels['std11'] = 'Datum (RFC 2822)';
$labels['zone'] = 'Zeitzone';
$labels['weekday'] = 'Wochentag (0-6)';
$labels['advancedopts'] = 'Erweiterte Optionen';
$labels['body'] = 'Inhalt';
$labels['address'] = 'Adresse';
$labels['envelope'] = 'Umschlag';
$labels['modifier'] = 'Wandler';
$labels['text'] = 'Text';
$labels['undecoded'] = 'kodiert (roh)';
$labels['contenttype'] = 'Inhaltstyp';
$labels['modtype'] = 'Typ:';
$labels['allparts'] = 'alle';
$labels['domain'] = 'Domain';
$labels['localpart'] = 'lokaler Teil';
$labels['user'] = 'Benutzer';
$labels['detail'] = 'Detail';
$labels['comparator'] = 'Komparator';
$labels['default'] = 'Vorgabewert';
$labels['octet'] = 'strikt (Oktet)';
$labels['asciicasemap'] = 'Gross-/Kleinschreibung ignorieren';
$labels['asciinumeric'] = 'numerisch (ascii-numeric)';
$labels['index'] = 'Index:';
$labels['indexlast'] = 'rückwärts';
$labels['spamtestequals'] = 'ist gleich';
$labels['spamtestnotequals'] = 'ist ungleich';
$labels['vacation'] = 'Abwesenheit';
$labels['vacation.reply'] = 'Antworte mit Nachricht';
$labels['vacation.advanced'] = 'Erweiterte Einstellungen';
$labels['vacation.from'] = 'Antwort E-Mail-Adresse:';
$labels['vacation.subject'] = 'Betreff';
$labels['vacation.body'] = 'Inhalt';
$labels['vacation.start'] = 'Beginn der Abwesenheit';
$labels['vacation.end'] = 'Ende der Abwesenheit';
$labels['vacation.status'] = 'Status';
$labels['vacation.on'] = 'Ein';
$labels['vacation.off'] = 'Aus';
$labels['vacation.addresses'] = 'Meine E-Mail-Adressen';
$labels['vacation.interval'] = 'Antwort-Intervall';
$labels['vacation.after'] = 'Abwesenheitsregel einfügen nach';
$labels['vacation.saving'] = 'Speichere Daten...';
$labels['vacation.action'] = 'Aktion für eingehende Nachrichten';
$labels['vacation.keep'] = 'Behalten';
$labels['vacation.discard'] = 'Verwerfen';
$labels['vacation.redirect'] = 'Weiterleiten an';
$labels['vacation.copy'] = 'Kopie an';
$labels['forward'] = 'Weiterleitung';
$labels['forward.redirect'] = 'Weiterleiten an';
$labels['forward.copy'] = 'Kopie an';
$labels['forward.on'] = 'Ein';
$labels['forward.off'] = 'Aus';
$labels['forward.status'] = 'Status:';
$labels['forward.action'] = 'Für eingehende Mails die folgende Aktion ausführen:';
$labels['forward.saving'] = 'Speichere Daten...';
$labels['filladdresses'] = 'Mit allen meiner Adressen ausfüllen';
$labels['arialabelfiltersetactions'] = 'Filtersatz-Aktionen';
$labels['arialabelfilteractions'] = 'Filteraktionen';
$labels['arialabelfilterform'] = 'Filtereigenschaften';
$labels['ariasummaryfilterslist'] = 'Filterliste';
$labels['ariasummaryfiltersetslist'] = 'Filtersatzliste';
$labels['filterstitle'] = 'Eingehende Nachrichtenfilter bearbeiten';
$labels['vacationtitle'] = 'Abwesenheitsregel bearbeiten';
$labels['forwardtitle'] = 'Mail-Weiterleitungsregel bearbeiten';
$labels['message'] = 'Nachricht';
$labels['duplicate'] = 'ist doppelt';
$labels['notduplicate'] = 'ist nicht doppelt';
$labels['duplicate.handle'] = 'verarbeiten:';
$labels['duplicate.header'] = 'Kopfzeile:';
$labels['duplicate.uniqueid'] = 'Bezeichner:';
$labels['duplicate.seconds'] = 'Zeitüberschreitung (Sekunden):';
$labels['duplicate.last'] = 'relativ zur letzten Ausführung';
$messages['filterunknownerror'] = 'Unbekannter Serverfehler';
$messages['filterconnerror'] = 'Kann nicht zum Sieve-Server verbinden';
$messages['filterdeleteerror'] = 'Serverfehler beim Löschen des Filters.';
$messages['filterdeleted'] = 'Filter erfolgreich gelöscht';
$messages['filtersaved'] = 'Filter gespeichert';
$messages['filtersaveerror'] = 'Serverfehler beim Speichern des Filters.';
$messages['filterformerror'] = 'Filter-Formular enthält Fehler.';
$messages['filterdeleteconfirm'] = 'Möchten Sie den Filter löschen ?';
$messages['ruledeleteconfirm'] = 'Sicher, dass Sie die Regel löschen wollen?';
$messages['actiondeleteconfirm'] = 'Sicher, dass Sie die ausgewaehlte Aktion löschen wollen?';
$messages['forbiddenchars'] = 'Unerlaubte Zeichen im Feld';
$messages['cannotbeempty'] = 'Feld darf nicht leer sein';
$messages['ruleexist'] = 'Ein Filter mit dem angegebenen Namen existiert bereits.';
$messages['activateerror'] = 'Serverfehler beim Aktivieren des/der gewählten Filter(s).';
$messages['deactivateerror'] = 'Serverfehler beim Deaktivieren des/der gewählten Filter(s).';
$messages['deactivated'] = 'Filter erfolgreich aktiviert.';
$messages['activated'] = 'Filter erfolgreich deaktiviert.';
$messages['moved'] = 'Filter erfolgreich verschoben.';
$messages['moveerror'] = 'Serverfehler beim Verschieben des gewählten Filters.';
$messages['nametoolong'] = 'Filtersatz kann nicht erstellt werden. Name zu lang.';
$messages['namereserved'] = 'Reservierter Name.';
$messages['setexist'] = 'Filtersatz existiert bereits.';
$messages['nodata'] = 'Mindestens eine Position muss ausgewählt werden!';
$messages['invaliddateformat'] = 'Ungültiges Datumsformat';
$messages['saveerror'] = 'Fehler beim Speichern (Serverfehler)';
$messages['vacationsaved'] = 'Abwesenheitsnotiz erfolgreich gespeichert.';
$messages['forwardsaved'] = 'Weiterleitungsdaten erfolgreich gespeichert.';
$messages['emptyvacationbody'] = 'Mitteilungstext ist erforderlich!';
$messages['duplicate.conflict.err'] = 'Kopfzeile und eindeutiger Bezeichner sind nicht zusammen erlaubt.';
$messages['disabledaction'] = 'Aktion nicht erlaubt.';
