#aclcontainer
{
  overflow-x: auto;
  border: 1px solid #CCDDE4;
  background-color: #D9ECF4;
  height: 272px;
  box-shadow: none;
}

#acllist-content
{
  position: relative;
  height: 230px;
  background-color: white;
}

#acllist-footer
{
  position: relative;
}

#acltable
{
  width: 100%;
  border-collapse: collapse;
  border: none;
}

#acltable th,
#acltable td
{
  white-space: nowrap;
  text-align: center;
}

#acltable thead tr th
{
  font-size: 11px;
  font-weight: bold;
}

#acltable tbody td
{
  text-align: center;
  height: 16px;
  cursor: default;
}

#acltable thead tr > .user
{
  width: 30%;
  border-left: none;
}

#acltable.advanced thead tr > .user {
  width: 25%;
}

#acltable tbody td.user
{
  text-align: left;
}

#acltable tbody td.partial
{
  background-image: url(images/partial.png);
  background-position: center;
  background-repeat: no-repeat;
}

#acltable tbody td.enabled
{
  background-image: url(images/enabled.png);
  background-position: center;
  background-repeat: no-repeat;
}

#acltable tbody tr.selected td.partial
{
  background-color: #019bc6;
  background-image: url(images/partial.png), -moz-linear-gradient(top, #019bc6 0%, #017cb4 100%);
  background-image: url(images/partial.png), -webkit-gradient(linear, left top, left bottom, color-stop(0%,#019bc6), color-stop(100%,#017cb4));
  background-image: url(images/partial.png), -o-linear-gradient(top, #019bc6 0%, #017cb4 100%);
  background-image: url(images/partial.png), -ms-linear-gradient(top, #019bc6 0%, #017cb4 100%);
  background-image: url(images/partial.png), linear-gradient(top, #019bc6 0%, #017cb4 100%);
}

#acltable tbody tr.selected td.enabled
{
  background-color: #019bc6;
  background-image: url(images/enabled.png), -moz-linear-gradient(top, #019bc6 0%, #017cb4 100%);
  background-image: url(images/enabled.png), -webkit-gradient(linear, left top, left bottom, color-stop(0%,#019bc6), color-stop(100%,#017cb4));
  background-image: url(images/enabled.png), -o-linear-gradient(top, #019bc6 0%, #017cb4 100%);
  background-image: url(images/enabled.png), -ms-linear-gradient(top, #019bc6 0%, #017cb4 100%);
  background-image: url(images/enabled.png), linear-gradient(top, #019bc6 0%, #017cb4 100%);
}

#aclform
{
  display: none;
}

#aclform div
{
  padding: 0;
  text-align: center;
  clear: both;
}

#aclform ul
{
  list-style: none;
  margin: 0.2em;
  padding: 0;
}

#aclform ul li label
{
  margin-left: 0.5em;
}

ul.toolbarmenu li span.delete {
  background-position: 0 -1509px;
}
