<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'მოგესალმებათ $product';
$labels['username'] = 'მომხმარებელი';
$labels['password'] = 'პაროლი';
$labels['server'] = 'სერვერი';
$labels['login'] = 'შესვლა';
$labels['logout'] = 'გამოსვლა';
$labels['mail'] = 'ელფოსტა';
$labels['settings'] = 'პარამეტრები';
$labels['addressbook'] = 'მისამართები';
$labels['inbox'] = 'მიღებული';
$labels['drafts'] = 'დროებითი';
$labels['sent'] = 'გაგზავნილი';
$labels['trash'] = 'წაშლილი';
$labels['junk'] = 'სპამი';
$labels['subject'] = 'სათაური';
$labels['from'] = 'გამგზავნი';
$labels['sender'] = 'გამგზავნელი';
$labels['to'] = 'ვის';
$labels['cc'] = 'ასლი';
$labels['bcc'] = 'ფარული';
$labels['replyto'] = 'პასუხი';
$labels['followupto'] = 'მიმდევარი';
$labels['date'] = 'თარიღი';
$labels['size'] = 'ზომა';
$labels['priority'] = 'პრიორიტეტი';
$labels['organization'] = 'ორგანიზაცია';
$labels['readstatus'] = 'წაკითხულის სტატუსი';
$labels['listoptions'] = 'სიის ოფციები...';
$labels['mailboxlist'] = 'საქაღალდეები';
$labels['messagesfromto'] = 'შეტყობინება $from-სგან $to-ს სულ $count\' ცალი';
$labels['messagenrof'] = 'შეტყობინება $nr დან $count';
$labels['copy'] = 'ასლი';
$labels['move'] = 'გადატანა';
$labels['moveto'] = 'გადატანა...';
$labels['download'] = 'გადმოწერა';
$labels['open'] = 'გახსნა';
$labels['showattachment'] = 'ჩვენება';
$labels['filename'] = 'ფაილის სახელი';
$labels['filesize'] = 'ფაილის ზომა';
$labels['addtoaddressbook'] = 'მისამართებში დამატება';
$labels['sun'] = 'კვი';
$labels['mon'] = 'ორშ';
$labels['tue'] = 'სამ';
$labels['wed'] = 'ოთხ';
$labels['thu'] = 'ხუთ';
$labels['fri'] = 'პარ';
$labels['sat'] = 'შაბ';
$labels['sunday'] = 'კვირა';
$labels['monday'] = 'ორშაბათი';
$labels['tuesday'] = 'სამშაბათი';
$labels['wednesday'] = 'ოთხშაბათი';
$labels['thursday'] = 'ხუთშაბათი';
$labels['friday'] = 'პარასკევი';
$labels['saturday'] = 'შაბათი';
$labels['jan'] = 'იან';
$labels['feb'] = 'თებ';
$labels['mar'] = 'მარ';
$labels['apr'] = 'აპრ';
$labels['may'] = 'მაისი';
$labels['jun'] = 'ივნ';
$labels['jul'] = 'ივლ';
$labels['aug'] = 'აგვ';
$labels['sep'] = 'სექ';
$labels['oct'] = 'ოქტ';
$labels['nov'] = 'ნოე';
$labels['dec'] = 'დეკ';
$labels['longjan'] = 'იანვარი';
$labels['longfeb'] = 'თებერვალი';
$labels['longmar'] = 'მარტი';
$labels['longapr'] = 'აპრილი';
$labels['longmay'] = 'მაისი';
$labels['longjun'] = 'ივნისი';
$labels['longjul'] = 'ივლისი';
$labels['longaug'] = 'აგვისტო';
$labels['longsep'] = 'სექტემბერი';
$labels['longoct'] = 'ოქტომბერი';
$labels['longnov'] = 'ნოემბერი';
$labels['longdec'] = 'დეკემბერი';
$labels['today'] = 'დღეს';
$labels['refresh'] = 'განახლება';
$labels['checkmail'] = 'შემოწმება ახალ შეტყობინებაზე';
$labels['compose'] = 'შეტყობინების დაწერა';
$labels['writenewmessage'] = 'ახალი შეტყობინება';
$labels['reply'] = 'პასუხის გაცემა';
$labels['replytomessage'] = 'პასუხი';
$labels['replytoallmessage'] = 'პასუხი ყველას';
$labels['replyall'] = 'პასუხის გაცემა ყველას';
$labels['replylist'] = 'პასუხის გაცემა სიით';
$labels['forward'] = 'გადაგზავნა';
$labels['forwardmessage'] = 'გადაგზავნა';
$labels['deletemessage'] = 'წაშლა';
$labels['movemessagetotrash'] = 'შეტყობინების წაშლილებში გადატანა';
$labels['printmessage'] = 'შეტყობინების ამობეჭვდა';
$labels['previousmessage'] = 'წინა შეტყობინების ნახვა';
$labels['firstmessage'] = 'პირველი შეტყობინების ნახვა';
$labels['nextmessage'] = 'შემდეგი შეტყობინების ნახვა';
$labels['lastmessage'] = 'ბოლო შეტყობინების ნახვა';
$labels['backtolist'] = 'უკან ჩამონათვალში';
$labels['viewsource'] = 'შიგთავსი';
$labels['mark'] = 'მონიშვნა';
$labels['markmessages'] = 'მონიშნეთ შეტყობინებები';
$labels['markread'] = 'როგორც წაკითხული';
$labels['markunread'] = 'როგორც წაუკითხავი';
$labels['markflagged'] = 'როგორც მონიშნული';
$labels['markunflagged'] = 'როგორც მოუნიშნავი';
$labels['moreactions'] = 'მეტი მოქმედება...';
$labels['folders-all'] = 'ყველა საქაღალდე';
$labels['more'] = 'მეტი';
$labels['back'] = 'უკან';
$labels['first'] = 'პირველი';
$labels['last'] = 'ბოლო';
$labels['previous'] = 'წინა';
$labels['next'] = 'შემდეგი';
$labels['select'] = 'მონიშვნა';
$labels['all'] = 'ყველა';
$labels['none'] = 'არცერთი';
$labels['currpage'] = 'მიმდინარე გვერდი';
$labels['isread'] = 'წაკითხვა';
$labels['unread'] = 'წაუკითხავი';
$labels['flagged'] = 'მონიშნული';
$labels['unflagged'] = 'მოუნიშნავი';
$labels['unanswered'] = 'უპასუხო';
$labels['deleted'] = 'წაშლილი';
$labels['undeleted'] = 'წაუშლელი';
$labels['replied'] = 'პასუხგაცემული';
$labels['forwarded'] = 'გადაგზავნილი';
$labels['invert'] = 'შებრუნებული';
$labels['filter'] = 'ფილტრი';
$labels['list'] = 'სია';
$labels['expand-all'] = 'ყველას გაშლა';
$labels['expand-unread'] = 'წაუკითხავის გაშლა';
$labels['collapse-all'] = 'ყველას დაკეცვა';
$labels['expand_only_unread'] = 'მარტო წაუკითხავი შეტყობინებები';
$labels['fromto'] = 'ვისგან/ვის';
$labels['flag'] = 'დროშა';
$labels['attachment'] = 'მიმაგრებული ფაილი';
$labels['nonesort'] = 'არცერთი';
$labels['sentdate'] = 'გაგზავნის თარიღი';
$labels['arrival'] = 'მოსვლის თარიღი';
$labels['asc'] = 'ზრდადობით';
$labels['desc'] = 'კლებადობით';
$labels['listcolumns'] = 'სვეტების სია';
$labels['listsorting'] = 'სვეტების დალაგება';
$labels['listorder'] = 'დალაგება';
$labels['layoutlist'] = 'სია';
$labels['folderactions'] = 'საქაღალდეზე მოქმედება..';
$labels['compact'] = 'შეკუმშვა';
$labels['empty'] = 'გაცარიელება';
$labels['quota'] = 'შეზღუდვა';
$labels['unknown'] = 'უცნობი';
$labels['unlimited'] = 'შეუზღუდავი';
$labels['quotatotal'] = 'ლიმიტი';
$labels['quotaused'] = 'გამოყენებული';
$labels['quotastorage'] = 'ადგილი დისკზე';
$labels['quotamessage'] = 'შეტყობინებების რაოდენობა';
$labels['quicksearch'] = 'სწრაფი ძიება';
$labels['resetsearch'] = 'ძიების გასუფთავება';
$labels['searchmod'] = 'ძებნის ვარიანტები';
$labels['msgtext'] = 'ყველა შეტყობინება';
$labels['body'] = 'შეტყობინების ტექსტი';
$labels['type'] = 'ტიპი';
$labels['namex'] = 'სახელი';
$labels['subfolders'] = 'ეს და ქვესაქაღალდეები';
$labels['allfolders'] = 'ყველა საქაღალდე';
$labels['searchinterval-1W'] = 'ერთ კვირაზე ძველი';
$labels['searchinterval-1M'] = 'ერთ წელზე ძველი';
$labels['searchinterval-1Y'] = 'ერთ თვეზე ძველი';
$labels['searchinterval1W'] = 'ერთ კვირაზე ახალი';
$labels['searchinterval1M'] = 'ერთ თვეზე ახალი';
$labels['searchinterval1Y'] = 'ერთ წელზე ახალი';
$labels['openinextwin'] = 'გახსნა ახალ ფანჯარაში';
$labels['emlsave'] = 'გადმოწერა (.eml)';
$labels['editasnew'] = 'რედაქტირება როგორც ახლის';
$labels['send'] = 'გაგზავნა';
$labels['sendmessage'] = 'შეტყობინების გაგზავნა';
$labels['savemessage'] = 'დროებით შენახვა';
$labels['addattachment'] = 'ფაილის ატვირთვა';
$labels['charset'] = 'კოდირება';
$labels['editortype'] = 'რედაქტორი';
$labels['returnreceipt'] = 'პასუხის მოთხოვნა';
$labels['mailreplyintro'] = '$date-ში, $sender დაწერა:';
$labels['originalmessage'] = 'ორიგინალი შეტყობინება';
$labels['selectimage'] = 'სურათის არჩევა';
$labels['addimage'] = 'სურათის დამატება';
$labels['selectmedia'] = 'ფილმის არჩევა';
$labels['addmedia'] = 'ფილმის დამატება';
$labels['keyexpired'] = 'ვადაგასული';
$labels['spellcheck'] = 'გრამატიკა';
$labels['checkspelling'] = 'ორთოგრაფიული შემოწმება';
$labels['resumeediting'] = 'რედაქტირების გაგრძელება';
$labels['revertto'] = 'გაუქმება';
$labels['restore'] = 'აღდგენა';
$labels['restoremessage'] = 'აღვადგინო შეტყობინება?';
$labels['ignore'] = 'იგნორირება';
$labels['responses'] = 'პასუხები';
$labels['insertresponse'] = 'პასუხის ჩასმა';
$labels['manageresponses'] = 'პასუხების მართვა';
$labels['newresponse'] = 'ახალი პასუხის შექმნა';
$labels['addresponse'] = 'პასუხის დამატება';
$labels['editresponse'] = 'პასუხის რედაქტირება';
$labels['editresponses'] = 'პასუხების რედაქტირება';
$labels['responsename'] = 'სახელი';
$labels['responsetext'] = 'პასუხის ტექსტი';
$labels['attach'] = 'მიბმა';
$labels['attachments'] = 'გზავნილები';
$labels['upload'] = 'ატვირთვა';
$labels['close'] = 'დახურვა';
$labels['messageoptions'] = 'შეტყობინების ოფციები...';
$labels['low'] = 'დაბალი';
$labels['lowest'] = 'უდაბლესი';
$labels['normal'] = 'საშუალო';
$labels['high'] = 'მაღალი';
$labels['highest'] = 'უმაღლესი';
$labels['nosubject'] = '(უსათაურო)';
$labels['showimages'] = 'გამოსახულების ჩვენება';
$labels['alwaysshow'] = 'ყოველთვის გამოაჩინე სურათები $sender –გან';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'ტექსტური';
$labels['savesentmessagein'] = 'შეინახე შეტყობინება';
$labels['dontsave'] = 'არ შეინახო';
$labels['maxuploadsize'] = 'მაქსიმალური დაშვებული ფაილის ზომა $size';
$labels['addcc'] = 'დაამატე კოპიო';
$labels['addbcc'] = 'დაამატე ფარული კოპიო';
$labels['addreplyto'] = 'დაამატე გამომგზავნი';
$labels['mdnrequest'] = 'გამომგზავნს სურს შეიტყოს წერილის მიღება. გსურთ შეატყობინოთ გამომგზავნს?';
$labels['receiptread'] = 'გზავნილის დაბრუნება';
$labels['yourmessage'] = 'ეს არის მიღების დასტური თქვენს შეტყობინებაზე';
$labels['receiptnote'] = 'განმარტება: ეს ნიშნავს რომ ადრესატმა მიიღო შეტყობინება. მაგრამ, არ ნიშნავს რომ წაიკითხა ან გაიგო ტექსტი';
$labels['name'] = 'სრული სახელი';
$labels['firstname'] = 'სახელი';
$labels['surname'] = 'გვარი';
$labels['nameprefix'] = 'პრეფიქსი';
$labels['namesuffix'] = 'სუფიქსი';
$labels['jobtitle'] = 'თანამდებობა';
$labels['department'] = 'დეპარტამენტი';
$labels['gender'] = 'სქესი';
$labels['email'] = 'ელ–ფოსტა';
$labels['phone'] = 'ტელეფონი';
$labels['address'] = 'მისამართი';
$labels['street'] = 'ქუჩა';
$labels['locality'] = 'ქალაქი';
$labels['zipcode'] = 'ZIP კოდი';
$labels['region'] = 'შტატი/პროვინცია';
$labels['country'] = 'ქვეყანა';
$labels['birthday'] = 'დაბადების დღე';
$labels['website'] = 'ვებგვერდი';
$labels['male'] = 'მამრობითი';
$labels['female'] = 'მდედრობით';
$labels['manager'] = 'მენეჯერი';
$labels['allfields'] = 'ყველა ველი';
$labels['search'] = 'ძებნა';
$labels['searchresult'] = 'ძებნის რეზულტატი';
$labels['advsearch'] = 'გაფართოებული ძებნა';
$labels['other'] = 'სხვა';
$labels['typehome'] = 'სახლი';
$labels['typework'] = 'სამსახური';
$labels['typeother'] = 'სხვა';
$labels['typemobile'] = 'მობილური';
$labels['typemain'] = 'ძირითადი';
$labels['typehomefax'] = 'სახლის ფაქსი';
$labels['typeworkfax'] = 'სამსახურის ფაქსი';
$labels['typecar'] = 'მანქანა';
$labels['typepager'] = 'პეიჯერი';
$labels['typevideo'] = 'ვიდეო';
$labels['typeblog'] = 'ბლოგი';
$labels['typeprofile'] = 'პროფილი';
$labels['addfield'] = 'ველის დამატება...';
$labels['addcontact'] = 'კონტაქტის დამატება';
$labels['editcontact'] = 'კონტაქტის რედაქტირება';
$labels['contacts'] = 'კონტაქტები';
$labels['contactnameandorg'] = 'სახელი და ორგანიზაცია';
$labels['personalinfo'] = 'პირადი ინფორმაცია';
$labels['contactphoto'] = 'კონტაქტის ფოტო';
$labels['edit'] = 'რედაქტირება';
$labels['cancel'] = 'გაუქმება';
$labels['save'] = 'შენახვა';
$labels['delete'] = 'წაშლა';
$labels['rename'] = 'გადარქმევა';
$labels['addphoto'] = 'დამატება';
$labels['replacephoto'] = 'გამოცვლა';
$labels['uploadphoto'] = 'სურათის ატვირთვა';
$labels['deletecontact'] = 'მონიშნელი კონტაქტის წაშლა';
$labels['composeto'] = 'ფოსტის გაგზავნა შერჩეულ ადრესატებთან';
$labels['contactsfromto'] = 'კონტაქტები $from დან $to ში $count';
$labels['print'] = 'დაბეჭვდა';
$labels['export'] = 'ექსპორტი';
$labels['exportvcards'] = 'კონტაქტების ექსპორტი vCard ფორმატში';
$labels['grouprename'] = 'ჯგუფის სახელის შეცვლა';
$labels['groupdelete'] = 'ჯგუფის წაშლა';
$labels['previouspage'] = 'წინას ჩვენება';
$labels['firstpage'] = 'პირველის ჩვენება';
$labels['nextpage'] = 'შემდეგის ჩვენება';
$labels['lastpage'] = 'ბოლოს ჩვენება';
$labels['group'] = 'ჯგუფი';
$labels['groups'] = 'ჯგუფები';
$labels['personaladrbook'] = 'პერსონალური მისამართები';
$labels['searchsave'] = 'ძებნის შენახვა';
$labels['searchdelete'] = 'ძებნის წაშლა';
$labels['import'] = 'შემოტანა';
$labels['importcontacts'] = 'კონტაქტების შემოტანა';
$labels['importreplace'] = 'ჩაანაცვლეთ არსებული მისამართები';
$labels['done'] = 'დასრულებულია';
$labels['settingsfor'] = 'პარამეტრები';
$labels['preferences'] = 'პარამეტრები';
$labels['userpreferences'] = 'მომხმარებლის პარამეტრები';
$labels['editpreferences'] = 'მომხმარებლის პარამეტრების რედაქტირება';
$labels['identities'] = 'პროფილები';
$labels['preferhtml'] = 'როგორც HTML';
$labels['defaultcharset'] = 'ნაგულისხმები სიმბოლოთა ნაკრები';
$labels['htmlmessage'] = 'HTML შეტყობინება';
$labels['dateformat'] = 'თარიღის ფორმატი';
$labels['timeformat'] = 'დროის ფორმატი';
$labels['prettydate'] = 'კარგი თარიღები';
$labels['setdefault'] = 'როგორც ზოგაგად';
$labels['autodetect'] = 'ავტომატური';
$labels['language'] = 'ენა';
$labels['timezone'] = 'დროითი ზონა';
$labels['pagesize'] = 'სტრიქონი გვერდზე';
$labels['signature'] = 'ხელმოწერა';
$labels['dstactive'] = 'დროის გადაყვანა';
$labels['htmleditor'] = 'შეტყობინების შექმნა HTML –ში';
$labels['htmlsignature'] = 'HTML ხელმოწერა';
$labels['previewpane'] = 'ჩვენება';
$labels['skin'] = 'ინტერფეისი';
$labels['logoutclear'] = 'წაშლილების გასუფთავება გამოსვლისას';
$labels['logoutcompact'] = 'მიღებულების შეკუმშვა გამოსვლისას';
$labels['uisettings'] = 'მომხმარებლის ინტერფეისი';
$labels['serversettings'] = 'სერვერის პარამეტრები';
$labels['mailboxview'] = 'საფოსტო ყუთის ჩვენება';
$labels['mdnrequests'] = 'მგზავნელის შეტყობინებები';
$labels['askuser'] = 'ჰკითხე მომხმარებელს';
$labels['autosend'] = 'გაგზავნე ავტომატურად';
$labels['readwhendeleted'] = 'მონიშნე გზავნილი წაკითხულად წაშლის დროს';
$labels['flagfordeletion'] = 'აღნიშნეთ გზავნილები როგორც წასაშლელი წაშლის ნაცვლად';
$labels['skipdeleted'] = 'არ გამოაჩინო წაშლილი გზავნილები';
$labels['showremoteimages'] = 'გამოაჩინე მოშორებული სურათები';
$labels['fromknownsenders'] = 'ნაცნობი მგზავნელებისგან';
$labels['always'] = 'ყოველთვის';
$labels['showinlineimages'] = 'ატვირთული სურათები გამოაჩინე გზავნილის ქვემოთ';
$labels['autosavedraft'] = 'ავტომატური შენახვა';
$labels['everynminutes'] = 'ყოველ $n წუთში';
$labels['never'] = 'არასდროს';
$labels['immediately'] = 'დაუყონებლივ';
$labels['messagesdisplaying'] = 'გამოაჩინე შეტყობინებები';
$labels['messagescomposition'] = 'შეტყობინებების შექმნა';
$labels['mimeparamfolding'] = 'ბმულის სახელები';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (other)';
$labels['force7bit'] = 'MIME კოდირების გამოყენება 8 ბიტიანი სიმბოლოებისთვის';
$labels['advancedoptions'] = 'დამატებითი პარამეტრები';
$labels['focusonnewmessage'] = 'ფოკუსირება ახალ შეტყობინებებზე';
$labels['checkallfolders'] = 'შეამოწმე ყველა საქაღალდე ახალ შეტყობინებაზე';
$labels['mainoptions'] = 'ძირითადი პარამეტრები';
$labels['section'] = 'განყოფილება';
$labels['maintenance'] = 'მომსახურება';
$labels['newmessage'] = 'ახალი შეტყობინება';
$labels['signatureoptions'] = 'ხელმოწერის ოფციები';
$labels['whenreplying'] = 'პასუხის შემთხვევაში';
$labels['replytopposting'] = 'დაიწყოს ახალი შეტყობინება ორიგინალის ზემოთ';
$labels['replybottomposting'] = 'დაიწყოს ახალი შეტყობინება ორიგინალის ქვემოთ';
$labels['replyremovesignature'] = 'წაიშალოს ხელმოწერა პასუხის შემთხვევაში';
$labels['autoaddsignature'] = 'ავტომატურად დაემატოს ხელმოწერა';
$labels['newmessageonly'] = 'მხოლოდ ახალი შეტყობინება';
$labels['replyandforwardonly'] = 'მხოლოდ გადაგზავნის და პასუხის შემთხვევაში';
$labels['insertsignature'] = 'ხელმოცერის ჩასმა';
$labels['afternseconds'] = '$n წამის შემდეგ';
$labels['addtodict'] = 'ლექსიკონში დამატება';
$labels['folder'] = 'საქაღალდე';
$labels['folders'] = 'საქაღალდეები';
$labels['foldername'] = 'საქაღალდის დასახელება';
$labels['subscribed'] = 'გამოწერილია';
$labels['messagecount'] = 'შეტყობინებები';
$labels['create'] = 'შექმნა';
$labels['createfolder'] = 'საქაღალდის შექმნა';
$labels['managefolders'] = 'საქაღალდეების მართვა';
$labels['specialfolders'] = 'სპეციალური საქაღალდე';
$labels['location'] = 'მდებარეობა';
$labels['info'] = 'ინფორმაცია';
$labels['foldertype'] = 'დასტის ტიპი';
$labels['personalfolder'] = 'კერძო დასტა';
$labels['sharedfolder'] = 'საჯარო დასტა';
$labels['sortby'] = 'დალაგება';
$labels['sortasc'] = 'დალაგება ზრდადობით';
$labels['sortdesc'] = 'დალაგება კლებადობით';
$labels['undo'] = 'დაბრუნება';
$labels['B'] = 'ბტ';
$labels['KB'] = 'კბტ';
$labels['MB'] = 'მბტ';
$labels['GB'] = 'გბტ';
$labels['unicode'] = 'უნიკოდი';
$labels['english'] = 'ინსგლისური';
$labels['westerneuropean'] = 'დასავლურევროპული';
$labels['easterneuropean'] = 'აღმოსავლეთევროპული';
$labels['baltic'] = 'ბალტიური';
$labels['cyrillic'] = 'კირილიცა';
$labels['arabic'] = 'არაბული';
$labels['greek'] = 'ბერძნული';
$labels['hebrew'] = 'ებრაული';
$labels['turkish'] = 'თურქული';
$labels['thai'] = 'ტაი';
$labels['celtic'] = 'კელტური';
$labels['vietnamese'] = 'ვიეტნამური';
$labels['japanese'] = 'იაპონური';
$labels['korean'] = 'კორეული';
$labels['chinese'] = 'ჩინური';
