<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Bienvenido a $product';
$labels['username'] = 'Nombre de usuario';
$labels['password'] = 'Contraseña';
$labels['server'] = 'Servidor';
$labels['login'] = 'Iniciar sesión';
$labels['oauthlogin'] = 'Iniciar sesión con $provider';
$labels['menu'] = 'Menú';
$labels['logout'] = 'Cerrar sesión';
$labels['mail'] = 'Correo';
$labels['settings'] = 'Configuración';
$labels['addressbook'] = 'Contactos';
$labels['darkmode'] = 'Modo oscuro';
$labels['lightmode'] = 'Modo claro';
$labels['inbox'] = 'Entrada';
$labels['drafts'] = 'Borradores';
$labels['sent'] = 'Enviados';
$labels['trash'] = 'Papelera';
$labels['junk'] = 'SPAM';
$labels['show_real_foldernames'] = 'Mostrar nombres reales para carpetas especiales';
$labels['subject'] = 'Asunto';
$labels['from'] = 'De';
$labels['sender'] = 'Remitente';
$labels['to'] = 'Destinatario';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Cco';
$labels['replyto'] = 'Responder a';
$labels['followupto'] = 'Responder a todos';
$labels['date'] = 'Fecha';
$labels['size'] = 'Tamaño';
$labels['priority'] = 'Prioridad';
$labels['organization'] = 'Organización';
$labels['readstatus'] = 'Estado de lectura';
$labels['listoptions'] = 'Opciones de listado...';
$labels['listoptionstitle'] = 'Lista de opciones';
$labels['mailboxlist'] = 'Carpetas';
$labels['messagesfromto'] = 'Mensajes $from a $to de $count';
$labels['threadsfromto'] = 'Hilos $from a $to de $count';
$labels['messagenrof'] = 'Mensaje $nr de $count';
$labels['fromtoshort'] = '$from – $to de $count';
$labels['copy'] = 'Copiar';
$labels['move'] = 'Mover';
$labels['moveto'] = 'Mover a…';
$labels['copyto'] = 'Copiar a...';
$labels['download'] = 'Descargar';
$labels['open'] = 'Abrir';
$labels['showattachment'] = 'Mostrar';
$labels['showanyway'] = 'Mostrarlo de todos modos';
$labels['filename'] = 'Nombre del archivo';
$labels['filesize'] = 'Tamaño del archivo';
$labels['addtoaddressbook'] = 'Añadir a contactos';
$labels['sun'] = 'dom';
$labels['mon'] = 'lun';
$labels['tue'] = 'mar';
$labels['wed'] = 'mié';
$labels['thu'] = 'jue';
$labels['fri'] = 'vie';
$labels['sat'] = 'sáb';
$labels['sunday'] = 'domingo';
$labels['monday'] = 'lunes';
$labels['tuesday'] = 'martes';
$labels['wednesday'] = 'miércoles';
$labels['thursday'] = 'jueves';
$labels['friday'] = 'viernes';
$labels['saturday'] = 'sábado';
$labels['jan'] = 'ene';
$labels['feb'] = 'feb';
$labels['mar'] = 'mar';
$labels['apr'] = 'abr';
$labels['may'] = 'may';
$labels['jun'] = 'jun';
$labels['jul'] = 'jul';
$labels['aug'] = 'ago';
$labels['sep'] = 'sep';
$labels['oct'] = 'oct';
$labels['nov'] = 'nov';
$labels['dec'] = 'dic';
$labels['longjan'] = 'enero';
$labels['longfeb'] = 'febrero';
$labels['longmar'] = 'marzo';
$labels['longapr'] = 'abril';
$labels['longmay'] = 'mayo';
$labels['longjun'] = 'junio';
$labels['longjul'] = 'julio';
$labels['longaug'] = 'agosto';
$labels['longsep'] = 'septiembre';
$labels['longoct'] = 'octubre';
$labels['longnov'] = 'noviembre';
$labels['longdec'] = 'diciembre';
$labels['today'] = 'Hoy';
$labels['refresh'] = 'Actualizar';
$labels['checkmail'] = 'Comprobar si hay mensajes nuevos';
$labels['compose'] = 'Redactar';
$labels['writenewmessage'] = 'Crear un mensaje nuevo';
$labels['reply'] = 'Responder';
$labels['replytomessage'] = 'Responder al remitente';
$labels['replytoallmessage'] = 'Responder a la lista o al remitente y a todos los destinatarios';
$labels['replyall'] = 'Responder a todos';
$labels['replylist'] = 'Responder a la lista';
$labels['forward'] = 'Reenviar';
$labels['forwardinline'] = 'Reenviar entre-líneas';
$labels['forwardattachment'] = 'Reenviar como adjunto';
$labels['forwardmessage'] = 'Reenviar mensaje';
$labels['bouncemsg'] = 'Volver a enviar (rebotar)';
$labels['bounce'] = 'Reenviar';
$labels['deletemessage'] = 'Eliminar mensaje';
$labels['movemessagetotrash'] = 'Mover mensaje a la papelera';
$labels['printmessage'] = 'Imprimir este mensaje';
$labels['previousmessage'] = 'Mostrar mensaje anterior';
$labels['firstmessage'] = 'Mostrar primer mensaje';
$labels['nextmessage'] = 'Mostrar el siguiente mensaje';
$labels['lastmessage'] = 'Mostrar el último mensaje';
$labels['backtolist'] = 'Volver a la lista de mensajes';
$labels['viewsource'] = 'Mostrar código';
$labels['mark'] = 'Marcar';
$labels['markmessages'] = 'Marcar mensajes';
$labels['markread'] = 'Como leído';
$labels['markunread'] = 'Como no leído';
$labels['markflagged'] = 'Como resaltado';
$labels['markunflagged'] = 'Como no resaltado';
$labels['moreactions'] = 'Más acciones…';
$labels['markallread'] = 'Marcar todos como leídos';
$labels['folders-cur'] = 'Sólo la carpeta seleccionada';
$labels['folders-sub'] = 'Carpeta seleccionada y sus subcarpetas';
$labels['folders-all'] = 'Todas las carpetas';
$labels['more'] = 'Más';
$labels['back'] = 'Volver';
$labels['options'] = 'Opciones';
$labels['composeoptions'] = 'Opciones de redacción';
$labels['optionsandattachments'] = 'Opciones y ficheros adjuntos';
$labels['actions'] = 'Acciones';
$labels['first'] = 'Primero';
$labels['last'] = 'Último';
$labels['previous'] = 'Anterior';
$labels['next'] = 'Siguiente';
$labels['select'] = 'Seleccionar';
$labels['selection'] = 'Selección';
$labels['all'] = 'Todos';
$labels['none'] = 'Ninguno';
$labels['currpage'] = 'Página actual';
$labels['isread'] = 'Leído';
$labels['unread'] = 'No leído';
$labels['flagged'] = 'Resaltado';
$labels['unflagged'] = 'No Resaltado';
$labels['unanswered'] = 'Sin contestar';
$labels['withattachment'] = 'Con adjunto';
$labels['deleted'] = 'Eliminado';
$labels['undeleted'] = 'No eliminado';
$labels['replied'] = 'Contestado';
$labels['forwarded'] = 'Reenviado';
$labels['invert'] = 'Invertir';
$labels['filter'] = 'Filtrar';
$labels['list'] = 'Lista';
$labels['threads'] = 'Hilos';
$labels['expand-all'] = 'Expandir todos';
$labels['expand-unread'] = 'Expandir no leídos';
$labels['collapse-all'] = 'Colapsar todos';
$labels['threaded'] = 'Encadenados';
$labels['showunread'] = 'Mostrar no leídos';
$labels['autoexpand_threads'] = 'Expandir hilos de mensajes';
$labels['do_expand'] = 'todos los hilos';
$labels['expand_only_unread'] = 'solo con mensajes no leídos';
$labels['fromto'] = 'De/A';
$labels['flag'] = 'Resaltar';
$labels['attachment'] = 'Adjunto';
$labels['nonesort'] = 'Ninguno';
$labels['sentdate'] = 'Fecha de envío';
$labels['arrival'] = 'Fecha de llegada';
$labels['asc'] = 'ascendente';
$labels['desc'] = 'descendente';
$labels['listcolumns'] = 'Listar columnas';
$labels['listsorting'] = 'Columna de ordenación';
$labels['listorder'] = 'Criterio de ordenación';
$labels['listmode'] = 'Modo de vista de lista';
$labels['lmode'] = 'Forma de ordenación';
$labels['layout'] = 'Disposición';
$labels['layoutwidescreen'] = 'Pantalla ancha';
$labels['layoutdesktop'] = 'Escritorio';
$labels['layoutlist'] = 'Lista';
$labels['layoutwidescreendesc'] = 'Pantalla ancha (vista de 3 columnas)';
$labels['layoutdesktopdesc'] = 'Escritorio (Lista ancha y vista previa del correo debajo)';
$labels['layoutlistdesc'] = 'Lista (sin vista previa del correo)';
$labels['folderactions'] = 'Acciones de carpeta...';
$labels['compact'] = 'Compactar';
$labels['empty'] = 'Vaciar';
$labels['importmessages'] = 'Importar mensajes';
$labels['mailimportdesc'] = 'Puedes subir ficheros usando formatos <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> o <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>.';
$labels['mailimportzip'] = 'Se pueden comprimir varios ficheros en archivos zip.';
$labels['quota'] = 'Uso de disco';
$labels['unknown'] = 'desconocido';
$labels['unlimited'] = 'sin límite';
$labels['quotatype'] = 'Tipo de cuota';
$labels['quotatotal'] = 'Límite';
$labels['quotaused'] = 'Usado';
$labels['quotastorage'] = 'Espacio en disco';
$labels['quotamessage'] = 'Número de mensajes';
$labels['shortheaderdate'] = 'El $date';
$labels['shortheaderto'] = 'A $to el $date';
$labels['shortheaderfrom'] = 'De $from el $date';
$labels['quicksearch'] = 'Búsqueda rápida';
$labels['searchplaceholder'] = 'Buscar...';
$labels['resetsearch'] = 'Reiniciar la búsqueda';
$labels['searchmod'] = 'Opciones de búsqueda';
$labels['msgtext'] = 'Mensaje completo';
$labels['body'] = 'Cuerpo';
$labels['type'] = 'Tipo';
$labels['namex'] = 'Nombre';
$labels['searchscope'] = 'Ámbito';
$labels['currentfolder'] = 'Carpeta actual';
$labels['subfolders'] = 'Ésta y subcarpetas';
$labels['allfolders'] = 'Todas las carpetas';
$labels['searchinterval-1W'] = 'más antiguo que una semana';
$labels['searchinterval-1M'] = 'más antiguo que un mes';
$labels['searchinterval-1Y'] = 'más antiguo que un año';
$labels['searchinterval1W'] = 'más reciente que una semana';
$labels['searchinterval1M'] = 'más reciente que un mes';
$labels['searchinterval1Y'] = 'más reciente que un mes';
$labels['openinextwin'] = 'Abrir en nueva ventana';
$labels['emlsave'] = 'Descargar (.eml)';
$labels['changeformattext'] = 'Mostrar en formato de texto simple';
$labels['changeformathtml'] = 'Mostrar en formato HTML';
$labels['editasnew'] = 'Editar como nuevo';
$labels['send'] = 'Enviar';
$labels['sendmessage'] = 'Enviar el mensaje';
$labels['savemessage'] = 'Guardar como borrador';
$labels['addattachment'] = 'Adjuntar un archivo';
$labels['charset'] = 'Codificación';
$labels['editortype'] = 'Tipo de editor';
$labels['returnreceipt'] = 'Confirmación de recibo';
$labels['dsn'] = 'Notificación de estado de la entrega';
$labels['mailreplyintro'] = 'El $date, $sender escribió:';
$labels['originalmessage'] = 'Mensaje Original';
$labels['selectimage'] = 'Seleccionar imagen';
$labels['addimage'] = 'Añadir imagen';
$labels['selectmedia'] = 'Seleccionar película';
$labels['addmedia'] = 'Añadir película';
$labels['encrypt'] = 'Encriptar';
$labels['encryptmessage'] = 'Encriptar mensaje';
$labels['encryptmessagemailvelope'] = 'Cifrar mensaje con Malivelope';
$labels['importpubkeys'] = 'Importar claves públicas';
$labels['encryptedsendialog'] = 'Mandando mensaje encriptado';
$labels['encryptandsign'] = 'Encriptar y firmar';
$labels['keyid'] = 'ID de la clave';
$labels['keylength'] = 'Bits';
$labels['keyexpired'] = 'Expirado';
$labels['keyrevoked'] = 'Rechazado';
$labels['bccinstead'] = 'Usar Cco';
$labels['addheader'] = 'Añadir destinatario (cabecera)';
$labels['insert'] = 'Insertar';
$labels['insertcontact'] = 'Insertar contacto(s)';
$labels['recipient'] = 'Destinatario';
$labels['recipientedit'] = 'Editar destinatario';
$labels['editidents'] = 'Editar identidades';
$labels['spellcheck'] = 'Corrector ortográfico';
$labels['checkspelling'] = 'Revisar ortografía';
$labels['resumeediting'] = 'Reanudar edición';
$labels['revertto'] = 'Revertir a';
$labels['restore'] = 'Restaurar';
$labels['restoremessage'] = '¿Restaurar el mensaje?';
$labels['ignore'] = 'Ignorar';
$labels['responses'] = 'Respuestas';
$labels['insertresponse'] = 'Insertar una respuesta';
$labels['manageresponses'] = 'Gestionar respuestas';
$labels['newresponse'] = 'Crear nueva respuesta';
$labels['addresponse'] = 'Añadir respuesta';
$labels['editresponse'] = 'Editar respuesta';
$labels['editresponses'] = 'Editar respuestas';
$labels['responsename'] = 'Nombre';
$labels['responsetext'] = 'Texto de respuesta';
$labels['attach'] = 'Adjuntar';
$labels['attachments'] = 'Adjuntos';
$labels['upload'] = 'Cargar';
$labels['uploadprogress'] = '$percent ($current de $total)';
$labels['close'] = 'Cerrar';
$labels['messageoptions'] = 'Opciones de mensaje...';
$labels['togglecomposeoptions'] = 'Mostrar opciones de escritura';
$labels['attachmentrename'] = 'Renombrar el adjunto';
$labels['low'] = 'Baja';
$labels['lowest'] = 'La más baja';
$labels['normal'] = 'Normal';
$labels['high'] = 'Alta';
$labels['highest'] = 'La más alta';
$labels['nosubject'] = '(sin asunto)';
$labels['showimages'] = 'Mostrar imágenes';
$labels['allow'] = 'Permitir';
$labels['alwaysshow'] = 'Siempre mostrar imágenes de $sender';
$labels['alwaysallow'] = 'Permitir siempre de $sender';
$labels['isdraft'] = 'Este es un mensaje de borrador.';
$labels['andnmore'] = '$nr más…';
$labels['details'] = 'Detalles';
$labels['summary'] = 'Resumen';
$labels['headers'] = 'Cabeceras';
$labels['allheaders'] = 'Todas las cabeceras...';
$labels['togglemoreheaders'] = 'Mostrar más encabezados del mensaje';
$labels['togglefullheaders'] = 'Desplegar u ocultar encabezados de mensajes';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Sólo texto';
$labels['savesentmessagein'] = 'Guardar mensaje enviado en';
$labels['dontsave'] = 'no guardar';
$labels['maxuploadsize'] = 'Tamaño de archivo máximo permitido: $size';
$labels['addcc'] = 'Añadir Cc';
$labels['addbcc'] = 'Añadir Cco';
$labels['addreplyto'] = 'Añadir Responder a';
$labels['addfollowupto'] = 'Añadir Seguir a';
$labels['sendreceipt'] = '¿Enviar confirmación de lectura?';
$labels['mdnrequest'] = 'El remitente de este mensaje desea ser notificado cuando usted lo lea. ¿Desea enviar esta notificación?';
$labels['receiptread'] = 'Devolver recibo de confirmación (lectura)';
$labels['yourmessage'] = 'Esto es un acuse de recibo de su mensaje';
$labels['receiptnote'] = 'Nota: Esta notificación sólo confirma que su mensaje fue abierto en el ordenador del destinatario. Eso no garantiza que el destinatario haya leído o entendido el contenido del mensaje.';
$labels['sendalwaysto'] = 'Enviar siempre a $email';
$labels['zoomin'] = 'Acercar';
$labels['zoomout'] = 'Alejar';
$labels['rotate'] = 'Girar';
$labels['increaseimage'] = 'Aumentar el tamaño de la imagen';
$labels['decreaseimage'] = 'Disminuir el tamaño de la imagen';
$labels['rotateimage'] = 'Girar imagen';
$labels['showtools'] = 'Mostrar herramientas de imagen';
$labels['hidetools'] = 'Ocultar herramientas de imagen';
$labels['name'] = 'Nombre de visualización';
$labels['firstname'] = 'Nombre';
$labels['surname'] = 'Apellido';
$labels['middlename'] = 'Segundo nombre';
$labels['nameprefix'] = 'Prefijo';
$labels['namesuffix'] = 'Sufijo';
$labels['nickname'] = 'Alias';
$labels['jobtitle'] = 'Título Profesional';
$labels['department'] = 'Departamento';
$labels['gender'] = 'Sexo';
$labels['maidenname'] = 'Apellido de soltera';
$labels['email'] = 'Correo electrónico';
$labels['phone'] = 'Teléfono';
$labels['address'] = 'Dirección';
$labels['street'] = 'Calle';
$labels['locality'] = 'Ciudad';
$labels['zipcode'] = 'Código postal';
$labels['region'] = 'Provincia';
$labels['country'] = 'País';
$labels['birthday'] = 'Cumpleaños';
$labels['anniversary'] = 'Aniversario';
$labels['website'] = 'Página web';
$labels['instantmessenger'] = 'Mensajería instantánea';
$labels['notes'] = 'Notas';
$labels['male'] = 'masculino';
$labels['female'] = 'femenino';
$labels['manager'] = 'Director';
$labels['assistant'] = 'Auxiliar';
$labels['spouse'] = 'Cónyuge';
$labels['allfields'] = 'Todos los campos';
$labels['search'] = 'Buscar';
$labels['searchresult'] = 'Resultado de búsqueda';
$labels['advsearch'] = 'Búsqueda avanzada';
$labels['advanced'] = 'Avanzadas';
$labels['other'] = 'Otro';
$labels['printcontact'] = 'Imprimir contacto';
$labels['qrcode'] = 'Código QR';
$labels['typehome'] = 'Casa';
$labels['typework'] = 'Trabajo';
$labels['typeother'] = 'Otro';
$labels['typemobile'] = 'Móvil';
$labels['typemain'] = 'Principal';
$labels['typehomefax'] = 'Fax de casa';
$labels['typeworkfax'] = 'Fax del trabajo';
$labels['typecar'] = 'Automóvil';
$labels['typepager'] = 'Paginador';
$labels['typevideo'] = 'Vídeo';
$labels['typeassistant'] = 'Auxiliar';
$labels['typehomepage'] = 'Página Principal';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Perfil';
$labels['addfield'] = 'Añadir campo...';
$labels['addcontact'] = 'Añadir contacto';
$labels['editcontact'] = 'Editar contacto';
$labels['contacts'] = 'Contactos';
$labels['contactproperties'] = 'Propiedades del contacto';
$labels['contactnameandorg'] = 'Nombre y organización';
$labels['personalinfo'] = 'Información personal';
$labels['personal'] = 'Personal';
$labels['contactphoto'] = 'Foto del contacto';
$labels['edit'] = 'Editar';
$labels['cancel'] = 'Cancelar';
$labels['save'] = 'Guardar';
$labels['delete'] = 'Eliminar';
$labels['discard'] = 'Descartar';
$labels['continue'] = 'Continuar';
$labels['ok'] = 'OK';
$labels['rename'] = 'Renombrar';
$labels['addphoto'] = 'Añadir';
$labels['replacephoto'] = 'Reemplazar';
$labels['uploadphoto'] = 'Subir foto';
$labels['choosefile'] = 'Elegir el fichero...';
$labels['choosefiles'] = 'Elegir los ficheros...';
$labels['browse'] = 'Navegar';
$labels['newcontact'] = 'Crear nuevo contacto';
$labels['deletecontact'] = 'Eliminar contactos seleccionados';
$labels['composeto'] = 'Escribir mensaje a';
$labels['contactsfromto'] = 'Contactos $from a $to de $count';
$labels['print'] = 'Imprimir';
$labels['export'] = 'Exportar';
$labels['exportall'] = 'Exportar todo';
$labels['exportsel'] = 'Exportar seleccionados';
$labels['exportvcards'] = 'Exportar contactos en formato vCard';
$labels['newgroup'] = 'Crear nuevo grupo';
$labels['addgroup'] = 'Añadir grupo';
$labels['grouprename'] = 'Renombrar grupo';
$labels['groupdelete'] = 'Borrar grupo';
$labels['groupassign'] = 'Asignar a un grupo...';
$labels['groupremove'] = 'Eliminar de un grupo';
$labels['groupremoveselected'] = 'Eliminar los contactos seleccionados del grupo';
$labels['uponelevel'] = 'Subir un nivel';
$labels['previouspage'] = 'Mostrar grupo anterior';
$labels['firstpage'] = 'Mostrar primer grupo';
$labels['nextpage'] = 'Mostrar grupo siguiente';
$labels['lastpage'] = 'Mostrar último grupo';
$labels['group'] = 'Grupo';
$labels['groups'] = 'Grupos';
$labels['listgroup'] = 'Listar miembros del grupo';
$labels['personaladrbook'] = 'Direcciones personales';
$labels['searchsave'] = 'Guardar búsqueda';
$labels['searchdelete'] = 'Borrar búsqueda';
$labels['import'] = 'Importar';
$labels['importcontacts'] = 'Importar contactos';
$labels['importfromfile'] = 'Importar desde archivo';
$labels['importtarget'] = 'Agregar contactos a';
$labels['importreplace'] = 'Reemplazar toda la lista de contactos';
$labels['importgroups'] = 'Importar asignaciones de grupo';
$labels['importgroupsall'] = 'Todos (crear grupos si es necesario)';
$labels['importgroupsexisting'] = 'Sólo para los grupos existentes';
$labels['importdesc'] = 'Puede cargar contactos de una libreta de contactos existente.<br/>Actualmente soportamos la importación de direcciones desde formatos <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> o desde CSV (separados por comas).';
$labels['importmapdesc'] = 'Confirme que la información de mapeado de campos mostrada abajo es correcta antes de proceder con la importación de datos del CSV (separado por comas).';
$labels['fieldnotmapped'] = 'Campo no mapeado (no importar)';
$labels['skipheader'] = 'No importar la primera línea (cabeceras)';
$labels['done'] = 'Hecho';
$labels['settingsfor'] = 'Configuración para';
$labels['about'] = 'Acerca de';
$labels['preferences'] = 'Preferencias';
$labels['userpreferences'] = 'Preferencias de usuario';
$labels['editpreferences'] = 'Editar preferencias de usuario';
$labels['identities'] = 'Identidades';
$labels['manageidentities'] = 'Administrar identidades';
$labels['newidentity'] = 'Crear nueva identidad';
$labels['addidentity'] = 'Añadir identidad';
$labels['editidentity'] = 'Editar identidad';
$labels['identityencryption'] = 'Encriptación';
$labels['preferhtml'] = 'Mostrar HTML';
$labels['defaultcharset'] = 'Conjunto de caracteres predeterminado';
$labels['htmlmessage'] = 'Mensaje HTML';
$labels['messagepart'] = 'Parte';
$labels['digitalsig'] = 'Firma digital';
$labels['dateformat'] = 'Formato de fecha';
$labels['timeformat'] = 'Formato de hora';
$labels['prettydate'] = 'Transformar fechas recientes';
$labels['setdefault'] = 'Establecer como  predeterminado';
$labels['autodetect'] = 'Automático';
$labels['language'] = 'Idioma';
$labels['timezone'] = 'Zona horaria';
$labels['pagesize'] = 'Filas por página';
$labels['signature'] = 'Firma';
$labels['dstactive'] = 'Horario de verano';
$labels['showinextwin'] = 'Abrir mensaje en una ventana nueva';
$labels['composeextwin'] = 'Redactar en una ventana nueva';
$labels['htmleditor'] = 'Redactar mensajes HTML';
$labels['htmlonreply'] = 'en respuesta a mensaje HTML';
$labels['htmlonreplyandforward'] = 'en reenvío o respuesta a mensaje HTML';
$labels['htmlsignature'] = 'Firma HTML';
$labels['showemail'] = 'Mostrar dirección electrónica con el nombre de visualización';
$labels['previewpane'] = 'Mostrar panel de vista previa';
$labels['skin'] = 'Apariencia de la interfaz';
$labels['logoutclear'] = 'Vaciar Papelera al cerrar sesión';
$labels['logoutcompact'] = 'Compactar Bandeja de Entrada al cerrar sesión';
$labels['uisettings'] = 'Interfaz de Usuario';
$labels['serversettings'] = 'Configuración del servidor';
$labels['mailboxview'] = 'Vista de Buzón';
$labels['mdnrequests'] = 'Cuando se solicite confirmación de recibo';
$labels['askuser'] = 'preguntarme';
$labels['autosend'] = 'enviar confirmación de recibo';
$labels['autosendknown'] = 'enviar confirmación de recibo a mis contactos, preguntar por los demás';
$labels['autosendknownignore'] = 'enviar confirmación de recibo a mis contactos, ignorar los demás';
$labels['autosendtrusted'] = 'Enviar la confirmación de recepción a mis remitentes de confianza, para el resto preguntarme.';
$labels['autosendtrustedignore'] = 'Enviar la confirmación de recepción a mis remitentes de confianza, para el resto ignorar.';
$labels['ignorerequest'] = 'Ignorar petición';
$labels['readwhendeleted'] = 'Marcar el mensaje como leído al borrarlo';
$labels['flagfordeletion'] = 'Marcar el mensaje para borrarse en vez de borrarlo';
$labels['skipdeleted'] = 'No mostrar mensajes borrados';
$labels['deletealways'] = 'Si mover mensajes a la Papelera fracasa, borrarlos';
$labels['deletejunk'] = 'Directamente eliminar mensajes en SPAM';
$labels['showremoteimages'] = 'Mostrar las imágenes externas';
$labels['allowremoteresources'] = 'Permitir recursos remotos (imágenes, estilos)';
$labels['fromknownsenders'] = 'de remitentes conocidos';
$labels['fromtrustedsenders'] = 'de remitentes de confianza';
$labels['frommycontacts'] = 'de mis contactos';
$labels['always'] = 'siempre';
$labels['alwaysbutplain'] = 'siempre, salvo cuando se responda a un texto llano';
$labels['showinlineimages'] = 'Mostrar imágenes adjuntas debajo del mensaje';
$labels['autosavedraft'] = 'Guardar borrador automáticamente';
$labels['everynminutes'] = 'cada $n minuto(s)';
$labels['refreshinterval'] = 'Actualizar (comprobar mensajes nuevos, etc.)';
$labels['never'] = 'nunca';
$labels['immediately'] = 'inmediatamente';
$labels['messagesdisplaying'] = 'Vista de Mensajes';
$labels['messagescomposition'] = 'Composición de Mensajes';
$labels['mimeparamfolding'] = 'Nombres de archivos adjuntos';
$labels['2231folding'] = 'RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'RFC 2047 (otro)';
$labels['force7bit'] = 'Usar codificación MIME para caracteres de 8 bits';
$labels['savelocalstorage'] = "Guardar (temporalmente) en el almacenamiento local del navegador";
$labels['advancedoptions'] = 'Opciones avanzadas';
$labels['toggleadvancedoptions'] = 'Desplegar opciones avanzadas';
$labels['focusonnewmessage'] = 'Enfocar ventana del navegador al recibir nuevo mensaje';
$labels['checkallfolders'] = 'Revisar todas las carpetas por nuevos mensajes';
$labels['displaynext'] = 'Mostrar el siguiente elemento de la lista después de borrar o mover';
$labels['defaultfont'] = 'Tipo de letra predeterminada de mensaje HTML';
$labels['mainoptions'] = 'Opciones Principales';
$labels['browseroptions'] = 'Opciones del Navegador';
$labels['section'] = 'Sección';
$labels['maintenance'] = 'Mantenimiento';
$labels['newmessage'] = 'Nuevo Mensaje';
$labels['signatureoptions'] = 'Opciones de Firma';
$labels['whenreplying'] = 'Al responder';
$labels['replyempty'] = 'no citar el mensaje original';
$labels['replytopposting'] = 'comenzar mensaje nuevo encima del original';
$labels['replytoppostingnoindent'] = 'comenzar nuevo mensaje encima del citado (sin sangría)';
$labels['replybottomposting'] = 'comenzar mensaje nuevo debajo del original';
$labels['replyremovesignature'] = 'Eliminar la firma original del mensaje al responder';
$labels['autoaddsignature'] = 'Añadir firma automáticamente';
$labels['newmessageonly'] = 'solamente nuevo mensaje';
$labels['replyandforwardonly'] = 'respuestas y reenvíos solamente';
$labels['insertsignature'] = 'Insertar firma';
$labels['sigbelow'] = 'Escribir la firma debajo del mensaje entrecomillado';
$labels['sigseparator'] = 'Forzar el separador estándar en las firmas';
$labels['automarkread'] = 'Marcar mensajes como leídos';
$labels['afternseconds'] = 'después de $n segundos';
$labels['reqmdn'] = 'Siempre solicitar confirmación de recibo';
$labels['reqdsn'] = 'Siempre solicitar notificación del estado de la entrega';
$labels['replysamefolder'] = 'Colocar respuestas en la carpeta del mensaje al cual se responde';
$labels['defaultabook'] = 'Libreta de direcciones predeterminada';
$labels['autocompletesingle'] = 'Omitir direcciones electrónicas alternas en el autocompletado';
$labels['listnamedisplay'] = 'Listar contactos como';
$labels['contactformmode'] = 'Modo de formulario de contacto';
$labels['privatemode'] = 'Privado (Casa)';
$labels['businessmode'] = 'Empresa (Trabajo)';
$labels['collectedaddresses'] = 'Direcciones recogidas';
$labels['collectedrecipients'] = 'Destinatarios recogidos';
$labels['collectedrecipientsopt'] = 'Almacena los destinatarios de correo electrónico de salida en';
$labels['collectedsendersopt'] = 'Almacena los remitentes de confianza en';
$labels['trustedsenders'] = 'Remitentes de confianza';
$labels['spellcheckbeforesend'] = 'Comprobar ortografía antes de enviar un mensaje';
$labels['spellcheckoptions'] = 'Opciones de Revisado de Ortografía';
$labels['spellcheckignoresyms'] = 'Ignorar palabras con símbolos';
$labels['spellcheckignorenums'] = 'Ignorar palabras con números';
$labels['spellcheckignorecaps'] = 'Ignorar palabras con todo mayúsculas';
$labels['addtodict'] = 'Añadir al diccionario';
$labels['mailtoprotohandler'] = 'Registrar controlador de protocolo para enlaces mailto:';
$labels['standardwindows'] = 'Gestionar ventanas emergentes como ventanas estándar';
$labels['forwardmode'] = 'Reenvío de mensajes';
$labels['inline'] = 'entre-línea';
$labels['asattachment'] = 'como adjunto';
$labels['replyallmode'] = 'Acción predeterminada del botón [Responder a todos]';
$labels['replyalldefault'] = 'responder a todos';
$labels['replyalllist'] = 'responder sólo a la lista de correo (si se encuentra)';
$labels['folder'] = 'Bandeja';
$labels['folders'] = 'Carpetas';
$labels['foldername'] = 'Nombre de carpeta';
$labels['subscribed'] = 'Suscrito';
$labels['messagecount'] = 'Mensajes';
$labels['create'] = 'Crear';
$labels['createfolder'] = 'Crear nueva carpeta';
$labels['managefolders'] = 'Administrar carpetas';
$labels['specialfolders'] = 'Carpetas especiales';
$labels['properties'] = 'Propiedades';
$labels['folderproperties'] = 'Propiedades de carpeta';
$labels['parentfolder'] = 'Carpeta raíz';
$labels['location'] = 'Ubicación';
$labels['info'] = 'Información';
$labels['getfoldersize'] = 'Clic para saber el tamaño de la bandeja';
$labels['changesubscription'] = 'Haga clic para cambiar suscripción';
$labels['foldertype'] = 'Tipo de Carpeta';
$labels['personalfolder'] = 'Carpeta Privada';
$labels['otherfolder'] = 'Carpeta de Otro Usuario';
$labels['sharedfolder'] = 'Carpeta Pública';
$labels['findfolders'] = 'Encontrar carpetas';
$labels['findcontacts'] = 'Encontrar contactos';
$labels['findmail'] = 'Buscar mensajes de correo electrónico';
$labels['namespace.personal'] = 'Personal';
$labels['namespace.other'] = 'Otros usuarios';
$labels['namespace.shared'] = 'Compartido';
$labels['dualuselabel'] = 'Puede contener únicamente';
$labels['dualusemail'] = 'mensajes';
$labels['dualusefolder'] = 'carpetas';
$labels['generate'] = 'Generar';
$labels['encryptioncreatekey'] = 'Crear una nueva clave par';
$labels['openmailvelopesettings'] = 'Abrir ajustes de Mailvelope';
$labels['encryptionprivkeysinmailvelope'] = 'Tiene $nr claves privadas que coinciden almacenadas en su llavero Mailvelope:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Esta identidad de remitentes todavía no tiene una clave privada PGP almacenada en su extensión Mailvelope. ¿Quiere crear una para activar la mensajería encriptada?';
$labels['encryption'] = 'Cifrado';
$labels['mailvelopeoptions'] = 'Opciones de Mailvelope';
$labels['mailvelopemainkeyring'] = 'Usar el llavero de claves principal de Mailvelope';
$labels['mailvelopenotfound'] = 'La extensión Mailvelope no está habilitada/instalada en su navegador.';
$labels['sortby'] = 'Ordenar por';
$labels['sortasc'] = 'Orden ascendente';
$labels['sortdesc'] = 'Orden descendente';
$labels['undo'] = 'Deshacer';
$labels['installedplugins'] = 'Complementos instalados';
$labels['plugin'] = 'Complemento';
$labels['version'] = 'Versión';
$labels['source'] = 'Origen';
$labels['destination'] = 'Destino';
$labels['license'] = 'Licencia';
$labels['support'] = 'Obtener soporte';
$labels['savedsearches'] = 'Búsquedas guardadas';
$labels['dateformatY'] = 'AAAA';
$labels['dateformaty'] = 'AA';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Inglés';
$labels['westerneuropean'] = 'Europeo Occidental';
$labels['easterneuropean'] = 'Europeo Oriental';
$labels['southeasterneuropean'] = 'Europeo Sudoriental';
$labels['baltic'] = 'Báltico';
$labels['cyrillic'] = 'Cirílico';
$labels['arabic'] = 'Árabe';
$labels['greek'] = 'Griego';
$labels['hebrew'] = 'Hebreo';
$labels['turkish'] = 'Turco';
$labels['nordic'] = 'Nórdico';
$labels['thai'] = 'Tailandés';
$labels['celtic'] = 'Celta';
$labels['vietnamese'] = 'Vietnamita';
$labels['japanese'] = 'Japonés';
$labels['korean'] = 'Coreano';
$labels['chinese'] = 'Chino';
$labels['arialabeltopnav'] = 'Control de ventana';
$labels['arialabeltasknav'] = 'Tareas de la aplicación';
$labels['arialabeltoolbar'] = 'Barra de herramientas de la aplicación';
$labels['arialabellistnav'] = 'Navegación por listas';
$labels['arialabelactivetask'] = 'Tarea activa';
$labels['arialabelmessagessearchfilter'] = 'Filtro de listado de correo electrónico';
$labels['arialabelmailsearchform'] = 'Formulario de búsqueda de mensaje de correo electrónico';
$labels['arialabelcontactsearchform'] = 'Formulario de búsqueda de contactos';
$labels['arialabelmailquicksearchbox'] = 'Entrada de búsqueda de correo electrónico';
$labels['arialabelquicksearchbox'] = 'Entrada de búsqueda';
$labels['arialabelfoldersearchfilter'] = 'Filtro de listas de carpetas';
$labels['arialabelfoldersearchform'] = 'Formulario de búsqueda de carpeta';
$labels['arialabelfolderlist'] = 'Selección de carpeta de correo electrónico';
$labels['arialabelmessagelist'] = 'Listado de mensajes de correo electrónico';
$labels['arialabelmailpreviewframe'] = 'Previsualizar mensaje';
$labels['arialabelmailboxmenu'] = 'Menú de acciones de carpeta';
$labels['arialabellistselectmenu'] = 'Menú de selección de listado';
$labels['arialabelthreadselectmenu'] = 'Menú de listado de conversaciones';
$labels['arialabelmessagelistoptions'] = 'Opciones para mostrar y ordenar los mensajes';
$labels['arialabelmailimportdialog'] = 'Diálogo de importación de mensaje';
$labels['arialabelmessagenav'] = 'Navegación entre mensajes';
$labels['arialabelmessagebody'] = 'Cuerpo del mensaje';
$labels['arialabelmessageactions'] = 'Acciones del mensaje';
$labels['arialabelcontactquicksearch'] = 'Formulario de búsqueda de contactos';
$labels['arialabelcontactsearchbox'] = 'Entra de búsqueda de contacto';
$labels['arialabelmessageheaders'] = 'Encabezados del mensaje';
$labels['arialabelforwardingoptions'] = 'Opciones de reenvío';
$labels['arialabelreplyalloptions'] = 'Opciones de "Responder a todos"';
$labels['arialabelmoremessageactions'] = 'Más acciones de mensaje';
$labels['arialabelmorecontactactions'] = 'Más acciones de contacto';
$labels['arialabelmarkmessagesas'] = 'Marcar los mensajes seleccionados como…';
$labels['arialabelcomposeoptions'] = 'Opciones de composición';
$labels['arialabelresponsesmenu'] = 'Menú de respuestas enlatadas';
$labels['arialabelattachmentuploadform'] = 'Formulario de subida de adjunto';
$labels['arialabelattachmentmenu'] = 'Opciones de archivo adjunto';
$labels['arialabelmailtomenu'] = 'Opciones de dirección de correo electrónico';
$labels['arialabelattachmentpreview'] = 'Previsualizar adjunto';
$labels['ariasummarycomposecontacts'] = 'Lista de contactos y grupos para elegir como destinatarios';
$labels['arialabelcontactexportoptions'] = 'Opciones de exportación de contacto';
$labels['arialabelabookgroupoptions'] = 'Opciones de grupo de contactos de la agenda';
$labels['arialabelpreferencesform'] = 'Formulario de preferencias';
$labels['arialabelidentityeditfrom'] = 'Formulario de edición de identidad';
$labels['arialabelresponseeditfrom'] = 'Formulario de edición de respuesta';
$labels['arialabelsearchterms'] = 'Términos de búsqueda';
$labels['arialabeldropactionmenu'] = 'Menú de acciones de Arrastrar y Soltar';
$labels['arialabelheadersmenu'] = 'Menú para añadir el destinatario (cabecera)';
$labels['arialabelimagetools'] = 'Herramientas de imagen';
$labels['helplistnavigation'] = 'Listar la navegación por teclado';
$labels['helplistkeyboardnavigation'] = "Flechas arriba/abajo: Mover de fila el foco o selección.
Espacio: Seleccionar la fila enfocada.
Mayúscula + arriba/abajo: Seleccionar otra fila de arriba/abajo.
Control + Espacio: Añadir fila enfocada a la selección / quitar de la selección.";
$labels['helplistkeyboardnavmessages'] = "Flechas izquierda/derecha: expandir/recoger hilo de mensaje (sólo en modo hilo).
Retorno: Abrir el mensaje seleccionado/enfocado.
Borrar: Mover los mensajes seleccionado a la Papelera.";
$labels['helplistkeyboardnavcontacts'] = "Retorno: Abrir el contacto seleccionado";
