<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<roundcube:include file="/includes/links.html" />
<script type="text/javascript" src="/functions.js"></script>

</head>
<body class="iframe">

<div id="prefs-title" class="boxtitle"><roundcube:object name="steptitle" /></div>

<div id="response-details" class="boxcontent">
  <roundcube:object name="responseform" class="propform" size="60" textareacols="60" textarearows="18" />

  <div id="formfooter">
    <div class="footerindent">
      <roundcube:button command="save" type="input" class="button mainaction" label="save" condition="!env:readonly" />
    </div>
  </div>
</div>

</body>
</html>
