<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'بەخێربێیت بۆ $product';
$labels['username'] = 'ناوی بەکارهێنەر';
$labels['password'] = 'تێپەڕەوشە';
$labels['login'] = 'چوونەژوورەوە';
$labels['logout'] = 'دەرچوون';
$labels['settings'] = 'ڕێکخستنەکان';
$labels['inbox'] = 'هاتوو';
$labels['sent'] = 'نێردراو';
$labels['subject'] = 'ناونیشان';
$labels['from'] = 'لە';
$labels['to'] = 'بۆ';
$labels['date'] = 'بەروار';
$labels['size'] = 'قەبارە';
$labels['readstatus'] = 'ڕەوشی خوێندنەوە';
$labels['listoptions'] = 'لیستی هەڵبژاردەکان';
$labels['mailboxlist'] = 'بوخچەکان';
$labels['copy'] = 'لەبەرگرتنەوە';
$labels['move'] = 'گواستنەوە';
$labels['moveto'] = 'گواستنەوە بۆ';
$labels['copyto'] = 'گواستنەوە بۆ...';
$labels['download'] = 'داگرتن';
$labels['open'] = 'کردنەوە';
$labels['showattachment'] = 'پیشاندان';
$labels['filename'] = 'ناوی پەڕگە';
$labels['filesize'] = 'قەبارەی پەڕگە';
$labels['reply'] = 'وەڵامدانەوە';
$labels['folders-all'] = 'هەموو بوخچەکان';
$labels['options'] = 'هەڵبژاردەکان';
$labels['first'] = 'یەکەم';
$labels['last'] = 'کۆتایی';
$labels['previous'] = 'پێشتر';
$labels['next'] = 'دواتر';
$labels['select'] = 'هەڵبژاردن';
$labels['all'] = 'هەمووی';
$labels['none'] = 'هیچ';
$labels['currpage'] = 'پەڕی ئێستا';
$labels['list'] = 'لیست';
$labels['fromto'] = 'لە/بۆ';
$labels['attachment'] = 'هاوپێچ';
$labels['nonesort'] = 'هیچ';
$labels['sentdate'] = 'بەرواری ناردن';
$labels['arrival'] = 'بەرواری گەیشتن';
$labels['layoutlist'] = 'لیست';
$labels['empty'] = 'بەتاڵ';
$labels['unknown'] = 'نەناسراو';
$labels['unlimited'] = 'بێ سنوور';
$labels['quotatotal'] = 'سنوور';
$labels['quotaused'] = 'بەکارهاتوو';
$labels['namex'] = 'ناو';
$labels['allfolders'] = 'هەموو بوخچەکان';
$labels['send'] = 'ناردن';
$labels['responsename'] = 'ناو';
$labels['attach'] = 'هاوپێچ';
$labels['attachments'] = 'هاوپێچەکان';
$labels['upload'] = 'بارکردن';
$labels['close'] = 'داخستن';
$labels['nickname'] = 'نازناو';
$labels['jobtitle'] = 'ناونیشانی کار';
$labels['department'] = 'بەش';
$labels['gender'] = 'ڕەگەز';
$labels['phone'] = 'تەلەفۆن';
$labels['address'] = 'ناونیشان';
$labels['street'] = 'شەقام';
$labels['locality'] = 'شار';
$labels['country'] = 'وڵات';
$labels['birthday'] = 'ڕۆژی لەدایکبوون';
$labels['website'] = 'ماڵپەڕ';
$labels['notes'] = 'تێبینییەکان';
$labels['male'] = 'نێر';
$labels['female'] = 'مێ';
$labels['manager'] = 'بەڕێوەبەر';
$labels['allfields'] = 'هەموو خانەکان';
$labels['search'] = 'گەڕان';
$labels['searchresult'] = 'ئەنجامی گەڕان';
$labels['advsearch'] = 'گەڕانی پێشکەوتوو';
$labels['advanced'] = 'پێشکەوتوو';
$labels['typehome'] = 'ماڵ';
$labels['typework'] = 'کار';
$labels['typemobile'] = 'مۆبایل';
$labels['typemain'] = 'سەرەکی';
$labels['delete'] = 'سڕینەوە';
$labels['about'] = 'دەربارە';
$labels['folders'] = 'بوخچەکان';
$labels['create'] = 'دروستکردن';
$labels['license'] = 'مۆڵەت';
