<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Comhroinnt';
$labels['myrights'] = 'Cearta rochtana';
$labels['username'] = 'An tÚsáideoir:';
$labels['advanced'] = 'Mód le hardroghanna';
$labels['add'] = 'Cuir leis';
$labels['newuser'] = 'Cuir iontráil leis';
$labels['editperms'] = 'Cuir na ceadanna in eagar';
$labels['actions'] = 'Gníomhartha maidir le cearta rochtana...';
$labels['anyone'] = 'Gach duine';
$labels['anonymous'] = 'Aíonna (gan ainm)';
$labels['identifier'] = 'Aitheantóir';
$labels['acll'] = 'Cuardaigh';
$labels['aclr'] = 'Léigh teachtaireachtaí';
$labels['acls'] = 'Coinnigh an staid Feicthe';
$labels['aclw'] = 'Scríobh bratacha';
$labels['acli'] = 'Ionsáigh (macasamhlaigh isteach ann)';
$labels['aclp'] = 'Foilsigh';
$labels['aclc'] = 'Cruthaigh fófhillteáin';
$labels['aclk'] = 'Cruthaigh fofhillteáin';
$labels['acld'] = 'Scrios teachtaireachtaí';
$labels['aclt'] = 'Scrios teachtaireachtaí';
$labels['acle'] = 'Scrios';
$labels['aclx'] = 'Scrios an fillteán';
$labels['acla'] = 'Riar';
$labels['acln'] = 'Cuir nótaí le teachtaireachtaí';
$labels['aclfull'] = 'Smacht iomlán';
$labels['aclother'] = 'Eile';
$labels['aclread'] = 'Léite';
$labels['aclwrite'] = ' Cum';
$labels['acldelete'] = 'Scrios';
$labels['shortacll'] = 'Féach';
$labels['shortaclr'] = 'Léite';
$labels['shortacls'] = 'Coinnigh';
$labels['shortaclw'] = 'Cum';
$labels['shortacli'] = 'Ionsáigh';
$labels['shortaclp'] = 'Foilsigh';
$labels['shortaclc'] = 'Cruthaigh';
$labels['shortaclk'] = 'Cruthaigh';
$labels['shortacld'] = 'Scrios';
$labels['shortaclt'] = 'Scrios';
$labels['shortacle'] = 'Bain den liosta';
$labels['shortaclx'] = 'Scrios an fillteán';
$labels['shortacla'] = 'Riaraigh';
$labels['shortacln'] = 'Cuir nóta leis';
$labels['shortaclother'] = 'Eile';
$labels['shortaclread'] = 'Léite';
$labels['shortaclwrite'] = 'Scríobh';
$labels['shortacldelete'] = 'Scrios';
$labels['longacll'] = 'Tá an fillteán infheicthe ar liostaí agus is féidir sintiúis leis a ghlacadh';
$labels['longaclr'] = 'Is féidir an fillteán a oscailt chun é a léam';
$labels['longacls'] = 'Is féidir bratach Teachtaireachtaí Feicthe a athrú';
$labels['longaclw'] = 'Is féidir bratacha agus treoirfhocail na dteachtaireachtaí a athrú, cé is moite de Feicthe agus Scriosta';
$labels['longacli'] = 'Is féidir teachtaireachtaí a scríobh nó a mhacasamhlú chuig an bhfillteán';
$labels['longaclp'] = 'Is féidir teachtaireachtaí a fhoilsiú chuig an bhfillteán seo';
$labels['longaclc'] = 'Is féidir fillteáin a chruthú (nó iad a athainmniú) go díreach faoin bhfillteán sin';
$labels['longaclk'] = 'Is féidir fillteáin a chruthú (nó iad a athainmniú) go díreach faoin bhfillteán sin';
$labels['longacld'] = 'Is féidir bratach Scrios Teachétaireachtaí a athrú';
$labels['longaclt'] = 'Is féidir bratach Scrios Teachétaireachtaí a athrú';
$labels['longacle'] = 'Is féidir teachtaireachtaí a bhaint de';
$labels['longaclx'] = 'Is féidir an fillteán seo a scriosadh nó é athainmniú';
$labels['longacla'] = 'Is féidir cearta rochtana an fhillteáin a athrú';
$labels['longacln'] = 'Is féidir meiteashonraí comhroinnte na dteachtaireachtaí (nótaí mínithe) a athrú';
$labels['longaclfull'] = 'Smacht iomlán lena n-áirítear riar an fhillteáin';
$labels['longaclread'] = 'Is féidir an fillteán a oscailt chun é a léamh';
$labels['longaclwrite'] = 'Is féidir teachtaireachtaí a rianú, a scríobh nó a mhacasamhlú chuig an bhfillteán';
$labels['longacldelete'] = 'Is féidir teachtaireachtaí a scriosadh';
$labels['longaclother'] = 'Cearta rochtana eile';
$labels['ariasummaryacltable'] = 'Liosta de na cearta rochtana';
$labels['arialabelaclactions'] = 'Sonraigh na gníomhartha';
$labels['arialabelaclform'] = 'Cearta rochtana ó';
$messages['deleting'] = 'Ag scriosadh cearta rochtana...';
$messages['saving'] = 'Ag taisceadh cearta rochtana...';
$messages['updatesuccess'] = 'Athraíodh go rathúil na cearta rochtana';
$messages['deletesuccess'] = 'Scriosadh go rathúil na cearta rochtana';
$messages['createsuccess'] = 'Cuireadh na cearta rochtana go rathúil leis';
$messages['updateerror'] = 'Ní féidir na cearta rochtana a nuashonrú';
$messages['deleteerror'] = 'Ní féidir na cearta rochtana a scriosadh';
$messages['createerror'] = 'Ní féidir cearta rochtana a chur leis';
$messages['deleteconfirm'] = 'An bhfuil tú cinnte gur mian leat na cearta rochtana a bhaint den úsáideoir(í) roghnaithe?';
$messages['norights'] = 'Níor sonraíodh aon chearta!';
$messages['nouser'] = 'Níor sonraíodh aon ainm úsáideora!';
