#messagemenu li a.filterlink {
  background-image: url(images/filter.png);
  background-position: 7px 1px;
}

#sievefilterform {
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  background-color: #F2F2F2;
  border: 1px solid #999999;
  padding: 0;
  margin: 5px;
}

#sievefilterform iframe {
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  width: 100%;
  min-height: 100%; /* Chrome 14 bug */
  background-color: #F2F2F2;
  border: 0;
  padding: 0;
  margin: 0;
}

#sievefilterform ul {
  list-style: none;
  padding: 0;
  margin: 0;
  margin-top: 5px;
}

#sievefilterform fieldset {
  margin: 5px;
}

#sievefilterform ul li {
  margin-bottom: 5px;
  white-space: nowrap;
}

#sievefilterform ul li input {
  margin-right: 5px;
}

#sievefilterform label {
  font-weight: bold;
}

#managesieve-tip {
  z-index: 100000;
}

span.sieve.error {
  color: red;
}
