body
{
  height: 100%;
}

html>body*#messagelist[id$="messagelist"]:not([class="none"]) { width: 99.8%; }
html>body*#messagelist[id$="messagelist"]:not([class="none"]) tr td.flag,
html>body*#messagelist[id$="messagelist"]:not([class="none"]) tr td.icon { width: 20px; }
html>body*input[type$="file"]:not([class="none"]) { background-color: transparent; border: 0; }

div.message-part pre,
div.message-htmlpart pre,
div.message-part div.pre
{
  word-wrap: break-word;
}

#messagelist thead tr td,
#messagelist tbody tr td
{
  height: 18px;
}
