<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Zdieľanie';
$labels['myrights'] = 'Prístupové oprávnenia';
$labels['username'] = 'Používateľ:';
$labels['advanced'] = 'Režim pre pokročilých';
$labels['add'] = 'Pridať';
$labels['newuser'] = 'Pridať záznam';
$labels['editperms'] = 'Upraviť oprávnenia';
$labels['actions'] = 'Prístupové práva pre akcie...';
$labels['anyone'] = 'Všetci užívatelia (ktokoľvek)';
$labels['anonymous'] = 'Hostia (anonymní)';
$labels['identifier'] = 'Identifikátor';
$labels['acll'] = 'Vyhľadať';
$labels['aclr'] = 'Čítať správy';
$labels['acls'] = 'Ponechať ako prečítané';
$labels['aclw'] = 'Príznaky pre zápis';
$labels['acli'] = 'Vložiť (Skopírovať do)';
$labels['aclp'] = 'Odoslať na';
$labels['aclc'] = 'Vytvoriť podpriečinky';
$labels['aclk'] = 'Vytvoriť podpriečinky';
$labels['acld'] = 'Vymazať správy';
$labels['aclt'] = 'Vymazať správy';
$labels['acle'] = 'Vyčistiť';
$labels['aclx'] = 'Vymazať priečinok';
$labels['acla'] = 'Spravovať';
$labels['acln'] = 'Označiť správy poznámkou';
$labels['aclfull'] = 'Úplný prístup';
$labels['aclother'] = 'Iné';
$labels['aclread'] = 'Čítanie';
$labels['aclwrite'] = 'Zápis';
$labels['acldelete'] = 'Odstránenie';
$labels['shortacll'] = 'Vyhľadať';
$labels['shortaclr'] = 'Čítanie';
$labels['shortacls'] = 'Ponechať';
$labels['shortaclw'] = 'Zápis';
$labels['shortacli'] = 'Vložiť';
$labels['shortaclp'] = 'Odoslať na';
$labels['shortaclc'] = 'Vytvoriť';
$labels['shortaclk'] = 'Vytvoriť';
$labels['shortacld'] = 'Vymazať';
$labels['shortaclt'] = 'Vymazať';
$labels['shortacle'] = 'Vyčistiť';
$labels['shortaclx'] = 'Vymazať priečinok';
$labels['shortacla'] = 'Spravovať';
$labels['shortacln'] = 'Označiť poznámkou';
$labels['shortaclother'] = 'Iné';
$labels['shortaclread'] = 'Čítanie';
$labels['shortaclwrite'] = 'Zápis';
$labels['shortacldelete'] = 'Odstránenie';
$labels['longacll'] = 'Priečinok je v zoznamoch viditeľný a dá sa k nemu prihlásiť';
$labels['longaclr'] = 'Prečinok je možné otvoriť na čítanie';
$labels['longacls'] = 'Príznak "Prečítané" je možné zmeniť';
$labels['longaclw'] = 'Príznaky správ a kľúčové slová je možné zmeniť, okrem "Prečítané" a "Vymazané"';
$labels['longacli'] = 'Do tohto priečinka je možné zapisovať alebo kopírovať správy';
$labels['longaclp'] = 'Do tohto priečinka je možné publikovať správy';
$labels['longaclc'] = 'Priečinky je možné vytvárať (alebo premenovávať) priamo v tomto priečinku';
$labels['longaclk'] = 'Priečinky je možné vytvárať (alebo premenovávať) priamo v tomto priečinku';
$labels['longacld'] = 'Príznak správ "Vymazané" je možné zmeniť';
$labels['longaclt'] = 'Príznak správ "Vymazané" je možné zmeniť';
$labels['longacle'] = 'Správy je možné vyčistiť';
$labels['longaclx'] = 'Priečinok je možné vymazať alebo premenovať';
$labels['longacla'] = 'Prístupové oprávnenia k tomuto priečinku je možné zmeniť';
$labels['longacln'] = 'Meta-dáta (poznámky) zdieľané medzi správami, je možné zmeniť';
$labels['longaclfull'] = 'Úplný prístup, vrátane správy priečinka';
$labels['longaclread'] = 'Prečinok je možné otvoriť na čítanie';
$labels['longaclwrite'] = 'Správy je možné označiť, zapísať alebo skopírovať do prečinka';
$labels['longacldelete'] = 'Správy je možné vymazať';
$labels['longaclother'] = 'Iné prístupové oprávnenia';
$labels['ariasummaryacltable'] = 'Zoznam prístupových oprávnení';
$labels['arialabelaclactions'] = 'Zoznam akcií';
$labels['arialabelaclform'] = 'Formulár pre prístupové oprávnenia';
$messages['deleting'] = 'Odstraňovanie prístupových oprávnení...';
$messages['saving'] = 'Ukladanie prístupových oprávnení...';
$messages['updatesuccess'] = 'Prístupové oprávnenia boli úspešne zmenené';
$messages['deletesuccess'] = 'Prístupové oprávnenia boli úspešne vymazané';
$messages['createsuccess'] = 'Prístupové oprávnenia boli úspešne pridané';
$messages['updateerror'] = 'Nemožno aktualizovať prístupové oprávnenia';
$messages['deleteerror'] = 'Prístupové oprávnenia sa nepodarilo vymazať';
$messages['createerror'] = 'Prístupové oprávnenia sa nepodarilo pridať';
$messages['deleteconfirm'] = 'Naozaj chcete odstrániť prístupové oprávnenia vybraného používateľa?';
$messages['norights'] = 'Neboli určené žiadne oprávnenia!';
$messages['nouser'] = 'Nebolo určené žiadne meno používateľa!';
