<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Dobrodošli v $product';
$labels['username'] = 'Uporabniško ime';
$labels['password'] = 'Geslo';
$labels['server'] = 'Strežnik';
$labels['login'] = 'Prijava';
$labels['menu'] = 'Meni';
$labels['logout'] = 'Odjava';
$labels['mail'] = 'E-Pošta';
$labels['settings'] = 'Osebne nastavitve';
$labels['addressbook'] = 'Stiki';
$labels['inbox'] = 'Prejeto';
$labels['drafts'] = 'Osnutki';
$labels['sent'] = 'Poslano';
$labels['trash'] = 'Smeti';
$labels['junk'] = 'Neželena sporočila';
$labels['show_real_foldernames'] = 'Prikaži prava imena za posebne mape';
$labels['subject'] = 'Zadeva';
$labels['from'] = 'Od';
$labels['sender'] = 'Pošiljatelj';
$labels['to'] = 'Za';
$labels['cc'] = 'Kp';
$labels['bcc'] = 'Skp';
$labels['replyto'] = 'Odgovor na';
$labels['followupto'] = 'Odgovor na';
$labels['date'] = 'Datum';
$labels['size'] = 'Velikost';
$labels['priority'] = 'Prioriteta';
$labels['organization'] = 'Organizacija';
$labels['readstatus'] = 'Status';
$labels['listoptions'] = 'Možnosti prikaza...';
$labels['listoptionstitle'] = 'Prikaži možnosti';
$labels['mailboxlist'] = 'Mape';
$labels['messagesfromto'] = 'Sporočila $from do $to od $count';
$labels['threadsfromto'] = 'Nit $from do $to od $count';
$labels['messagenrof'] = 'Sporočilo $nr od $count';
$labels['fromtoshort'] = '$from – $to od $count';
$labels['copy'] = 'Kopiraj';
$labels['move'] = 'Premakni';
$labels['moveto'] = 'Premakni v...';
$labels['copyto'] = 'Kopiraj v...';
$labels['download'] = 'Prenesi';
$labels['open'] = 'Odpri';
$labels['showattachment'] = 'Prikaži';
$labels['showanyway'] = 'Prikaži';
$labels['filename'] = 'Ime datoteke';
$labels['filesize'] = 'Velikost datoteke';
$labels['addtoaddressbook'] = 'Dodaj med stike';
$labels['sun'] = 'ned';
$labels['mon'] = 'pon';
$labels['tue'] = 'tor';
$labels['wed'] = 'sre';
$labels['thu'] = 'čet';
$labels['fri'] = 'pet';
$labels['sat'] = 'sob';
$labels['sunday'] = 'nedelja';
$labels['monday'] = 'ponedeljek';
$labels['tuesday'] = 'torek';
$labels['wednesday'] = 'sreda';
$labels['thursday'] = 'četrtek';
$labels['friday'] = 'petek';
$labels['saturday'] = 'sobota';
$labels['jan'] = 'jan';
$labels['feb'] = 'feb';
$labels['mar'] = 'mar';
$labels['apr'] = 'apr';
$labels['may'] = 'maj';
$labels['jun'] = 'jun';
$labels['jul'] = 'jul';
$labels['aug'] = 'avg';
$labels['sep'] = 'sep';
$labels['oct'] = 'okt';
$labels['nov'] = 'nov';
$labels['dec'] = 'dec';
$labels['longjan'] = 'januar';
$labels['longfeb'] = 'februar';
$labels['longmar'] = 'marec';
$labels['longapr'] = 'april';
$labels['longmay'] = 'maj';
$labels['longjun'] = 'junij';
$labels['longjul'] = 'julij';
$labels['longaug'] = 'avgust';
$labels['longsep'] = 'september';
$labels['longoct'] = 'oktober';
$labels['longnov'] = 'november';
$labels['longdec'] = 'december';
$labels['today'] = 'Danes';
$labels['refresh'] = 'Osveži';
$labels['checkmail'] = 'Poglej za nova sporočila';
$labels['compose'] = 'Sestavi sporočilo';
$labels['writenewmessage'] = 'Novo sporočilo';
$labels['reply'] = 'Odgovori';
$labels['replytomessage'] = 'Odgovori';
$labels['replytoallmessage'] = 'Odgovori listi ali vsem prejemnikom';
$labels['replyall'] = 'Odgovori vsem';
$labels['replylist'] = 'Odgovori listi';
$labels['forward'] = 'Posreduj';
$labels['forwardinline'] = 'Posreduj kot besedilo';
$labels['forwardattachment'] = 'Posreduj kot priponko';
$labels['forwardmessage'] = 'Posreduj';
$labels['bouncemsg'] = 'Preusmeri (prepošlji)';
$labels['bounce'] = 'Preusmeri';
$labels['deletemessage'] = 'Izbriši';
$labels['movemessagetotrash'] = 'Premakni v smeti';
$labels['printmessage'] = 'Natisni';
$labels['previousmessage'] = 'Prikaži prejšnje sporočilo';
$labels['firstmessage'] = 'Prikaži prvo sporočilo';
$labels['nextmessage'] = 'Prikaži naslednje sporočilo';
$labels['lastmessage'] = 'Prikaži zadnje sporočilo';
$labels['backtolist'] = 'Nazaj na seznam sporočil';
$labels['viewsource'] = 'Prikaži izvorno kodo';
$labels['mark'] = 'Označi';
$labels['markmessages'] = 'Označi sporočilo';
$labels['markread'] = 'Kot prebrano';
$labels['markunread'] = 'Kot neprebrano';
$labels['markflagged'] = 'Kot označeno';
$labels['markunflagged'] = 'Kot neoznačeno';
$labels['moreactions'] = 'Več možnosti...';
$labels['markallread'] = 'Označi vse kot prebrano';
$labels['folders-cur'] = 'Samo označeno mapo';
$labels['folders-sub'] = 'Označeno mapo in njene podmape';
$labels['folders-all'] = 'Vse mape';
$labels['more'] = 'Več';
$labels['back'] = 'Nazaj';
$labels['options'] = 'Možnosti';
$labels['composeoptions'] = 'Možnosti sestavljanja sporočil';
$labels['optionsandattachments'] = 'Možnosti in priponke';
$labels['actions'] = 'Možnosti';
$labels['first'] = 'Prvo';
$labels['last'] = 'Zadnje';
$labels['previous'] = 'Prejšnje';
$labels['next'] = 'Naslednje';
$labels['select'] = 'Izberi';
$labels['selection'] = 'Izbor';
$labels['all'] = 'Vse';
$labels['none'] = 'Brez';
$labels['currpage'] = 'Trenutna stran';
$labels['isread'] = 'Prebrano';
$labels['unread'] = 'Neprebrano';
$labels['flagged'] = 'Označeno';
$labels['unflagged'] = 'Ni označeno';
$labels['unanswered'] = 'Neoznačeno';
$labels['withattachment'] = 'S priponko';
$labels['deleted'] = 'Izbrisano';
$labels['undeleted'] = 'Ni izbrisano';
$labels['replied'] = 'Odgovorjeno';
$labels['forwarded'] = 'Posredovano';
$labels['invert'] = 'Zamenjaj';
$labels['filter'] = 'Prikaži';
$labels['list'] = 'Seznam';
$labels['threads'] = 'Niti';
$labels['expand-all'] = 'Razširi vse';
$labels['expand-unread'] = 'Razširi neprebrano';
$labels['collapse-all'] = 'Zloži vse';
$labels['threaded'] = 'Nitno';
$labels['showunread'] = 'Pokaži neprebrana sporočila';
$labels['autoexpand_threads'] = 'Razširi niti';
$labels['do_expand'] = 'vse niti';
$labels['expand_only_unread'] = 'samo niti z neprebranimi sporočili';
$labels['fromto'] = 'Od/Za';
$labels['flag'] = 'Oznaka';
$labels['attachment'] = 'Priponka';
$labels['nonesort'] = 'Brez';
$labels['sentdate'] = 'Datum pošiljanja';
$labels['arrival'] = 'Datum prejema';
$labels['asc'] = 'naraščajoče';
$labels['desc'] = 'padajoče';
$labels['listcolumns'] = 'Seznam stolpcev';
$labels['listsorting'] = 'Urejanje stolpcev';
$labels['listorder'] = 'Vrstni red';
$labels['listmode'] = 'Način prikaza seznama';
$labels['lmode'] = 'Način prikaza seznama';
$labels['layout'] = 'Postavitev';
$labels['layoutwidescreen'] = 'Širok zaslon';
$labels['layoutdesktop'] = 'Namizje';
$labels['layoutlist'] = 'Seznam';
$labels['layoutwidescreendesc'] = 'Širok zaslon (pogled v 3 stolpcih)';
$labels['layoutdesktopdesc'] = 'Namizje (širok seznam in spodaj predogled sporočila)';
$labels['layoutlistdesc'] = 'Seznam sporočil (brez predogleda)';
$labels['folderactions'] = 'Upravljanje map...';
$labels['compact'] = 'Stisni';
$labels['empty'] = 'Izprazni';
$labels['importmessages'] = 'Uvozi sporočila';
$labels['mailimportdesc'] = 'Naložite lahko sporočila v formatu <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> ali <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>.';
$labels['mailimportzip'] = 'Več dokumentov lahko skrčite v arhiv zip.';
$labels['quota'] = 'Poraba prostora';
$labels['unknown'] = 'neznana';
$labels['unlimited'] = 'neomejena';
$labels['quotatype'] = 'Tip kvote';
$labels['quotatotal'] = 'Omejitev';
$labels['quotaused'] = 'Porabljeno';
$labels['quotastorage'] = 'Prostor na disku';
$labels['quotamessage'] = 'Število sporočil';
$labels['shortheaderdate'] = 'Dne $date';
$labels['shortheaderto'] = 'Za $to dne $date';
$labels['shortheaderfrom'] = 'Od $from dne $date';
$labels['quicksearch'] = 'Hitri iskalnik';
$labels['searchplaceholder'] = 'Iskanje...';
$labels['resetsearch'] = 'Prekliči iskanje';
$labels['searchmod'] = 'Spremembe iskanja';
$labels['msgtext'] = 'Celotno sporočilo';
$labels['body'] = 'Vsebina sporočila';
$labels['type'] = 'Tip';
$labels['namex'] = 'Ime';
$labels['searchscope'] = 'Obseg';
$labels['currentfolder'] = 'Trenutna mapa';
$labels['subfolders'] = 'To in podmape';
$labels['allfolders'] = 'Vse mape';
$labels['searchinterval-1W'] = 'starejše od enega tedna';
$labels['searchinterval-1M'] = 'starejše od enega meseca';
$labels['searchinterval-1Y'] = 'starejše od enega leta';
$labels['searchinterval1W'] = 'novejše od enega tedna';
$labels['searchinterval1M'] = 'novejše od enega meseca';
$labels['searchinterval1Y'] = 'novejše od enega leta';
$labels['openinextwin'] = 'Odpri v novem oknu';
$labels['emlsave'] = 'Prenos datoteke (.eml)';
$labels['changeformattext'] = 'Prikaži kot golo besedilo';
$labels['changeformathtml'] = 'Prikaži v formatu HTML';
$labels['editasnew'] = 'Uredi kot novo';
$labels['send'] = 'Pošlji';
$labels['sendmessage'] = 'Pošlji sporočilo';
$labels['savemessage'] = 'Shrani kot osnutek';
$labels['addattachment'] = 'Pripni datoteko';
$labels['charset'] = 'Nabor znakov';
$labels['editortype'] = 'Vrsta urejevalnika';
$labels['returnreceipt'] = 'Potrdilo prejemnika';
$labels['dsn'] = 'Status dostave sporočila';
$labels['mailreplyintro'] = '$date, je $sender napisal';
$labels['originalmessage'] = 'Izvorno sporočilo';
$labels['selectimage'] = 'Izberi sliko';
$labels['addimage'] = 'Dodaj sliko';
$labels['selectmedia'] = 'Izberi film';
$labels['addmedia'] = 'Dodaj film';
$labels['encrypt'] = 'Šifriraj';
$labels['encryptmessage'] = 'Šifriraj sporočilo';
$labels['encryptmessagemailvelope'] = 'Šifriraj sporočilo z Mailvelope';
$labels['importpubkeys'] = 'Uvozi javne ključe';
$labels['encryptedsendialog'] = 'Pošilji šifrirano sporočilo';
$labels['encryptandsign'] = 'Šifriraj in podpiši';
$labels['keyid'] = 'ID ključa';
$labels['keylength'] = 'Bitov';
$labels['keyexpired'] = 'Pretečen';
$labels['keyrevoked'] = 'Preklican';
$labels['bccinstead'] = 'Uporabi Skp';
$labels['addheader'] = 'Dodaj prejemnika (glava sporočila)';
$labels['insert'] = 'Vstavi';
$labels['insertcontact'] = 'Vstavi stik(e)';
$labels['recipient'] = 'Prejemnik';
$labels['recipientedit'] = 'Uredi prejemnika';
$labels['editidents'] = 'Uredi identitete';
$labels['spellcheck'] = 'Črkovanje';
$labels['checkspelling'] = 'Preglej pravopis';
$labels['resumeediting'] = 'Nadaljuj z urejanjem';
$labels['revertto'] = 'Razveljavi';
$labels['restore'] = 'Obnovi';
$labels['restoremessage'] = 'Obnovi sporočilo';
$labels['ignore'] = 'Prezri';
$labels['responses'] = 'Odgovori';
$labels['insertresponse'] = 'Vnesi odgovor';
$labels['manageresponses'] = 'Uredi odgovore';
$labels['newresponse'] = 'Ustvari nov odgovor';
$labels['addresponse'] = 'Dodaj odgovor';
$labels['editresponse'] = 'Uredi odgovor';
$labels['editresponses'] = 'Uredi odgovore';
$labels['responsename'] = 'Ime';
$labels['responsetext'] = 'Tekst za odgovor';
$labels['attach'] = 'Pripni';
$labels['attachments'] = 'Priponke';
$labels['upload'] = 'Naloži';
$labels['uploadprogress'] = '$percent ($current od $total)';
$labels['close'] = 'Zapri';
$labels['messageoptions'] = 'Možnosti';
$labels['togglecomposeoptions'] = 'Preklopi med možnostmi sestavljanja';
$labels['attachmentrename'] = 'Preimenuj priponko';
$labels['low'] = 'Nizka';
$labels['lowest'] = 'Najnižja';
$labels['normal'] = 'Običajna';
$labels['high'] = 'Visoka';
$labels['highest'] = 'Najvišja';
$labels['nosubject'] = '(brez naslova)';
$labels['showimages'] = 'Prikaži slike';
$labels['allow'] = 'Dovoli';
$labels['alwaysshow'] = 'Vedno prikaži slike od $sender';
$labels['alwaysallow'] = 'Vedno dovoli pošiljatelju $sender';
$labels['isdraft'] = 'To je osnutek sporočila.';
$labels['andnmore'] = '$nr več...';
$labels['details'] = 'Podrobnosti';
$labels['headers'] = 'Glave sporočil';
$labels['allheaders'] = 'Vse glave...';
$labels['togglemoreheaders'] = 'Prikaži več glav sporočila';
$labels['togglefullheaders'] = 'Preklopi na neobdelan zapis glave sporočila';
$labels['htmltoggle'] = 'Obogateno besedilo (HTML)';
$labels['plaintoggle'] = 'Samo besedilo';
$labels['savesentmessagein'] = 'Shrani poslana sporočila v';
$labels['dontsave'] = 'Ne shrani';
$labels['maxuploadsize'] = 'Največja dovoljena velikost datoteke je $size';
$labels['addcc'] = 'Dodaj Kp';
$labels['addbcc'] = 'Dodaj Skp';
$labels['addreplyto'] = 'Dodaj naslov za odgovor';
$labels['addfollowupto'] = 'Dodaj naslov za odgovor';
$labels['mdnrequest'] = 'Pošiljatelj tega sporočila je zaprosil za potrdilo o branju. Želite o tem obvestiti pošiljatelja?';
$labels['receiptread'] = 'Potrdilo o branju';
$labels['yourmessage'] = 'To je potrdilo o branju.';
$labels['receiptnote'] = 'Pozor: to je samo potrdilo, da je bilo vaše sporočilo prikazano na prejemnikovem računalniku. To še ne pomeni, da je prejemnik prebral ali razumel vsebino vašega sporočila.';
$labels['zoomin'] = 'Povečaj';
$labels['zoomout'] = 'Pomanjšaj';
$labels['rotate'] = 'Zasukaj';
$labels['increaseimage'] = 'Povečaj velikost slike';
$labels['decreaseimage'] = 'Zmanjšaj velikost slike';
$labels['rotateimage'] = 'Zasukaj sliko';
$labels['showtools'] = 'Prikaži orodja za urejanje slik';
$labels['hidetools'] = 'Skrij orodja za urejanje slik';
$labels['name'] = 'Ime za prikaz';
$labels['firstname'] = 'Ime';
$labels['surname'] = 'Priimek';
$labels['middlename'] = 'Drugo ime';
$labels['nameprefix'] = 'Predpona';
$labels['namesuffix'] = 'Pripona';
$labels['nickname'] = 'Vzdevek';
$labels['jobtitle'] = 'Naziv';
$labels['department'] = 'Oddelek';
$labels['gender'] = 'Spol';
$labels['maidenname'] = 'Dekliški priimek';
$labels['email'] = 'E-Pošta';
$labels['phone'] = 'Telefon';
$labels['address'] = 'Naslov';
$labels['street'] = 'Ulica';
$labels['locality'] = 'Mesto';
$labels['zipcode'] = 'Poštna številka';
$labels['region'] = 'Regija';
$labels['country'] = 'Država';
$labels['birthday'] = 'Rojstni dan';
$labels['anniversary'] = 'Rojstni dan';
$labels['website'] = 'Spletna stran';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Opombe';
$labels['male'] = 'moški';
$labels['female'] = 'ženska';
$labels['manager'] = 'Vodja';
$labels['assistant'] = 'Pomoč';
$labels['spouse'] = 'Zakonec';
$labels['allfields'] = 'Vsa polja';
$labels['search'] = 'Iskanje';
$labels['searchresult'] = 'Rezultat iskanja';
$labels['advsearch'] = 'Napredno iskanje';
$labels['advanced'] = 'Napredno';
$labels['other'] = 'Ostalo';
$labels['printcontact'] = 'Natisni stik';
$labels['qrcode'] = 'QR-koda';
$labels['typehome'] = 'Doma';
$labels['typework'] = 'Služba';
$labels['typeother'] = 'Ostalo';
$labels['typemobile'] = 'Mobilni telefon';
$labels['typemain'] = 'Osnovno';
$labels['typehomefax'] = 'Domači fax';
$labels['typeworkfax'] = 'Službeni fax';
$labels['typecar'] = 'Avto';
$labels['typepager'] = 'Pozivnik';
$labels['typevideo'] = 'Video';
$labels['typeassistant'] = 'Pomoč';
$labels['typehomepage'] = 'Domača stran';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Dodaj polje...';
$labels['addcontact'] = 'Dodaj stik';
$labels['editcontact'] = 'Uredi vizitko';
$labels['contacts'] = 'Stiki';
$labels['contactproperties'] = 'Lastnosti stika';
$labels['contactnameandorg'] = 'Ime in Organizacija';
$labels['personalinfo'] = 'Osebni podatki';
$labels['personal'] = 'Osebno';
$labels['contactphoto'] = 'Kontaktna slika';
$labels['edit'] = 'Uredi';
$labels['cancel'] = 'Prekliči';
$labels['save'] = 'Shrani';
$labels['delete'] = 'Izbriši';
$labels['discard'] = 'Zavrzi';
$labels['continue'] = 'Nadaljuj';
$labels['ok'] = 'V redu';
$labels['rename'] = 'Preimenuj';
$labels['addphoto'] = 'Dodaj';
$labels['replacephoto'] = 'Zamenjaj';
$labels['uploadphoto'] = 'Naloži sliko';
$labels['choosefile'] = 'Izberi dokument...';
$labels['choosefiles'] = 'Izberi dokumente..';
$labels['browse'] = 'Prebrskaj';
$labels['newcontact'] = 'Ustvari nov stik';
$labels['deletecontact'] = 'Izbriši izbrane vizitke';
$labels['composeto'] = 'Sestavi sporočilo za';
$labels['contactsfromto'] = 'Vizitke $from od $to do $count';
$labels['print'] = 'Natisni';
$labels['export'] = 'Izvozi';
$labels['exportall'] = 'Izvozi vse';
$labels['exportsel'] = 'Izvozi označeno';
$labels['exportvcards'] = 'Izvozi stike v formatu vCard';
$labels['newgroup'] = 'Ustvari novo skupino';
$labels['addgroup'] = 'Dodaj skupino';
$labels['grouprename'] = 'Preimenuj skupino';
$labels['groupdelete'] = 'Izbriši skupino';
$labels['groupassign'] = 'Dodeli skupini';
$labels['groupremove'] = 'Odstrani iz skupine';
$labels['groupremoveselected'] = 'Odstrani izbrane stike iz skupine';
$labels['uponelevel'] = 'Nivo višje';
$labels['previouspage'] = 'Prejšnja stran';
$labels['firstpage'] = 'Prva stran';
$labels['nextpage'] = 'Naslednja stran';
$labels['lastpage'] = 'Zadnja stran';
$labels['group'] = 'Skupina';
$labels['groups'] = 'Skupine';
$labels['listgroup'] = 'Izpiši seznam članov skupine';
$labels['personaladrbook'] = 'Stiki';
$labels['searchsave'] = 'Shrani iskanje';
$labels['searchdelete'] = 'Izbriši iskanje';
$labels['import'] = 'Uvozi';
$labels['importcontacts'] = 'Uvozi stike';
$labels['importfromfile'] = 'Uvozi iz dokumenta';
$labels['importtarget'] = 'Dodaj stike v';
$labels['importreplace'] = 'Zamenjaj celoten imenik';
$labels['importgroups'] = 'Vnesi skupinske zadolžitve';
$labels['importgroupsall'] = 'Vse (ustvari skupine, če je potrebno)';
$labels['importgroupsexisting'] = 'Samo za obstoječe skupine';
$labels['importdesc'] = 'Stike lahko naložite iz obstoječega imenika. <br/>Trenutno je podprt uvoz stikov v zapisu <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> ali v CSV (z vejico ločene vrednosti) zapisu. ';
$labels['done'] = 'Dokončano';
$labels['settingsfor'] = 'Nastavitve za';
$labels['about'] = 'Vizitka';
$labels['preferences'] = 'Nastavitve';
$labels['userpreferences'] = 'Uporabniške nastavitve';
$labels['editpreferences'] = 'Uredi uporabniške nastavitve';
$labels['identities'] = 'Identitete';
$labels['manageidentities'] = 'Upravljaj identitete';
$labels['newidentity'] = 'Ustvari novo identiteto';
$labels['addidentity'] = 'Dodaj identiteto';
$labels['editidentity'] = 'Uredi identiteto';
$labels['identityencryption'] = 'Šifriranje';
$labels['preferhtml'] = 'Prednostno HTML';
$labels['defaultcharset'] = 'Privzeto kodiranje znakov';
$labels['htmlmessage'] = 'HTML sporočilo';
$labels['messagepart'] = 'Del';
$labels['digitalsig'] = 'Digitalni podpis';
$labels['dateformat'] = 'Prikaz datuma';
$labels['timeformat'] = 'Prikaz časa';
$labels['prettydate'] = 'Bolj čitljivi datumi';
$labels['setdefault'] = 'Nastavi privzeto';
$labels['autodetect'] = 'Samodejno';
$labels['language'] = 'Jezik';
$labels['timezone'] = 'Časovni pas';
$labels['pagesize'] = 'Vrstic na stran';
$labels['signature'] = 'Podpis';
$labels['dstactive'] = 'Samodejna nastavitev zimskega/letnega časa';
$labels['showinextwin'] = 'Odpri v novem oknu';
$labels['composeextwin'] = 'Sestavi sporočilo v novem oknu';
$labels['htmleditor'] = 'Sestavi sporočila z obogatenim besedilom';
$labels['htmlonreply'] = 'le pri odgovoru na sporočila z obogatenim besedilom';
$labels['htmlonreplyandforward'] = 'le pri posredovanju ali odgovoru na sporočila z obogatenim besedilom';
$labels['htmlsignature'] = 'Podpis z obogatenim besedilom';
$labels['showemail'] = 'Prikaži e-naslove poleg imen';
$labels['previewpane'] = 'Prikaži predogled';
$labels['skin'] = 'Tema uporabniškega vmesnika';
$labels['logoutclear'] = 'Izprazni mapo Smeti ob odjavi';
$labels['logoutcompact'] = 'Stisni sporočila v mapi Inbox ob odjavi';
$labels['uisettings'] = 'Uporabniški vmesnik';
$labels['serversettings'] = 'Nastavitve strežnika';
$labels['mailboxview'] = 'Pogled poštnega predala';
$labels['mdnrequests'] = 'Obvestila pošiljatelja';
$labels['askuser'] = 'vprašaj uporabnika';
$labels['autosend'] = 'pošlji povratnico samodejno';
$labels['autosendknown'] = 'samodejno pošlji povratnico samo mojim stikom';
$labels['autosendknownignore'] = 'pošlji potrdilo le mojim stikom';
$labels['ignorerequest'] = 'prezri zahtevo';
$labels['readwhendeleted'] = 'Označi izbrisano sporočilo kot prebrano';
$labels['flagfordeletion'] = 'Ne izbriši sporočila, le označi kot izbrisano';
$labels['skipdeleted'] = 'Ne prikaži izbrisanih sporočil';
$labels['deletealways'] = 'Če premikanje sporočil v Smeti spodleti, naj bodo izbrisana.';
$labels['deletejunk'] = 'Neposredno izbriši sporočila v mapi Nezaželena sporočila';
$labels['showremoteimages'] = 'Prikaži slike iz oddaljenih strežnikov';
$labels['allowremoteresources'] = 'Dovoli zunanje vire (slike, stile)';
$labels['fromknownsenders'] = 'od znanih pošiljateljev';
$labels['always'] = 'vedno';
$labels['alwaysbutplain'] = 'vedno, razen ko odgovarjam v golem besedilu';
$labels['showinlineimages'] = 'Prikaži priponke na dnu sporočila';
$labels['autosavedraft'] = 'Samodejno shrani osnutke';
$labels['everynminutes'] = '$n minut';
$labels['refreshinterval'] = 'Osveži (preglej nova sporočila)';
$labels['never'] = 'nikoli';
$labels['immediately'] = 'takoj';
$labels['messagesdisplaying'] = 'Prikazovanje sporočil';
$labels['messagescomposition'] = 'Sestavljanje sporočil';
$labels['mimeparamfolding'] = 'Imena priponk';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (ostali)';
$labels['force7bit'] = 'Uporabi MIME kodiranje za 8-bitne znake';
$labels['savelocalstorage'] = "Shrani v lokalni pomnilnik brskalnika (začasno)";
$labels['advancedoptions'] = 'Dodatne možnosti';
$labels['toggleadvancedoptions'] = 'Preklopi napredne nastavitve';
$labels['focusonnewmessage'] = 'Usmeri okno brskalnika na novo sporočilo';
$labels['checkallfolders'] = 'Preglej nova sporočila za vse mape';
$labels['displaynext'] = 'Po brisanju/premikanju prikaži naslednji element seznama';
$labels['defaultfont'] = 'Privzeta pisava HTML sporočil';
$labels['mainoptions'] = 'Osnovne nastavitve';
$labels['browseroptions'] = 'Možnosti brskalnika';
$labels['section'] = 'Nastavitve';
$labels['maintenance'] = 'Vzdrževanje';
$labels['newmessage'] = 'Novo sporočilo';
$labels['signatureoptions'] = 'Nastavitve podpisa';
$labels['whenreplying'] = 'Pri odgovoru';
$labels['replyempty'] = 'ne navajaj izvornega sporočila v odgovoru';
$labels['replytopposting'] = 'začni z novim sporočilom nad izvornim sporočilom';
$labels['replytoppostingnoindent'] = 'začni z novim sporočilom nad izvornim sporočilom (brez zamika)';
$labels['replybottomposting'] = 'začni z novim sporočilom pod izvornim sporočilom';
$labels['replyremovesignature'] = 'Pri odgovoru na sporočilo odstrani izvorni podpis iz sporočila';
$labels['autoaddsignature'] = 'Samodejno dodaj podpis';
$labels['newmessageonly'] = 'samo novim sporočilom';
$labels['replyandforwardonly'] = 'samo k odgovorom in posredovanim sporočilom';
$labels['insertsignature'] = 'Vstavi podpis';
$labels['sigbelow'] = 'Prikaži podpis pod citirano sporočilo';
$labels['sigseparator'] = 'V podpisu uporabi standardni razmejevalnik';
$labels['automarkread'] = 'Označi sporočila kot prebrana';
$labels['afternseconds'] = 'po $n sekundah';
$labels['reqmdn'] = 'Vedno zahtevaj povratnico';
$labels['reqdsn'] = 'Vedno zahtevaj obvestilo o statusu dostave';
$labels['replysamefolder'] = 'Shrani odgovore na sporočilo v mapo izvornega sporočila';
$labels['defaultabook'] = 'Privzeti stiki';
$labels['autocompletesingle'] = 'Preskoči nadomestni e-naslov pri samodejnem dokončanju';
$labels['listnamedisplay'] = 'Prikaži seznam stikov kot';
$labels['spellcheckbeforesend'] = 'Preveri črkovanje pred pošiljanjem sporočila';
$labels['spellcheckoptions'] = 'Možnosti črkovanja';
$labels['spellcheckignoresyms'] = 'Ne upoštevaj besed, ki vsebujejo simbole';
$labels['spellcheckignorenums'] = 'Ne upoštevaj besed, ki vsebujejo številke';
$labels['spellcheckignorecaps'] = 'Ne upoštevaj besed, ki vsebujejo samo velike črke';
$labels['addtodict'] = 'Dodaj v slovar';
$labels['mailtoprotohandler'] = 'Določi stran kot privzeti poštni odjemalec.';
$labels['standardwindows'] = 'Prikaži pojavna okna kot običajna';
$labels['forwardmode'] = 'Posredovanje sporočil';
$labels['inline'] = 'medvrstično';
$labels['asattachment'] = 'Kot priponka';
$labels['replyallmode'] = 'Privzete možnosti gumba [Odgovori vsem]';
$labels['replyalldefault'] = 'odgovori vsem';
$labels['replyalllist'] = 'odgovori na dopisni seznam (če ta obstaja)';
$labels['folder'] = 'Mapa';
$labels['folders'] = 'Mape';
$labels['foldername'] = 'Ime mape';
$labels['subscribed'] = 'Vpisan';
$labels['messagecount'] = 'Sporočila';
$labels['create'] = 'Ustvari';
$labels['createfolder'] = 'Ustvari novo mapo';
$labels['managefolders'] = 'Uredi mape';
$labels['specialfolders'] = 'Posebne mape';
$labels['properties'] = 'Lastnosti';
$labels['folderproperties'] = 'Lastnosti mape';
$labels['parentfolder'] = 'Glavna mapa';
$labels['location'] = 'Lokacija';
$labels['info'] = 'Podatki';
$labels['getfoldersize'] = 'Klikni za prikaz velikosti mape';
$labels['changesubscription'] = 'Klikni za spremembo prijave mape';
$labels['foldertype'] = 'Tip mape';
$labels['personalfolder'] = 'Zasebna mapa';
$labels['otherfolder'] = 'Mapa drugega uporabnika';
$labels['sharedfolder'] = 'Javna mapa';
$labels['findfolders'] = 'Najdi mape';
$labels['findcontacts'] = 'Poišči stik';
$labels['findmail'] = 'Poišči sporočilo';
$labels['namespace.personal'] = 'Osebno';
$labels['namespace.other'] = 'Drugi uporabniki';
$labels['namespace.shared'] = 'V skupni rabi';
$labels['dualuselabel'] = 'Vsebuje lahko samo';
$labels['dualusemail'] = 'sporočila';
$labels['dualusefolder'] = 'mape';
$labels['generate'] = 'Generiraj';
$labels['encryptioncreatekey'] = 'Ustvari nov par ključev';
$labels['openmailvelopesettings'] = 'Odpri nastavitve za Mailvelope';
$labels['encryptionprivkeysinmailvelope'] = 'V Mailvelope imate shranjenih $nr zasebnih ključev';
$labels['encryptionnoprivkeysinmailvelope'] = 'Ta identiteta pošiljatelja v Mailvelope še nima shranjenega zasebnega ključa GPG. Želite ključ ustvariti in s tem omogočiti pošiljanje šifriranih sporočil?';
$labels['encryption'] = 'Šifriranje';
$labels['sortby'] = 'Uredi po';
$labels['sortasc'] = 'Uredi naraščajoče';
$labels['sortdesc'] = 'Uredi padajoče';
$labels['undo'] = 'Prekliči';
$labels['installedplugins'] = 'Nameščeni vtičniki';
$labels['plugin'] = 'Vtičnik';
$labels['version'] = 'Različica';
$labels['source'] = 'Vir';
$labels['license'] = 'Licenca';
$labels['support'] = 'Podpora';
$labels['savedsearches'] = 'Shranjena iskanja';
$labels['dateformatY'] = 'LLLL';
$labels['dateformaty'] = 'LL';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Angleško';
$labels['westerneuropean'] = 'Zahodnoevropsko';
$labels['easterneuropean'] = 'Vzhodnoevropsko';
$labels['southeasterneuropean'] = 'JV Evropsko';
$labels['baltic'] = 'Baltsko';
$labels['cyrillic'] = 'Cirilica';
$labels['arabic'] = 'Arabsko';
$labels['greek'] = 'Grško';
$labels['hebrew'] = 'Hebrejsko';
$labels['turkish'] = 'Turško';
$labels['nordic'] = 'Nordijsko';
$labels['thai'] = 'Tajsko';
$labels['celtic'] = 'Keltsko';
$labels['vietnamese'] = 'Vietnamsko';
$labels['japanese'] = 'Japonsko';
$labels['korean'] = 'Korejsko';
$labels['chinese'] = 'Kitajsko';
$labels['arialabeltopnav'] = 'Upravljanje oken';
$labels['arialabeltasknav'] = 'Opravila programa';
$labels['arialabeltoolbar'] = 'Opravilna vrstica programa';
$labels['arialabelactivetask'] = 'Aktivna opravila';
$labels['arialabelmessagessearchfilter'] = 'Filter seznama sporočil';
$labels['arialabelmailsearchform'] = 'Iskalnik sporočil';
$labels['arialabelcontactsearchform'] = 'Iskalnik stikov';
$labels['arialabelmailquicksearchbox'] = 'Vnos iskanja sporočil';
$labels['arialabelquicksearchbox'] = 'Vnos iskanja';
$labels['arialabelfoldersearchfilter'] = 'Filter seznama map';
$labels['arialabelfoldersearchform'] = 'Iskalnik map';
$labels['arialabelfolderlist'] = 'Izbor map sporočil';
$labels['arialabelmessagelist'] = 'Seznam sporočil';
$labels['arialabelmailpreviewframe'] = 'Predogled sporočila';
$labels['arialabelmailboxmenu'] = 'Meni operacij mape';
$labels['arialabellistselectmenu'] = 'Prikaži meni za izbiro';
$labels['arialabelthreadselectmenu'] = 'Meni za izpis niti';
$labels['arialabelmessagelistoptions'] = 'Možnosti prikaza in razvrščanja sporočil';
$labels['arialabelmailimportdialog'] = 'Dialog za uvoz sporočil';
$labels['arialabelmessagenav'] = 'Krmarjenje po sporočilu';
$labels['arialabelmessagebody'] = 'Vsebina sporočila';
$labels['arialabelmessageactions'] = 'Operacije za sporočila';
$labels['arialabelcontactquicksearch'] = 'Iskalnik stikov';
$labels['arialabelcontactsearchbox'] = 'Vnesi stik za iskanje';
$labels['arialabelmessageheaders'] = 'Glave sporočil';
$labels['arialabelforwardingoptions'] = 'Možnosti posredovanja';
$labels['arialabelreplyalloptions'] = 'Možnost Odgovori vsem';
$labels['arialabelmoremessageactions'] = 'Več opravil za sporočila';
$labels['arialabelmorecontactactions'] = 'Več možnosti za stike';
$labels['arialabelmarkmessagesas'] = 'Označi izbrana sporočila kot ...';
$labels['arialabelcomposeoptions'] = 'Možnosti sestavljanja sporočil';
$labels['arialabelresponsesmenu'] = 'Meni v naprej pripravljenih odgovorov';
$labels['arialabelattachmentuploadform'] = 'Priponka naložena iz';
$labels['arialabelattachmentmenu'] = 'Možnosti za priponke';
$labels['arialabelmailtomenu'] = 'Možnosti za elektronske naslove';
$labels['arialabelattachmentpreview'] = 'Predogled priponke';
$labels['ariasummarycomposecontacts'] = 'Seznam stikov in skupin za izbor prejemnikov';
$labels['arialabelcontactexportoptions'] = 'Možnosti izvoza stika';
$labels['arialabelabookgroupoptions'] = 'Možnosti imenika';
$labels['arialabelpreferencesform'] = 'Nastavitve';
$labels['arialabelidentityeditfrom'] = 'Urejanje identitete';
$labels['arialabelresponseeditfrom'] = 'Urejanje odgovora';
$labels['arialabelsearchterms'] = 'Iskalni pogoji';
$labels['arialabeldropactionmenu'] = 'Meni operacij povleci in spusti';
$labels['arialabelheadersmenu'] = 'Meni za dodajanje naslovnika (glava sporočila)';
$labels['arialabelimagetools'] = 'Orodja za slike';
$labels['helplistnavigation'] = 'Izpiši možnosti krmarjenja s tipkovnico';
$labels['helplistkeyboardnavigation'] = "Puščica gor/dol: Premakni fokus/izbor vrstice
Presledek: Izberi označeno vrstico.
Shift + gor/dol: Izberi dodatne vrstice zgoraj/spodaj
Ctrl + presledek: Dodaj označeno vrstico v izbor/odstrani iz izbora";
$labels['helplistkeyboardnavmessages'] = "Puščice desno/levo: razširi/skrči nit sporočil (samo v nitnem načinu)
Enter: Odpri izbrano sporočilo
Delete: Premakni izbrana sporočila v Smeti.";
$labels['helplistkeyboardnavcontacts'] = "Odpri izbran stik.";
