<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Ein Fehler ist aufgetreten!';
$messages['loginfailed']  = 'Die Anmeldung ist fehlgeschlagen.';
$messages['cookiesdisabled'] = 'Ihr Browser akzeptiert keine Cookies.';
$messages['sessionerror'] = 'Ihre Sitzung ist ungültig oder abgelaufen.';
$messages['cookiesmismatch'] = 'Cookiefehler erkannt. Bitte die Browser Cookies löschen.';
$messages['storageerror'] = 'Verbindung zum Speicherserver fehlgeschlagen.';
$messages['servererror'] = 'Serverfehler!';
$messages['servererrormsg'] = 'Serverfehler: $msg';
$messages['accountlocked'] = 'Zu viele fehlgeschlagene Anmeldeversuche. Versuchen Sie es später noch einmal.';
$messages['connerror'] = 'Verbindungsfehler (Fehler beim Erreichen des Servers)!';
$messages['dberror'] = 'Datenbankfehler!';
$messages['windowopenerror'] = 'Das Popup-Fenster wurde blockiert!';
$messages['requesttimedout'] = 'Zeitüberschreitung der Anforderung';
$messages['errorreadonly'] = 'Die Aktion kann nicht ausgeführt werden. Der Ordner ist schreibgeschützt.';
$messages['errornoperm'] = 'Die Aktion kann nicht ausgeführt werden. Zugriff verweigert.';
$messages['erroroverquota'] = 'Die Aktion kann nicht ausgeführt werden. Nicht genug freier Speicherplatz.';
$messages['erroroverquotadelete'] = 'Nicht genug freier Speicherplatz. Verwenden sie SHIFT+ENTF um Nachrichten zu löschen.';
$messages['invalidrequest'] = 'Ungültige Anfrage! Es wurden keine Daten gespeichert.';
$messages['invalidhost'] = 'Ungültiger Servername.';
$messages['nomessagesfound'] = 'Keine Nachrichten in diesem Postfach.';
$messages['loggedout'] = 'Sie haben Ihre Sitzung erfolgreich beendet. Auf Wiedersehen!';
$messages['mailboxempty'] = 'Postfach ist leer';
$messages['nomessages'] = 'Keine Nachrichten';
$messages['refreshing'] = 'Aktualisierung läuft …';
$messages['loading'] = 'Wird geladen …';
$messages['uploading'] = 'Datei wird hochgeladen …';
$messages['attaching'] = 'Datei wird angehängt …';
$messages['uploadingmany'] = 'Dateien werden hochgeladen …';
$messages['loadingdata'] = 'Daten werden geladen …';
$messages['checkingmail'] = 'Auf neue Nachrichten wird geprüft …';
$messages['sendingmessage'] = 'Nachricht wird gesendet …';
$messages['messagesent'] = 'Nachricht erfolgreich gesendet.';
$messages['savingmessage'] = 'Nachricht wird gespeichert …';
$messages['messagesaved'] = 'Nachricht als Entwurf gespeichert.';
$messages['successfullysaved'] = 'Erfolgreich gespeichert.';
$messages['savingresponse'] = 'Antwortvorlage wird gespeichert …';
$messages['deleteresponseconfirm'] = 'Möchten Sie diese Vorlage wirklich löschen?';
$messages['nocontactselected'] = 'Sie haben noch keinen Kontakt ausgewählt.';
$messages['addedsuccessfully'] = 'Kontakt zum Adressbuch hinzugefügt.';
$messages['contactexists'] = 'Es existiert bereits ein Kontakt mit dieser E-Mail-Adresse.';
$messages['contactnameexists'] = 'Ein Kontakt mit dem gleichen Namen existiert bereits.';
$messages['blockedimages'] = 'Um Ihre Privatsphäre zu schützen, wurden externe Bilder blockiert.';
$messages['blockedresources'] = 'Um Ihre Privatsphäre zu schützen, wurden externe Ressourcen blockiert.';
$messages['encryptedmessage'] = 'Dies ist eine verschlüsselte Nachricht und kann leider nicht angezeigt werden.';
$messages['externalmessagedecryption'] = 'Dies ist eine verschlüsselte Nachricht und kann mit Ihrer Browser-Erweiterung entschlüsselt werden.';
$messages['nopubkeyfor'] = 'Kein gültiger öffentlicher Schlüssel für $email gefunden';
$messages['nopubkeyforsender'] = 'Kein gültiger öffentlicher Schlüssel für Ihre Absenderidentität gefunden. Möchten Sie die Nachricht nur für die Empfänger verschlüsseln?';
$messages['encryptnoattachments'] = 'Bereits hochgeladene Anhänge können nicht verschlüsselt werden. Bitte fügen Sie sie erneut im Verschlüsselungseditor hinzu.';
$messages['searchpubkeyservers'] = 'Möchten Sie öffentliche Schlüsselserver nach den fehlenden Schlüsseln durchsuchen?';
$messages['encryptpubkeysfound'] = 'Die folgenden öffentlichen Schlüssel wurden gefunden:';
$messages['keyservererror'] = 'Fehler beim Holen des Schlüssels vom Schlüsselserver.';
$messages['keyimportsuccess'] = 'Öffentlicher Schlüssel $key erfolgreich in Ihren Schlüsselbund importiert.';
$messages['nocontactsfound'] = 'Keine Kontakte gefunden.';
$messages['contactnotfound'] = 'Der angeforderte Kontakt wurde nicht gefunden.';
$messages['contactsearchonly'] = 'Du musst das Suchformular nutzen, um die Kontakte vom ausgewählten Adressbuch zu sehen.';
$messages['sendingfailed'] = 'Versenden der Nachricht fehlgeschlagen.';
$messages['senttooquickly'] = 'Bitte warten Sie $sec Sekunde(n) vor dem Senden dieser Nachricht.';
$messages['errorsavingsent'] = 'Ein Fehler ist beim Speichern der gesendeten Nachricht aufgetreten.';
$messages['errorsaving'] = 'Beim Speichern ist ein Fehler aufgetreten.';
$messages['errormoving'] = 'Nachricht(en) konnte(n) nicht verschoben werden.';
$messages['errorcopying'] = 'Nachticht(en) konnte(n) nicht kopiert werden.';
$messages['errordeleting'] = 'Nachricht(en) konnte(n) nicht gelöscht werden.';
$messages['errormarking'] = 'Nachricht(en) konnte(n) nicht markiert werden.';
$messages['alerttitle'] = 'Achtung';
$messages['confirmationtitle'] = 'Sind Sie sich sicher...';
$messages['deletecontactconfirm']  = 'Wollen Sie die ausgewählten Kontakte wirklich löschen?';
$messages['deletegroupconfirm']  = 'Wollen Sie die gewählte Gruppe wirklich löschen?';
$messages['deletemessagesconfirm'] = 'Wollen Sie die ausgewählten Nachrichten wirklich löschen?';
$messages['deletefolderconfirm']  = 'Wollen Sie diesen Ordner wirklich löschen?';
$messages['movefolderconfirm']  = 'Wollen Sie diesen Ordner wirklich verschieben?';
$messages['purgefolderconfirm']  = 'Wollen Sie diesen Ordner wirklich leeren?';
$messages['contactdeleting'] = 'Kontakt(e) werden gelöscht …';
$messages['groupdeleting'] = 'Gruppe wird gelöscht …';
$messages['folderdeleting'] = 'Ordner wird gelöscht …';
$messages['foldermoving'] = 'Ordner wird verschoben …';
$messages['foldersubscribing'] = 'Ordner wird abonniert …';
$messages['folderunsubscribing'] = 'Ordner wird abbestellt …';
$messages['formincomplete'] = 'Das Formular wurde nicht vollständig ausgefüllt.';
$messages['noemailwarning'] = 'Bitte geben Sie eine gültige E-Mail-Adresse ein.';
$messages['nonamewarning']  = 'Bitte geben Sie einen Namen ein.';
$messages['nopagesizewarning'] = 'Bitte geben Sie die Einträge pro Seite an.';
$messages['nosenderwarning'] = 'Bitte geben Sie die E-Mail-Adresse des Senders an.';
$messages['recipientsadded'] = 'Empfänger erfolgreich hinzugefügt.';
$messages['norecipientwarning'] = 'Bitte geben Sie mindestens einen Empfänger an.';
$messages['disclosedrecipwarning'] = 'Alle Empfänger sehen die E-Mail Adressen der anderen Empfänger. Um deren Privatsphäre zu schützen, können Sie das BCC-Feld verwenden.';
$messages['disclosedreciptitle'] = 'Zu viele öffentliche Empfänger';
$messages['nosubjectwarning']  = 'Die Betreffzeile ist leer. Möchten Sie jetzt einen Betreff eingeben?';
$messages['nosubjecttitle']  = 'Kein Betreff';
$messages['nobodywarning'] = 'Diese Nachricht ohne Inhalt senden?';
$messages['notsentwarning'] = 'Die Nachricht wurde nicht gesendet und hat nicht gespeicherte Änderungen. Möchten Sie Ihre Änderungen verwerfen?';
$messages['restoresavedcomposedata'] = 'Es wurde ein nicht versandter Entwurf einer Nachricht gefunden.\n\nBetreff: $subject\nGespeichert am: $date\n\nMöchten Sie diese Nachricht wiederherstellen?';
$messages['nosearchname'] = 'Bitte geben Sie einen Namen oder eine E-Mail-Adresse ein.';
$messages['notuploadedwarning'] = 'Es wurden noch nicht alle Dateien hochgeladen. Bitte warten oder Hochladen abbrechen.';
$messages['searchsuccessful'] = '$nr Nachrichten gefunden.';
$messages['contactsearchsuccessful'] = '$nr Kontakte gefunden.';
$messages['searchnomatch'] = 'Die Suche lieferte keine Treffer.';
$messages['searching'] = 'Suche läuft …';
$messages['checking'] = 'Überprüfung läuft …';
$messages['stillsearching'] = 'Suche läuft noch …';
$messages['nospellerrors'] = 'Keine Rechtschreibfehler gefunden.';
$messages['folderdeleted'] = 'Ordner erfolgreich gelöscht.';
$messages['foldersubscribed'] = 'Der Ordner wurde erfolgreich abonniert.';
$messages['folderunsubscribed'] = 'Der Ordner wurde erfolgreich abbestellt.';
$messages['deletedsuccessfully'] = 'Erfolgreich gelöscht.';
$messages['converting'] = 'Formatierungen werden antfernt …';
$messages['messageopenerror'] = 'Die Nachricht konnte nicht vom Server geladen werden.';
$messages['filelinkerror'] = 'Anhängen der Datei ist fehlgeschlagen.';
$messages['fileuploaderror'] = 'Hochladen der Datei fehlgeschlagen.';
$messages['csvfilemismatch'] = 'Der Import von mehreren CSV-Dateien mit unterschiedlichen Feldern wird nicht unterstützt.';
$messages['filesizeerror'] = 'Die hochzuladende Datei überschreitet die Maximalgröße von $size.';
$messages['filecounterror'] = 'Sie können maximal $count Dateien mit einmal hochladen.';
$messages['msgsizeerror'] = 'Hinzufügen einer Datei fehlgeschlagen. Die maximale Größe einer Nachricht ($size) wurde überschritten.';
$messages['msgsizeerrorfwd'] = 'Maximalgröße einer Nachricht ($size) überschritten. $num Nachricht(en) wird/wurden nicht angehängt.';
$messages['copysuccess'] = 'Erfolgreich kopiert $nr Kontakte.';
$messages['movesuccess'] = 'Erfolgreich verschoben $nr Kontakte.';
$messages['copyerror'] = 'Die Kontakte konnten nicht kopiert werden.';
$messages['moveerror'] = 'Die Kontakte konnten nicht verschoben werden.';
$messages['sourceisreadonly'] = 'Das Adressverzeichnis kann nicht verändert werden.';
$messages['errorsavingcontact'] = 'Die Änderungen konnten nicht gespeichert werden.';
$messages['movingmessage'] = 'Nachrichten werden verschoben …';
$messages['copyingmessage'] = 'Nachrichten werden kopiert …';
$messages['copyingcontact'] = 'Kontakte werden kopiert …';
$messages['movingcontact'] = 'Kontakte werden verschoben …';
$messages['deletingmessage'] = 'Nachrichten werden gelöscht …';
$messages['markingmessage'] = 'Nachrichten werden markiert …';
$messages['addingmember'] = 'Kontakte werden der Gruppe hinzugefügt …';
$messages['removingmember'] = 'Kontakte werden von der Gruppe entfernt …';
$messages['receiptsent'] = 'Lesebestätigung erfolgreich gesendet.';
$messages['errorsendingreceipt'] = 'Bestätigung konnte nicht gesendet werden.';
$messages['deleteidentityconfirm'] = 'Möchten Sie wirklich diese Identität löschen?';
$messages['nodeletelastidentity'] = 'Diese Identität kann nicht gelöscht werden, da dies die letzte ist.';
$messages['forbiddencharacter'] = 'Der Ordnername enthält ein ungültiges Zeichen.';
$messages['selectimportfile'] = 'Bitte wählen Sie eine Datei zum Importieren aus.';
$messages['addresswriterror'] = 'Das gewählte Adressbuch kann nicht verändert werden.';
$messages['contactaddedtogroup'] = 'Kontakte wurden dieser Gruppe hinzugefügt.';
$messages['contactremovedfromgroup'] = 'Kontakte wurden aus dieser Gruppe entfernt.';
$messages['nogroupassignmentschanged'] = 'Es wurden keine Gruppenzuordnungen geändert.';
$messages['importwait'] = 'Daten werden importiert, bitte warten …';
$messages['importformaterror'] = 'Import fehlgeschlagen! Die hochgeladene Datei ist keine gültige Importdatei.';
$messages['importconfirm'] = '<b>Es wurden $inserted Adressen erfolgreich importiert.</b>';
$messages['importconfirmskipped'] = '<b>$skipped bestehende Einträge wurden übersprungen.</b>';
$messages['importmessagesuccess'] = 'Nachrichten $nr erfolgreich importiert';
$messages['importmessageerror'] = 'Import fehlgeschlagen! Die hochgeladene Datei ist keine gültige Importdatei.';
$messages['opnotpermitted'] = 'Operation nicht erlaubt!';
$messages['nofromaddress'] = 'Fehlende E-Mail-Adresse in ausgewählter Identität.';
$messages['editorwarning'] = 'Wenn sie den Editor wechseln, könnten Textformatierungen verloren gehen. Möchten sie fortfahren?';
$messages['httpreceivedencrypterror'] = 'Ein fataler Konfigurationsfehler ist aufgetreten. Kontaktieren Sie bitte sofort Ihren Administrator. <b>Ihre Nachricht konnte nicht versendet werden.</b>';
$messages['smtpconnerror'] = 'SMTP Fehler ($code): Die Verbindung ist fehlgeschlagen.';
$messages['smtpautherror'] = 'SMTP Fehler ($code): Die Authentisierung ist fehlgeschlagen.';
$messages['smtpfromerror'] = 'SMTP Fehler ($code): Der Absender "$from" konnte nicht gesetzt werden ($msg).';
$messages['smtptoerror'] = 'SMTP Fehler ($code): Der Empfänger "$to" konnte nicht gesetzt werden ($msg).';
$messages['smtprecipientserror'] = 'SMTP-Fehler: die Empfängerliste konnte nicht verarbeitet werden.';
$messages['smtputf8error'] = 'SMTP-Fehler: Der Server unterstützt Unicode in der E-Mail-Adresse nicht.';
$messages['smtpsizeerror'] = 'SMTP-Fehler: Nachrichtengröße übersteigt die Servergrenze ($limit)';
$messages['smtperror'] = 'SMTP Fehler: $msg';
$messages['emailformaterror'] = 'Ungültige E-Mail-Adresse: $email';
$messages['toomanyrecipients'] = 'Zuviele Empfänger. Reduzieren Sie die Anzahl Empfängeradressen auf $max.';
$messages['maxgroupmembersreached'] = 'Die Anzahl Adressen in dieser Gruppe überschreitet das Maximum von $max.';
$messages['internalerror'] = 'Ein interner Fehler ist aufgetreten. Bitte versuchen Sie es erneut.';
$messages['contactdelerror'] = 'Fehler beim Löschen.';
$messages['contactdeleted'] = 'Kontakt(e) erfolgreich gelöscht.';
$messages['contactrestoreerror'] = 'Konnte die gelöschten Kontakte nicht wiederherstellen.';
$messages['contactrestored'] = 'Kontakte erfolgreich wiederhergestellt.';
$messages['groupdeleted'] = 'Gruppe erfolgreich gelöscht.';
$messages['grouprenamed'] = 'Gruppe erfolgreich umbenannt.';
$messages['groupcreated'] = 'Gruppe erfolgreich erstellt.';
$messages['savedsearchdeleted'] = 'Suchergebnisse erfolgreich gelöscht.';
$messages['savedsearchdeleteerror'] = 'Suchergebnisse konnten nicht gelöscht werden.';
$messages['savedsearchcreated'] = 'Suchergebnisse wurden erfolgreich wiederherstellt.';
$messages['savedsearchcreateerror'] = 'Suchergebnisse konnten nicht wiederhergestellt werden.';
$messages['messagedeleted'] = 'Nachricht(en) erfolgreich gelöscht.';
$messages['messagemoved'] = 'Nachricht(en) erfolgreich verschoben.';
$messages['messagemovedtotrash'] = 'Nachricht(en) erfolgreich in Papierkorb gelegt.';
$messages['messagecopied'] = 'Nachricht(en) erfolgreich kopiert.';
$messages['messagemarked'] = 'Nachricht(en) erfolgreich markiert.';
$messages['autocompletechars'] = 'Geben Sie mind. $min Zeichen für die Auto-Vervollständigung ein.';
$messages['autocompletemore'] = 'Mehrere Treffer. Bitte geben Sie mehr Buchstaben ein.';
$messages['namecannotbeempty'] = 'Der Name darf nicht leer sein.';
$messages['nametoolong'] = 'Der Name ist zu lang.';
$messages['namedotforbidden'] = 'Ordnername darf nicht mit einem Punkt beginnen.';
$messages['folderupdated'] = 'Der Ordner wurde erfolgreich aktualisiert.';
$messages['foldercreated'] = 'Der Ordner wurde erfolgreich erstellt.';
$messages['invalidimageformat'] = 'Kein gültiges Bildformat.';
$messages['mispellingsfound'] = 'Es wurden noch Rechtschreibfehler in der Nachricht gefunden.';
$messages['parentnotwritable'] = 'Konnte den Ordner nicht erstellen/verschieben. Keine Berechtigung.';
$messages['messagetoobig'] = 'Die Nachricht ist zu gross und kann nicht verarbeitet werden.';
$messages['attachmentvalidationerror'] = 'Dieser Anhang ist verdächtig, weil sein Typ nicht mit dem in der Nachricht angegebenen Typ übereinstimmt. Wenn Sie dem Absender nicht vertrauen, sollten Sie ihn nicht im Browser öffnen, da er bösartige Inhalte enthalten kann.<br/><br/><em>Erwartet: $expected; gefunden: $detected</em>';
$messages['noscriptwarning'] = 'Warnung: Dieser Webmail-Service erfordert Javascript. Um ihn zu benutzten aktivieren Sie Javascript in ihren Browser-Einstellungen.';
$messages['messageissent'] = 'Die Nachricht wurde bereits gesendet, aber noch nicht gespeichert. Wollen Sie es jetzt speichern?';
$messages['errnotfound'] = 'Datei nicht gefunden!';
$messages['errnotfoundexplain'] = 'Die angeforderte Ressource wurde nicht gefunden!';
$messages['errfailedrequest'] = 'Anforderung fehlgeschlagen';
$messages['errauthorizationfailed'] = 'Autorisierung fehlgeschlagen';
$messages['errunauthorizedexplain'] = 'Es konnte nicht überprüft werden, ob Sie berechtigt sind, auf diesen Dienst zuzugreifen!';
$messages['errrequestcheckfailed'] = 'Anforderungsprüfung fehlgeschlagen';
$messages['errcsrfprotectionexplain'] = "Zu Ihrer Sicherheit wird der Zugriff auf diese Ressource gegen CSRF geschützt.\nWenn Sie dies sehen, haben Sie sich wahrscheinlich vor dem Verlassen der Webanwendung nicht abgemeldet.\n\nNun ist eine menschliche Interaktion erforderlich, um fortzusetzen.";
$messages['errcontactserveradmin'] = 'Bitte kontaktieren Sie Ihren Server-Administrator.';
$messages['clicktoresumesession'] = 'Klicken Sie hier, um Ihre vorherige Sitzung fortzusetzen';
$messages['errcomposesession'] = 'Verfasssitzungsfehler';
$messages['errcomposesessionexplain'] = 'Angeforderte Verfasssitzung nicht gefunden.';
$messages['clicktocompose'] = 'Klicken Sie hier, um eine neue Nachricht zu verfassen';
$messages['nosupporterror'] = 'Diese Funktion wird von Ihrem Webbrowser nicht unterstützt.';
$messages['siginserted'] = 'Signatur erfolgreich eingefügt.';
$messages['responseinserted'] = 'Antwort erfolgreich eingefügt.';
$messages['listempty'] = 'Die Liste ist leer.';
$messages['listusebutton'] = 'Um einen neuen Datensatz hinzufügen, verwenden Sie bitte die Schaltfläche \'Erstellen\'.';
$messages['keypaircreatesuccess'] = 'En neues Schlüsselpaar wurde erfolgreich für $identity erstellt.';
$messages['emptyattachment'] = 'Dieser Anhang scheint leer zu sein.<br>Bitte erkundigen Sie sich bei der Person, die diesen gesendet hat.';
$messages['oauthloginfailed'] = 'OAuth-Anmeldung fehlgeschlagen. Bitte versuchen Sie es erneut.';
