<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/timezones/
*/

$labels['tz:america'] = 'Amerika';
$labels['tz:antarctica'] = 'Antarktis';
$labels['tz:asia'] = 'Asien';
$labels['tz:asia:bangkok'] = 'Bangkok';
$labels['tz:europe'] = 'Europa';
$labels['tz:europe:athens'] = 'Athen';
$labels['tz:europe:belgrade'] = 'Belgien';
$labels['tz:europe:brussels'] = 'Bruxelles';
$labels['tz:europe:copenhagen'] = 'København';
$labels['tz:europe:lisbon'] = 'Lissabon';
$labels['tz:europe:prague'] = 'Prag';
$labels['tz:europe:rome'] = 'Rom';
