<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = '共享';
$labels['myrights'] = '存取權限';
$labels['username'] = '使用者：';
$labels['advanced'] = '進階模式';
$labels['add'] = '加入';
$labels['newuser'] = '新增項目';
$labels['editperms'] = '編輯權限';
$labels['actions'] = '權限設定...';
$labels['anyone'] = '所有使用者 (任何人)';
$labels['anonymous'] = '訪客 (匿名)';
$labels['identifier'] = '識別碼';
$labels['acll'] = '尋找';
$labels['aclr'] = '讀取郵件';
$labels['acls'] = '保持上線狀態';
$labels['aclw'] = '寫入旗標';
$labels['acli'] = '插入 (複製到這裡)';
$labels['aclp'] = '發表';
$labels['aclc'] = '建立子資料夾';
$labels['aclk'] = '建立子資料夾';
$labels['acld'] = '刪除郵件';
$labels['aclt'] = '刪除郵件';
$labels['acle'] = '刪去';
$labels['aclx'] = '刪除資料夾';
$labels['acla'] = '管理者';
$labels['acln'] = '評注郵件';
$labels['aclfull'] = '完全控制';
$labels['aclother'] = '其他';
$labels['aclread'] = '讀取';
$labels['aclwrite'] = '寫入';
$labels['acldelete'] = '刪除';
$labels['shortacll'] = '尋找';
$labels['shortaclr'] = '讀取';
$labels['shortacls'] = '保存';
$labels['shortaclw'] = '寫入';
$labels['shortacli'] = '插入';
$labels['shortaclp'] = '發表';
$labels['shortaclc'] = '建立';
$labels['shortaclk'] = '建立';
$labels['shortacld'] = '刪除';
$labels['shortaclt'] = '刪除';
$labels['shortacle'] = '刪去';
$labels['shortaclx'] = '資料夾刪除';
$labels['shortacla'] = '管理者';
$labels['shortacln'] = '評注';
$labels['shortaclother'] = '其他';
$labels['shortaclread'] = '讀取';
$labels['shortaclwrite'] = '寫入';
$labels['shortacldelete'] = '刪除';
$labels['longacll'] = '此資料夾可以觀看和訂閱';
$labels['longaclr'] = '此資料夾可以開啟並讀取';
$labels['longacls'] = '能修改郵件旗標';
$labels['longaclw'] = '郵件旗標和關鍵字可以變更，不包含已檢視和刪除的';
$labels['longacli'] = '郵件能寫入或複製到資料夾';
$labels['longaclp'] = '郵件能發表到此資料夾';
$labels['longaclc'] = '這個資料夾之下可以建子資料夾 (或重新命名）';
$labels['longaclk'] = '這個資料夾之下可以建子資料夾 (或重新命名）';
$labels['longacld'] = '能修改郵件刪除旗標';
$labels['longaclt'] = '能修改郵件刪除旗標';
$labels['longacle'] = '能刪去郵件';
$labels['longaclx'] = '資料夾能刪除或重新命名';
$labels['longacla'] = '能變更資料夾權限';
$labels['longacln'] = '郵件共享的元資料 (評注) 能更改';
$labels['longaclfull'] = '完全控制包含資料夾管理';
$labels['longaclread'] = '資料夾能開啟並讀取';
$labels['longaclwrite'] = '郵件可以標記、寫入或複製到資料夾';
$labels['longacldelete'] = '郵件能刪除';
$labels['longaclother'] = '其他權限';
$labels['ariasummaryacltable'] = '權限清單';
$labels['arialabelaclactions'] = '清單動作';
$labels['arialabelaclform'] = '權限表單';
$messages['deleting'] = '刪除權限...';
$messages['saving'] = '儲存權限...';
$messages['updatesuccess'] = '權限變更完成';
$messages['deletesuccess'] = '權限刪除完成';
$messages['createsuccess'] = '權限新增完成';
$messages['updateerror'] = '無法更新權限';
$messages['deleteerror'] = '無法刪除權限';
$messages['createerror'] = '無法新增權限';
$messages['deleteconfirm'] = '確定要刪除所選使用者的權限嗎？';
$messages['norights'] = '沒有指定任何權限';
$messages['nouser'] = '沒有指定用戶名稱';
