<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-password/
*/

$labels['changepasswd']  = 'Promjena zaporke';
$labels['curpasswd']  = 'Važeća zaporka:';
$labels['newpasswd']  = 'Nova zaporka:';
$labels['confpasswd']  = 'Potvrda nove zaporke:';
$messages['nopassword'] = 'Molimo unesite novu zaporku.';
$messages['nocurpassword'] = 'Molimo unesite trenutnu zaporku.';
$messages['passwordincorrect'] = 'Trenutna zaporka je nevažeća.';
$messages['passwordinconsistency'] = 'Zaporke su različite, pokušajte ponovo.';
$messages['crypterror'] = 'Nemoguće promijeniti zaporku. Nedostaje enkripcijska funkcija.';
$messages['connecterror'] = 'Nemoguće promijeniti zaporku. Greška prilikom spajanja.';
$messages['internalerror'] = 'Nemoguće promijeniti zaporku.';
$messages['passwordshort'] = 'Zaporka mora sadržavati barem $length znakova.';
$messages['passwordweak'] = 'Zaporka mora sadržavati barem jednu znamenku i jedan interpunkcijski znak.';
$messages['passwordtooweak'] = 'Preslaba zaporka.';
$messages['passwordnoseq'] = 'Zaporka ne smije biti niz poput 123456 ili QWERTZ';
$messages['passwordnocommon'] = 'Zaporka ne bi smjela biti uobičajena riječ ili ime.';
$messages['passwordforbidden'] = 'Zaporka sadrži nedozvoljene znakove.';
$messages['firstloginchange'] = 'Ovo je vaša prva prijava u sustav. Molimo promijenite vašu zaporku.';
$messages['disablednotice'] = 'Sustav je trenutno u fazi održavanja i promjena zaporke trenutno nije moguća. Uskoro bi sve trebalo raditi ispravno. Ispričavamo se zbog neugodnosti.';
$messages['passwinhistory'] = 'Zaporka je bila prije u uporabi.';
$messages['samepasswd'] = 'Nova zaporka mora biti drukčija od stare.';
$messages['passwdexpirewarning'] = 'Upozorenje! Vaša će zaporka uskoro isteći, promijenite je prije $expirationdatetime.';
$messages['passwdexpired'] = 'Vaša je zaporka istekla, morate je odmah promijeniti!';
