<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<roundcube:include file="/includes/links.html" />
<script type="text/javascript" src="/functions.js"></script>
</head>
<body class="iframe">

<div id="prefs-title" class="boxtitle"><roundcube:object name="sectionname" /></div>

<div id="prefs-details" class="boxcontent">
  <roundcube:object name="userprefs" form="form" />
  <div id="formfooter">
    <div class="footerleft">
      <roundcube:button command="save" type="input" class="button mainaction" label="save" />
    </div>
  </div>
</div>

</body>
</html>
