<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Çewtiyek pêk hat!';
$messages['loginfailed']  = 'Têketin têk çû';
$messages['cookiesdisabled'] = 'Geroka te destûrê nade çerezan';
$messages['sessionerror'] = 'Danişîna te çewt e an jî bi dawî bûye';
$messages['storageerror'] = 'Girêdana pêşkêşkara IMAP têk çû';
$messages['servererror'] = 'Çewtiya pêşkêş!';
$messages['servererrormsg'] = 'Çewtiya Pêşkêş: $msg';
$messages['connerror'] = 'Çewtiya Girêdanê (Negihîşte pêşkêş)!';
$messages['dberror'] = 'Çewtiya Danegehê!';
$messages['requesttimedout'] = 'Dema xwestinê hat derbaskirin';
$messages['errorreadonly'] = 'Ev kar pêk nehat. Dosya tenê tê xwendin.';
$messages['errornoperm'] = 'Ev kar pêk nehat. Destûr nehat dayîn.';
$messages['erroroverquota'] = 'Ev kara pêk nehat. Di dîskê de cihê vala nîn e.';
$messages['erroroverquotadelete'] = 'Di dîskê de cihê vala nîn e. SHIFT+DELê bi kar bîne da ku peyamekê jê bibî.';
$messages['invalidrequest'] = 'Dawxaza nederbasdar! Tu dane nehat tomarkirin.';
$messages['invalidhost'] = 'Navê pêşkêş ê nederbasdar.';
$messages['nomessagesfound'] = 'Di vê peyamdankê de tu peyam nehat dîtin';
$messages['mailboxempty'] = 'Cihê peyamên hatî vala ye';
$messages['nomessages'] = 'Peyam nîn in';
$messages['refreshing'] = 'Tê tezekirin...';
$messages['loading'] = 'Tê barkirin...';
$messages['uploading'] = 'Pel tê barkirin...';
$messages['uploadingmany'] = 'Pel tên barkirin...';
$messages['loadingdata'] = 'Dane tên barkirin...';
$messages['checkingmail'] = 'Li peyamên nû vedinihêre...';
$messages['sendingmessage'] = 'Peyamê dişîne...';
$messages['messagesent'] = 'Peyam hate şandin';
$messages['savingmessage'] = 'Peyam tê hilanîn...';
$messages['messagesaved'] = 'Peyam di Hilanînî de hat hilanîn';
$messages['successfullysaved'] = 'Hat hilanîn';
$messages['savingresponse'] = 'Bersiva nivîsê tê tomarkirin...';
$messages['deleteresponseconfirm'] = 'Tu bi rastî dixwazî vê nivîsa bersivê jê bibî?';
$messages['addedsuccessfully'] = 'Têkilî li navnîşanan hat zêdekirin';
$messages['contactnameexists'] = 'Jixwe kesekî bi heman navî heye.';
$messages['blockedimages'] = 'Ji bo ewlekariya te wêneyên cuda yên vê peyamê hatin astenkirin.';
$messages['encryptedmessage'] = 'Ev peyamenek şîfrekirî ye, bibore, nayê vekirin!';
$messages['nocontactsfound'] = 'Tu têkiliyek nehat dîtin';
$messages['contactnotfound'] = 'Têkiliya dihat xwestin nehat dîtin';
$messages['sendingfailed'] = 'Peyam nehat şandin';
$messages['senttooquickly'] = 'Ji kerema xwe, bo $ saniyek saniye(yan) bisekine beriya şandina vê peyamê.';
$messages['errorsavingsent'] = 'Dema ku peyama şandî hat tomarkirin çewtiyek pêk hat.';
$messages['errorsaving'] = 'Wextê tomarkirinê çewtiyek çêbû. ';
$messages['errormoving'] = 'Ciyê peyamê nehat guherandin';
$messages['errorcopying'] = 'Peyam(gel) nehat(in) hemankirin. ';
$messages['errordeleting'] = 'Peyam nehat jêbirin';
$messages['deletecontactconfirm']  = 'Ji dil dixwazî têkiliya/ên nîşankirî jê bibî?';
$messages['deletemessagesconfirm'] = 'Ji dil dixwazî peya/ên nîşankirî jê bibî?';
$messages['deletefolderconfirm']  = 'Ji dil dixwazî vê peldankê jê bibî?';
$messages['purgefolderconfirm']  = 'Ji dil dixwazî hemû peyamên di vê peldankê de jê bibî?';
$messages['groupdeleting'] = 'Kom tê rakirin...';
$messages['folderdeleting'] = 'Dosye tê rakirin...';
$messages['foldermoving'] = 'Dosye tê kêşandin...';
$messages['formincomplete'] = 'Form bi temamî nehat tijekirin';
$messages['noemailwarning'] = 'Tika ye, navnîşaneke rast têkevê';
$messages['nonamewarning']  = 'Tika ye, navekî têkevê';
$messages['nopagesizewarning'] = 'Tika ye, mezinahiyeke pelê têkevê';
$messages['norecipientwarning'] = 'Tika ye, herî kêm standyarekê têkevê';
$messages['nosubjectwarning']  = 'Qada "Mijar"ê vala ye. Dixwazî niha tiştekî lê binivîsî?';
$messages['nobodywarning'] = 'Peyamê bê nivîs bişeyînî?';
$messages['nosearchname'] = 'Tika ye, nav an jî navnîşaneke têkiliyê têkevê';
$messages['searchsuccessful'] = '$nr peyam hat(in) dîtin';
$messages['searchnomatch'] = 'Di lêgerînê de tu tişt nehat dîtin';
$messages['searching'] = 'Digere...';
$messages['checking'] = 'Vedinihêre...';
$messages['stillsearching'] = 'Hin lê digere...';
$messages['nospellerrors'] = 'Tu şaşiyeke rastnivîsê nehat dîtin';
$messages['folderdeleted'] = 'Peldank hat jêbirin';
$messages['deletedsuccessfully'] = 'Hat jêbirin';
$messages['converting'] = 'Formatkirin ji peyamê tê birin...';
$messages['messageopenerror'] = 'Peyam ji pêşkêşkar nehat barkirin';
$messages['fileuploaderror'] = 'Barkirina pelê têk çû';
$messages['filesizeerror'] = 'Pel pir mezin e. Herî zêde divê $size be';
$messages['sourceisreadonly'] = 'Çavkaniya vê navnîşanê tenê-xwendin e';
$messages['errorsavingcontact'] = 'Navnîşana têkiliyê nehat barkirin';
$messages['movingmessage'] = 'Ciyê peyamê tê guhertin...';
$messages['copyingmessage'] = 'Peyam(gel) tên kopîkirin... ';
$messages['deletingmessage'] = 'Peyam(gel) tê jêbirin...';
$messages['receiptsent'] = 'Rapora şandina serkeftî';
$messages['errorsendingreceipt'] = 'Rapor nehat şandin';
$messages['nodeletelastidentity'] = 'Nikarî vê nasnameyê jê bibî. Ew ya dawî ye.';
$messages['groupcreated'] = 'Kom bi serkeftin hat afirandin.';
