<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Compartiendo';
$labels['myrights'] = 'Permisos de acceso';
$labels['username'] = 'Usuario:';
$labels['advanced'] = 'Modo avanzado';
$labels['add'] = 'Agregar';
$labels['newuser'] = 'Añadir entrada';
$labels['editperms'] = 'Editar permisos';
$labels['actions'] = 'Acciones de derecho de acceso...';
$labels['anyone'] = 'Todos los usuarios (cualquiera)';
$labels['anonymous'] = 'Invitados (anónimos)';
$labels['identifier'] = 'Identificador';
$labels['acll'] = 'Búsqueda';
$labels['aclr'] = 'Leer mensajes';
$labels['acls'] = 'Mantener estado de visto';
$labels['aclw'] = 'Etiquetas de escritura';
$labels['acli'] = 'Insertar (copiar a)';
$labels['aclp'] = 'Publicar';
$labels['aclc'] = 'Crear subcarpetas';
$labels['aclk'] = 'Crear subcarpetas';
$labels['acld'] = 'Eliminar mensajes';
$labels['aclt'] = 'Eliminar mensajes';
$labels['acle'] = 'Borrar';
$labels['aclx'] = 'Eliminar carpeta';
$labels['acla'] = 'Administrar';
$labels['acln'] = 'Anotar mensajes';
$labels['aclfull'] = 'Control total';
$labels['aclother'] = 'Otro';
$labels['aclread'] = 'Leer';
$labels['aclwrite'] = 'Escribir';
$labels['acldelete'] = 'Eliminar';
$labels['shortacll'] = 'Búsqueda';
$labels['shortaclr'] = 'Leer';
$labels['shortacls'] = 'Mantener';
$labels['shortaclw'] = 'Escribir';
$labels['shortacli'] = 'Insertar';
$labels['shortaclp'] = 'Publicar';
$labels['shortaclc'] = 'Crear';
$labels['shortaclk'] = 'Crear';
$labels['shortacld'] = 'Eliminar';
$labels['shortaclt'] = 'Eliminar';
$labels['shortacle'] = 'Borrar';
$labels['shortaclx'] = 'Eliminar carpeta';
$labels['shortacla'] = 'Administrar';
$labels['shortacln'] = 'Anotar';
$labels['shortaclother'] = 'Otro';
$labels['shortaclread'] = 'Leer';
$labels['shortaclwrite'] = 'Escribir';
$labels['shortacldelete'] = 'Eliminar';
$labels['longacll'] = 'La carpeta es visible en listas y se la puede suscribir';
$labels['longaclr'] = 'La carpeta puede ser abierta para lectura';
$labels['longacls'] = 'Etiqueta de mensajes leídos puede ser cambiada';
$labels['longaclw'] = 'Las etiquetas de mensajes y palabras clave puede ser cambiada, excepto Leídos y Eliminados';
$labels['longacli'] = 'Se pueden escribir o copiar mensajes a la carpeta';
$labels['longaclp'] = 'Los mensajes pueden ser publicados en esta carpeta';
$labels['longaclc'] = 'Las carpetas pueden ser creadas (o renombradas) directamente desde esta carpeta';
$labels['longaclk'] = 'Las carpetas pueden ser creadas (o renombradas) directamente desde esta carpeta';
$labels['longacld'] = 'La etiqueta de mensajes eliminados puede ser cambiada';
$labels['longaclt'] = 'La etiqueta de mensajes eliminados puede ser cambiada';
$labels['longacle'] = 'Los mensajes pueden ser borrados';
$labels['longaclx'] = 'La carpeta puede ser eliminada o renombrada';
$labels['longacla'] = 'Los derechos de acceso de la carpeta pueden ser cambiados';
$labels['longacln'] = 'Los metadatos compartidos de los mensajes (anotaciones) puede ser cambiado';
$labels['longaclfull'] = 'Control total incluyendo administración de carpetas';
$labels['longaclread'] = 'La carpeta puede ser abierta para lectura';
$labels['longaclwrite'] = 'Los mensajes pueden ser marcados, escritos o copiados a la carpeta';
$labels['longacldelete'] = 'Los mensajes pueden ser eliminados';
$labels['longaclother'] = 'Otros derechos de acceso';
$labels['ariasummaryacltable'] = 'Lista de derechos de acceso';
$labels['arialabelaclactions'] = 'Listar acciones';
$labels['arialabelaclform'] = 'Formulario de derechos de acceso';
$messages['deleting'] = 'Derechos de acceso de eliminación...';
$messages['saving'] = 'Guardando derechos de acceso...';
$messages['updatesuccess'] = 'Se han cambiado los derechos de acceso exitosamente';
$messages['deletesuccess'] = 'Se han eliminado los derechos de acceso exitosamente';
$messages['createsuccess'] = 'Se han agregado los derechos de acceso exitosamente';
$messages['updateerror'] = 'No es posible actualizar los derechos de acceso';
$messages['deleteerror'] = 'No es posible eliminar los derechos de acceso';
$messages['createerror'] = 'No es posible agregar los derechos de acceso';
$messages['deleteconfirm'] = '¿Estás seguro de que deseas eliminar los derechos de acceso a usuario(s) seleccionado(s)?';
$messages['norights'] = '¡No se hace especificado un derecho!';
$messages['nouser'] = '¡No se ha especificado un nombre de usuario!';
