<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<roundcube:include file="/includes/links.html" />
<script type="text/javascript" src="/functions.js"></script>
</head>
<body>

<roundcube:include file="/includes/taskbar.html" />
<roundcube:include file="/includes/header.html" />
<roundcube:include file="/includes/settingstabs.html" />

<div id="mainscreen">
  <div class="box" style="height: 100%; overflow: auto">
    <div id="prefs-title" class="boxtitle"><roundcube:label name="managesieve.vacation" /></div>
    <roundcube:object name="vacationform" id="vacationform" style="margin: 10px 10px 0 10px" />
    <div id="formfooter" style="padding: 0 10px">
      <div class="footerleft">
        <roundcube:button command="plugin.managesieve-save" type="input" class="button mainaction" label="save" />
      </div>
    </div>
  </div>
</div>

<script type="text/javascript">
rcube_init_mail_ui();
</script>

</body>
</html>
