<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Vitajte v $product';
$labels['username'] = 'Meno používateľa';
$labels['password'] = 'Heslo';
$labels['server'] = 'Server';
$labels['login'] = 'Prihlásiť';
$labels['oauthlogin'] = 'Prihlásenie cez $provider';
$labels['menu'] = 'Menu';
$labels['logout'] = 'Odhlásiť';
$labels['mail'] = 'E-mail';
$labels['settings'] = 'Nastavenia';
$labels['addressbook'] = 'Adresár kontaktov';
$labels['darkmode'] = 'Tmavý režim';
$labels['lightmode'] = 'Svetlý režim';
$labels['inbox'] = 'Doručená pošta';
$labels['drafts'] = 'Koncepty';
$labels['sent'] = 'Odoslané';
$labels['trash'] = 'Kôš';
$labels['junk'] = 'Nevyžiadaná pošta';
$labels['show_real_foldernames'] = 'Pri osobitných priečinkoch zobrazovať skutočné názvy';
$labels['subject'] = 'Predmet';
$labels['from'] = 'Od';
$labels['sender'] = 'Odosielateľ';
$labels['to'] = 'Komu';
$labels['cc'] = 'Kópia';
$labels['bcc'] = 'Skrytá kópia';
$labels['replyto'] = 'Odpovedať na';
$labels['followupto'] = 'Preposlať na';
$labels['date'] = 'Dátum';
$labels['size'] = 'Veľkosť';
$labels['priority'] = 'Priorita';
$labels['organization'] = 'Organizácia';
$labels['readstatus'] = 'Prečítať stav';
$labels['listoptions'] = 'Nastavenia zoznamu...';
$labels['listoptionstitle'] = 'Nastavenia zoznamu';
$labels['mailboxlist'] = 'Priečinky';
$labels['messagesfromto'] = 'Správy: $from – $to, z $count';
$labels['threadsfromto'] = 'Konverzácie: $from – $to, z $count';
$labels['messagenrof'] = 'Správa č. $nr z $count';
$labels['fromtoshort'] = '$from – $to z $count';
$labels['copy'] = 'Kopírovať';
$labels['move'] = 'Presunúť';
$labels['moveto'] = 'Presunúť do...';
$labels['copyto'] = 'Kopírovať do...';
$labels['download'] = 'Stiahnuť';
$labels['open'] = 'Otvoriť';
$labels['showattachment'] = 'Zobraziť';
$labels['showanyway'] = 'Zobraziť aj napriek tomu';
$labels['filename'] = 'Názov súboru';
$labels['filesize'] = 'Veľkosť súboru';
$labels['addtoaddressbook'] = 'Pridať do adresára';
$labels['sun'] = 'Ne';
$labels['mon'] = 'Po';
$labels['tue'] = 'Ut';
$labels['wed'] = 'St';
$labels['thu'] = 'Št';
$labels['fri'] = 'Pi';
$labels['sat'] = 'So';
$labels['sunday'] = 'Nedeľa';
$labels['monday'] = 'Pondelok';
$labels['tuesday'] = 'Utorok';
$labels['wednesday'] = 'Streda';
$labels['thursday'] = 'Štvrtok';
$labels['friday'] = 'Piatok';
$labels['saturday'] = 'Sobota';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Feb';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Apr';
$labels['may'] = 'Máj';
$labels['jun'] = 'Jún';
$labels['jul'] = 'Júl';
$labels['aug'] = 'Aug';
$labels['sep'] = 'Sep';
$labels['oct'] = 'Okt';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Dec';
$labels['longjan'] = 'Január';
$labels['longfeb'] = 'Február';
$labels['longmar'] = 'Marec';
$labels['longapr'] = 'Apríl';
$labels['longmay'] = 'Máj';
$labels['longjun'] = 'Jún';
$labels['longjul'] = 'Júl';
$labels['longaug'] = 'August';
$labels['longsep'] = 'September';
$labels['longoct'] = 'Október';
$labels['longnov'] = 'November';
$labels['longdec'] = 'December';
$labels['today'] = 'Dnes';
$labels['refresh'] = 'Obnoviť';
$labels['checkmail'] = 'Skontrolovať nové správy';
$labels['compose'] = 'Vytvoriť správu';
$labels['writenewmessage'] = 'Vytvoriť novú správu';
$labels['reply'] = 'Odpovedať';
$labels['replytomessage'] = 'Odpovedať na správu';
$labels['replytoallmessage'] = 'Odpovedať do zoznamu alebo odosielateľovi a všetkým príjemcom';
$labels['replyall'] = 'Odpovedať všetkým';
$labels['replylist'] = 'Zoznam pre odpovedanie';
$labels['forward'] = 'Poslať ďalej';
$labels['forwardinline'] = 'Poslať ďalej v správe';
$labels['forwardattachment'] = 'Poslať ďalej ako prílohu';
$labels['forwardmessage'] = 'Poslať správu ďalej';
$labels['bouncemsg'] = 'Opätovne odoslať (odrazenie)';
$labels['bounce'] = 'Opätovne odoslať';
$labels['deletemessage'] = 'Vymazať správu';
$labels['movemessagetotrash'] = 'Presunúť správu do koša';
$labels['printmessage'] = 'Vytlačiť túto správu';
$labels['previousmessage'] = 'Zobraziť predchádzajúcu správu';
$labels['firstmessage'] = 'Zobraziť prvú správu';
$labels['nextmessage'] = 'Zobraziť ďalšiu správu';
$labels['lastmessage'] = 'Zobraziť poslednú správu';
$labels['backtolist'] = 'Naspäť na zoznam správ';
$labels['viewsource'] = 'Zobraziť zdrojový text';
$labels['mark'] = 'Označiť';
$labels['markmessages'] = 'Označiť správy';
$labels['markread'] = 'Ako prečítané';
$labels['markunread'] = 'Ako neprečítané';
$labels['markflagged'] = 'Ako označené značkou';
$labels['markunflagged'] = 'Ako neoznačené značkou';
$labels['moreactions'] = 'Viac akcií...';
$labels['markallread'] = 'Označiť všetko ako prečítané';
$labels['folders-cur'] = 'Vybraný len priečinok';
$labels['folders-sub'] = 'Vybraný priečinok a jeho podpriečinky';
$labels['folders-all'] = 'Všetky priečinky';
$labels['more'] = 'Viac';
$labels['back'] = 'Dozadu';
$labels['options'] = 'Možnosti';
$labels['composeoptions'] = 'Možnosti zostavovania';
$labels['optionsandattachments'] = 'Možnosti a prílohy';
$labels['actions'] = 'Akcie';
$labels['first'] = 'Prvá/prvý';
$labels['last'] = 'Posledná/-ý';
$labels['previous'] = 'Predchádzajúca/-i';
$labels['next'] = 'Ďalšia/-í';
$labels['select'] = 'Výber';
$labels['selection'] = 'Výber';
$labels['all'] = 'Všetko';
$labels['none'] = 'Nič';
$labels['currpage'] = 'Aktuálna stránka';
$labels['isread'] = 'Prečítané';
$labels['unread'] = 'Neprečítané';
$labels['flagged'] = 'Označené značkou';
$labels['unflagged'] = 'Neoznačené značkou';
$labels['unanswered'] = 'Bez odpovede';
$labels['withattachment'] = 'S prílohou';
$labels['deleted'] = 'Vymazané';
$labels['undeleted'] = 'Nevymazané';
$labels['replied'] = 'Odpovedané';
$labels['forwarded'] = 'Preposlané';
$labels['invert'] = 'Obrátiť';
$labels['filter'] = 'Filter';
$labels['list'] = 'Zoznam';
$labels['threads'] = 'Konverzácie';
$labels['expand-all'] = 'Rozbaliť všetko';
$labels['expand-unread'] = 'Rozbaliť neprečítané';
$labels['collapse-all'] = 'Zbaliť všetko';
$labels['threaded'] = 'Spojené do konverzácií';
$labels['showunread'] = 'Zobraziť neprečítané správy';
$labels['autoexpand_threads'] = 'Rozbaliť konverzácie';
$labels['do_expand'] = 'všetky';
$labels['expand_only_unread'] = 'len s neprečítanými správami';
$labels['fromto'] = 'Od/Komu';
$labels['flag'] = 'Značka';
$labels['attachment'] = 'Príloha';
$labels['nonesort'] = 'Žiadne';
$labels['sentdate'] = 'Dátum odoslania';
$labels['arrival'] = 'Dátum prijatia';
$labels['asc'] = 'vzostupne';
$labels['desc'] = 'zostupne';
$labels['listcolumns'] = 'Stĺpce';
$labels['listsorting'] = 'Zoraďovanie';
$labels['listorder'] = 'Systém zoraďovania';
$labels['listmode'] = 'Režim zobrazenia zoznamu';
$labels['lmode'] = 'Režim zoznamu';
$labels['layout'] = 'Rozloženie';
$labels['layoutwidescreen'] = 'Na šírku obrazovky';
$labels['layoutdesktop'] = 'Desktop';
$labels['layoutlist'] = 'Zoznam';
$labels['layoutwidescreendesc'] = 'Na šírku obrazovky (zobrazenie 3 stĺpcov)';
$labels['layoutdesktopdesc'] = 'Plocha (široký zoznam a dole náhľad na správu)';
$labels['layoutlistdesc'] = 'Zoznam (žiadny náhľad na správu)';
$labels['folderactions'] = 'Akcie pre priečinky...';
$labels['compact'] = 'Zhustiť';
$labels['empty'] = 'Vyprázdniť';
$labels['importmessages'] = 'Importovať správy';
$labels['mailimportdesc'] = 'E-mail môžete nahrať s použitím súborov vo formáte <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> alebo <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>.';
$labels['mailimportzip'] = 'Viaceré súbory je možné skomprimovať do archívov ZIP.';
$labels['quota'] = 'Úložné miesto';
$labels['unknown'] = 'neznáme';
$labels['unlimited'] = 'neobmedzené';
$labels['quotatype'] = 'Typ kvóty';
$labels['quotatotal'] = 'Limit';
$labels['quotaused'] = 'Použité';
$labels['quotastorage'] = 'Priestor na disku';
$labels['quotamessage'] = 'Počet správ';
$labels['shortheaderdate'] = 'Dňa: $date';
$labels['shortheaderto'] = 'Komu: $to dňa $date';
$labels['shortheaderfrom'] = 'Od: $from dňa $date';
$labels['quicksearch'] = 'Rýchle vyhľadávanie';
$labels['searchplaceholder'] = 'Vyhľadať...';
$labels['resetsearch'] = 'Reset vyhľadávania';
$labels['searchmod'] = 'Zmeniť kritériá vyhľadávania';
$labels['msgtext'] = 'Celá správa';
$labels['body'] = 'Telo (obsah)';
$labels['type'] = 'Typ';
$labels['namex'] = 'Meno';
$labels['searchscope'] = 'Rozsah';
$labels['currentfolder'] = 'Aktuálny priečinok';
$labels['subfolders'] = 'Tento a podpriečinky';
$labels['allfolders'] = 'Všetky priečinky';
$labels['searchinterval-1W'] = 'staršie ako týždeň';
$labels['searchinterval-1M'] = 'staršie ako mesiac';
$labels['searchinterval-1Y'] = 'staršie ako rok';
$labels['searchinterval1W'] = 'nie staršie ako týždeň';
$labels['searchinterval1M'] = 'nie staršie ako mesiac';
$labels['searchinterval1Y'] = 'nie staršie ako rok';
$labels['openinextwin'] = 'Otvoriť v novom okne';
$labels['emlsave'] = 'Stiahnuť (.eml)';
$labels['changeformattext'] = 'Zobraziť vo formáte čistého textu';
$labels['changeformathtml'] = 'Zobraziť vo formáte HTML';
$labels['editasnew'] = 'Upraviť ako novú správu';
$labels['send'] = 'Odoslať';
$labels['sendmessage'] = 'Odoslať správu';
$labels['savemessage'] = 'Uložiť správu ako koncept';
$labels['addattachment'] = 'Priložiť súbor';
$labels['charset'] = 'Znaková sada';
$labels['editortype'] = 'Typ editora';
$labels['returnreceipt'] = 'Potvrdenie o doručení';
$labels['dsn'] = 'Oznámenie o stave doručenia';
$labels['mailreplyintro'] = 'Dňa $date $sender napísal(a):';
$labels['originalmessage'] = 'Pôvodná správa';
$labels['selectimage'] = 'Vybrať obrázok';
$labels['addimage'] = 'Pridať obrázok';
$labels['selectmedia'] = 'Vybrať film';
$labels['addmedia'] = 'Pridať film';
$labels['encrypt'] = 'Zašifrovať';
$labels['encryptmessage'] = 'Zašifrovať správu';
$labels['encryptmessagemailvelope'] = 'Zašifrovať správu pomocou Mailvelope';
$labels['importpubkeys'] = 'Importovať verejné kľúče';
$labels['encryptedsendialog'] = 'Odosielanie zašifrovanej správy';
$labels['encryptandsign'] = 'Zašifrovať a podpísať';
$labels['keyid'] = 'ID kľúča';
$labels['keylength'] = 'Bity';
$labels['keyexpired'] = 'Expirované';
$labels['keyrevoked'] = 'Odvolané';
$labels['bccinstead'] = 'Použiť skrytú kópiu';
$labels['addheader'] = 'Pridať príjemcu (hlavička)';
$labels['insert'] = 'Vložiť';
$labels['insertcontact'] = 'Vložiť kontakt(y)';
$labels['recipient'] = 'Príjemca';
$labels['recipientedit'] = 'Úprava príjemcu';
$labels['editidents'] = 'Upraviť identitu odosielateľa';
$labels['spellcheck'] = 'Pravopis';
$labels['checkspelling'] = 'Skontrolovať pravopis';
$labels['resumeediting'] = 'Pokračovať v úpravách';
$labels['revertto'] = 'Vrátiť sa na';
$labels['restore'] = 'Obnoviť';
$labels['restoremessage'] = 'Obnoviť správu?';
$labels['ignore'] = 'Ignorovať';
$labels['responses'] = 'Odpovede';
$labels['insertresponse'] = 'Vložiť odpoveď';
$labels['manageresponses'] = 'Spravovať odpovede';
$labels['newresponse'] = 'Vytvoriť novú odpoveď';
$labels['addresponse'] = 'Pridať odpoveď';
$labels['editresponse'] = 'Upraviť odpoveď';
$labels['editresponses'] = 'Upraviť odpovede';
$labels['responsename'] = 'Meno';
$labels['responsetext'] = 'Text odpovede';
$labels['attach'] = 'Priložiť';
$labels['attachments'] = 'Prílohy';
$labels['upload'] = 'Nahrať';
$labels['uploadprogress'] = '$percent ($current z $total)';
$labels['close'] = 'Zatvoriť';
$labels['messageoptions'] = 'Nastavenia správy...';
$labels['togglecomposeoptions'] = 'Prepnúť možnosti kompozície';
$labels['attachmentrename'] = 'Premenovať prílohu';
$labels['low'] = 'Nízka';
$labels['lowest'] = 'Najnižšia';
$labels['normal'] = 'Normálna';
$labels['high'] = 'Vysoká';
$labels['highest'] = 'Najvyššia';
$labels['nosubject'] = '(bez predmetu)';
$labels['showimages'] = 'Zobraziť obrázky';
$labels['allow'] = 'Povoliť';
$labels['alwaysshow'] = 'Vždy zobraziť obrázky od odosielateľa $sender';
$labels['alwaysallow'] = 'Vždy povoliť od $sender';
$labels['isdraft'] = 'Toto je koncept';
$labels['andnmore'] = 'Počet ďalších: $nr...';
$labels['details'] = 'Podrobnosti';
$labels['summary'] = 'Zhrnutie';
$labels['headers'] = 'Hlavičky';
$labels['allheaders'] = 'Všetky hlavičky...';
$labels['togglemoreheaders'] = 'Zobraziť viac hlavičiek správ';
$labels['togglefullheaders'] = 'Prepnúť zobrazenie úplných hlavičiek správ';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Čistý text';
$labels['savesentmessagein'] = 'Uložiť odoslanú správu do';
$labels['dontsave'] = 'neukladať';
$labels['maxuploadsize'] = 'Maximálna povolená veľkosť súboru je $size';
$labels['addcc'] = 'Pridať kópiu';
$labels['addbcc'] = 'Pridať skrytú kopiu';
$labels['addreplyto'] = 'Pridať pole Odpovedať na';
$labels['addfollowupto'] = 'Pridať pole Preposlať na';
$labels['sendreceipt'] = 'Odoslať potvrdenie o prečítaní?';
$labels['mdnrequest'] = 'Odosielateľ tejto správy chce byť informovaný o tom, že ste túto správu čítali. Chcete mu potvrdiť prijatie správy?';
$labels['receiptread'] = 'Potvrdenie o doručení (a prečítaní) správy';
$labels['yourmessage'] = 'Toto je potvrdenie o doručení vašej správy';
$labels['receiptnote'] = 'Poznámka: Toto potvrdenie znamená len to, že správa sa zobrazila na počítači príjemcu. Nie je však zaručené, že príjemca správu čítal a porozumel jej obsahu.';
$labels['sendalwaysto'] = 'Vždy odoslať na $email';
$labels['zoomin'] = 'Priblížiť';
$labels['zoomout'] = 'Oddialiť';
$labels['rotate'] = 'Otočiť';
$labels['increaseimage'] = 'Zväčšiť veľkosť obrázka';
$labels['decreaseimage'] = 'Zmenšiť veľkosť obrázka';
$labels['rotateimage'] = 'Otočiť obrázok';
$labels['showtools'] = 'Zobraziť nástroje pre obrázok';
$labels['hidetools'] = 'Skryť nástroje pre obrázok';
$labels['name'] = 'Zobrazované meno';
$labels['firstname'] = 'Meno';
$labels['surname'] = 'Priezvisko';
$labels['middlename'] = 'Stredná časť mena';
$labels['nameprefix'] = 'Titul';
$labels['namesuffix'] = 'Dodatok za menom';
$labels['nickname'] = 'Prezývka';
$labels['jobtitle'] = 'Označenie povolania';
$labels['department'] = 'Oddelenie/firma/zastúpenie';
$labels['gender'] = 'Pohlavie';
$labels['maidenname'] = 'Rodné priezvisko';
$labels['email'] = 'E-mail';
$labels['phone'] = 'Telefón';
$labels['address'] = 'Adresa';
$labels['street'] = 'Ulica';
$labels['locality'] = 'Mesto';
$labels['zipcode'] = 'PSČ';
$labels['region'] = 'Región';
$labels['country'] = 'Krajina';
$labels['birthday'] = 'Narodeniny';
$labels['anniversary'] = 'Výročie';
$labels['website'] = 'Internetová stránka';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Poznámky';
$labels['male'] = 'muž';
$labels['female'] = 'žena';
$labels['manager'] = 'Manažér';
$labels['assistant'] = 'Asistent';
$labels['spouse'] = 'Partner/ka';
$labels['allfields'] = 'Všetky polia';
$labels['search'] = 'Hľadať';
$labels['searchresult'] = 'Výsledok vyhľadávania';
$labels['advsearch'] = 'Rozšírené vyhľadávanie';
$labels['advanced'] = 'Rozšírené';
$labels['other'] = 'Ostatné';
$labels['printcontact'] = 'Vytlačiť kontakt';
$labels['qrcode'] = 'QR kód';
$labels['typehome'] = 'Domov';
$labels['typework'] = 'Práca';
$labels['typeother'] = 'Iné';
$labels['typemobile'] = 'Mobilný telefón';
$labels['typemain'] = 'Hlavné číslo';
$labels['typehomefax'] = 'Fax - domov';
$labels['typeworkfax'] = 'Fax - práca';
$labels['typecar'] = 'Auto';
$labels['typepager'] = 'Pager';
$labels['typevideo'] = 'Video';
$labels['typeassistant'] = 'Asistent';
$labels['typehomepage'] = 'Domovská stránka';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Pridať pole...';
$labels['addcontact'] = 'Pridať kontakt';
$labels['editcontact'] = 'Upraviť kontakt';
$labels['contacts'] = 'Kontakty';
$labels['contactproperties'] = 'Vlastnosti kontaktu';
$labels['contactnameandorg'] = 'Názov a organizácia';
$labels['personalinfo'] = 'Osobné informácie';
$labels['personal'] = 'Osobné';
$labels['contactphoto'] = 'Fotografia kontaktu';
$labels['edit'] = 'Upraviť';
$labels['cancel'] = 'Zrušiť';
$labels['save'] = 'Uložiť';
$labels['delete'] = 'Vymazať';
$labels['discard'] = 'Vyhodiť';
$labels['continue'] = 'Pokračovať';
$labels['ok'] = 'OK';
$labels['rename'] = 'Premenovať';
$labels['addphoto'] = 'Pridať fotografiu';
$labels['replacephoto'] = 'Nahradiť fotografiu';
$labels['uploadphoto'] = 'Nahrať fotografiu';
$labels['choosefile'] = 'Vybrať súbor...';
$labels['choosefiles'] = 'Vybrať súbory...';
$labels['browse'] = 'Prehľadávať';
$labels['newcontact'] = 'Vytvoriť nový kontakt';
$labels['deletecontact'] = 'Vymazať vybrané kontakty';
$labels['composeto'] = 'Vytvoriť správu pre';
$labels['contactsfromto'] = 'Kontakty: $from – $to, z $count';
$labels['print'] = 'Tlač';
$labels['export'] = 'Exportovať';
$labels['exportall'] = 'Exportovať všetko';
$labels['exportsel'] = 'Exportovať vybrané';
$labels['exportvcards'] = 'Exportovať kontakty vo formáte vCard';
$labels['newgroup'] = 'Vytvoriť novú skupinu';
$labels['addgroup'] = 'Pridať skupinu';
$labels['grouprename'] = 'Premenovať skupinu';
$labels['groupdelete'] = 'Vymazať skupinu';
$labels['groupassign'] = 'Prideliť k skupine...';
$labels['groupremove'] = 'Odstrániť zo skupiny';
$labels['groupremoveselected'] = 'Odstrániť vybrané kontakty zo skupiny';
$labels['uponelevel'] = 'O jednu úroveň nahor';
$labels['previouspage'] = 'Zobraziť predchádzajúcu stranu';
$labels['firstpage'] = 'Zobraziť prvú stranu';
$labels['nextpage'] = 'Zobraziť nasledujúcu stranu';
$labels['lastpage'] = 'Zobraziť poslednú stranu';
$labels['group'] = 'Skupina';
$labels['groups'] = 'Skupiny';
$labels['listgroup'] = 'Zoznam členov skupiny';
$labels['personaladrbook'] = 'Osobné adresy';
$labels['searchsave'] = 'Uložiť výsledky vyhľadávania';
$labels['searchdelete'] = 'Vymazať výsledky vyhľadávania';
$labels['import'] = 'Import';
$labels['importcontacts'] = 'Importovať kontakty';
$labels['importfromfile'] = 'Importovať zo súboru';
$labels['importtarget'] = 'Pridať kontakty do';
$labels['importreplace'] = 'Nahradiť celý adresár kontaktov';
$labels['importgroups'] = 'Importovať priradenia do skupín';
$labels['importgroupsall'] = 'Všetky (vytvoriť skupiny ak je to potrebné)';
$labels['importgroupsexisting'] = 'Len pre existujúce skupiny';
$labels['importdesc'] = 'Môžete nahrať kontakty z existujúceho adresára. <br/>Momentálne podporujeme import adries z formátu <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> alebo CSV (údaje oddeľované čiarkou).';
$labels['importmapdesc'] = 'Skôr než budete pokračovať v importovaní údajov vo formáte CSV (údaje oddeľované čiarkou), potvrďte správnosť informácie o priradení polí.';
$labels['fieldnotmapped'] = 'Pole nie je priradené (neimportuje sa)';
$labels['skipheader'] = 'Neimportovať prvý riadok (hlavičky)';
$labels['done'] = 'Hotovo';
$labels['settingsfor'] = 'Nastavenia pre';
$labels['about'] = 'O systéme';
$labels['preferences'] = 'Nastavenia';
$labels['userpreferences'] = 'Používateľské nastavenia';
$labels['editpreferences'] = 'Upraviť používateľské nastavenia';
$labels['identities'] = 'Identity';
$labels['manageidentities'] = 'Spravovať identity';
$labels['newidentity'] = 'Vytvoriť novú identitu';
$labels['addidentity'] = 'Pridať identitu';
$labels['editidentity'] = 'Upraviť identitu';
$labels['identityencryption'] = 'Šifrovanie';
$labels['preferhtml'] = 'Zobraziť HTML';
$labels['defaultcharset'] = 'Predvolené kódovanie';
$labels['htmlmessage'] = 'HTML správa';
$labels['messagepart'] = 'Časť';
$labels['digitalsig'] = 'Digitálny podpis';
$labels['dateformat'] = 'Formát dátumu';
$labels['timeformat'] = 'Formát času';
$labels['prettydate'] = 'Krátke formáty dátumov';
$labels['setdefault'] = 'Nastaviť ako štandardné';
$labels['autodetect'] = 'Automaticky';
$labels['language'] = 'Jazyk';
$labels['timezone'] = 'Časová zóna';
$labels['pagesize'] = 'Počet záznamov na stránku';
$labels['signature'] = 'Podpis';
$labels['dstactive'] = 'Letný čas';
$labels['showinextwin'] = 'Otvoriť správu v novom okne';
$labels['composeextwin'] = 'Písať v novom okne';
$labels['htmleditor'] = 'Vytvárať HTML správy';
$labels['htmlonreply'] = 'len v odpovedi na HTML správu';
$labels['htmlonreplyandforward'] = 'pri odosielaní ďalej alebo pri odpovedi na HTML správu';
$labels['htmlsignature'] = 'HTML podpis';
$labels['showemail'] = 'Zobrazovať e-mailovú adresu so zobrazovaným menom';
$labels['previewpane'] = 'Zobraziť panel s náhľadom na správu';
$labels['skin'] = 'Vzhľad rozhrania';
$labels['logoutclear'] = 'Vyprázdniť kôš pri odhlásení';
$labels['logoutcompact'] = 'Zhustiť priečinok Doručená pošta pri odhlásení';
$labels['uisettings'] = 'Používateľské rozhranie';
$labels['serversettings'] = 'Nastavenia servera';
$labels['mailboxview'] = 'Zobrazenie schránky';
$labels['mdnrequests'] = 'Pri žiadosti o potvrdenie o doručení';
$labels['askuser'] = 'opýtať sa používateľa';
$labels['autosend'] = 'odoslať potvrdenie';
$labels['autosendknown'] = 'odoslať potvrdenie iba mojim kontaktom';
$labels['autosendknownignore'] = 'odoslať potvrdenie známym odosielateľom, inak ignorovať';
$labels['autosendtrusted'] = 'odoslať potvrdenie dôveryhodným odosielateľom, inak sa ma opýtať';
$labels['autosendtrustedignore'] = 'odoslať potvrdenie dôveryhodným odosielateľom, inak ignorovať';
$labels['ignorerequest'] = 'ignorovať požiadavku';
$labels['readwhendeleted'] = 'Označiť správu ako prečítanú pri jej vymazávaní';
$labels['flagfordeletion'] = 'Namiesto vymazania správy ju iba označiť ako vymazanú';
$labels['skipdeleted'] = 'Nezobrazovať vymazané správy';
$labels['deletealways'] = 'Vymazať správy, ak zlyhá ich presun do koša';
$labels['deletejunk'] = 'Hneď vymazávať správy v priečinku Nevyžiadaná pošta (spam)';
$labels['showremoteimages'] = 'Zobrazovať obrázky uložené mimo správy';
$labels['allowremoteresources'] = 'Povoliť vzdialené zdroje (obrázky, štýly)';
$labels['fromknownsenders'] = 'pri známych odosielateľoch';
$labels['fromtrustedsenders'] = 'od dôveryhodných odosielateľov';
$labels['frommycontacts'] = 'od mojich kontaktov';
$labels['always'] = 'vždy';
$labels['alwaysbutplain'] = 'vždy, okrem odpovedí na správy v čistom texte';
$labels['showinlineimages'] = 'Zobrazovať priložené obrázky pod správou';
$labels['autosavedraft'] = 'Automaticky uložiť koncept';
$labels['everynminutes'] = 'každých $n minút';
$labels['refreshinterval'] = 'Obnoviť (skontrolovať nové správy atď.)';
$labels['never'] = 'nikdy';
$labels['immediately'] = 'ihneď';
$labels['messagesdisplaying'] = 'Zobrazovanie správ';
$labels['messagescomposition'] = 'Vytváranie správ';
$labels['mimeparamfolding'] = 'Názvy príloh';
$labels['2231folding'] = 'Úplné RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Úplné RFC 2047 (iné)';
$labels['force7bit'] = 'Použiť kódovanie MIME pre 8-bitové znaky';
$labels['savelocalstorage'] = "Uložiť v lokálnom úložisku prehliadača (dočasne)";
$labels['advancedoptions'] = 'Rozšírené nastavenia';
$labels['toggleadvancedoptions'] = 'Prepnúť pokročilé nastavenia';
$labels['focusonnewmessage'] = 'Aktivovať okno prehliadača pri novej správe';
$labels['checkallfolders'] = 'Kontrolovať nové správy vo všetkých priečinkoch';
$labels['displaynext'] = 'Po vymazaní/presune zobraziť ďalší záznam v zozname';
$labels['defaultfont'] = 'Predvolené písmo pre HTML správu';
$labels['mainoptions'] = 'Hlavné nastavenia';
$labels['browseroptions'] = 'Nastavenia prehliadania';
$labels['section'] = 'Sekcia';
$labels['maintenance'] = 'Údržba';
$labels['newmessage'] = 'Nová správa';
$labels['signatureoptions'] = 'Nastavenia podpísania';
$labels['whenreplying'] = 'Pri odpovedi';
$labels['replyempty'] = 'necitovať pôvodnú správu';
$labels['replytopposting'] = 'začať odpoveď nad citovanou správou';
$labels['replytoppostingnoindent'] = 'začať odpoveď nad citovanou správou (bez odsadenia)';
$labels['replybottomposting'] = 'začať odpoveď pod citovanou správou';
$labels['replyremovesignature'] = 'Pri odpovedaní odstrániť zo správy pôvodný podpis';
$labels['autoaddsignature'] = 'Automaticky pridať podpis';
$labels['newmessageonly'] = 'iba k novým správam';
$labels['replyandforwardonly'] = 'iba k odpovediam a preposielaným správam';
$labels['insertsignature'] = 'Vložiť podpis';
$labels['sigbelow'] = 'Podpis umiestniť pod citovanú správu';
$labels['sigseparator'] = 'Vynútiť si štandardné oddeľovače v podpisoch';
$labels['automarkread'] = 'Označiť správy ako prečítané';
$labels['afternseconds'] = 'po $n sekundách';
$labels['reqmdn'] = 'Vždy vyžadovať potvrdenie o doručení';
$labels['reqdsn'] = 'Vždy vyžadovať oznámenie o stave doručenia';
$labels['replysamefolder'] = 'Umiestňovať odpovede do rovnakého priečinka ako pôvodnú správu';
$labels['defaultabook'] = 'Predvolený adresár kontaktov';
$labels['autocompletesingle'] = 'Vynechať alternatívne e-mailové adresy pri automatickom dopĺňaní';
$labels['listnamedisplay'] = 'Zobraziť kontakty ako';
$labels['contactformmode'] = 'Režim kontaktného formulára';
$labels['privatemode'] = 'Súkromný (doma)';
$labels['businessmode'] = 'Biznisový (práca)';
$labels['collectedaddresses'] = 'Zozbierané adresy';
$labels['collectedrecipients'] = 'Zozbieraní príjemcovia';
$labels['collectedrecipientsopt'] = 'Ukladať príjemcov odchádzajúcich e-mailov do';
$labels['collectedsendersopt'] = 'Ukladať dôveryhodných odosielateľov do';
$labels['trustedsenders'] = 'Dôveryhodní odosielatelia';
$labels['spellcheckbeforesend'] = 'Skontrolovať pravopis pred odoslaním správy';
$labels['spellcheckoptions'] = 'Nastavenia kontroly pravopisu';
$labels['spellcheckignoresyms'] = 'Ignorovať slová so symbolmi';
$labels['spellcheckignorenums'] = 'Ignorovať slová s číslami';
$labels['spellcheckignorecaps'] = 'Ignorovať slová písané iba veľkými písmenami';
$labels['addtodict'] = 'Pridať do slovníka';
$labels['mailtoprotohandler'] = 'Zaregistrovať priradenie pre odkazy typu „mailto:“';
$labels['standardwindows'] = 'S vyskakovacími oknami pracovať ako so štandardnými oknami';
$labels['forwardmode'] = 'Odosielanie správ ďalej';
$labels['inline'] = 'vo vnútri správy';
$labels['asattachment'] = 'ako príloha';
$labels['replyallmode'] = 'Predvolená akcia pre tlačidlo [Odpovedať všetkým]';
$labels['replyalldefault'] = 'odpovedať všetkým';
$labels['replyalllist'] = 'odpovedať len do mailing-listu (ak bol nájdený)';
$labels['folder'] = 'Priečinok';
$labels['folders'] = 'Priečinky';
$labels['foldername'] = 'Názov priečinka';
$labels['subscribed'] = 'Odber aktívny';
$labels['messagecount'] = 'Správy';
$labels['create'] = 'Vytvoriť';
$labels['createfolder'] = 'Vytvoriť nový priečinok';
$labels['managefolders'] = 'Spravovať priečinky';
$labels['specialfolders'] = 'Špeciálne priečinky';
$labels['properties'] = 'Vlastnosti';
$labels['folderproperties'] = 'Vlastnosti priečinka';
$labels['parentfolder'] = 'Rodičovský priečinok';
$labels['location'] = 'Umiestnenie';
$labels['info'] = 'Informácia';
$labels['getfoldersize'] = 'Na zistenie veľkosti priečinka kliknite sem';
$labels['changesubscription'] = 'Na zmenu odberu kliknite sem';
$labels['foldertype'] = 'Typ priečinka';
$labels['personalfolder'] = 'Súkromný priečinok';
$labels['otherfolder'] = 'Iné priečinky používateľa';
$labels['sharedfolder'] = 'Verejný priečinok';
$labels['findfolders'] = 'Hľadať priečinky';
$labels['findcontacts'] = 'Nájsť kontakty';
$labels['findmail'] = 'Nájsť e-mailové správy';
$labels['namespace.personal'] = 'Osobné';
$labels['namespace.other'] = 'Iní používatelia';
$labels['namespace.shared'] = 'Zdieľané';
$labels['dualuselabel'] = 'Môže obsahovať len';
$labels['dualusemail'] = 'spr.';
$labels['dualusefolder'] = 'prieč.';
$labels['generate'] = 'Vygenerovať';
$labels['encryptioncreatekey'] = 'Vytvoriť nový pár kľúčov';
$labels['openmailvelopesettings'] = 'Otvoriť nastavenia Mailvelope';
$labels['encryptionprivkeysinmailvelope'] = 'Vo vašej súprave kľúčov Mailvelope máte uložených $nr zodpovedajúcich súkromných kľúčov.';
$labels['encryptionnoprivkeysinmailvelope'] = 'Pre túto identitu odosielateľa ešte nemáte v rozšírení Mailvelope uložený žiadny súkromný kľúč PGP. Chcete nejaký vytvoriť, aby bolo možné aktivovať posielanie zašifrovaných správ?';
$labels['encryption'] = 'Šifrovanie';
$labels['mailvelopeoptions'] = 'Možnosti Mailvelope';
$labels['mailvelopemainkeyring'] = 'Použiť hlavnú kľúčenku Mailvelope';
$labels['mailvelopenotfound'] = 'Vo vašom prehliadači nie je zapnuté/nainštalovať rozšírenie Mailvelope.';
$labels['sortby'] = 'Zoradiť podľa';
$labels['sortasc'] = 'Zoradiť vzostupne';
$labels['sortdesc'] = 'Zoradiť zostupne';
$labels['undo'] = 'Späť';
$labels['installedplugins'] = 'Nainštalované prídavné moduly';
$labels['plugin'] = 'Zásuvný modul';
$labels['version'] = 'Verzia';
$labels['source'] = 'Zdrojový kód';
$labels['destination'] = 'Cieľ';
$labels['license'] = 'Licencia';
$labels['support'] = 'Podpora';
$labels['savedsearches'] = 'Uložené vyhľadávania';
$labels['dateformatY'] = 'RRRR';
$labels['dateformaty'] = 'RR';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Angličtina';
$labels['westerneuropean'] = 'Západoeurópske';
$labels['easterneuropean'] = 'Východoeurópske';
$labels['southeasterneuropean'] = 'Juho-východná Európa';
$labels['baltic'] = 'Baltština';
$labels['cyrillic'] = 'Cyrilika';
$labels['arabic'] = 'Arabsky';
$labels['greek'] = 'Grécky';
$labels['hebrew'] = 'Hebrejsky';
$labels['turkish'] = 'Turecky';
$labels['nordic'] = 'Nórsky';
$labels['thai'] = 'Thajsky';
$labels['celtic'] = 'Keltština';
$labels['vietnamese'] = 'Vietnamčina';
$labels['japanese'] = 'Japonsky';
$labels['korean'] = 'Kórejsky';
$labels['chinese'] = 'Čínsky';
$labels['arialabeltopnav'] = 'Ovládanie okna';
$labels['arialabeltasknav'] = 'Úlohy aplikácie';
$labels['arialabeltoolbar'] = 'Panel nástrojov aplikácie';
$labels['arialabellistnav'] = 'Zoznam navigovania';
$labels['arialabelactivetask'] = 'Aktívna úloha';
$labels['arialabelmessagessearchfilter'] = 'Filter zoznamu e-mailov';
$labels['arialabelmailsearchform'] = 'Formulár pre vyhľadanie e-mailu';
$labels['arialabelcontactsearchform'] = 'Formulár pre vyhľadávanie kontaktov';
$labels['arialabelmailquicksearchbox'] = 'Vstup pre vyhľadávanie e-mailu';
$labels['arialabelquicksearchbox'] = 'Vstup pre vyhľadávanie';
$labels['arialabelfoldersearchfilter'] = 'Filter pre zoznam priečinkov';
$labels['arialabelfoldersearchform'] = 'Formulár pre vyhľadávanie priečinkov';
$labels['arialabelfolderlist'] = 'Výber priečinka s e-mailovými správami';
$labels['arialabelmessagelist'] = 'Zoznam e-mailových správ';
$labels['arialabelmailpreviewframe'] = 'Náhľad správy';
$labels['arialabelmailboxmenu'] = 'Menu akcií pre priečinok';
$labels['arialabellistselectmenu'] = 'Menu pre výber zoznamu';
$labels['arialabelthreadselectmenu'] = 'Menu pre zoznam vlákien';
$labels['arialabelmessagelistoptions'] = 'Nastavenia zobrazenia a triedenia zoznamu správ';
$labels['arialabelmailimportdialog'] = 'Dialóg pre import správy';
$labels['arialabelmessagenav'] = 'Navigácia správy';
$labels['arialabelmessagebody'] = 'Telo správy';
$labels['arialabelmessageactions'] = 'Akcie správy';
$labels['arialabelcontactquicksearch'] = 'Formulár pre vyhľadanie kontaktov';
$labels['arialabelcontactsearchbox'] = 'Vstup pre vyhľadávanie kontaktov';
$labels['arialabelmessageheaders'] = 'Hlavičky správ';
$labels['arialabelforwardingoptions'] = 'Nastavenia preposielania';
$labels['arialabelreplyalloptions'] = 'Nastavenia pre „Odpovedať všetkým“';
$labels['arialabelmoremessageactions'] = 'Viac akcií so správou';
$labels['arialabelmorecontactactions'] = 'Viac akcií pre kontakt';
$labels['arialabelmarkmessagesas'] = 'Označiť vybrané správy ako';
$labels['arialabelcomposeoptions'] = 'Nastavenia kompozície';
$labels['arialabelresponsesmenu'] = 'Menu pre preddefinované odpovede';
$labels['arialabelattachmentuploadform'] = 'Formulár pre odoslanie prílohy';
$labels['arialabelattachmentmenu'] = 'Nastavenia prílohy';
$labels['arialabelmailtomenu'] = 'Možnosti pre e-mailovú adresu';
$labels['arialabelattachmentpreview'] = 'Náhľad prílohy';
$labels['ariasummarycomposecontacts'] = 'Zoznam kontaktov a skupín pre výber príjemcov';
$labels['arialabelcontactexportoptions'] = 'Nastavenia exportu kontaktov';
$labels['arialabelabookgroupoptions'] = 'Nastavenia adresára/skupiny';
$labels['arialabelpreferencesform'] = 'Formulár s nastaveniami';
$labels['arialabelidentityeditfrom'] = 'Formulár pre úpravu identity';
$labels['arialabelresponseeditfrom'] = 'Formulár pre úpravu odpovede';
$labels['arialabelsearchterms'] = 'Vyhľadávanie položiek';
$labels['arialabeldropactionmenu'] = 'Menu akcií typu Ťahaj a pusť';
$labels['arialabelheadersmenu'] = 'Menu pre pridanie príjemcu (hlavičky)';
$labels['arialabelimagetools'] = 'Nástroje pre obrázok';
$labels['helplistnavigation'] = 'Zoznam navigovania pomocou klávesnice';
$labels['helplistkeyboardnavigation'] = "Šípky nahor/nadol: presunúť zvýraznenie/výber.
Medzerník: vybrať zvýraznený riadok.
Shift + nahor/nadol: vybrať ďalší riadok hore/dole.
Ctrl + medzerník: pridať zvýraznený riadok do výberu/odstrániť ho z výberu.";
$labels['helplistkeyboardnavmessages'] = "Šípky doprava/doľava: rozbaliť/zbaliť vlákno správy (len v režime pre vlákna).
Enter: otvoriť vybranú/zvýraznenú správu.
Delete: presunúť vybrané správy do koša.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Otvoriť vybraný/zvýraznený kontakt.";
