<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = '$product에 오신 것을 환영합니다';
$labels['username'] = '사용자명';
$labels['password'] = '암호';
$labels['server'] = '서버';
$labels['login'] = '로그인';
$labels['oauthlogin'] = '$provider(으)로 로그인';
$labels['menu'] = '메뉴';
$labels['logout'] = '로그아웃';
$labels['mail'] = '메일';
$labels['settings'] = '설정';
$labels['addressbook'] = '주소록';
$labels['darkmode'] = '다크 모드';
$labels['lightmode'] = '라이트 모드';
$labels['inbox'] = '받은 편지함';
$labels['drafts'] = '임시 보관함';
$labels['sent'] = '보낸 편지함';
$labels['trash'] = '지운 편지함';
$labels['junk'] = '스팸 편지함';
$labels['show_real_foldernames'] = '특수 폴더에서 실제 명칭 표시';
$labels['subject'] = '제목';
$labels['from'] = '보낸 사람';
$labels['sender'] = '보내는 사람';
$labels['to'] = '받는 사람';
$labels['cc'] = '참조';
$labels['bcc'] = '숨은 참조';
$labels['replyto'] = '회신 주소';
$labels['followupto'] = '전달';
$labels['date'] = '날짜';
$labels['size'] = '크기';
$labels['priority'] = '우선 순위';
$labels['organization'] = '조직';
$labels['readstatus'] = '읽음 상태';
$labels['listoptions'] = '목록 옵션...';
$labels['listoptionstitle'] = '목록 옵션';
$labels['mailboxlist'] = '폴더';
$labels['messagesfromto'] = '총 $count개 중 $from 번째부터 $to 번째까지의 메시지';
$labels['threadsfromto'] = '총 $count개 중 $from 번째부터 $to 번째까지의 대화';
$labels['messagenrof'] = '총 $count개 중  $nr 번째 메시지';
$labels['fromtoshort'] = '총 $count개 중 $from 번째 - $to 번째';
$labels['copy'] = '복사';
$labels['move'] = '이동';
$labels['moveto'] = '다음 위치로 이동...';
$labels['copyto'] = '다음 위치로 복사...';
$labels['download'] = '다운로드';
$labels['open'] = '열기';
$labels['showattachment'] = '보기';
$labels['showanyway'] = '그래도 항상 표시';
$labels['filename'] = '파일명';
$labels['filesize'] = '파일 크기';
$labels['addtoaddressbook'] = '주소록에 추가';
$labels['sun'] = '일';
$labels['mon'] = '월';
$labels['tue'] = '화';
$labels['wed'] = '수';
$labels['thu'] = '목';
$labels['fri'] = '금';
$labels['sat'] = '토';
$labels['sunday'] = '일요일';
$labels['monday'] = '월요일';
$labels['tuesday'] = '화요일';
$labels['wednesday'] = '수요일';
$labels['thursday'] = '목요일';
$labels['friday'] = '금요일';
$labels['saturday'] = '토요일';
$labels['jan'] = '1월';
$labels['feb'] = '2월';
$labels['mar'] = '3월';
$labels['apr'] = '4월';
$labels['may'] = '5월';
$labels['jun'] = '6월';
$labels['jul'] = '7월';
$labels['aug'] = '8월';
$labels['sep'] = '9월';
$labels['oct'] = '10월';
$labels['nov'] = '11월';
$labels['dec'] = '12월';
$labels['longjan'] = '1월';
$labels['longfeb'] = '2월';
$labels['longmar'] = '3월';
$labels['longapr'] = '4월';
$labels['longmay'] = '5월';
$labels['longjun'] = '6월';
$labels['longjul'] = '7월';
$labels['longaug'] = '8월';
$labels['longsep'] = '9월';
$labels['longoct'] = '10월';
$labels['longnov'] = '11월';
$labels['longdec'] = '12월';
$labels['today'] = '오늘';
$labels['refresh'] = '새로고침';
$labels['checkmail'] = '새 메시지 확인';
$labels['compose'] = '쓰기';
$labels['writenewmessage'] = '새 메시지 만들기';
$labels['reply'] = '회신';
$labels['replytomessage'] = '보낸 사람에게 회신';
$labels['replytoallmessage'] = '목록 또는 보낸 사람 및 모든 받는 사람에게 회신';
$labels['replyall'] = '전체 회신';
$labels['replylist'] = '회신 목록';
$labels['forward'] = '전달';
$labels['forwardinline'] = '본문 내용으로 전달';
$labels['forwardattachment'] = '첨부파일로 전달';
$labels['forwardmessage'] = '메시지 전달';
$labels['bouncemsg'] = '재전송 (반송)';
$labels['bounce'] = '재전송';
$labels['deletemessage'] = '메시지 삭제';
$labels['movemessagetotrash'] = '메시지를 지운 편지함으로 이동';
$labels['printmessage'] = '이 메시지 인쇄';
$labels['previousmessage'] = '이전 메시지 표시';
$labels['firstmessage'] = '처음 메시지 표시';
$labels['nextmessage'] = '다음 메시지 표시';
$labels['lastmessage'] = '마지막 메시지 표시';
$labels['backtolist'] = '메시지 목록으로 돌아가기';
$labels['viewsource'] = '소스 표시';
$labels['mark'] = '표시';
$labels['markmessages'] = '메시지 표시';
$labels['markread'] = '읽은 상태로 표시';
$labels['markunread'] = '읽지 않은 상태로 표시';
$labels['markflagged'] = '플래그 추가 상태';
$labels['markunflagged'] = '플래그 제거 상태';
$labels['moreactions'] = '추가 동작...';
$labels['markallread'] = '모두 읽은 상태로 표시';
$labels['folders-cur'] = '선택한 폴더에만 적용';
$labels['folders-sub'] = '선택한 폴더 및 하위 폴더에만 적용';
$labels['folders-all'] = '모든 폴더에 적용';
$labels['more'] = '더 보기';
$labels['back'] = '뒤로';
$labels['options'] = '옵션';
$labels['composeoptions'] = '쓰기 옵션';
$labels['optionsandattachments'] = '옵션 및 첨부파일';
$labels['actions'] = '동작';
$labels['first'] = '처음';
$labels['last'] = '마지막';
$labels['previous'] = '이전';
$labels['next'] = '다음';
$labels['select'] = '선택';
$labels['selection'] = '선택';
$labels['all'] = '모두';
$labels['none'] = '없음';
$labels['currpage'] = '현재 페이지';
$labels['isread'] = '읽음';
$labels['unread'] = '읽지 않음';
$labels['flagged'] = '플래그 지정';
$labels['unflagged'] = '플래그 없음';
$labels['unanswered'] = '답변하지 않음';
$labels['withattachment'] = '첨부파일을 포함';
$labels['deleted'] = '삭제됨';
$labels['undeleted'] = '삭제되지 않음';
$labels['replied'] = '회신함';
$labels['forwarded'] = '전달함';
$labels['invert'] = '반전';
$labels['filter'] = '필터';
$labels['list'] = '목록';
$labels['threads'] = '대화';
$labels['expand-all'] = '모두 펼치기';
$labels['expand-unread'] = '읽지 않은 상태의 메시지 펼치기';
$labels['collapse-all'] = '모두 접기';
$labels['threaded'] = '대화형';
$labels['showunread'] = '읽지 않은 메시지 표시';
$labels['autoexpand_threads'] = '메시지 대화 펼치기';
$labels['do_expand'] = '모든 대화';
$labels['expand_only_unread'] = '읽지 않은 상태의 메시지에만 적용';
$labels['fromto'] = '보내는 사람/받는 사람';
$labels['flag'] = '플래그 있음';
$labels['attachment'] = '첨부파일';
$labels['nonesort'] = '없음';
$labels['sentdate'] = '보낸 날짜';
$labels['arrival'] = '받은 날짜';
$labels['asc'] = '오름차순';
$labels['desc'] = '내림차순';
$labels['listcolumns'] = '열 목록 표시';
$labels['listsorting'] = '열 정렬 기준';
$labels['listorder'] = '정렬 순서';
$labels['listmode'] = '목록 화면 모드 ';
$labels['lmode'] = '목록 모드';
$labels['layout'] = '레이아웃';
$labels['layoutwidescreen'] = '와이드스크린';
$labels['layoutdesktop'] = '데스크탑';
$labels['layoutlist'] = '목록';
$labels['layoutwidescreendesc'] = '와이드스크린 (3열 화면)';
$labels['layoutdesktopdesc'] = '데스크탑 (와이드 목록 및 하단 메일 미리보기)';
$labels['layoutlistdesc'] = '목록 (메일 미리보기 없음)';
$labels['folderactions'] = '폴더 동작...';
$labels['compact'] = '압축';
$labels['empty'] = '비우기';
$labels['importmessages'] = '메시지 가져오기';
$labels['mailimportdesc'] = '<a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> 또는 <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a> 형식의 파일로 메일을 업로드할 수 있습니다.';
$labels['mailimportzip'] = '여러 개 파일을 ZIP 압축 파일로 압축할 수 있습니다.';
$labels['quota'] = '디스크 사용량';
$labels['unknown'] = '알 수 없음';
$labels['unlimited'] = '무제한';
$labels['quotatype'] = '용량 제한 유형';
$labels['quotatotal'] = '제한 용량';
$labels['quotaused'] = '사용 용량';
$labels['quotastorage'] = '디스크 공간';
$labels['quotamessage'] = '메시지 개수';
$labels['shortheaderdate'] = '날짜: $date';
$labels['shortheaderto'] = '받는 사람: $to, 날짜: $date';
$labels['shortheaderfrom'] = '보낸 사람: $from, 날짜: $date';
$labels['quicksearch'] = '빠른 검색';
$labels['searchplaceholder'] = '검색...';
$labels['resetsearch'] = '검색 재설정';
$labels['searchmod'] = '수정자 검색';
$labels['msgtext'] = '전체 메시지';
$labels['body'] = '본문';
$labels['type'] = '유형';
$labels['namex'] = '이름';
$labels['searchscope'] = '범위';
$labels['currentfolder'] = '현재 폴더';
$labels['subfolders'] = '이 폴더 및 하위 폴더';
$labels['allfolders'] = '모든 폴더';
$labels['searchinterval-1W'] = '일주일 이전';
$labels['searchinterval-1M'] = '한 달 이전';
$labels['searchinterval-1Y'] = '일 년 이전';
$labels['searchinterval1W'] = '일주일 이후';
$labels['searchinterval1M'] = '한 달 이후';
$labels['searchinterval1Y'] = '일 년 이후';
$labels['openinextwin'] = '새 창에서 열기';
$labels['emlsave'] = '다운로드 (.eml)';
$labels['changeformattext'] = '메시지를 평문 형식으로 표시';
$labels['changeformathtml'] = 'HTML 형식으로 표시';
$labels['editasnew'] = '새 메시지로 편집';
$labels['send'] = '보내기';
$labels['sendmessage'] = '메일 보내기';
$labels['savemessage'] = '임시 보관함에 저장';
$labels['addattachment'] = '파일 첨부';
$labels['charset'] = '인코딩';
$labels['editortype'] = '편집기 유형';
$labels['returnreceipt'] = '읽음 확인';
$labels['dsn'] = '전송 상태 알림';
$labels['mailreplyintro'] = '$date에 $sender이(가) 쓴 내용:';
$labels['originalmessage'] = '원본 메시지';
$labels['selectimage'] = '이미지 선택';
$labels['addimage'] = '이미지 추가';
$labels['selectmedia'] = '동영상 선택';
$labels['addmedia'] = '동영상 추가';
$labels['encrypt'] = '암호화';
$labels['encryptmessage'] = '메시지 암호화';
$labels['encryptmessagemailvelope'] = 'Mailvelope으로 메시지 암호화';
$labels['importpubkeys'] = '공개 키 가져오기';
$labels['encryptedsendialog'] = '암호화 메시지 보내기';
$labels['encryptandsign'] = '암호화 및 서명';
$labels['keyid'] = '키 ID';
$labels['keylength'] = '비트';
$labels['keyexpired'] = '만료됨';
$labels['keyrevoked'] = '해지됨';
$labels['bccinstead'] = 'Bcc 사용';
$labels['addheader'] = '받는 사람 추가 (헤더)';
$labels['insert'] = '삽입';
$labels['insertcontact'] = '연락처 삽입';
$labels['recipient'] = '받는 사람';
$labels['recipientedit'] = '받는 사람 편집';
$labels['editidents'] = '신원 편집';
$labels['spellcheck'] = '맞춤법';
$labels['checkspelling'] = '맞춤법 검사';
$labels['resumeediting'] = '이어서 편집';
$labels['revertto'] = '돌아가기';
$labels['restore'] = '복구';
$labels['restoremessage'] = '메시지를 복구할까요?';
$labels['ignore'] = '무시';
$labels['responses'] = '응답';
$labels['insertresponse'] = '응답 삽입';
$labels['manageresponses'] = '응답 관리';
$labels['newresponse'] = '새 응답 만들기';
$labels['addresponse'] = '응답 추가';
$labels['editresponse'] = '응답 편집';
$labels['editresponses'] = '응답 편집';
$labels['responsename'] = '이름';
$labels['responsetext'] = '응답 문구';
$labels['attach'] = '첨부';
$labels['attachments'] = '첨부파일';
$labels['upload'] = '업로드';
$labels['uploadprogress'] = '$percent ($total 중 $current)';
$labels['close'] = '닫기';
$labels['messageoptions'] = '메시지 옵션...';
$labels['togglecomposeoptions'] = '구성 옵션 표시/숨기기';
$labels['attachmentrename'] = '첨부파일명 바꾸기';
$labels['low'] = '낮음';
$labels['lowest'] = '가장 낮음';
$labels['normal'] = '보통';
$labels['high'] = '높음';
$labels['highest'] = '가장 높음';
$labels['nosubject'] = '(제목 없음)';
$labels['showimages'] = '이미지 표시';
$labels['allow'] = '허용';
$labels['alwaysshow'] = '$sender이(가) 보낸 이미지 항상 표시';
$labels['alwaysallow'] = '$sender이(가) 보낸 메시지 항상 허용';
$labels['isdraft'] = '이것은 작성 중인 메시지입니다.';
$labels['andnmore'] = '$nr 더 보기...';
$labels['details'] = '세부사항';
$labels['summary'] = '요약';
$labels['headers'] = '헤더';
$labels['allheaders'] = '전체 헤더...';
$labels['togglemoreheaders'] = '메시지 헤더 더 보기';
$labels['togglefullheaders'] = '원본 메시지 헤더 표시/숨기기';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = '평문';
$labels['savesentmessagein'] = '보낸 메시지를 다음 위치에 저장';
$labels['dontsave'] = '저장하지 않음';
$labels['maxuploadsize'] = '최대 허용 파일 크기는 $size 입니다';
$labels['addcc'] = '참조 추가';
$labels['addbcc'] = '숨은 참조 추가';
$labels['addreplyto'] = '회신 주소 추가';
$labels['addfollowupto'] = '전달 추가';
$labels['sendreceipt'] = '읽음 확인 요청을 보낼까요?';
$labels['mdnrequest'] = '이 메시지를 보낸 사람이 사용자가 이 메시지를 읽었을 때 읽음 확인을 요청했습니다. 보낸 사람에게 알리시겠습니까?';
$labels['receiptread'] = '읽음 확인 (수신)';
$labels['yourmessage'] = '이것은 사용자의 메시지에 대한 읽음 확인입니다.';
$labels['receiptnote'] = '참고: 이 읽음 확인은 이 메시지가 받는 사람의 컴퓨터에 표시되었다는 것만을 의미합니다. 받는 사람이 해당 메시지 내용을 읽었거나 이해했다는 보장은 없습니다.';
$labels['sendalwaysto'] = '항상 $email(으)로 보내기';
$labels['zoomin'] = '확대';
$labels['zoomout'] = '축소';
$labels['rotate'] = '회전';
$labels['increaseimage'] = '이미지 크기 증가';
$labels['decreaseimage'] = '이미지 크기 감소';
$labels['rotateimage'] = '이미지 회전';
$labels['showtools'] = '이미지 도구 표시';
$labels['hidetools'] = '이미지 도구 숨기기';
$labels['name'] = '표시명';
$labels['firstname'] = '이름';
$labels['surname'] = '성';
$labels['middlename'] = '중간 이름';
$labels['nameprefix'] = '접두사';
$labels['namesuffix'] = '접미사';
$labels['nickname'] = '별칭';
$labels['jobtitle'] = '직책';
$labels['department'] = '부서';
$labels['gender'] = '성별';
$labels['maidenname'] = '결혼 전의 성';
$labels['email'] = '이메일';
$labels['phone'] = '전화';
$labels['address'] = '주소';
$labels['street'] = '도로명';
$labels['locality'] = '시/구/군';
$labels['zipcode'] = '우편번호';
$labels['region'] = '시/도';
$labels['country'] = '국가';
$labels['birthday'] = '생년월일';
$labels['anniversary'] = '기념일';
$labels['website'] = '웹사이트';
$labels['instantmessenger'] = '인스턴트 메신저';
$labels['notes'] = '메모';
$labels['male'] = '남성';
$labels['female'] = '여성';
$labels['manager'] = '상사';
$labels['assistant'] = '비서';
$labels['spouse'] = '배우자';
$labels['allfields'] = '모든 항목';
$labels['search'] = '검색';
$labels['searchresult'] = '검색 결과';
$labels['advsearch'] = '고급 검색';
$labels['advanced'] = '고급';
$labels['other'] = '기타';
$labels['printcontact'] = '연락처 인쇄';
$labels['qrcode'] = 'QR 코드';
$labels['typehome'] = '자택';
$labels['typework'] = '직장';
$labels['typeother'] = '기타';
$labels['typemobile'] = '휴대전화';
$labels['typemain'] = '대표';
$labels['typehomefax'] = '자택 팩스';
$labels['typeworkfax'] = '직장 팩스';
$labels['typecar'] = '차량';
$labels['typepager'] = '호출기';
$labels['typevideo'] = '동영상';
$labels['typeassistant'] = '비서';
$labels['typehomepage'] = '홈페이지';
$labels['typeblog'] = '블로그';
$labels['typeprofile'] = '자기소개';
$labels['addfield'] = '필드 추가..';
$labels['addcontact'] = '연락처 추가';
$labels['editcontact'] = '연락처 편집';
$labels['contacts'] = '연락처';
$labels['contactproperties'] = '연락처 속성';
$labels['contactnameandorg'] = '상호 및 조직';
$labels['personalinfo'] = '개인 정보';
$labels['personal'] = '개인';
$labels['contactphoto'] = '연락처 사진';
$labels['edit'] = '편집';
$labels['cancel'] = '취소';
$labels['save'] = '저장';
$labels['delete'] = '삭제';
$labels['discard'] = '폐기';
$labels['continue'] = '계속';
$labels['ok'] = '확인';
$labels['rename'] = '이름 바꾸기';
$labels['addphoto'] = '추가';
$labels['replacephoto'] = '변경';
$labels['uploadphoto'] = '사진 업로드';
$labels['choosefile'] = '파일 선택...';
$labels['choosefiles'] = '파일 선택...';
$labels['browse'] = '찾아보기';
$labels['newcontact'] = '새 연락처 만들기';
$labels['deletecontact'] = '선택한 연락처 삭제';
$labels['composeto'] = '메일 쓰기 대상';
$labels['contactsfromto'] = '총 $count개의 연락처 중 $from 번째부터 $to 번째 까지';
$labels['print'] = '인쇄';
$labels['export'] = '내보내기';
$labels['exportall'] = '모두 내보내기';
$labels['exportsel'] = '선택한 항목 내보내기';
$labels['exportvcards'] = '연락처를 vCard 형식으로 내보내기';
$labels['newgroup'] = '새 그룹 만들기';
$labels['addgroup'] = '그룹 추가';
$labels['grouprename'] = '그룹명 바꾸기';
$labels['groupdelete'] = '그룹 삭제';
$labels['groupassign'] = '그룹 지정...';
$labels['groupremove'] = '그룹에서 제거';
$labels['groupremoveselected'] = '선택한 연락처를 그룹에서 제거';
$labels['uponelevel'] = '한 단계 상위 이동';
$labels['previouspage'] = '이전 페이지 보기';
$labels['firstpage'] = '처음 페이지 보기';
$labels['nextpage'] = '다음 페이지 보기';
$labels['lastpage'] = '마지막 페이지 보기';
$labels['group'] = '그룹';
$labels['groups'] = '그룹';
$labels['listgroup'] = '그룹 구성원 목록 표시';
$labels['personaladrbook'] = '개인 주소';
$labels['searchsave'] = '검색 저장';
$labels['searchdelete'] = '검색 삭제';
$labels['import'] = '가져오기';
$labels['importcontacts'] = '연락처 가져오기';
$labels['importfromfile'] = '파일에서 가져오기';
$labels['importtarget'] = '연락처를 추가할 위치';
$labels['importreplace'] = '전체 주소록을 바꾸기';
$labels['importgroups'] = '그룹 할당 가져오기';
$labels['importgroupsall'] = '전체 (필요에 따라 그룹 생성)';
$labels['importgroupsexisting'] = '기존 그룹에만 해당';
$labels['importdesc'] = '기존 주소록에서 연락처를 가져올 수 있습니다.<br/> 현재 <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> 및 CSV (콤마-구분) 데이터 형식에서 주소 가져오기를 지원합니다.';
$labels['importmapdesc'] = 'CSV(쉼표 구분) 데이터를 가져오기를 진행하기 전에 아래 필드 맵핑 정보가 정확한지 확인하십시오.';
$labels['fieldnotmapped'] = '필드가 매핑되지 않음 (가져오지 않음)';
$labels['skipheader'] = '첫 번째 행 (헤더) 가져오지 않음';
$labels['done'] = '완료';
$labels['settingsfor'] = '설정';
$labels['about'] = '정보...';
$labels['preferences'] = '환경설정';
$labels['userpreferences'] = '사용자 환경설정';
$labels['editpreferences'] = '사용자 환경설정 편집';
$labels['identities'] = '신원';
$labels['manageidentities'] = '신원 관리';
$labels['newidentity'] = '새 신원 만들기';
$labels['addidentity'] = '신원 추가';
$labels['editidentity'] = '신원 편집';
$labels['identityencryption'] = '암호화';
$labels['preferhtml'] = 'HTML 표시';
$labels['defaultcharset'] = '기본 인코딩';
$labels['htmlmessage'] = 'HTML 메시지';
$labels['messagepart'] = '부분';
$labels['digitalsig'] = '디지털 서명';
$labels['dateformat'] = '날짜 형식';
$labels['timeformat'] = '시간 형식';
$labels['prettydate'] = '요일 및 시간으로 날짜 표시';
$labels['setdefault'] = '기본 값으로 설정';
$labels['autodetect'] = '자동';
$labels['language'] = '언어';
$labels['timezone'] = '시간대';
$labels['pagesize'] = '페이지당 행 개수';
$labels['signature'] = '서명';
$labels['dstactive'] = '일광 절약 시간';
$labels['showinextwin'] = '메시지를 새 창에서 열기';
$labels['composeextwin'] = '새 창에서 쓰기';
$labels['htmleditor'] = 'HTML 메시지 쓰기';
$labels['htmlonreply'] = 'HTML 메시지 회신 시';
$labels['htmlonreplyandforward'] = '전달 또는 HTML 메시지 회신 시';
$labels['htmlsignature'] = 'HTML 서명';
$labels['showemail'] = '이메일 주소를 표시명과 함께 표시';
$labels['previewpane'] = '미리보기 창 표시';
$labels['skin'] = '인터페이스 스킨';
$labels['logoutclear'] = '로그아웃 할 때 휴지통 비우기';
$labels['logoutcompact'] = '로그아웃 할 때 받은 편지함 압축';
$labels['uisettings'] = '사용자 인터페이스';
$labels['serversettings'] = '서버 설정';
$labels['mailboxview'] = '편지함 화면';
$labels['mdnrequests'] = '읽음 확인 요청 시';
$labels['askuser'] = '사용자에게 물음';
$labels['autosend'] = '읽음 확인 요청';
$labels['autosendknown'] = '내 연락처에 읽음 확인을 요청하고, 내 연락처가 아닐 경우 물어봄';
$labels['autosendknownignore'] = '내 연락처에 읽음 확인을 요청하고, 내 연락처가 아닐 경우 무시함';
$labels['autosendtrusted'] = '읽음 확인 요청을 신뢰하는 연락처에게 보내기, 아닐 경우 묻기';
$labels['autosendtrustedignore'] = '읽음 확인 요청을 신뢰하는 연락처에게 보내기, 아닐 경우 무시하기';
$labels['ignorerequest'] = '요청 무시';
$labels['readwhendeleted'] = '삭제 시 메시지를 읽은 상태로 표시';
$labels['flagfordeletion'] = '삭제 대신 삭제 대상 메시지에 플래그 추가';
$labels['skipdeleted'] = '삭제된 메시지를 표시하지 않음';
$labels['deletealways'] = '지운 편지함으로 메시지 이동이 실패할 경우 삭제';
$labels['deletejunk'] = '스팸 메일함에 있는 메시지를 직접 삭제';
$labels['showremoteimages'] = '본문에 원격 이미지 표시';
$labels['allowremoteresources'] = '외부 리소스 허용 (이미지, 스타일)';
$labels['fromknownsenders'] = '알려진 사람으로부터 받은 메시지만';
$labels['fromtrustedsenders'] = '신뢰하는 연락처로부터';
$labels['frommycontacts'] = '내 연락처에서';
$labels['always'] = '항상';
$labels['alwaysbutplain'] = '항상, 단 평문으로 회신할 때는 예외';
$labels['showinlineimages'] = '메시지 하단에 첨부 이미지 표시';
$labels['autosavedraft'] = '작성 중인 메시지 자동 저장';
$labels['everynminutes'] = '$n분 마다';
$labels['refreshinterval'] = '새로고침 (새 메시지 확인 등)';
$labels['never'] = '하지 않음';
$labels['immediately'] = '즉시';
$labels['messagesdisplaying'] = '메시지 표시';
$labels['messagescomposition'] = '메시지 작성';
$labels['mimeparamfolding'] = '첨부파일명';
$labels['2231folding'] = 'Full RFC 2231 (썬더버드)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS 아웃룩)';
$labels['2047folding'] = 'Full RFC 2047 (기타)';
$labels['force7bit'] = '8-bit 문자에 MIME 인코딩 사용';
$labels['savelocalstorage'] = "브라우저의 로컬 저장소에 저장 (임시)";
$labels['advancedoptions'] = '고급 옵션';
$labels['toggleadvancedoptions'] = '고급 옵션 표시/숨기기';
$labels['focusonnewmessage'] = '새 메시지가 있을 경우 브라우저 창으로 포커스 이동';
$labels['checkallfolders'] = '모든 폴더에서 새 메시지 확인';
$labels['displaynext'] = '삭제/이동 후 다음 항목 표시';
$labels['defaultfont'] = 'HTML 메시지의 기본 글꼴';
$labels['mainoptions'] = '메인 옵션';
$labels['browseroptions'] = '브라우저 옵션';
$labels['section'] = '섹션';
$labels['maintenance'] = '유지관리';
$labels['newmessage'] = '새 메시지';
$labels['signatureoptions'] = '서명 옵션';
$labels['whenreplying'] = '회신 시';
$labels['replyempty'] = '원문 메시지를 인용하지 않음';
$labels['replytopposting'] = '새 메시지를 인용문 상단에서 시작';
$labels['replytoppostingnoindent'] = '새 메시지를 인용문 상단에서 시작 (들여쓰기 없음)';
$labels['replybottomposting'] = '새 메시지를 인용문 하단에서 시작';
$labels['replyremovesignature'] = '회신 시 메시지에서 원문 서명을 제거';
$labels['autoaddsignature'] = '서명 자동 추가';
$labels['newmessageonly'] = '새 메시지에만';
$labels['replyandforwardonly'] = '회신 및 전달 메시지에만';
$labels['insertsignature'] = '서명 삽입';
$labels['sigbelow'] = '인용한 메시지 아래에 서명 표시';
$labels['sigseparator'] = '서명에 표준 분리자 강제 적용';
$labels['automarkread'] = '메시지를 읽은 상태로 표시';
$labels['afternseconds'] = '$n초 후';
$labels['reqmdn'] = '읽음 확인을 항상 요청';
$labels['reqdsn'] = '전송 상태 알림을 항상 요청';
$labels['replysamefolder'] = ' 회신 메시지를 회신 대상 메시지의 폴더로 이동';
$labels['defaultabook'] = '기본 주소록';
$labels['autocompletesingle'] = '자동 완성에서 대체 이메일 주소를 건너뜀';
$labels['listnamedisplay'] = '연락처 정렬 방식';
$labels['contactformmode'] = '연락처 양식 모드';
$labels['privatemode'] = '개인 (집)';
$labels['businessmode'] = '직장 (회사)';
$labels['collectedaddresses'] = '수집된 주소';
$labels['collectedrecipients'] = '수집된 수신자';
$labels['collectedrecipientsopt'] = '발송 이메일의 수신인을 저장할 위치';
$labels['collectedsendersopt'] = '신뢰하는 연락처 저장 위치';
$labels['trustedsenders'] = '신뢰하는 연락처';
$labels['spellcheckbeforesend'] = '메시지를 보내기 전에 맞춤법 검사';
$labels['spellcheckoptions'] = '맞춤법 검사 옵션';
$labels['spellcheckignoresyms'] = '기호가 포함된 단어 무시';
$labels['spellcheckignorenums'] = '숫자가 포함된 단어 무시';
$labels['spellcheckignorecaps'] = '모두 대문자로 표기된 단어 무시';
$labels['addtodict'] = '사전에 추가';
$labels['mailtoprotohandler'] = 'mailto: 링크의 프로토콜 처리자 등록';
$labels['standardwindows'] = '팝업을 일반 창같이 취급';
$labels['forwardmode'] = '메시지 전달 방식';
$labels['inline'] = '본문 내용';
$labels['asattachment'] = '첨부파일';
$labels['replyallmode'] = '[전체 회신] 버튼의 기본 동작';
$labels['replyalldefault'] = '전체 회신';
$labels['replyalllist'] = '발송 목록에만 회신 (찾았을 경우)';
$labels['folder'] = '폴더';
$labels['folders'] = '폴더';
$labels['foldername'] = '폴더명';
$labels['subscribed'] = '구독함';
$labels['messagecount'] = '메시지';
$labels['create'] = '추가';
$labels['createfolder'] = '새 폴더 만들기';
$labels['managefolders'] = '폴더 관리';
$labels['specialfolders'] = '특수 폴더';
$labels['properties'] = '속성';
$labels['folderproperties'] = '폴더 속성';
$labels['parentfolder'] = '상위 폴더';
$labels['location'] = '위치';
$labels['info'] = '정보';
$labels['getfoldersize'] = '폴더 크기를 확인하려면 클릭';
$labels['changesubscription'] = '구독을 변경하려면 클릭';
$labels['foldertype'] = '폴더 유형';
$labels['personalfolder'] = '개인 폴더';
$labels['otherfolder'] = '다른 사용자의 폴더';
$labels['sharedfolder'] = '공개 폴더';
$labels['findfolders'] = '폴더 찾기';
$labels['findcontacts'] = '연락처 검색';
$labels['findmail'] = '메일 메시지 검색';
$labels['namespace.personal'] = '개인';
$labels['namespace.other'] = '기타 사용자';
$labels['namespace.shared'] = '공유됨';
$labels['dualuselabel'] = '다음 항목만 담기:';
$labels['dualusemail'] = '메시지';
$labels['dualusefolder'] = '폴더';
$labels['generate'] = '생성';
$labels['encryptioncreatekey'] = '새 키 페어 만들기';
$labels['openmailvelopesettings'] = 'Mailvelope 설정 열기';
$labels['encryptionprivkeysinmailvelope'] = 'Mailvelope 열쇠고리에 저장된 개인 키 중 $nr개의 일치하는 키가 있습니다:';
$labels['encryptionnoprivkeysinmailvelope'] = '현재 보내는 사람 신원에는 Mailvelope 확장에 보관된 PGP 개인 키가 없습니다. 암호화된 메시지를 사용하기 위해 키를 하나 만드시겠습니까?';
$labels['encryption'] = '암호화';
$labels['mailvelopeoptions'] = 'Mailvelope 옵션';
$labels['mailvelopemainkeyring'] = 'Mailvelope 메인 키링 사용';
$labels['mailvelopenotfound'] = 'Mailvelope 확장기능이 브라우저에(서) 활성화/설치되지 않았습니다.';
$labels['sortby'] = '정렬 ';
$labels['sortasc'] = '오름차순으로 정렬';
$labels['sortdesc'] = '내림차순으로 정렬';
$labels['undo'] = '실행 취소';
$labels['installedplugins'] = '설치된 플러그인';
$labels['plugin'] = '플러그인';
$labels['version'] = '버전';
$labels['source'] = '원본';
$labels['destination'] = '대상';
$labels['license'] = '라이선스';
$labels['support'] = '지원 요청';
$labels['savedsearches'] = '저장된 검색';
$labels['dateformatY'] = 'YYYY';
$labels['dateformaty'] = 'YY';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = '유니코드';
$labels['english'] = '영어';
$labels['westerneuropean'] = '서유럽어';
$labels['easterneuropean'] = '동유럽어';
$labels['southeasterneuropean'] = '남동유럽어';
$labels['baltic'] = '발트어';
$labels['cyrillic'] = '키릴어';
$labels['arabic'] = '아랍어';
$labels['greek'] = '그리스어';
$labels['hebrew'] = '히브리어';
$labels['turkish'] = '터키어';
$labels['nordic'] = '북유럽어';
$labels['thai'] = '태국어';
$labels['celtic'] = '켈트어';
$labels['vietnamese'] = '베트남어';
$labels['japanese'] = '일본어';
$labels['korean'] = '한국어';
$labels['chinese'] = '중국어';
$labels['arialabeltopnav'] = '창 제어';
$labels['arialabeltasknav'] = '앱 작업';
$labels['arialabeltoolbar'] = '앱 도구 표시줄';
$labels['arialabellistnav'] = '목록 탐색';
$labels['arialabelactivetask'] = '활성화된 작업';
$labels['arialabelmessagessearchfilter'] = '이메일 목록 필터';
$labels['arialabelmailsearchform'] = '이메일 메시지 검색 양식';
$labels['arialabelcontactsearchform'] = '연락처 검색 양식';
$labels['arialabelmailquicksearchbox'] = '이메일 검색 입력';
$labels['arialabelquicksearchbox'] = '검색 입력';
$labels['arialabelfoldersearchfilter'] = '폴더 목록 표시 필터';
$labels['arialabelfoldersearchform'] = '폴터 검색 양식';
$labels['arialabelfolderlist'] = '이메일 폴더 선택';
$labels['arialabelmessagelist'] = '이메일 메시지 목록';
$labels['arialabelmailpreviewframe'] = '메시지 미리보기';
$labels['arialabelmailboxmenu'] = '폴더 동작 메뉴';
$labels['arialabellistselectmenu'] = '목록 선택 메뉴';
$labels['arialabelthreadselectmenu'] = '대화 목록 메뉴';
$labels['arialabelmessagelistoptions'] = '메시지 목록 표시 및 정렬 옵션';
$labels['arialabelmailimportdialog'] = '메시지 가져오기 대화';
$labels['arialabelmessagenav'] = '메시지 탐색';
$labels['arialabelmessagebody'] = '메시지 본문';
$labels['arialabelmessageactions'] = '메시지 동작';
$labels['arialabelcontactquicksearch'] = '연락처 검색 양식';
$labels['arialabelcontactsearchbox'] = '연락처 검색 입력';
$labels['arialabelmessageheaders'] = '메시지 헤더';
$labels['arialabelforwardingoptions'] = '전달 옵션';
$labels['arialabelreplyalloptions'] = '전체 회신 옵션';
$labels['arialabelmoremessageactions'] = '더 많은 메시지 동작';
$labels['arialabelmorecontactactions'] = '더 많은 연락처 동작';
$labels['arialabelmarkmessagesas'] = '선택한 메시지를 다음으로 표시..';
$labels['arialabelcomposeoptions'] = '작성 옵션';
$labels['arialabelresponsesmenu'] = '저장된 응답 메뉴';
$labels['arialabelattachmentuploadform'] = '첨부파일 업로드 양식';
$labels['arialabelattachmentmenu'] = '첨부파일 옵션';
$labels['arialabelmailtomenu'] = '이메일 주소 옵션';
$labels['arialabelattachmentpreview'] = '첨부파일 미리보기';
$labels['ariasummarycomposecontacts'] = '받는 사람으로 선택할 연락처 및 그룹 목록';
$labels['arialabelcontactexportoptions'] = '연락처 내보내기 옵션';
$labels['arialabelabookgroupoptions'] = '주소록/그룹 옵션';
$labels['arialabelpreferencesform'] = '환경 설정 양식';
$labels['arialabelidentityeditfrom'] = '신원 편집 양식';
$labels['arialabelresponseeditfrom'] = '응답 편집 양식';
$labels['arialabelsearchterms'] = '용어 검색';
$labels['arialabeldropactionmenu'] = '끌어서 놓기 동작 메뉴';
$labels['arialabelheadersmenu'] = '받는 사람 (헤더) 추가 메뉴';
$labels['arialabelimagetools'] = '이미지 도구';
$labels['helplistnavigation'] = '키보드 탐색 목록 표시';
$labels['helplistkeyboardnavigation'] = "상/하 화살표: 행 포커스/선택 이동
Space: 포커스된 행 선택
Shift + 상/하 화살표: 위/아래 행을 추가적으로 선택
Ctrl + Space: 포커스된 행을 선택/제거 대상 선택에서 추가";
$labels['helplistkeyboardnavmessages'] = "상/하 화살표: 메시지 대화 펼치기/접기(오직 대화 모드에서)
Enter: 선택한/포커스된 메시지 열기
Delete: 선택한 메시지를 지운 편지함으로 이동";
$labels['helplistkeyboardnavcontacts'] = "Enter: 선택한/포커스된 연락처 열기";
