<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<roundcube:include file="/includes/links.html" />
<script type="text/javascript" src="/functions.js"></script>
<script type="text/javascript" src="/splitter.js"></script>
<style type="text/css">
#identities-list { width: <roundcube:exp expression="!empty(cookie:identviewsplitter) ? cookie:identviewsplitter-5 : 295" />px; }
#identity-details { left: <roundcube:exp expression="!empty(cookie:identviewsplitter) ? cookie:identviewsplitter+5 : 305" />px; }
</style>

</head>
<body class="iframe">

<div id="identity-title" class="boxtitle"><roundcube:object name="steptitle" /></div>

<div id="identity-details" class="boxcontent">
  <roundcube:object name="identityform" id="identity-form" size="40" textareacols="70" textarearows="6" />

  <script type="text/javascript">
    rcube_init_tabs('identity-form');
    rcmail.addEventListener('identity-encryption-show', function() {
      rcube_init_tabs('identity-form');
    });
  </script>

  <div id="formfooter">
    <div class="footerleft">
      <roundcube:button command="save" type="input" class="button mainaction" label="save" />
    </div>
  </div>
</div>

</body>
</html>
