<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = '$product-a xoş gəldiniz!';
$labels['username'] = 'İstifadəçi adı';
$labels['password'] = 'Şifrə';
$labels['server'] = 'Server';
$labels['login'] = 'Giriş';
$labels['logout'] = 'Çıx';
$labels['mail'] = 'Poçt';
$labels['settings'] = 'Nizamlamalar';
$labels['addressbook'] = 'Ünvanlar';
$labels['inbox'] = 'Gələnlər';
$labels['drafts'] = 'Qaralamalar';
$labels['sent'] = 'Göndərilənlər';
$labels['trash'] = 'Səbət';
$labels['junk'] = 'Spam';
$labels['show_real_foldernames'] = 'Xüsusi qovluqlar üçün real adları göstər';
$labels['subject'] = 'Mövzu';
$labels['from'] = 'Kimdən';
$labels['sender'] = 'Göndərən';
$labels['to'] = 'Kimə';
$labels['cc'] = 'Nüsxə';
$labels['bcc'] = 'Gizli';
$labels['replyto'] = 'Cavabla';
$labels['followupto'] = 'İzlə';
$labels['date'] = 'Tarix';
$labels['size'] = 'Ölçü';
$labels['priority'] = 'Vaciblik';
$labels['organization'] = 'Təşkilat';
$labels['readstatus'] = 'Statusu oxu';
$labels['listoptions'] = 'Siyahı ayarları...';
$labels['mailboxlist'] = 'Qovluqlar';
$labels['messagesfromto'] = '$count mesajdan $from - $to arası mesajlar';
$labels['threadsfromto'] = 'Müzakirə: $from - $to Toplam: $count';
$labels['messagenrof'] = 'Məktub: $nr / $count';
$labels['fromtoshort'] = '$from – $to-dan $count';
$labels['copy'] = 'Kopyala';
$labels['move'] = 'Köçür';
$labels['moveto'] = 'Burada köçür...';
$labels['copyto'] = 'Bura kopyala...';
$labels['download'] = 'Endir';
$labels['open'] = 'Aç';
$labels['showattachment'] = 'Göstər';
$labels['showanyway'] = 'İstənilən halda göstər';
$labels['filename'] = 'Faylın adı';
$labels['filesize'] = 'Faylın ölçüsü';
$labels['addtoaddressbook'] = 'Ünvanlara əlavə et';
$labels['sun'] = 'B';
$labels['mon'] = 'Be';
$labels['tue'] = 'Ç';
$labels['wed'] = 'Ça';
$labels['thu'] = 'C';
$labels['fri'] = 'Ca';
$labels['sat'] = 'Ş';
$labels['sunday'] = 'Bazar';
$labels['monday'] = 'Bazar ertəsi';
$labels['tuesday'] = 'Çərçənbə';
$labels['wednesday'] = 'Çərşənbə axşamı';
$labels['thursday'] = 'Cümə';
$labels['friday'] = 'Cümə axşamı';
$labels['saturday'] = 'Şənbə';
$labels['jan'] = 'Yan';
$labels['feb'] = 'Fev';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Apr';
$labels['may'] = 'May';
$labels['jun'] = 'İyn';
$labels['jul'] = 'İyl';
$labels['aug'] = 'Avq';
$labels['sep'] = 'Sen';
$labels['oct'] = 'Okt';
$labels['nov'] = 'Noy';
$labels['dec'] = 'Dek';
$labels['longjan'] = 'Yanvar';
$labels['longfeb'] = 'Fevral';
$labels['longmar'] = 'Mart';
$labels['longapr'] = 'Aprel';
$labels['longmay'] = 'May';
$labels['longjun'] = 'İyun';
$labels['longjul'] = 'İyul';
$labels['longaug'] = 'Avqust';
$labels['longsep'] = 'Sentyabr';
$labels['longoct'] = 'Oktyabr';
$labels['longnov'] = 'Noyabr';
$labels['longdec'] = 'Dekabr';
$labels['today'] = 'Bu gün';
$labels['refresh'] = 'Yenilə';
$labels['checkmail'] = 'Gələnləri yoxla';
$labels['compose'] = 'Məktub yaz';
$labels['writenewmessage'] = 'Yeni məktub';
$labels['reply'] = 'Cavabla';
$labels['replytomessage'] = 'Göndərənə cavabla';
$labels['replytoallmessage'] = 'Hamıya cavabla';
$labels['replyall'] = 'Hamıya cavab';
$labels['replylist'] = 'Cavab siyahısı';
$labels['forward'] = 'Ötür';
$labels['forwardinline'] = 'Məktubda ötür';
$labels['forwardattachment'] = 'Əlavə kimi ötür';
$labels['forwardmessage'] = 'Yönəlt';
$labels['deletemessage'] = 'Sil';
$labels['movemessagetotrash'] = 'Məktubu səbətə köçür';
$labels['printmessage'] = 'Çap et';
$labels['previousmessage'] = 'Əvvəlki məktubu göstər';
$labels['firstmessage'] = 'Birinci məktubu göstər';
$labels['nextmessage'] = 'Sonrakı məktubu göstər';
$labels['lastmessage'] = 'Sonuncu məktubu göstər';
$labels['backtolist'] = 'Məktublar siyahısına qayıt';
$labels['viewsource'] = 'Mənbəni göstər';
$labels['mark'] = 'İşarələ';
$labels['markmessages'] = 'Məktubları işarələ';
$labels['markread'] = 'Oxunmuş';
$labels['markunread'] = 'Oxunmamış';
$labels['markflagged'] = 'Qeyd et';
$labels['markunflagged'] = 'Qeydi çıxar';
$labels['moreactions'] = 'Daha çox seçim...';
$labels['folders-all'] = 'Bütün qovluqlar';
$labels['more'] = 'Daha çox';
$labels['back'] = 'Geri';
$labels['options'] = 'Ayarlar';
$labels['first'] = 'İlk';
$labels['last'] = 'Son';
$labels['previous'] = 'Əvvəlki';
$labels['next'] = 'Sonrakı';
$labels['select'] = 'Seçin';
$labels['all'] = 'Hamısı';
$labels['none'] = 'Heç biri';
$labels['currpage'] = 'Hazırki səhifəni';
$labels['isread'] = 'Oxu';
$labels['unread'] = 'Oxunmamışları';
$labels['flagged'] = 'İşarəliləri';
$labels['unflagged'] = 'İşarətlənməyib';
$labels['unanswered'] = 'Cavabsızları';
$labels['withattachment'] = 'Qoşma ilə';
$labels['deleted'] = 'Silinmişləri';
$labels['undeleted'] = 'Silinməyib';
$labels['replied'] = 'Cavablanıb';
$labels['forwarded'] = 'Yönləndirilib';
$labels['invert'] = 'İnvertliləri';
$labels['filter'] = 'Süzgəc';
$labels['list'] = 'Siyahı';
$labels['threads'] = 'Müzakirələr';
$labels['expand-all'] = 'Hamısını aç';
$labels['expand-unread'] = 'Oxunmamışları aç';
$labels['collapse-all'] = 'Hamısını bük';
$labels['threaded'] = 'Müzakirə';
$labels['autoexpand_threads'] = 'Müzakirəni aç';
$labels['do_expand'] = 'bütün müzakirələr';
$labels['expand_only_unread'] = 'yalnız oxunmamış məktublarla';
$labels['fromto'] = 'Göndərən/Qəbul edən';
$labels['flag'] = 'Bayrağ';
$labels['attachment'] = 'Əlavə';
$labels['nonesort'] = 'Heç biri';
$labels['sentdate'] = 'Göndərilmə tarixi';
$labels['arrival'] = 'Çatdırılma tarixi';
$labels['asc'] = 'Çoxalan';
$labels['desc'] = 'Azalan';
$labels['listcolumns'] = 'Sütunlar';
$labels['listsorting'] = 'Sütunları çeşidlə';
$labels['listorder'] = 'Çeşidləmə qaydası';
$labels['listmode'] = 'Görünüş rejimi';
$labels['layoutlist'] = 'Siyahı';
$labels['folderactions'] = 'Qovluq işləri...';
$labels['compact'] = 'Sıx';
$labels['empty'] = 'Boşalt';
$labels['importmessages'] = 'Mesajların idxalı';
$labels['quota'] = 'Disk istifadəsi';
$labels['unknown'] = 'naməlum';
$labels['unlimited'] = 'limitsiz';
$labels['quotatotal'] = 'Limit';
$labels['quotaused'] = 'İşlədilib';
$labels['quotastorage'] = 'Disk həcmi';
$labels['quotamessage'] = 'Mesaj sayı';
$labels['quicksearch'] = 'Sürətli axtarış';
$labels['resetsearch'] = 'Axtarışı yenilə';
$labels['searchmod'] = 'Axtarış variantları';
$labels['msgtext'] = 'Bütün məktub';
$labels['body'] = 'Mətn';
$labels['type'] = 'Növ';
$labels['namex'] = 'Ad';
$labels['currentfolder'] = 'Hazırki qovluq';
$labels['subfolders'] = 'Bu və alt qovluqlar';
$labels['allfolders'] = 'Bütün qovluqlar';
$labels['searchinterval-1W'] = 'bir həftədən köhnə';
$labels['searchinterval-1M'] = 'bir aydan əvvəl';
$labels['searchinterval-1Y'] = 'bir ildən əvvəl';
$labels['searchinterval1W'] = 'bir həftədən cavan';
$labels['searchinterval1M'] = 'bir aydan cavan';
$labels['searchinterval1Y'] = 'bir ildən cavan';
$labels['openinextwin'] = 'Yeni pəncərədə aç';
$labels['emlsave'] = 'Saxla (.eml)';
$labels['changeformattext'] = 'Sadə mətn formatında göstər';
$labels['changeformathtml'] = 'HTML formatında göstər';
$labels['editasnew'] = 'Yeni kimi redaktə et';
$labels['send'] = 'Göndər';
$labels['sendmessage'] = 'İndi göndər';
$labels['savemessage'] = 'Qaralama saxla';
$labels['addattachment'] = 'Fayl əlavə et';
$labels['charset'] = 'Kodlaşdırma';
$labels['editortype'] = 'Redaktor';
$labels['returnreceipt'] = 'Cavab sorğusu';
$labels['dsn'] = 'Çatdırılma statusu haqda bildiriş';
$labels['mailreplyintro'] = '$date tarixdə, $sender yazıb:';
$labels['originalmessage'] = 'Orijinal məktub';
$labels['selectimage'] = 'Şəkli seç';
$labels['addimage'] = 'Şəkil əlavə et';
$labels['encrypt'] = 'Şifrələ';
$labels['encryptmessage'] = 'Mesajı şifrələ';
$labels['importpubkeys'] = 'İctimai açarları idxal et';
$labels['encryptedsendialog'] = 'Şifrəli mesaj göndərilir';
$labels['keyid'] = 'Açar ID';
$labels['keyexpired'] = 'Vaxtı keçib';
$labels['insert'] = 'Yerləşdir';
$labels['recipient'] = 'Qəbul edən';
$labels['editidents'] = 'İdentifikasiyanı dəyiş';
$labels['spellcheck'] = 'Orfoqrafiya';
$labels['checkspelling'] = 'Orfoqrafiyanı yoxla';
$labels['resumeediting'] = 'Redaktəni davam et';
$labels['revertto'] = 'Dəyişiklikləri ləğv et';
$labels['restore'] = 'Bərpa';
$labels['restoremessage'] = 'Məktub bərpa edilsin?';
$labels['responses'] = 'Cavablar';
$labels['insertresponse'] = 'Cavab daxil et';
$labels['manageresponses'] = 'Cavabların idarə edilməsi';
$labels['newresponse'] = 'Yeni cavab yarat';
$labels['addresponse'] = 'Cavab əlavə et';
$labels['editresponse'] = 'Cavabı redaktə et';
$labels['editresponses'] = 'Cavabları redaktə et';
$labels['responsename'] = 'Ad';
$labels['responsetext'] = 'Cavab mətni';
$labels['attach'] = 'Fayl əlavə et';
$labels['attachments'] = 'Bərkidilmiş Fayllar';
$labels['upload'] = 'Yüklə';
$labels['close'] = 'Bağla';
$labels['messageoptions'] = 'Məktub xüsusiyyətləri...';
$labels['low'] = 'Alçaq';
$labels['lowest'] = 'Çox alçaq';
$labels['normal'] = 'Normal';
$labels['high'] = 'Yüksək';
$labels['highest'] = 'Çox yüksək';
$labels['nosubject'] = '(mövzu yoxdur)';
$labels['showimages'] = 'Şəkilləri göstər';
$labels['alwaysshow'] = '$sender-dən olan məktublarda həmişə şəkilləri göstər';
$labels['isdraft'] = 'Bu qaralama məktubudur.';
$labels['andnmore'] = 'Daha çox $nr more...';
$labels['togglemoreheaders'] = 'Daha çox məktub';
$labels['togglefullheaders'] = 'Məktubun çiy başlıqlarını keçir';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Mətn';
$labels['savesentmessagein'] = 'Məktubu saxla...';
$labels['dontsave'] = 'saxlama';
$labels['maxuploadsize'] = 'Faylın maksimal ölçüsü: $size';
$labels['addcc'] = 'Kopya əlavə et';
$labels['addbcc'] = 'Gizli kopya əlavə et';
$labels['addreplyto'] = 'Yönəltmə əlavə et';
$labels['addfollowupto'] = '"İzlə" əlavə et';
$labels['mdnrequest'] = 'Məktubu göndərən onu oxuduğunuz haqda sorğu almaq istəyir. Göndərilsin?';
$labels['receiptread'] = 'Oxunulma haqda soğru';
$labels['yourmessage'] = 'Bu məktubunuzun oxunulduğu haqda sorğudur';
$labels['receiptnote'] = 'Bu sorğu yalnız qəbul edilən tərəfindən məktubun açıldığına göstərir. Onun oxunulduğuna zəmanət vermir.';
$labels['name'] = 'Göstərilən ad';
$labels['firstname'] = 'Adı';
$labels['surname'] = 'Soyadı';
$labels['middlename'] = 'Orta adı';
$labels['nameprefix'] = 'Prefiks';
$labels['namesuffix'] = 'Suffiks';
$labels['nickname'] = 'Ləqəb';
$labels['jobtitle'] = 'Vəzifə';
$labels['department'] = 'Departament';
$labels['gender'] = 'Cins';
$labels['maidenname'] = 'Qız adı';
$labels['email'] = 'E-Poçt';
$labels['phone'] = 'Telefon';
$labels['address'] = 'Ünvan';
$labels['street'] = 'Küçə';
$labels['locality'] = 'Şəhər';
$labels['zipcode'] = 'ZIP kod';
$labels['region'] = 'Region';
$labels['country'] = 'Ölkə';
$labels['birthday'] = 'Ad günü';
$labels['anniversary'] = 'İldönümü';
$labels['website'] = 'Vebsayt';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Qeydlər';
$labels['male'] = 'kişi';
$labels['female'] = 'qadın';
$labels['manager'] = 'Menecer';
$labels['assistant'] = 'Köməkçi';
$labels['spouse'] = 'Ər-arvad';
$labels['allfields'] = 'Bütün sahələr';
$labels['search'] = 'Axtar';
$labels['searchresult'] = 'Axtarış nəticəsi';
$labels['advsearch'] = 'Ətraflı axtarış';
$labels['advanced'] = 'Əlavə';
$labels['other'] = 'Başqa';
$labels['typehome'] = 'Ev';
$labels['typework'] = 'İş';
$labels['typeother'] = 'Başqa';
$labels['typemobile'] = 'Mobil';
$labels['typemain'] = 'Əsas';
$labels['typehomefax'] = 'Ev faksı';
$labels['typeworkfax'] = 'İş faksı';
$labels['typecar'] = 'Maşın';
$labels['typepager'] = 'Peycer';
$labels['typevideo'] = 'Video';
$labels['typeassistant'] = 'Köməkçi';
$labels['typehomepage'] = 'Ana səhifə';
$labels['typeblog'] = 'Bloq';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Sahə əlavə et';
$labels['addcontact'] = 'Əlaqə əlavə et';
$labels['editcontact'] = 'Ünvanı redaktə et';
$labels['contacts'] = 'Əlaqələr';
$labels['contactproperties'] = 'Kontakt xüsusiyyətləri';
$labels['personalinfo'] = 'Şəxsi məlumat';
$labels['personal'] = 'Şəxsi';
$labels['edit'] = 'Redaktə et';
$labels['cancel'] = 'Ləğv et';
$labels['save'] = 'Saxla';
$labels['delete'] = 'Sil';
$labels['rename'] = 'Adlandır';
$labels['addphoto'] = 'Əlavə et';
$labels['replacephoto'] = 'Adı dəyiş';
$labels['uploadphoto'] = 'Şəkil yüklə';
$labels['deletecontact'] = 'Seçilmiş ünvanları sil';
$labels['composeto'] = 'Seçilmiş ünvanlara məktub yaz';
$labels['contactsfromto'] = '$count ünvanının $from - $to arası';
$labels['print'] = 'Çap et';
$labels['export'] = 'İxrac et';
$labels['exportall'] = 'Hamısını İxrac et';
$labels['exportsel'] = 'Seçilmişləri İxrac et';
$labels['exportvcards'] = 'Ünvanları vCards formatında ixrac et';
$labels['addgroup'] = 'Qrup əlavə et';
$labels['grouprename'] = 'Qruğun adını dəyişdir';
$labels['groupdelete'] = 'Qrupu sil';
$labels['groupremoveselected'] = 'Qrupdan seçilmiş kontaktları sil';
$labels['previouspage'] = 'Əvvəlkini göstər';
$labels['firstpage'] = 'Birincini göstər';
$labels['nextpage'] = 'Sonrakını göstər';
$labels['lastpage'] = 'Sonuncunu göstər';
$labels['group'] = 'Qrup';
$labels['groups'] = 'Qruplar';
$labels['listgroup'] = 'Qrup üzvlərinin siyahısı';
$labels['personaladrbook'] = 'Şəxsi ünvanlar';
$labels['searchsave'] = 'Sorğunu saxla';
$labels['searchdelete'] = 'Sorğunu sil';
$labels['import'] = 'İdxal';
$labels['importcontacts'] = 'Ünvanların idxalı';
$labels['importtarget'] = 'Kontaktları əlavə et';
$labels['importreplace'] = 'Ünvan kitabçasını dəyiş';
$labels['importgroups'] = 'Qrup idxalı tapşırığı';
$labels['importgroupsall'] = 'Hamısı (əgər lazımdırsa qrupun yaradılması)';
$labels['importgroupsexisting'] = 'Yalnız mövcud qruplar üçün';
$labels['done'] = 'Bitdi';
$labels['settingsfor'] = 'Nizamlamaları';
$labels['about'] = 'Haqqında';
$labels['preferences'] = 'Nizamlamalar';
$labels['userpreferences'] = 'İstifadəçi nizamlamaları';
$labels['editpreferences'] = 'İstifadəçi nizamlamalarını redaktə et';
$labels['identities'] = 'Kimliklər';
$labels['preferhtml'] = 'HTML-də göstər';
$labels['defaultcharset'] = 'İlkin vəziyyətdəki kodlaşdırma';
$labels['htmlmessage'] = 'HTML məktub';
$labels['messagepart'] = 'Hissə';
$labels['digitalsig'] = 'Rəqəmsal imza';
$labels['dateformat'] = 'Tarix formatı';
$labels['timeformat'] = 'Vaxt formatı';
$labels['prettydate'] = 'Qəşəng tarixlər';
$labels['setdefault'] = 'İlkin vəziyyətə qaytar';
$labels['autodetect'] = 'Avto';
$labels['language'] = 'Dil';
$labels['timezone'] = 'Saat qurşağı';
$labels['pagesize'] = 'Səhifədə sətrlər';
$labels['signature'] = 'İmza';
$labels['dstactive'] = 'Yay vaxtı';
$labels['showinextwin'] = 'Məktubu yeni pəncərədə aç';
$labels['composeextwin'] = 'Yeni pəncərədə yarat';
$labels['htmleditor'] = 'HTML-də mesaj yaz';
$labels['htmlonreply'] = 'yalnız HTML mesajlar ilə cavab';
$labels['htmlonreplyandforward'] = 'HTML məktuba cavab və yönəltmə zamanı';
$labels['htmlsignature'] = 'HTML imza';
$labels['showemail'] = 'E-poçt ünvanları displey adları ilə göstər';
$labels['previewpane'] = 'Prevyu paneli göstər';
$labels['skin'] = 'İnterfeys stili';
$labels['logoutclear'] = 'Poçtdan çıxan zaman səbəti təmizlə';
$labels['logoutcompact'] = 'Poçtdan çıxan zaman gələnləri sıx';
$labels['uisettings'] = 'İstifadəçi interfeysi';
$labels['serversettings'] = 'Server nizamlamaları';
$labels['mailboxview'] = 'Poçt qutusunun görünüşü';
$labels['mdnrequests'] = 'Göndərilmə bildirişi';
$labels['askuser'] = 'göndərilmə zamanı istifadəçidən soruş';
$labels['autosend'] = 'avtomatik göndər';
$labels['autosendknown'] = 'kontaktlarıma qəbz yolla. Əks halda soruş';
$labels['autosendknownignore'] = 'kontaktlarıma qəbz yolla. Əks halda iqnor et';
$labels['readwhendeleted'] = 'Məktubu siləndə oxunmuş kimi qeyd et';
$labels['flagfordeletion'] = 'Silmə əvəzi silinmə işarəsilə qeyd et';
$labels['skipdeleted'] = 'Silinmiş məktubları göstərmə';
$labels['deletealways'] = 'Məktubu səbətə köçürmək alınmırsa, silinsin';
$labels['deletejunk'] = 'SPAM-dakı məktubları səbətə yollamadan sil';
$labels['showremoteimages'] = 'Silinmiç şəkilləri göstər';
$labels['fromknownsenders'] = 'məlum göndərənlərdən';
$labels['always'] = 'hər zaman';
$labels['showinlineimages'] = 'Əlavə olunmuş şəkili məktubun aşağısında göstər';
$labels['autosavedraft'] = 'Qaralamanı avtomatik saxla';
$labels['everynminutes'] = 'hər $n dəqiqə(lər)';
$labels['refreshinterval'] = 'Yenilə (yeni məktubları yoxla v.s.)';
$labels['never'] = 'heç vaxt';
$labels['immediately'] = 'dərhal';
$labels['messagesdisplaying'] = 'Məktubların göstərilməsi';
$labels['messagescomposition'] = 'Məktubların yazılması';
$labels['mimeparamfolding'] = 'Bərkidilənlərin adları';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (başqa)';
$labels['force7bit'] = '8-bitli simvollar üçün MIME istifadə et';
$labels['advancedoptions'] = 'Ətraflı nizamlama';
$labels['focusonnewmessage'] = 'Yeni məktub zamanı brauzerin pəncərəsini fokusla';
$labels['checkallfolders'] = 'Bütün qovluqlarda yeni məktubları yoxla';
$labels['defaultfont'] = 'HTML məktubun default şrifti';
$labels['mainoptions'] = 'Əsas nizamlamalar';
$labels['browseroptions'] = 'Brauzer ayarları';
$labels['section'] = 'Bölmə';
$labels['maintenance'] = 'Xidmət';
$labels['newmessage'] = 'Yeni məktub';
$labels['signatureoptions'] = 'İmzanın nizamlamaları';
$labels['whenreplying'] = 'Cavab zamanı';
$labels['replyempty'] = 'orijinal məktubu sitat gətirmə';
$labels['replytopposting'] = 'orijinaldan əvvəl yeni məktub yaz';
$labels['replybottomposting'] = 'orijinaldan sonra yeni məktub yaz';
$labels['replyremovesignature'] = 'Cavab zamanı imzanı sil';
$labels['autoaddsignature'] = 'İmzanı avtomatik əlavə et';
$labels['newmessageonly'] = 'yalnız yeni məktublarda';
$labels['replyandforwardonly'] = 'Yalnız cavab və yönəldilənlərdə';
$labels['insertsignature'] = 'İmza əlavə et';
$labels['afternseconds'] = '$n saniyədən sonra';
$labels['reqmdn'] = 'Hər zaman çatdırılma bildirişini istə';
$labels['reqdsn'] = 'Hər zaman çatıdrılma haqda statusu istə';
$labels['replysamefolder'] = 'Cavab mesajları üçün saxlanılan yer';
$labels['defaultabook'] = 'Öz qurğulu ünvan kitabçası';
$labels['autocompletesingle'] = 'Avtobitmədə əlavə ünvanları burax';
$labels['listnamedisplay'] = 'Kontaklar siyahısı bu cür göstər';
$labels['spellcheckbeforesend'] = 'Göndərməzdən əvvəl orfoqrafiyanı yoxla';
$labels['spellcheckoptions'] = 'Orfoqrafiya yoxlanışının ayarları';
$labels['spellcheckignoresyms'] = 'Simvollar ilə sözləri burax';
$labels['spellcheckignorenums'] = 'Rəqəmlər ilə sözləri keç';
$labels['spellcheckignorecaps'] = 'Böyük hərfləri olan sözlərdən keç';
$labels['addtodict'] = 'Lüğətə əlavə et';
$labels['mailtoprotohandler'] = 'mailto: keçid üçün protokol qeyd et';
$labels['standardwindows'] = 'Handle popapsı standart pəncərələr kimi';
$labels['forwardmode'] = 'Məktubların yönəldilməsi';
$labels['inline'] = 'mətndə';
$labels['asattachment'] = 'fayl kimi';
$labels['replyallmode'] = '[Hamıya cavab] düyməsinin susmaya görə hərəkəti';
$labels['replyalldefault'] = 'hamıya cavab';
$labels['replyalllist'] = 'yalnız poçt siyahısına (əgər tapılıbsa) cavab ';
$labels['folder'] = 'Qovluq';
$labels['folders'] = 'Qovluqlar';
$labels['foldername'] = 'Qovluq adı';
$labels['subscribed'] = 'İmzalanıb';
$labels['messagecount'] = 'Məktublar';
$labels['create'] = 'Yarad';
$labels['createfolder'] = 'Yeni qovluq yarad';
$labels['managefolders'] = 'Qovluqlarla iş';
$labels['specialfolders'] = 'Xüsusi qovluqlar';
$labels['properties'] = 'Xüsusiyyətlər';
$labels['folderproperties'] = 'Qovluq xüsusiyyətləri';
$labels['parentfolder'] = 'Ana qovluq';
$labels['location'] = 'Yerləşmə';
$labels['info'] = 'Məlumat';
$labels['getfoldersize'] = 'Qovluq ölçüsünü öyrənmək üçün vur';
$labels['changesubscription'] = 'Abunəni dəyişmək üçün vurun';
$labels['foldertype'] = 'Qovluq növü';
$labels['personalfolder'] = 'Gizli qovluq';
$labels['otherfolder'] = 'Başqa istifadəçilərin qovluğu';
$labels['sharedfolder'] = 'İctimai qovluq';
$labels['findfolders'] = 'Qovluqları tap';
$labels['namespace.personal'] = 'Şəxsi';
$labels['namespace.shared'] = 'Paylaşılıb';
$labels['sortby'] = 'Çeşidlə';
$labels['sortasc'] = 'Azdan çoxa';
$labels['sortdesc'] = 'Çoxdan aza';
$labels['undo'] = 'Ləğv et';
$labels['installedplugins'] = 'Yazılmış qoşmalar';
$labels['plugin'] = 'Qoşma';
$labels['version'] = 'Versiya';
$labels['source'] = 'Mənbə';
$labels['license'] = 'Lisenziya';
$labels['support'] = 'Dəstək';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'İngilis dili';
$labels['westerneuropean'] = 'Qərbi Avropa';
$labels['easterneuropean'] = 'Şərqi Avropa';
$labels['southeasterneuropean'] = 'Cənub-Şərqi Avropa';
$labels['baltic'] = 'Baltik';
$labels['cyrillic'] = 'Kirillə';
$labels['arabic'] = 'Ərəbcə';
$labels['greek'] = 'Yunanca';
$labels['hebrew'] = 'Yəhudicə';
$labels['turkish'] = 'Türkcə';
$labels['nordic'] = 'Skandinav';
$labels['thai'] = 'Tayca';
$labels['celtic'] = 'Keltcə';
$labels['vietnamese'] = 'Vyetnamca';
$labels['japanese'] = 'Yaponca';
$labels['korean'] = 'Koreya';
$labels['chinese'] = 'Çincə';
