<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-newmail_notifier/
*/

$labels['basic'] = 'Прикажи обавештења о новим порукама у прегледачу';
$labels['desktop'] = 'Прикажи обавештења о новим порукама у систему';
$labels['sound'] = 'Пусти звук при новој поруци';
$labels['test'] = 'Испробај';
$labels['title'] = 'Нова порука!';
$labels['body'] = 'Примили сте нову поруку.';
$labels['testbody'] = 'Ово је пробно обавештење.';
$labels['desktopdisabled'] = 'Обавештења у систему су искључена у вашем прегледачу.';
$labels['desktopunsupported'] = 'Ваш прегледач не подржава обавештења у систему.';
$labels['desktoptimeout'] = 'Затвори обавештења у систему';
