<?php

/**
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Enigma plugin              |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/roundcube/roundcube-webmail/plugin-enigma/
*/

$labels['encryption'] = 'Encriptación';
$labels['enigmacerts'] = 'Certificados S/MIME';
$labels['enigmakeys'] = 'Claves PGP';
$labels['keysfromto'] = 'Claves $from a $to de $count';
$labels['keyname'] = 'Nombre';
$labels['keyid'] = 'ID de clave';
$labels['keyuserid'] = 'ID de usuario';
$labels['keytype'] = 'Tipo de clave';
$labels['fingerprint'] = 'Huella';
$labels['subkeys'] = 'Subclave';
$labels['keyprops'] = 'Propiedades de la clave';
$labels['basicinfo'] = 'Información básica';
$labels['userids'] = 'Usuarios adicionales';
$labels['typepublickey'] = 'clave pública';
$labels['typekeypair'] = 'par de claves';
$labels['keyattfound'] = 'Este mensaje contiene clave(s) PGP adjunta(s)';
$labels['keyattimport'] = 'Importar clave(s)';
$labels['typesign'] = 'Firmar';
$labels['typeencrypt'] = 'Encriptar';
$labels['typecert'] = 'Certificar';
$labels['typeauth'] = 'Autenticación';
$labels['subkeyid'] = 'ID';
$labels['subkeyalgo'] = 'Algoritmo';
$labels['subkeycreated'] = 'Creado';
$labels['subkeyexpires'] = 'Expira';
$labels['subkeyusage'] = 'Uso';
$labels['expiresnever'] = 'nunca';
$labels['unknown'] = 'desconocido';
$labels['uservalid'] = 'Válido';
$labels['userid'] = 'ID';
$labels['valid'] = 'válido';
$labels['supportencryption'] = 'Habilita encriptación y firma de mensajes';
$labels['supportsignatures'] = 'Habilitar la verificación de firmas de mensaje';
$labels['createkeys'] = 'Crear un nuevo par de claves';
$labels['importkeys'] = 'Importar clave(s)';
$labels['keychpass'] = 'Cambiar contraseña';
$labels['newkeypass'] = 'Contraseña';
$labels['newkeytype'] = 'Tipo de clave';
$labels['keyimportlabel'] = 'Importar desde archivo';
