/***** Roundcube|Mail Help task styles *****/

#taskbar a.button-help
{
  background-image: url('help.gif');
}

.extwin #tabsbar
{
  top: 21px;
  left: 20px;
  right: 100px;
  border-bottom: 0;
}

.helpwin .closelink {
	position: absolute;
	top: 20px;
	right: 20px;
}

.help-box
{
  overflow: auto;
  background-color: #F2F2F2;
}

#helplicense, #helpabout
{
  width: 46em;
  padding: 1em 2em;
}

#helplicense a, #helpabout a
{
  color: #900;
}

#helpabout
{
  margin: 0 auto;
}

