
#helpcontentframe {
	border: 0;
	border-radius: 4px;
}

#mainscreen .readtext {
	margin: 20px;
}

#helptoolbar {
	position: absolute;
	top: -6px;
	left: 0;
	height: 40px;
	white-space: nowrap;
}

#taskbar a.button-help span.button-inner {
	background: url(help.png) 0 0 no-repeat;
	height: 19px;
}

#taskbar a.button-help:hover span.button-inner,
#taskbar a.button-help.button-selected span.button-inner {
	background: url(help.png) 0 -24px no-repeat;
	height: 19px;
}

.toolbar a.button.help {
	background: url(help.png) center -51px no-repeat;
}

.toolbar a.button.about {
	background: url(help.png) center -89px no-repeat;
}

.toolbar a.button.license {
	background: url(help.png) center -130px no-repeat;
}
