<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-newmail_notifier/
*/

$labels['basic'] = 'แสดงการแจ้งเตือนของเบราเซอร์ในข้อความใหม่';
$labels['desktop'] = 'แสดงการแจ้งเตือนบนเดสก์ท็อปในข้อความใหม่';
$labels['sound'] = 'เล่นเสียงในข้อความใหม่';
$labels['test'] = 'ทดสอบ';
$labels['title'] = 'เมล์ใหม่!';
$labels['body'] = 'คุณได้รับข้อความใหม่แล้ว';
$labels['testbody'] = 'นี่คือการทดสอบแจ้งเตือน';
$labels['desktopdisabled'] = 'ปิดการแจ้งเตือนบนเดสก์ท็อปในเบราว์เซอร์ของคุณ';
$labels['desktopunsupported'] = 'เบราว์เซอร์ของคุณไม่สนับสนุนการแจ้งเตือนบนเดสก์ท็อป';
$labels['desktoptimeout'] = 'ปิดการแจ้งเตือนจากเดสก์ท็อป';
