<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/timezones/
*/

$labels['tz:utc'] = 'UTC';
$labels['tz:africa'] = 'Afrikë';
$labels['tz:africa:abidjan'] = 'Abixhan';
$labels['tz:africa:accra'] = 'Akra';
$labels['tz:africa:addis_ababa'] = 'Adis Abeba';
$labels['tz:africa:algiers'] = 'Algjer';
$labels['tz:africa:asmara'] = 'Asmara';
$labels['tz:africa:bamako'] = 'Bamako';
$labels['tz:africa:bangui'] = 'Bangui';
$labels['tz:africa:banjul'] = 'Banxhul';
$labels['tz:africa:bissau'] = 'Bisau';
$labels['tz:africa:blantyre'] = 'Blantajër';
$labels['tz:africa:brazzaville'] = 'Brazavil';
$labels['tz:africa:bujumbura'] = 'Buxhumbura';
$labels['tz:africa:cairo'] = 'Kajro';
$labels['tz:africa:casablanca'] = 'Kazablanca';
$labels['tz:africa:ceuta'] = 'Ceuta';
$labels['tz:africa:conakry'] = 'Konakri';
$labels['tz:africa:dakar'] = 'Dakar';
$labels['tz:africa:dar_es_salaam'] = 'Dar es Salam';
$labels['tz:africa:djibouti'] = 'Xhibout';
$labels['tz:africa:douala'] = 'Duala';
$labels['tz:africa:el_aaiun'] = 'El Ajun';
$labels['tz:africa:freetown'] = 'Fritaun';
$labels['tz:africa:gaborone'] = 'Gaborone';
$labels['tz:africa:harare'] = 'Harare';
$labels['tz:africa:johannesburg'] = 'Johanesburg';
$labels['tz:africa:juba'] = 'Juba';
$labels['tz:africa:kampala'] = 'Kampala';
$labels['tz:africa:khartoum'] = 'Kartoum';
$labels['tz:africa:kigali'] = 'Kigali';
$labels['tz:africa:kinshasa'] = 'Kinshasa';
$labels['tz:africa:lagos'] = 'Lagos';
$labels['tz:africa:libreville'] = 'Librevil';
$labels['tz:africa:lome'] = 'Lome';
$labels['tz:africa:luanda'] = 'Luanda';
$labels['tz:africa:lubumbashi'] = 'Lubumbashi';
$labels['tz:africa:lusaka'] = 'Lusaka';
$labels['tz:africa:malabo'] = 'Malabo';
$labels['tz:africa:maputo'] = 'Maputo';
$labels['tz:africa:maseru'] = 'Maseru';
$labels['tz:africa:mbabane'] = 'Mbabane';
$labels['tz:africa:mogadishu'] = 'Mogadishu';
$labels['tz:africa:monrovia'] = 'Monrovia';
$labels['tz:africa:nairobi'] = 'Najrobi';
$labels['tz:africa:ndjamena'] = 'Nxhamena';
$labels['tz:africa:niamey'] = 'Niamei';
$labels['tz:africa:nouakchott'] = 'Nuakçot';
$labels['tz:africa:ouagadougou'] = 'Uagadugu';
$labels['tz:africa:porto-novo'] = 'Porto-Novo';
$labels['tz:africa:sao_tome'] = 'Sao Tome';
$labels['tz:africa:tripoli'] = 'Tripoli';
$labels['tz:africa:tunis'] = 'Tunis';
$labels['tz:africa:windhoek'] = 'Uindhoek';
$labels['tz:america'] = 'Amerikë';
$labels['tz:america:adak'] = 'Adak';
$labels['tz:america:anchorage'] = 'Ankorazh';
$labels['tz:america:anguilla'] = 'Anguila';
$labels['tz:america:antigua'] = 'Antigua';
$labels['tz:america:araguaina'] = 'Araguaina';
$labels['tz:america:argentina'] = 'Argjentinë';
$labels['tz:america:argentina:buenos_aires'] = 'Buenos Ajres';
$labels['tz:america:argentina:catamarca'] = 'Katamarka';
$labels['tz:america:argentina:cordoba'] = 'Kordoba ';
$labels['tz:america:argentina:jujuy'] = 'Jujui';
$labels['tz:america:argentina:la_rioja'] = 'La Rioha';
$labels['tz:america:argentina:mendoza'] = 'Mendoza';
$labels['tz:america:argentina:rio_gallegos'] = 'Rio Galegos';
$labels['tz:america:argentina:salta'] = 'Salta';
$labels['tz:america:argentina:san_juan'] = 'San Huan';
$labels['tz:america:argentina:san_luis'] = 'San Luis';
$labels['tz:america:argentina:tucuman'] = 'Tukuman';
$labels['tz:america:argentina:ushuaia'] = 'Ushuaja';
$labels['tz:america:aruba'] = 'Aruba';
$labels['tz:america:asuncion'] = 'Asuncion';
$labels['tz:america:atikokan'] = 'Atikokan';
$labels['tz:america:bahia'] = 'Bahia';
$labels['tz:america:bahia_banderas'] = 'Bahia Banderas';
$labels['tz:america:barbados'] = 'Barbados';
$labels['tz:america:belem'] = 'Belem';
$labels['tz:america:belize'] = 'Belize';
$labels['tz:america:blanc-sablon'] = 'Blank-Sablon';
$labels['tz:america:boa_vista'] = 'Boa Vista';
$labels['tz:america:bogota'] = 'Bogota';
$labels['tz:america:boise'] = 'Buaz';
$labels['tz:america:cambridge_bay'] = 'Kembrixh Bej';
$labels['tz:america:campo_grande'] = 'Kampo Grande';
$labels['tz:america:cancun'] = 'Kankun';
$labels['tz:america:caracas'] = 'Karakas';
$labels['tz:america:cayenne'] = 'Kajen';
$labels['tz:america:cayman'] = 'Kejmën';
$labels['tz:america:chicago'] = 'Çikago';
$labels['tz:america:chihuahua'] = 'Çiuaua';
$labels['tz:america:costa_rica'] = 'Kosta Rika';
$labels['tz:america:creston'] = 'Kreston';
$labels['tz:america:cuiaba'] = 'Kujaba';
$labels['tz:america:curacao'] = 'Kurasëo';
$labels['tz:america:danmarkshavn'] = 'Danmarkshavn';
$labels['tz:america:dawson'] = 'Dousën';
$labels['tz:america:dawson_creek'] = 'Dousën Krik';
$labels['tz:america:denver'] = 'Denver';
$labels['tz:america:detroit'] = 'Detroit';
$labels['tz:america:dominica'] = 'Dominika';
$labels['tz:america:edmonton'] = 'Edmonton';
$labels['tz:america:eirunepe'] = 'Eirunepe';
$labels['tz:america:el_salvador'] = 'El Salvador';
$labels['tz:america:fort_nelson'] = 'Fort Nelson';
$labels['tz:america:fortaleza'] = 'Fortaleca';
$labels['tz:america:glace_bay'] = 'Gjiri i Akullit';
$labels['tz:america:godthab'] = 'Godhab';
$labels['tz:america:goose_bay'] = 'Gus Bej';
$labels['tz:america:grand_turk'] = 'Grand Turk';
$labels['tz:america:grenada'] = 'Grenadë';
$labels['tz:america:guadeloupe'] = 'Guadalupë ';
$labels['tz:america:guatemala'] = 'Guatemalë';
$labels['tz:america:guayaquil'] = 'Guajakil';
$labels['tz:america:guyana'] = 'Guajanë';
$labels['tz:america:halifax'] = 'Halifaks';
$labels['tz:america:havana'] = 'Havanë';
$labels['tz:america:hermosillo'] = 'Hermosijo';
$labels['tz:america:indiana'] = 'Indiana';
$labels['tz:america:indiana:indianapolis'] = 'Indianapolis';
$labels['tz:america:indiana:knox'] = 'Knoks';
$labels['tz:america:indiana:marengo'] = 'Marengo';
$labels['tz:america:indiana:petersburg'] = 'Petërburg';
$labels['tz:america:indiana:tell_city'] = 'Tell City';
$labels['tz:america:indiana:vevay'] = 'Vevei';
$labels['tz:america:indiana:vincennes'] = 'Vincene';
$labels['tz:america:indiana:winamac'] = 'Uinamak';
$labels['tz:america:inuvik'] = 'Inuvik';
$labels['tz:america:iqaluit'] = 'Ikaluit';
$labels['tz:america:jamaica'] = 'Xhamajkë';
$labels['tz:america:juneau'] = 'Zhyno';
$labels['tz:america:kentucky'] = 'Kentaki';
$labels['tz:america:kentucky:louisville'] = 'Luisvil';
$labels['tz:america:kentucky:monticello'] = 'Montiçelo';
$labels['tz:america:kralendijk'] = 'Kralendijk';
$labels['tz:america:la_paz'] = 'La Paz';
$labels['tz:america:lima'] = 'Lima';
$labels['tz:america:los_angeles'] = 'Los Anxheles';
$labels['tz:america:lower_princes'] = 'Louër Prinses';
$labels['tz:america:maceio'] = 'Maceio';
$labels['tz:america:managua'] = 'Managua';
$labels['tz:america:manaus'] = 'Manaus';
$labels['tz:america:marigot'] = 'Marigo';
$labels['tz:america:martinique'] = 'Martinikë';
$labels['tz:america:matamoros'] = 'Matamoros';
$labels['tz:america:mazatlan'] = 'Mazatlan';
$labels['tz:america:menominee'] = 'Menomini';
$labels['tz:america:merida'] = 'Merida';
$labels['tz:america:metlakatla'] = 'Metlakatla';
$labels['tz:america:mexico_city'] = 'Meksiko Siti';
$labels['tz:america:miquelon'] = 'Mikëlon';
$labels['tz:america:moncton'] = 'Monkton';
$labels['tz:america:monterrey'] = 'Monterrej';
$labels['tz:america:montevideo'] = 'Montevideo';
$labels['tz:america:montserrat'] = 'Monserrat';
$labels['tz:america:nassau'] = 'Nasau';
$labels['tz:america:new_york'] = 'Nju Jork';
$labels['tz:america:nipigon'] = 'Nipigon';
$labels['tz:america:nome'] = 'Nome';
$labels['tz:america:noronha'] = 'Noronja';
$labels['tz:america:north_dakota'] = 'Dakota e Veriut';
$labels['tz:america:north_dakota:beulah'] = 'Beula';
$labels['tz:america:north_dakota:center'] = 'Qendër';
$labels['tz:america:north_dakota:new_salem'] = 'Nju Salem';
$labels['tz:america:ojinaga'] = 'Ojinaga';
$labels['tz:america:panama'] = 'Panama';
$labels['tz:america:pangnirtung'] = 'Pangnirtung';
$labels['tz:america:paramaribo'] = 'Paramaribo';
$labels['tz:america:phoenix'] = 'Feniks';
$labels['tz:america:port-au-prince'] = 'Port-o-Prins';
$labels['tz:america:port_of_spain'] = 'Port of Spein';
$labels['tz:america:porto_velho'] = 'Porto Velho';
$labels['tz:america:puerto_rico'] = 'Porto Riko';
$labels['tz:america:rainy_river'] = 'Reini Rivër';
$labels['tz:america:rankin_inlet'] = 'Rankin Inlet';
$labels['tz:america:recife'] = 'Recife';
$labels['tz:america:regina'] = 'Rexhina';
$labels['tz:america:resolute'] = 'Rezolut';
$labels['tz:america:rio_branco'] = 'Rio Branko';
$labels['tz:america:santarem'] = 'Santarem';
$labels['tz:america:santiago'] = 'Santiago';
$labels['tz:america:santo_domingo'] = 'Santo Domingo';
$labels['tz:america:sao_paulo'] = 'Sao Paulo';
$labels['tz:america:scoresbysund'] = 'Skorsbajsund';
$labels['tz:america:sitka'] = 'Sitka';
$labels['tz:america:st_barthelemy'] = 'Shën Bartolome';
$labels['tz:america:st_johns'] = "Shën Gjon";
$labels['tz:america:st_kitts'] = 'Shën Kits';
$labels['tz:america:st_lucia'] = 'Shën Luçia';
$labels['tz:america:st_thomas'] = 'Shën Thoma';
$labels['tz:america:st_vincent'] = 'Shën Vinsent';
$labels['tz:america:swift_current'] = 'Suift Kurrent';
$labels['tz:america:tegucigalpa'] = 'Tegucigalpa';
$labels['tz:america:thule'] = 'Tjul';
$labels['tz:america:thunder_bay'] = 'Thundërbej';
$labels['tz:america:tijuana'] = 'Tihuana';
$labels['tz:america:toronto'] = 'Toronto';
$labels['tz:america:tortola'] = 'Tortola';
$labels['tz:america:vancouver'] = 'Vankuver';
$labels['tz:america:whitehorse'] = 'Uajthors';
$labels['tz:america:winnipeg'] = 'Uinipeg';
$labels['tz:america:yakutat'] = 'Jakutat';
$labels['tz:america:yellowknife'] = 'Jellounaif';
$labels['tz:antarctica'] = 'Antarktidë ';
$labels['tz:antarctica:casey'] = 'Kasi';
$labels['tz:antarctica:davis'] = 'Dejvis';
$labels['tz:antarctica:dumontdurville'] = "Dymon d'Yrvil";
$labels['tz:antarctica:macquarie'] = 'Makuari';
$labels['tz:antarctica:mawson'] = 'Mousën';
$labels['tz:antarctica:mcmurdo'] = 'Mekmërdou';
$labels['tz:antarctica:palmer'] = 'Palmer';
$labels['tz:antarctica:rothera'] = 'Rotera';
$labels['tz:antarctica:syowa'] = 'Shoua';
$labels['tz:antarctica:troll'] = 'Troll';
$labels['tz:antarctica:vostok'] = 'Vostok';
$labels['tz:arctic'] = 'Arktik';
$labels['tz:arctic:longyearbyen'] = 'Longjiërbajn';
$labels['tz:asia'] = 'Azi';
$labels['tz:asia:aden'] = 'Aden';
$labels['tz:asia:almaty'] = 'Almati';
$labels['tz:asia:amman'] = 'Aman';
$labels['tz:asia:anadyr'] = 'Anadir';
$labels['tz:asia:aqtau'] = 'Aktau';
$labels['tz:asia:aqtobe'] = 'Aktobe';
$labels['tz:asia:ashgabat'] = 'Ashkabad';
$labels['tz:asia:atyrau'] = 'Atirau';
$labels['tz:asia:baghdad'] = 'Bagdad';
$labels['tz:asia:bahrain'] = 'Bahrein';
$labels['tz:asia:baku'] = 'Baku';
$labels['tz:asia:bangkok'] = 'Bangkok';
$labels['tz:asia:barnaul'] = 'Barnaul';
$labels['tz:asia:beirut'] = 'Bejrut';
$labels['tz:asia:bishkek'] = 'Bishkek';
$labels['tz:asia:brunei'] = 'Brunei ';
$labels['tz:asia:chita'] = 'Çita';
$labels['tz:asia:choibalsan'] = 'Çoibalsan';
$labels['tz:asia:colombo'] = 'Kolombo';
$labels['tz:asia:damascus'] = 'Damask';
$labels['tz:asia:dhaka'] = 'Daka';
$labels['tz:asia:dili'] = 'Dili';
$labels['tz:asia:dubai'] = 'Dubai';
$labels['tz:asia:dushanbe'] = 'Dushanbe';
$labels['tz:asia:famagusta'] = 'Famagusta';
$labels['tz:asia:gaza'] = 'Gaza';
$labels['tz:asia:hebron'] = 'Hebron';
$labels['tz:asia:ho_chi_minh'] = 'Ho Shi Min';
$labels['tz:asia:hong_kong'] = 'Hong Kong';
$labels['tz:asia:hovd'] = 'Hovd';
$labels['tz:asia:irkutsk'] = 'Irkutsk';
$labels['tz:asia:jakarta'] = 'Xhakartë';
$labels['tz:asia:jayapura'] = 'Jajapura';
$labels['tz:asia:jerusalem'] = 'Jeruzalem';
$labels['tz:asia:kabul'] = 'Kabul';
$labels['tz:asia:kamchatka'] = 'Kamçatkë';
$labels['tz:asia:karachi'] = 'Karaçi';
$labels['tz:asia:kathmandu'] = 'Katmandu';
$labels['tz:asia:khandyga'] = 'Kandiga';
$labels['tz:asia:kolkata'] = 'Kalkuta';
$labels['tz:asia:krasnoyarsk'] = 'Krasnojarsk';
$labels['tz:asia:kuala_lumpur'] = 'Kuala Lumpur';
$labels['tz:asia:kuching'] = 'Kuçing';
$labels['tz:asia:kuwait'] = 'Kuvajt';
$labels['tz:asia:macau'] = 'Makau';
$labels['tz:asia:magadan'] = 'Magadan';
$labels['tz:asia:makassar'] = 'Makasar';
$labels['tz:asia:manila'] = 'Manila';
$labels['tz:asia:muscat'] = 'Muskat';
$labels['tz:asia:nicosia'] = 'Nikosia';
$labels['tz:asia:novokuznetsk'] = 'Novokuznjeck';
$labels['tz:asia:novosibirsk'] = 'Novosibirsk';
$labels['tz:asia:omsk'] = 'Omsk';
$labels['tz:asia:oral'] = 'Oral';
$labels['tz:asia:phnom_penh'] = 'Pnom Pen';
$labels['tz:asia:pontianak'] = 'Pontianak';
$labels['tz:asia:pyongyang'] = 'Pjongiang';
$labels['tz:asia:qatar'] = 'Katar';
$labels['tz:asia:qyzylorda'] = 'Qyzylorda';
$labels['tz:asia:riyadh'] = 'Riad';
$labels['tz:asia:sakhalin'] = 'Sakalin';
$labels['tz:asia:samarkand'] = 'Samarkand';
$labels['tz:asia:seoul'] = 'Seul';
$labels['tz:asia:shanghai'] = 'Shangai';
$labels['tz:asia:singapore'] = 'Singapor';
$labels['tz:asia:srednekolymsk'] = 'Srednekolimsk';
$labels['tz:asia:taipei'] = 'Tajpei  ';
$labels['tz:asia:tashkent'] = 'Tashkent';
$labels['tz:asia:tbilisi'] = 'Tbilis';
$labels['tz:asia:tehran'] = 'Teheran';
$labels['tz:asia:thimphu'] = 'Timpu';
$labels['tz:asia:tokyo'] = 'Tokio';
$labels['tz:asia:tomsk'] = 'Tomsk';
$labels['tz:asia:ulaanbaatar'] = 'Ulan Bator';
$labels['tz:asia:urumqi'] = 'Urumki';
$labels['tz:asia:ust-nera'] = 'Ust-Nera';
$labels['tz:asia:vientiane'] = 'Vientiane';
$labels['tz:asia:vladivostok'] = 'Vladivostok';
$labels['tz:asia:yakutsk'] = 'Jakutsk';
$labels['tz:asia:yangon'] = 'Jangon';
$labels['tz:asia:yekaterinburg'] = 'Jekaterinburg';
$labels['tz:asia:yerevan'] = 'Erevan';
$labels['tz:atlantic'] = 'Atlantik';
$labels['tz:atlantic:azores'] = 'Azore';
$labels['tz:atlantic:bermuda'] = 'Bermuda';
$labels['tz:atlantic:canary'] = 'Kanarie';
$labels['tz:atlantic:cape_verde'] = 'Kepi i Gjelbër';
$labels['tz:atlantic:faroe'] = 'Faroe';
$labels['tz:atlantic:madeira'] = 'Madeira';
$labels['tz:atlantic:reykjavik'] = 'Reikjavik';
$labels['tz:atlantic:south_georgia'] = 'Xhorxhia e Jjugut';
$labels['tz:atlantic:st_helena'] = 'Shën Elena';
$labels['tz:atlantic:stanley'] = 'Stanli';
$labels['tz:australia'] = 'Australi';
$labels['tz:australia:adelaide'] = 'Adelaide';
$labels['tz:australia:brisbane'] = 'Brisbën';
$labels['tz:australia:broken_hill'] = 'Brokën Hill';
$labels['tz:australia:currie'] = 'Kurri';
$labels['tz:australia:darwin'] = 'Darvin';
$labels['tz:australia:eucla'] = 'Jukla';
$labels['tz:australia:hobart'] = 'Hobart';
$labels['tz:australia:lindeman'] = 'Lindeman';
$labels['tz:australia:lord_howe'] = 'Lord Hou';
$labels['tz:australia:melbourne'] = 'Melburn';
$labels['tz:australia:perth'] = 'Përth';
$labels['tz:australia:sydney'] = 'Sidni';
$labels['tz:europe'] = 'Europë';
$labels['tz:europe:amsterdam'] = 'Amsterdam';
$labels['tz:europe:andorra'] = 'Andorra';
$labels['tz:europe:astrakhan'] = 'Astrakan';
$labels['tz:europe:athens'] = 'Athinë';
$labels['tz:europe:belgrade'] = 'Beograd';
$labels['tz:europe:berlin'] = 'Berlin';
$labels['tz:europe:bratislava'] = 'Bratislavë';
$labels['tz:europe:brussels'] = 'Bruksel';
$labels['tz:europe:bucharest'] = 'Bukuresht';
$labels['tz:europe:budapest'] = 'Budapest';
$labels['tz:europe:busingen'] = 'Busingen';
$labels['tz:europe:chisinau'] = 'Kishinau';
$labels['tz:europe:copenhagen'] = 'Kopenhagen';
$labels['tz:europe:dublin'] = 'Dublin';
$labels['tz:europe:gibraltar'] = 'Gjibraltar';
$labels['tz:europe:guernsey'] = 'Gernsi';
$labels['tz:europe:helsinki'] = 'Helsinki';
$labels['tz:europe:isle_of_man'] = 'Ishulli i Robit';
$labels['tz:europe:istanbul'] = 'Stamboll';
$labels['tz:europe:jersey'] = 'Xhërsi';
$labels['tz:europe:kaliningrad'] = 'Kaliningrad';
$labels['tz:europe:kiev'] = 'Kiev';
$labels['tz:europe:kirov'] = 'Kirov';
$labels['tz:europe:lisbon'] = 'Lisbonë';
$labels['tz:europe:ljubljana'] = 'Ljubljanë';
$labels['tz:europe:london'] = 'Londër';
$labels['tz:europe:luxembourg'] = 'Luksemburg';
$labels['tz:europe:madrid'] = 'Madrid';
$labels['tz:europe:malta'] = 'Maltë';
$labels['tz:europe:mariehamn'] = 'Merihamn';
$labels['tz:europe:minsk'] = 'Minsk';
$labels['tz:europe:monaco'] = 'Monako';
$labels['tz:europe:moscow'] = 'Moskë';
$labels['tz:europe:oslo'] = 'Oslo';
$labels['tz:europe:paris'] = 'Paris';
$labels['tz:europe:podgorica'] = 'Podgoricë';
$labels['tz:europe:prague'] = 'Pragë';
$labels['tz:europe:riga'] = 'Rigë';
$labels['tz:europe:rome'] = 'Romë';
$labels['tz:europe:samara'] = 'Samara';
$labels['tz:europe:san_marino'] = 'San Marino';
$labels['tz:europe:sarajevo'] = 'Sarajevë';
$labels['tz:europe:saratov'] = 'Saratov';
$labels['tz:europe:simferopol'] = 'Simferopol';
$labels['tz:europe:skopje'] = 'Shkup';
$labels['tz:europe:sofia'] = 'Sofje';
$labels['tz:europe:stockholm'] = 'Stokholm';
$labels['tz:europe:tallinn'] = 'Talin';
$labels['tz:europe:tirane'] = 'Tiranë';
$labels['tz:europe:ulyanovsk'] = 'Uljanovsk';
$labels['tz:europe:uzhgorod'] = 'Uzhgorod';
$labels['tz:europe:vaduz'] = 'Vaduz';
$labels['tz:europe:vatican'] = 'Vatikan';
$labels['tz:europe:vienna'] = 'Vjenë';
$labels['tz:europe:vilnius'] = 'Vilnius';
$labels['tz:europe:volgograd'] = 'Volgograd';
$labels['tz:europe:warsaw'] = 'Varshavë';
$labels['tz:europe:zagreb'] = 'Zagreb';
$labels['tz:europe:zaporozhye'] = 'Zaporozhje';
$labels['tz:europe:zurich'] = 'Zyrih ';
$labels['tz:indian'] = 'Indian';
$labels['tz:indian:antananarivo'] = 'Antananarivo';
$labels['tz:indian:chagos'] = 'Çagos';
$labels['tz:indian:christmas'] = 'Kërshëndellat';
$labels['tz:indian:cocos'] = 'Kokos';
$labels['tz:indian:comoro'] = 'Komoro';
$labels['tz:indian:kerguelen'] = 'Kerguelen';
$labels['tz:indian:mahe'] = 'Mahe';
$labels['tz:indian:maldives'] = 'Maldive';
$labels['tz:indian:mauritius'] = 'Mauricius';
$labels['tz:indian:mayotte'] = 'Majote';
$labels['tz:indian:reunion'] = 'Reunion';
$labels['tz:pacific'] = 'Paqësor';
$labels['tz:pacific:apia'] = 'Apia';
$labels['tz:pacific:auckland'] = 'Okland';
$labels['tz:pacific:bougainville'] = 'Bugënvil';
$labels['tz:pacific:chatham'] = 'Çatëm';
$labels['tz:pacific:chuuk'] = 'Çuk';
$labels['tz:pacific:easter'] = 'Pashkët';
$labels['tz:pacific:efate'] = 'Efate';
$labels['tz:pacific:enderbury'] = 'Endërbëry';
$labels['tz:pacific:fakaofo'] = 'Fakaofo';
$labels['tz:pacific:fiji'] = 'Fixhi';
$labels['tz:pacific:funafuti'] = 'Funafuti';
$labels['tz:pacific:galapagos'] = 'Galapagos';
$labels['tz:pacific:gambier'] = 'Gambier';
$labels['tz:pacific:guadalcanal'] = 'Guadalkanal';
$labels['tz:pacific:guam'] = 'Guam';
$labels['tz:pacific:honolulu'] = 'Honolulu';
$labels['tz:pacific:johnston'] = 'Xhonston';
$labels['tz:pacific:kiritimati'] = 'Kiritimati';
$labels['tz:pacific:kosrae'] = 'Kosrae';
$labels['tz:pacific:kwajalein'] = 'Kuaxhëlin';
$labels['tz:pacific:majuro'] = 'Maxhuro';
$labels['tz:pacific:marquesas'] = 'Markezat';
$labels['tz:pacific:midway'] = 'Miduei';
$labels['tz:pacific:nauru'] = 'Nauru';
$labels['tz:pacific:niue'] = 'Niue';
$labels['tz:pacific:norfolk'] = 'Norfolk';
$labels['tz:pacific:noumea'] = 'Numea';
$labels['tz:pacific:pago_pago'] = 'Pago Pago';
$labels['tz:pacific:palau'] = 'Palau';
$labels['tz:pacific:pitcairn'] = 'Pitkern';
$labels['tz:pacific:pohnpei'] = 'Ponpei';
$labels['tz:pacific:port_moresby'] = 'Port Moresbi';
$labels['tz:pacific:rarotonga'] = 'Rarotonga';
$labels['tz:pacific:saipan'] = 'Saipan';
$labels['tz:pacific:tahiti'] = 'Tahiti';
$labels['tz:pacific:tarawa'] = 'Taraua';
$labels['tz:pacific:tongatapu'] = 'Tongatapu';
$labels['tz:pacific:wake'] = 'Ueik';
$labels['tz:pacific:wallis'] = 'Ualis';
