<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Добре дошли в $product';
$labels['username'] = 'Потребител';
$labels['password'] = 'Парола';
$labels['server'] = 'Сървър';
$labels['login'] = 'Вход';
$labels['oauthlogin'] = 'Вход с $provider';
$labels['menu'] = 'Меню';
$labels['logout'] = 'Изход';
$labels['mail'] = 'Поща';
$labels['settings'] = 'Настройки';
$labels['addressbook'] = 'Адресна книга';
$labels['darkmode'] = 'Тъмен режим';
$labels['lightmode'] = 'Светъл режим';
$labels['inbox'] = 'Входящи';
$labels['drafts'] = 'Чернови';
$labels['sent'] = 'Изпратени';
$labels['trash'] = 'Кошче';
$labels['junk'] = 'Спам';
$labels['show_real_foldernames'] = 'Показва истинските имена на служебните папки';
$labels['subject'] = 'Заглавие';
$labels['from'] = 'От';
$labels['sender'] = 'Подател';
$labels['to'] = 'До';
$labels['cc'] = 'Копие до';
$labels['bcc'] = 'Скрито копие до';
$labels['replyto'] = 'Отговор до';
$labels['followupto'] = 'Препращане към';
$labels['date'] = 'Дата';
$labels['size'] = 'Размер';
$labels['priority'] = 'Приоритет';
$labels['organization'] = 'Организация';
$labels['readstatus'] = 'Статус (прочетено/ново)';
$labels['listoptions'] = 'Настройки на списък...';
$labels['listoptionstitle'] = 'Настройки на списък';
$labels['mailboxlist'] = 'Папки';
$labels['messagesfromto'] = 'Писма $from до $to от $count';
$labels['threadsfromto'] = 'Кореспонденции $from до $to от $count';
$labels['messagenrof'] = 'Писмо $nr от $count';
$labels['fromtoshort'] = '$from – $to от $count';
$labels['copy'] = 'Копиране';
$labels['move'] = 'Преместване';
$labels['moveto'] = 'Премести във...';
$labels['copyto'] = 'Копирай във...';
$labels['download'] = 'Изтегли';
$labels['open'] = 'Отвори';
$labels['showattachment'] = 'Покажи';
$labels['showanyway'] = 'Показване въпреки това';
$labels['filename'] = 'Име на файла';
$labels['filesize'] = 'Размер на файла';
$labels['addtoaddressbook'] = 'Добави в адресната книга';
$labels['sun'] = 'Нед';
$labels['mon'] = 'Пон';
$labels['tue'] = 'Вто';
$labels['wed'] = 'Сря';
$labels['thu'] = 'Чет';
$labels['fri'] = 'Пет';
$labels['sat'] = 'Съб';
$labels['sunday'] = 'Неделя';
$labels['monday'] = 'Понеделник';
$labels['tuesday'] = 'Вторник';
$labels['wednesday'] = 'Сряда';
$labels['thursday'] = 'Четвъртък';
$labels['friday'] = 'Петък';
$labels['saturday'] = 'Събота';
$labels['jan'] = 'Яну';
$labels['feb'] = 'Фев';
$labels['mar'] = 'Мар';
$labels['apr'] = 'Апр';
$labels['may'] = 'Май';
$labels['jun'] = 'Юни';
$labels['jul'] = 'Юли';
$labels['aug'] = 'Авг';
$labels['sep'] = 'Сеп';
$labels['oct'] = 'Окт';
$labels['nov'] = 'Ное';
$labels['dec'] = 'Дек';
$labels['longjan'] = 'Януари';
$labels['longfeb'] = 'Февруари';
$labels['longmar'] = 'Март';
$labels['longapr'] = 'Април';
$labels['longmay'] = 'Май';
$labels['longjun'] = 'Юни';
$labels['longjul'] = 'Юли';
$labels['longaug'] = 'Август';
$labels['longsep'] = 'Септември';
$labels['longoct'] = 'Октомври';
$labels['longnov'] = 'Ноември';
$labels['longdec'] = 'Декември';
$labels['today'] = 'Днес';
$labels['refresh'] = 'Обнови';
$labels['checkmail'] = 'Провери за нова поща';
$labels['compose'] = 'Напиши';
$labels['writenewmessage'] = 'Създай ново писмо';
$labels['reply'] = 'Отговор';
$labels['replytomessage'] = 'Отговори на подателя';
$labels['replytoallmessage'] = 'Отговори на списъка или на подателя и всички получатели';
$labels['replyall'] = 'Отговор на всички';
$labels['replylist'] = 'Отговор на списък';
$labels['forward'] = 'Препрати';
$labels['forwardinline'] = 'Препрати като цитат в писмото';
$labels['forwardattachment'] = 'Препрати като прикачен файл';
$labels['forwardmessage'] = 'Препрати писмото';
$labels['bouncemsg'] = 'Повторно изпращане (bounce)';
$labels['bounce'] = 'Повторно изпращане';
$labels['deletemessage'] = 'Изтрий писмото';
$labels['movemessagetotrash'] = 'Премести писмото в Кошче';
$labels['printmessage'] = 'Печат на писмото';
$labels['previousmessage'] = 'Предишно писмо';
$labels['firstmessage'] = 'Първо писмо';
$labels['nextmessage'] = 'Следващо писмо';
$labels['lastmessage'] = 'Последно писмо';
$labels['backtolist'] = 'Обратно към списъка';
$labels['viewsource'] = 'Покажи изходния код';
$labels['mark'] = 'Маркирай';
$labels['markmessages'] = 'Маркирай писмата';
$labels['markread'] = 'Като прочетени';
$labels['markunread'] = 'Като нови';
$labels['markflagged'] = 'Като отбелязани';
$labels['markunflagged'] = 'Като неотбелязани';
$labels['moreactions'] = 'Допълнителни действия...';
$labels['markallread'] = 'Маркирай всички като прочетени';
$labels['folders-cur'] = 'Само за избраната папка';
$labels['folders-sub'] = 'Избраната папка и всички подпапки';
$labels['folders-all'] = 'Всички папки';
$labels['more'] = 'Още';
$labels['back'] = 'Назад';
$labels['options'] = 'Настройки';
$labels['composeoptions'] = 'Настройки за писане';
$labels['optionsandattachments'] = 'Настройки и прикачени файлове';
$labels['actions'] = 'Действия';
$labels['first'] = 'Първо';
$labels['last'] = 'Последно';
$labels['previous'] = 'Предишно';
$labels['next'] = 'Следващо';
$labels['select'] = 'Избери';
$labels['selection'] = 'Селекция';
$labels['all'] = 'Всички';
$labels['none'] = 'Остави без избор';
$labels['currpage'] = 'Всички на страницата';
$labels['isread'] = 'Прочетено';
$labels['unread'] = 'Нови';
$labels['flagged'] = 'Отбелязани';
$labels['unflagged'] = 'Без флаг';
$labels['unanswered'] = 'Без отговор';
$labels['withattachment'] = 'С прикачен файл';
$labels['deleted'] = 'Всички изтрити';
$labels['undeleted'] = 'Които не са изтрити';
$labels['replied'] = 'Отговорено';
$labels['forwarded'] = 'Препратено';
$labels['invert'] = 'Които не са избрани';
$labels['filter'] = 'Филтър';
$labels['list'] = 'Списък';
$labels['threads'] = 'Кореспонденции';
$labels['expand-all'] = 'Разгъни всички';
$labels['expand-unread'] = 'Разгъни непрочетените';
$labels['collapse-all'] = 'Сгъни всички';
$labels['threaded'] = 'Групирани по кореспонденции';
$labels['showunread'] = 'Покажи непрочетените писма';
$labels['autoexpand_threads'] = 'Разгъни кореспонденции';
$labels['do_expand'] = 'всички кореспонденции';
$labels['expand_only_unread'] = 'само с непрочетени писма';
$labels['fromto'] = 'От/До';
$labels['flag'] = 'Отбелязано';
$labels['attachment'] = 'Прикачен файл';
$labels['nonesort'] = 'Няма';
$labels['sentdate'] = 'Дата на изпращане';
$labels['arrival'] = 'Дата на получаване';
$labels['asc'] = 'нарастваща';
$labels['desc'] = 'намаляваща';
$labels['listcolumns'] = 'Колони на списък';
$labels['listsorting'] = 'Подреди по колона';
$labels['listorder'] = 'Посока на подреждане';
$labels['listmode'] = 'Изглед на списък';
$labels['lmode'] = 'Режим на списък';
$labels['layout'] = 'Оформление';
$labels['layoutwidescreen'] = 'Широк екран';
$labels['layoutdesktop'] = 'Настолен екран';
$labels['layoutlist'] = 'Списък';
$labels['layoutwidescreendesc'] = 'Широк екран (изглед с 3 колони)';
$labels['layoutdesktopdesc'] = 'Настолен екран (широк списък и преглед на пощата по-долу)';
$labels['layoutlistdesc'] = 'Списък (без преглед на пощата)';
$labels['folderactions'] = 'Действия за папки...';
$labels['compact'] = 'Уплътни данни';
$labels['empty'] = 'Изпразни';
$labels['importmessages'] = 'Импорт на писма';
$labels['mailimportdesc'] = 'Можете да качвате поща като използвате файлове във формат <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> или <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>.';
$labels['mailimportzip'] = 'Няколко файла могат да бъдат компресирани в zip архиви.';
$labels['quota'] = 'Използвано място';
$labels['unknown'] = 'няма информация';
$labels['unlimited'] = 'без ограничение';
$labels['quotatype'] = 'Тип квота';
$labels['quotatotal'] = 'Лимит';
$labels['quotaused'] = 'Използвано';
$labels['quotastorage'] = 'Дисково пространство';
$labels['quotamessage'] = 'Брой писма';
$labels['shortheaderdate'] = 'На $date';
$labels['shortheaderto'] = 'До $to на $date';
$labels['shortheaderfrom'] = 'От $from на $date';
$labels['quicksearch'] = 'Бързо търсене';
$labels['searchplaceholder'] = 'Търсене...';
$labels['resetsearch'] = 'Изчисти филтър и покажи всичко';
$labels['searchmod'] = 'Филтър по';
$labels['msgtext'] = 'Цялото писмо';
$labels['body'] = 'Основен текст';
$labels['type'] = 'Тип';
$labels['namex'] = 'Име';
$labels['searchscope'] = 'Обхват';
$labels['currentfolder'] = 'Текуща папка';
$labels['subfolders'] = 'Тази и подпапките';
$labels['allfolders'] = 'Всички папки';
$labels['searchinterval-1W'] = 'по-стари от седмица';
$labels['searchinterval-1M'] = 'по-стари от месец';
$labels['searchinterval-1Y'] = 'по-стари от година';
$labels['searchinterval1W'] = 'по-нови от седмица';
$labels['searchinterval1M'] = 'по-нови от месец';
$labels['searchinterval1Y'] = 'по-нови от година';
$labels['openinextwin'] = 'Отвори в нов прозорец';
$labels['emlsave'] = 'Изтегли (.eml)';
$labels['changeformattext'] = 'Покажи в текстов формат';
$labels['changeformathtml'] = 'Покажи в HTML формат';
$labels['editasnew'] = 'Редактирай като ново';
$labels['send'] = 'Изпрати';
$labels['sendmessage'] = 'Изпрати писмото';
$labels['savemessage'] = 'Запиши като чернова';
$labels['addattachment'] = 'Прикачване на файл';
$labels['charset'] = 'Кодова таблица';
$labels['editortype'] = 'Вид редактор';
$labels['returnreceipt'] = 'Обратна разписка';
$labels['dsn'] = 'Нотификация при доставка';
$labels['mailreplyintro'] = 'На $date, $sender написа:';
$labels['originalmessage'] = 'Оригинално писмо';
$labels['selectimage'] = 'Избери изображение';
$labels['addimage'] = 'Добави изображение';
$labels['selectmedia'] = 'Избери клип';
$labels['addmedia'] = 'Добави клип';
$labels['encrypt'] = 'Криптиране';
$labels['encryptmessage'] = 'Криптирай писмо';
$labels['encryptmessagemailvelope'] = 'Криптирай писмо с Mailvelope';
$labels['importpubkeys'] = 'Внасяне на публични ключове';
$labels['encryptedsendialog'] = 'Изпращане на криптирано писмо';
$labels['encryptandsign'] = 'Криптиране и подписване';
$labels['keyid'] = 'ИН на ключ';
$labels['keylength'] = 'Бита';
$labels['keyexpired'] = 'Изтекъл';
$labels['keyrevoked'] = 'Отменен';
$labels['bccinstead'] = 'Използвай Скрито копие до';
$labels['addheader'] = 'Добави получател (заглавен блок)';
$labels['insert'] = 'Вмъкване';
$labels['insertcontact'] = 'Вмъкване на контакт(и)';
$labels['recipient'] = 'Получател';
$labels['recipientedit'] = 'Редактиране на получател';
$labels['editidents'] = 'Промени самоличности';
$labels['spellcheck'] = 'Правопис';
$labels['checkspelling'] = 'Проверка на правописа';
$labels['resumeediting'] = 'Продължи черновата';
$labels['revertto'] = 'Върни се към';
$labels['restore'] = 'Възстанови';
$labels['restoremessage'] = 'Възстановяване на съобщението?';
$labels['ignore'] = 'Игнорирай';
$labels['responses'] = 'Отговори';
$labels['insertresponse'] = 'Вмъкване на отговор';
$labels['manageresponses'] = 'Настройка на отговори';
$labels['newresponse'] = 'Създай нов отговор';
$labels['addresponse'] = 'Добавяне на отговор';
$labels['editresponse'] = 'Редакция на отговор';
$labels['editresponses'] = 'Редакция на отговори';
$labels['responsename'] = 'Име';
$labels['responsetext'] = 'Текст на отговор';
$labels['attach'] = 'Прикачи';
$labels['attachments'] = 'Прикачени файлове';
$labels['upload'] = 'Качи';
$labels['uploadprogress'] = '$percent ($current от $total)';
$labels['close'] = 'Затвори';
$labels['messageoptions'] = 'Настройки на писма...';
$labels['togglecomposeoptions'] = 'Превключване опции за създаване';
$labels['attachmentrename'] = 'Преименуване на прикачен файл';
$labels['low'] = 'Нисък';
$labels['lowest'] = 'Най-нисък';
$labels['normal'] = 'Нормален';
$labels['high'] = 'Висок';
$labels['highest'] = 'Най-висок';
$labels['nosubject'] = '(няма заглавие)';
$labels['showimages'] = 'Показвай изображения';
$labels['allow'] = 'Разреши';
$labels['alwaysshow'] = 'Винаги показвай изображения от $sender';
$labels['alwaysallow'] = 'Винаги разрешавай от $sender';
$labels['isdraft'] = 'Това писмо е чернова.';
$labels['andnmore'] = 'още $nr...';
$labels['details'] = 'Детайли';
$labels['summary'] = 'Резюме';
$labels['headers'] = 'Заглавни блокове';
$labels['allheaders'] = 'Всички заглавни блокове';
$labels['togglemoreheaders'] = 'Покажи още заглавни блокове';
$labels['togglefullheaders'] = 'Изходни заглавни блокове';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Текстово';
$labels['savesentmessagein'] = 'Запази изпратеното писмо в';
$labels['dontsave'] = 'не запазвай';
$labels['maxuploadsize'] = 'Максимален размер на файл е $size';
$labels['addcc'] = 'Добави Копие до';
$labels['addbcc'] = 'Добави Скрито копие до';
$labels['addreplyto'] = 'Добави Отговор до';
$labels['addfollowupto'] = 'Добави Препращане към';
$labels['sendreceipt'] = 'Да се ​​изпрати ли обратна разписка?';
$labels['mdnrequest'] = 'Подателят е поискал да бъде уведомен, че сте прочели това писмо. Желаете ли да изпратите обратна разписка?';
$labels['receiptread'] = 'Обратна разписка (прочетено)';
$labels['yourmessage'] = 'Това е обратна разписка относно писмото Ви';
$labels['receiptnote'] = 'Забележка: Тази разписка потвърждава само, че писмото е било визуализирано на екрана на получателят. Няма никаква гаранция, че той е разбрал и/или дори прочел неговото съдържание.';
$labels['sendalwaysto'] = 'Винаги изпращай до $email';
$labels['zoomin'] = 'Увеличаване';
$labels['zoomout'] = 'Намаляване';
$labels['rotate'] = 'Завъртане';
$labels['increaseimage'] = 'Увеличаване размера на изображението';
$labels['decreaseimage'] = 'Намаляване размера на изображението';
$labels['rotateimage'] = 'Завъртане на изображението';
$labels['showtools'] = 'Показване на инструменти за изображения';
$labels['hidetools'] = 'Скриване на инструменти за изображения';
$labels['name'] = 'Екранно име';
$labels['firstname'] = 'Име';
$labels['surname'] = 'Фамилия';
$labels['middlename'] = 'Презиме';
$labels['nameprefix'] = 'Титла';
$labels['namesuffix'] = 'Наставка';
$labels['nickname'] = 'Псевдоним';
$labels['jobtitle'] = 'Длъжност';
$labels['department'] = 'Отдел';
$labels['gender'] = 'Пол';
$labels['maidenname'] = 'Моминско име';
$labels['email'] = 'Ел. поща';
$labels['phone'] = 'Телефон';
$labels['address'] = 'Адрес';
$labels['street'] = 'Улица';
$labels['locality'] = 'Град';
$labels['zipcode'] = 'Пощенски код';
$labels['region'] = 'Област';
$labels['country'] = 'Държава';
$labels['birthday'] = 'Рожден ден';
$labels['anniversary'] = 'Дата годишнина';
$labels['website'] = 'Сайт';
$labels['instantmessenger'] = 'Месинджър';
$labels['notes'] = 'Бележки';
$labels['male'] = 'мъж';
$labels['female'] = 'жена';
$labels['manager'] = 'Мениджър';
$labels['assistant'] = 'Асистент';
$labels['spouse'] = 'Съпруг(а)';
$labels['allfields'] = 'Всички полета';
$labels['search'] = 'Търсене';
$labels['searchresult'] = 'Резултат от търсене';
$labels['advsearch'] = 'Разширено търсене';
$labels['advanced'] = 'Търси';
$labels['other'] = 'Други';
$labels['printcontact'] = 'Печат на контакт';
$labels['qrcode'] = 'QR Код';
$labels['typehome'] = 'Домашен';
$labels['typework'] = 'Служебен';
$labels['typeother'] = 'Друг';
$labels['typemobile'] = 'Мобилен';
$labels['typemain'] = 'Основен';
$labels['typehomefax'] = 'Домашен факс';
$labels['typeworkfax'] = 'Служебен факс';
$labels['typecar'] = 'В колата';
$labels['typepager'] = 'Пейджър';
$labels['typevideo'] = 'Със видео';
$labels['typeassistant'] = 'На асистент';
$labels['typehomepage'] = 'Личен';
$labels['typeblog'] = 'Блог';
$labels['typeprofile'] = 'Профил';
$labels['addfield'] = 'Добави поле...';
$labels['addcontact'] = 'Добави контакт';
$labels['editcontact'] = 'Редактирай контакт';
$labels['contacts'] = 'Контакти';
$labels['contactproperties'] = 'Данни на контакт';
$labels['contactnameandorg'] = 'Име и Организация';
$labels['personalinfo'] = 'Лична информация';
$labels['personal'] = 'Лична';
$labels['contactphoto'] = 'Снимка на контакт';
$labels['edit'] = 'Редактирай';
$labels['cancel'] = 'Отказ';
$labels['save'] = 'Запис';
$labels['delete'] = 'Изтрий';
$labels['discard'] = 'Изхвърли';
$labels['continue'] = 'Продължи';
$labels['ok'] = 'ОК';
$labels['rename'] = 'Преименувай';
$labels['addphoto'] = 'Добави';
$labels['replacephoto'] = 'Замени';
$labels['uploadphoto'] = 'Качване на снимка';
$labels['choosefile'] = 'Изберете файл...';
$labels['choosefiles'] = 'Изберете файлове...';
$labels['browse'] = 'Преглед';
$labels['newcontact'] = 'Създай нов контакт';
$labels['deletecontact'] = 'Изтрий избраните контакти';
$labels['composeto'] = 'Напиши писмо до';
$labels['contactsfromto'] = 'Контакти $from до $to от $count';
$labels['print'] = 'Печат';
$labels['export'] = 'Експорт';
$labels['exportall'] = 'Експортиране на всичко';
$labels['exportsel'] = 'Експортиране на избраното';
$labels['exportvcards'] = 'Експорт във vCard формат';
$labels['newgroup'] = 'Създай нова група';
$labels['addgroup'] = 'Добави група';
$labels['grouprename'] = 'Преименувай групата';
$labels['groupdelete'] = 'Изтрий групата';
$labels['groupassign'] = 'Добави към група...';
$labels['groupremove'] = 'Премахни от групата';
$labels['groupremoveselected'] = 'Премахни избраните контакти от групата';
$labels['uponelevel'] = 'Нагоре едно ниво';
$labels['previouspage'] = 'Предишна страница';
$labels['firstpage'] = 'Първа страница';
$labels['nextpage'] = 'Следваща страница';
$labels['lastpage'] = 'Последна страница';
$labels['group'] = 'Група';
$labels['groups'] = 'Групи';
$labels['listgroup'] = 'Покажи членове на групата';
$labels['personaladrbook'] = 'Лични адреси';
$labels['searchsave'] = 'Запази филтър';
$labels['searchdelete'] = 'Изтрий филтър';
$labels['import'] = 'Импорт';
$labels['importcontacts'] = 'Импортиране на контакти';
$labels['importfromfile'] = 'Импорт от файл';
$labels['importtarget'] = 'Добави контакти към';
$labels['importreplace'] = 'Замени цялата адресна книга';
$labels['importgroups'] = 'Импорт на задачи на група';
$labels['importgroupsall'] = 'Всички (създава групи ако е необходимо)';
$labels['importgroupsexisting'] = 'Само за съществуващите групи';
$labels['importdesc'] = 'Можете да качвате контакти от съществуваща адресна книга.<br/>В момента поддържаме импорт на адреси от формати <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> или CSV (comma-separated).';
$labels['importmapdesc'] = 'Уверете се, че информацията за свързване на полето по-долу е вярна, преди да продължите с импортирането на CSV (разделени със запетая) данни';
$labels['fieldnotmapped'] = 'Полето не е свързано (не импортирай)';
$labels['skipheader'] = 'Не импортирай първия ред (заглавки)';
$labels['done'] = 'Готово';
$labels['settingsfor'] = 'Настройки за';
$labels['about'] = 'Относно';
$labels['preferences'] = 'Настройки';
$labels['userpreferences'] = 'Потребителски настройки';
$labels['editpreferences'] = 'Редактирай потребителските настройки';
$labels['identities'] = 'Самоличности';
$labels['manageidentities'] = 'Управление самоличности';
$labels['newidentity'] = 'Създай нова самоличност';
$labels['addidentity'] = 'Добави самоличност';
$labels['editidentity'] = 'Редактирай самоличност';
$labels['identityencryption'] = 'Криптиране';
$labels['preferhtml'] = 'Покажи първо HTML версия';
$labels['defaultcharset'] = 'Кодова таблица по подразбиране';
$labels['htmlmessage'] = 'HTML писмо';
$labels['messagepart'] = 'Част';
$labels['digitalsig'] = 'Електронен Подпис';
$labels['dateformat'] = 'Формат на дати';
$labels['timeformat'] = 'Формат на време';
$labels['prettydate'] = 'Удобни дати';
$labels['setdefault'] = 'По подразбиране';
$labels['autodetect'] = 'Автоматично';
$labels['language'] = 'Език';
$labels['timezone'] = 'Часова зона';
$labels['pagesize'] = 'Редове на страница';
$labels['signature'] = 'Подпис';
$labels['dstactive'] = 'Маркирай при лятно време';
$labels['showinextwin'] = 'Отваряй писмата в отделен прозорец';
$labels['composeextwin'] = 'Писане на ново писмо в отделен прозорец';
$labels['htmleditor'] = 'Писане на ново писмо като HTML';
$labels['htmlonreply'] = 'само при отговор на HTML писмо';
$labels['htmlonreplyandforward'] = 'само при препращане или отговор на HTML писмо';
$labels['htmlsignature'] = 'HTML подпис';
$labels['showemail'] = 'Показва адрес на ел. поща с екранното име';
$labels['previewpane'] = 'Показване на панел за преглед';
$labels['skin'] = 'Изглед на потребителски интерфейс';
$labels['logoutclear'] = 'Изпразни Кошчето при изход';
$labels['logoutcompact'] = 'Уплътни данни във Входящи при изход';
$labels['uisettings'] = 'Потребителски интерфейс';
$labels['serversettings'] = 'Настройки на сървъра';
$labels['mailboxview'] = 'Изглед на пощенска кутия';
$labels['mdnrequests'] = 'При искане за обратна разписка';
$labels['askuser'] = 'задай въпрос';
$labels['autosend'] = 'изпрати автоматично винаги';
$labels['autosendknown'] = 'изпрати автоматично само на моите контакти, иначе задай въпрос';
$labels['autosendknownignore'] = 'изпрати автоматично само на моите контакти, иначе отхвърли';
$labels['autosendtrusted'] = 'изпращай разписка на доверените податели, в противен случай ме попитай';
$labels['autosendtrustedignore'] = 'изпращай разписка на доверените податели, в противен случай игнорирай';
$labels['ignorerequest'] = 'игнорирай искането';
$labels['readwhendeleted'] = 'Маркирай писмото като прочетено при изтриване';
$labels['flagfordeletion'] = 'Отбележи писмото за изтриване';
$labels['skipdeleted'] = 'Не показвай изтритите писма';
$labels['deletealways'] = 'При неуспешно местене на писмо в Кошче, изтрий директно';
$labels['deletejunk'] = 'В папка Спам изтривай писмата без местене в Кошче';
$labels['showremoteimages'] = 'Покажи вградени изображения';
$labels['allowremoteresources'] = 'Разрешаване на отдалечени ресурси (изображения, стилове)';
$labels['fromknownsenders'] = 'от познати податели';
$labels['fromtrustedsenders'] = 'от доверени податели';
$labels['frommycontacts'] = 'от моите контакти';
$labels['always'] = 'винаги';
$labels['alwaysbutplain'] = 'винаги, освен когато е отговор на текстов формат';
$labels['showinlineimages'] = 'Покажи прикачените изображения след писмото';
$labels['autosavedraft'] = 'Автоматично записвай чернова';
$labels['everynminutes'] = 'през $n минути';
$labels['refreshinterval'] = 'Проверявай за нова поща';
$labels['never'] = 'никога';
$labels['immediately'] = 'веднага';
$labels['messagesdisplaying'] = 'Показване на писма';
$labels['messagescomposition'] = 'Писане на писма';
$labels['mimeparamfolding'] = 'Имена на прикачени файлове';
$labels['2231folding'] = 'Според RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Според RFC 2047 (други)';
$labels['force7bit'] = 'Използване на MIME кодиране за 8-битови символи';
$labels['savelocalstorage'] = "Запазване в локално хранилище на баузъра (временно)";
$labels['advancedoptions'] = 'Разширени настройки';
$labels['toggleadvancedoptions'] = 'Превключване на разширени опции';
$labels['focusonnewmessage'] = 'Премигване на прозореца при ново писмо';
$labels['checkallfolders'] = 'Проверка за нови писма във всички папки ';
$labels['displaynext'] = 'Покажи следващия запис от списъка след изтриване/преместване';
$labels['defaultfont'] = 'Шрифт по подразбиране за HTML писма';
$labels['mainoptions'] = 'Основни настройки';
$labels['browseroptions'] = 'Настройки на текущ браузър';
$labels['section'] = 'Секция';
$labels['maintenance'] = 'Поддръжка папки';
$labels['newmessage'] = 'Ново писмо';
$labels['signatureoptions'] = 'Настройки на подпис';
$labels['whenreplying'] = 'При отговор на писмо';
$labels['replyempty'] = 'не цитирай оригиналното писмо';
$labels['replytopposting'] = 'започни новото писмо над цитата';
$labels['replytoppostingnoindent'] = 'започни новото писмо над цитата (no indentation)';
$labels['replybottomposting'] = 'започни новото писмо след цитата';
$labels['replyremovesignature'] = 'При отговор на писмо премахни предишния подпис';
$labels['autoaddsignature'] = 'Автоматично добавяй подпис';
$labels['newmessageonly'] = 'само на нови писма';
$labels['replyandforwardonly'] = 'само на отговори и препратени';
$labels['insertsignature'] = 'Вмъкване на подпис';
$labels['sigbelow'] = 'Постави подписа след цитираното съобщение';
$labels['sigseparator'] = 'Използвай стандартен разделител в подписите';
$labels['automarkread'] = 'Маркиране на писмата като прочетени';
$labels['afternseconds'] = 'след $n секунди';
$labels['reqmdn'] = 'Винаги изисквай обратна разписка';
$labels['reqdsn'] = 'Винаги изисквай статус доставка на писмото';
$labels['replysamefolder'] = 'Постави отговор в папка на писмото, на което се отговаря';
$labels['defaultabook'] = 'Адресна книга по подразбиране';
$labels['autocompletesingle'] = 'Пропусни алтернативни адреси на ел. поща при автоматично попълване';
$labels['listnamedisplay'] = 'Форматирай списък с контакти като';
$labels['contactformmode'] = 'Режим на форма за контакт';
$labels['privatemode'] = 'Личен (Домашен)';
$labels['businessmode'] = 'Бизнес (Служебен)';
$labels['collectedaddresses'] = 'Събрани адреси';
$labels['collectedrecipients'] = 'Събрани Получатели';
$labels['collectedrecipientsopt'] = 'Съхранявай получателите на изходящи писма в';
$labels['collectedsendersopt'] = 'Съхранявай доверените податели в';
$labels['trustedsenders'] = 'Доверени Податели';
$labels['spellcheckbeforesend'] = 'Провери за правописни грешки преди изпращане на писмото';
$labels['spellcheckoptions'] = 'Настройки на проверката за правопис';
$labels['spellcheckignoresyms'] = 'Игнорирай думи съдържащи символи';
$labels['spellcheckignorenums'] = 'Игнорирай думи съдържащи числа';
$labels['spellcheckignorecaps'] = 'Игнорирай думи съдържащи единствено главни букви';
$labels['addtodict'] = 'Добави в речника';
$labels['mailtoprotohandler'] = 'Регистрирай RoundCube като интернет приложение, което обработва mailto: връзките в браузъра';
$labels['standardwindows'] = 'Обработва изскачащи прозорци като стандартни прозорци';
$labels['forwardmode'] = 'Препращай писмата';
$labels['inline'] = 'цитирани в писмото';
$labels['asattachment'] = 'като прикачен файл';
$labels['replyallmode'] = 'Действие по подразбиране на бутон [Отговор на всички]';
$labels['replyalldefault'] = 'отговори на всички';
$labels['replyalllist'] = 'отговори само на пощенския списък (ако има)';
$labels['folder'] = 'Папка';
$labels['folders'] = 'Папки';
$labels['foldername'] = 'Име на папката';
$labels['subscribed'] = 'Абониран';
$labels['messagecount'] = 'Писма';
$labels['create'] = 'Създай';
$labels['createfolder'] = 'Нова папка';
$labels['managefolders'] = 'Управление на папките';
$labels['specialfolders'] = 'Служебни папки';
$labels['properties'] = 'Данни';
$labels['folderproperties'] = 'Свойства на папката';
$labels['parentfolder'] = 'Основна папка';
$labels['location'] = 'Местоположение';
$labels['info'] = 'Информация';
$labels['getfoldersize'] = 'Щракни за размер на папката';
$labels['changesubscription'] = 'Щракни за промяна на абонамент';
$labels['foldertype'] = 'Вид на папката';
$labels['personalfolder'] = 'Лична папка';
$labels['otherfolder'] = 'Папка на друг потребител';
$labels['sharedfolder'] = 'Публична папка';
$labels['findfolders'] = 'Търсене на папки';
$labels['findcontacts'] = 'Търсене на контакти';
$labels['findmail'] = 'Търсене на писма';
$labels['namespace.personal'] = 'Лична';
$labels['namespace.other'] = 'Други потребители';
$labels['namespace.shared'] = 'Споделена';
$labels['dualuselabel'] = 'Може да съдържа само';
$labels['dualusemail'] = 'писма';
$labels['dualusefolder'] = 'папки';
$labels['generate'] = 'Генериране';
$labels['encryptioncreatekey'] = 'Създай нова ключова двойка';
$labels['openmailvelopesettings'] = 'Отвори настройки на Mailvelope';
$labels['encryptionprivkeysinmailvelope'] = 'Имате $nr съвпадащи частни ключа, съхранени във вашия Mailvelope ключодържател:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Тази самоличност на подателя все още няма частен PGP ключ, съхраняван във вашето Mailvelope разширение. Искате ли да създадете такъв, за да използвате криптирани писма?';
$labels['encryption'] = 'Криптиране';
$labels['mailvelopeoptions'] = 'Настройки на Mailvelope';
$labels['mailvelopemainkeyring'] = 'Използвай основния ключодържател на Mailvelope';
$labels['mailvelopenotfound'] = 'Разширението Mailvelope не е активирано/инсталирано във вашия браузър.';
$labels['sortby'] = 'Сортирай по';
$labels['sortasc'] = 'Сортирай нарастващо';
$labels['sortdesc'] = 'Сортирай намаляващо';
$labels['undo'] = 'Отмени';
$labels['installedplugins'] = 'Инсталирани добавки';
$labels['plugin'] = 'Добавка';
$labels['version'] = 'Версия';
$labels['source'] = 'Източник';
$labels['destination'] = 'Цел';
$labels['license'] = 'Лиценз';
$labels['support'] = 'Поддръжка';
$labels['savedsearches'] = 'Запазени търсения';
$labels['dateformatY'] = 'ГГГГ';
$labels['dateformaty'] = 'ГГ';
$labels['dateformatm'] = 'ММ';
$labels['dateformatd'] = 'ДД';
$labels['dateformatj'] = 'Д';
$labels['dateformatn'] = 'М';
$labels['B'] = 'Б';
$labels['KB'] = 'КБ';
$labels['MB'] = 'МБ';
$labels['GB'] = 'ГБ';
$labels['unicode'] = 'Уникод';
$labels['english'] = 'Английски';
$labels['westerneuropean'] = 'Западна Европа';
$labels['easterneuropean'] = 'Източна Европа';
$labels['southeasterneuropean'] = 'Югоизточна Европа';
$labels['baltic'] = 'Балтийски';
$labels['cyrillic'] = 'Кирилица';
$labels['arabic'] = 'Арабски';
$labels['greek'] = 'Гръцки';
$labels['hebrew'] = 'Иврит';
$labels['turkish'] = 'Турски';
$labels['nordic'] = 'Скандинавски';
$labels['thai'] = 'Тайландски';
$labels['celtic'] = 'Келтски';
$labels['vietnamese'] = 'Виетнамски';
$labels['japanese'] = 'Японски';
$labels['korean'] = 'Корейски';
$labels['chinese'] = 'Китайски';
$labels['arialabeltopnav'] = 'Контрол на прозорците';
$labels['arialabeltasknav'] = 'Задачи на приложението';
$labels['arialabeltoolbar'] = 'Ленти с инструменти';
$labels['arialabellistnav'] = 'Навигация на cписък';
$labels['arialabelactivetask'] = 'Активна задача';
$labels['arialabelmessagessearchfilter'] = 'Филтър на списък с писма';
$labels['arialabelmailsearchform'] = 'Форма за търсене на писма';
$labels['arialabelcontactsearchform'] = 'Форма за търсене на контакти';
$labels['arialabelmailquicksearchbox'] = 'Поле за търсене на писма';
$labels['arialabelquicksearchbox'] = 'Поле за търсене';
$labels['arialabelfoldersearchfilter'] = 'Филтър за списък папки';
$labels['arialabelfoldersearchform'] = 'Форма за търсене в папки';
$labels['arialabelfolderlist'] = 'Избор на папка с писма';
$labels['arialabelmessagelist'] = 'Списък с писма';
$labels['arialabelmailpreviewframe'] = 'Преглед на писмо';
$labels['arialabelmailboxmenu'] = 'Меню с действия върху папка';
$labels['arialabellistselectmenu'] = 'Меню за избор в списък';
$labels['arialabelthreadselectmenu'] = 'Меню за списък с кореспонденции';
$labels['arialabelmessagelistoptions'] = 'Опции за преглед и сортиране на списък с писма';
$labels['arialabelmailimportdialog'] = 'Диалог за импорт на писма';
$labels['arialabelmessagenav'] = 'Навигация на писма';
$labels['arialabelmessagebody'] = 'Текст на писмо';
$labels['arialabelmessageactions'] = 'Действия за писмо';
$labels['arialabelcontactquicksearch'] = 'Форма за търсене на контакти';
$labels['arialabelcontactsearchbox'] = 'Поле за търсене на контакт';
$labels['arialabelmessageheaders'] = 'Заглавни блокове на писмо';
$labels['arialabelforwardingoptions'] = 'Настройки за препращане';
$labels['arialabelreplyalloptions'] = 'Настройки за отговор към всички';
$labels['arialabelmoremessageactions'] = 'Още действия с писмо';
$labels['arialabelmorecontactactions'] = 'Още действия с контакт';
$labels['arialabelmarkmessagesas'] = 'Маркирай избраните писма като...';
$labels['arialabelcomposeoptions'] = 'Настройки за създаване';
$labels['arialabelresponsesmenu'] = 'Меню с готови отговори';
$labels['arialabelattachmentuploadform'] = 'Форма за качване на прикачени файлове';
$labels['arialabelattachmentmenu'] = 'Настройки на прикачени файлове';
$labels['arialabelmailtomenu'] = 'Настройки на адреса на ел. поща';
$labels['arialabelattachmentpreview'] = 'Преглед на прикачени файлове';
$labels['ariasummarycomposecontacts'] = 'Списък с контакти и групи за избор като получатели';
$labels['arialabelcontactexportoptions'] = 'Настройки за експорт на контакти';
$labels['arialabelabookgroupoptions'] = 'Настройки на адресна книга/групи';
$labels['arialabelpreferencesform'] = 'Форма с предпочитания';
$labels['arialabelidentityeditfrom'] = 'Форма редакция на самоличност';
$labels['arialabelresponseeditfrom'] = 'Форма редакция на отговор';
$labels['arialabelsearchterms'] = 'Търсене за';
$labels['arialabeldropactionmenu'] = 'Меню за действие Drag-n-Drop';
$labels['arialabelheadersmenu'] = 'Меню за Добавяне получател (заглавен блок)';
$labels['arialabelimagetools'] = 'Инструменти за изображения';
$labels['helplistnavigation'] = 'Списък за клавиатурна навигация';
$labels['helplistkeyboardnavigation'] = "Стрелки нагоре/надолу: Премества фокус/избран ред.
Интервал: Избор на фокусиран ред.
Shift + нагоре/надолу: Добавяне към избраните на реда отгоре/отдолу.
Ctrl + Интервал: Добавяне на фокусирания ред към избраните/премахване от избраните.";
$labels['helplistkeyboardnavmessages'] = "Стрелки надясно/наляво: Разпъване/сгъване на писмата на кореспонденцията (само в изглед по кореспонденции).
Enter: Отваряне на избраното/фокусираното писмо.
Delete: Премества избраните писва в Кошче.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Отваряне на избрания/фокусирания контакт.";
