<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Вітаем у $product';
$labels['username'] = 'Карыстальнік';
$labels['password'] = 'Пароль';
$labels['server'] = 'Сервер';
$labels['login'] = 'Уваход';
$labels['logout'] = 'Выхад';
$labels['mail'] = 'Пошта';
$labels['settings'] = 'Настаўленні';
$labels['addressbook'] = 'Адрасная кніга';
$labels['inbox'] = 'Атрыманыя';
$labels['drafts'] = 'Чарнавікі';
$labels['sent'] = 'Дасланыя';
$labels['trash'] = 'Сметніца';
$labels['junk'] = 'Спам';
$labels['show_real_foldernames'] = 'Паказваць сапраўдныя назвы для адмысловых папак';
$labels['subject'] = 'Тэма';
$labels['from'] = 'Ад каго';
$labels['sender'] = 'Адпраўнік';
$labels['to'] = 'Каму';
$labels['cc'] = 'Копія';
$labels['bcc'] = 'Схаваная копія';
$labels['replyto'] = 'Адказаць-на';
$labels['followupto'] = 'Групавы-адказ-на';
$labels['date'] = 'Дата';
$labels['size'] = 'Памер';
$labels['priority'] = 'Прыярытэт';
$labels['organization'] = 'Установа';
$labels['readstatus'] = 'Прачытана';
$labels['listoptions'] = 'Параметры спісу...';
$labels['mailboxlist'] = 'Папкі';
$labels['messagesfromto'] = 'Паведамленні $from—$to з $count';
$labels['threadsfromto'] = 'Абмеркаванні $from—$to з $count';
$labels['messagenrof'] = 'Паведамленне $nr з $count';
$labels['fromtoshort'] = '$from—$to з $count';
$labels['copy'] = 'Капіяваць';
$labels['move'] = 'Перамясціць';
$labels['moveto'] = 'Перамясціць у...';
$labels['copyto'] = 'Скапіяваць у...';
$labels['download'] = 'Сцягнуць';
$labels['open'] = 'Адкрыць';
$labels['showattachment'] = 'Паказаць';
$labels['showanyway'] = 'Усё адно паказваць';
$labels['filename'] = 'Назва файла';
$labels['filesize'] = 'Памер файла';
$labels['addtoaddressbook'] = 'Дадаць у адрасную кнігу';
$labels['sun'] = 'нд';
$labels['mon'] = 'пн';
$labels['tue'] = 'аў';
$labels['wed'] = 'ср';
$labels['thu'] = 'чц';
$labels['fri'] = 'пт';
$labels['sat'] = 'сб';
$labels['sunday'] = 'нядзеля';
$labels['monday'] = 'панядзелак';
$labels['tuesday'] = 'аўторак';
$labels['wednesday'] = 'серада';
$labels['thursday'] = 'чацвер';
$labels['friday'] = 'пятніца';
$labels['saturday'] = 'субота';
$labels['jan'] = 'сту';
$labels['feb'] = 'лют';
$labels['mar'] = 'сак';
$labels['apr'] = 'кра';
$labels['may'] = 'май';
$labels['jun'] = 'чэр';
$labels['jul'] = 'ліп';
$labels['aug'] = 'жні';
$labels['sep'] = 'вер';
$labels['oct'] = 'кас';
$labels['nov'] = 'ліс';
$labels['dec'] = 'сне';
$labels['longjan'] = 'студзень';
$labels['longfeb'] = 'люты';
$labels['longmar'] = 'сакавік';
$labels['longapr'] = 'красавік';
$labels['longmay'] = 'май';
$labels['longjun'] = 'чэрвень';
$labels['longjul'] = 'ліпень';
$labels['longaug'] = 'жнівень';
$labels['longsep'] = 'верасень';
$labels['longoct'] = 'кастрычнік';
$labels['longnov'] = 'лістапад';
$labels['longdec'] = 'снежань';
$labels['today'] = 'сёння';
$labels['refresh'] = 'Абнавіць';
$labels['checkmail'] = 'Праверыць новыя паведамленні';
$labels['compose'] = 'Скласці';
$labels['writenewmessage'] = 'Скласці новае паведамленне';
$labels['reply'] = 'Адказаць';
$labels['replytomessage'] = 'Адказаць адпраўніку';
$labels['replytoallmessage'] = 'Адказаць па спісе альбо адпраўніку і ўсім атрымальнікам';
$labels['replyall'] = 'Адказаць усім';
$labels['replylist'] = 'Адказаць у спіс рассылкі';
$labels['forward'] = 'Пераслаць';
$labels['forwardinline'] = 'Пераслаць у целе ліста';
$labels['forwardattachment'] = 'Пераслаць як далучэнне';
$labels['forwardmessage'] = 'Пераслаць гэтае паведамленне';
$labels['deletemessage'] = 'Выдаліць паведамленне';
$labels['movemessagetotrash'] = 'Перамясціць паведамленне ў сметніцу';
$labels['printmessage'] = 'Раздрукаваць гэтае паведамленне';
$labels['previousmessage'] = 'Паказаць папярэдняе паведамленне';
$labels['firstmessage'] = 'Паказаць першае паведамленне';
$labels['nextmessage'] = 'Паказаць наступнае паведамленне';
$labels['lastmessage'] = 'Паказаць апошняе паведамленне';
$labels['backtolist'] = 'Назад да спісу паведамленняў';
$labels['viewsource'] = 'Зыходны тэкст';
$labels['mark'] = 'Пазначыць';
$labels['markmessages'] = 'Пазначыць паведамленні';
$labels['markread'] = 'Як прачытаныя';
$labels['markunread'] = 'Як непрачытаныя';
$labels['markflagged'] = 'Паставіць флаг';
$labels['markunflagged'] = 'Зняць флаг';
$labels['moreactions'] = 'Больш дзеянняў...';
$labels['folders-all'] = 'Усе папкі';
$labels['more'] = 'Больш';
$labels['back'] = 'Назад';
$labels['options'] = 'Параметры';
$labels['first'] = 'Першая';
$labels['last'] = 'Апошняя';
$labels['previous'] = 'Папярэдняя';
$labels['next'] = 'Наступная';
$labels['select'] = 'Выбраць';
$labels['all'] = 'Усе';
$labels['none'] = 'Жаднага';
$labels['currpage'] = 'Бягучая старонка';
$labels['isread'] = 'Прачытаныя';
$labels['unread'] = 'Непрачытаныя';
$labels['flagged'] = 'З флагам';
$labels['unflagged'] = 'Без флага';
$labels['unanswered'] = 'Неадказаныя';
$labels['withattachment'] = 'З далучэннямі';
$labels['deleted'] = 'Выдаленыя';
$labels['undeleted'] = 'Нявыдаленыя';
$labels['replied'] = 'Адказаныя';
$labels['forwarded'] = 'Перасланыя';
$labels['invert'] = 'Інвертаваць';
$labels['filter'] = 'Фільтр';
$labels['list'] = 'Спіс';
$labels['threads'] = 'Абмеркаванні';
$labels['expand-all'] = 'Развінуць усё';
$labels['expand-unread'] = 'Развінуць непрачытаныя';
$labels['collapse-all'] = 'Звінуць усё';
$labels['threaded'] = 'Абмеркаванні';
$labels['autoexpand_threads'] = 'Развінуць абмеркаванні';
$labels['do_expand'] = 'усе абмеркаванні';
$labels['expand_only_unread'] = 'толькі з непрачытанымі паведамленнямі';
$labels['fromto'] = 'Ад/Да';
$labels['flag'] = 'Флаг';
$labels['attachment'] = 'Далучэнне';
$labels['nonesort'] = 'Адсутнічае';
$labels['sentdate'] = 'Дата адпраўкі';
$labels['arrival'] = 'Дата атрымання';
$labels['asc'] = 'на ўзрастанне';
$labels['desc'] = 'на змяншчэнне';
$labels['listcolumns'] = 'Слупкі';
$labels['listsorting'] = 'Сартаваць паводле';
$labels['listorder'] = 'Парадак сартавання';
$labels['listmode'] = 'Тып спісу';
$labels['layoutlist'] = 'Спіс';
$labels['folderactions'] = 'Аперацыі з папкай...';
$labels['compact'] = 'Сціснуць';
$labels['empty'] = 'Спаражніць';
$labels['importmessages'] = 'Імпартаваць паведамленні';
$labels['quota'] = 'Квота';
$labels['unknown'] = 'невядома';
$labels['unlimited'] = 'без абмежаванняў';
$labels['quicksearch'] = 'Хуткі пошук';
$labels['resetsearch'] = 'Скінуць пошук';
$labels['searchmod'] = 'Мадыфікатары пошуку';
$labels['msgtext'] = 'Усё паведамленне';
$labels['body'] = 'Цела';
$labels['type'] = 'Тып';
$labels['namex'] = 'Імя';
$labels['searchscope'] = 'Абсяг';
$labels['currentfolder'] = 'Бягучая папка';
$labels['subfolders'] = 'Гэтая і падпапкі';
$labels['allfolders'] = 'Усе папкі';
$labels['openinextwin'] = 'Адкрыць у новым акне';
$labels['emlsave'] = 'Сцягнуць (.eml)';
$labels['changeformattext'] = 'Паказаць як просты тэкст';
$labels['changeformathtml'] = 'Паказаць як HTML';
$labels['editasnew'] = 'Адрэдагаваць як новае';
$labels['send'] = 'Адправіць';
$labels['sendmessage'] = 'Адправіць паведамленне';
$labels['savemessage'] = 'Захаваць як чарнавік';
$labels['addattachment'] = 'Далучыць файл';
$labels['charset'] = 'Кадзіроўка';
$labels['editortype'] = 'Рэдактар';
$labels['returnreceipt'] = 'Пацверджанне атрымання';
$labels['dsn'] = 'Апавяшчэнне пра дастаўку';
$labels['mailreplyintro'] = '$sender пісаў $date:';
$labels['originalmessage'] = 'Арыгінальнае паведамленне';
$labels['selectimage'] = 'Абраць відарыс';
$labels['addimage'] = 'Дадаць відарыс';
$labels['selectmedia'] = 'Абраць фільмік';
$labels['addmedia'] = 'Дадаць фільмік';
$labels['insert'] = 'Даданне';
$labels['recipient'] = 'Каму';
$labels['editidents'] = 'Рэдагаваць тоеснасці';
$labels['spellcheck'] = 'Правапіс';
$labels['checkspelling'] = 'Праверыць правапіс';
$labels['resumeediting'] = 'Працягнуць рэдагаванне';
$labels['revertto'] = 'Адкаціцца на';
$labels['restore'] = 'Аднавіць';
$labels['restoremessage'] = 'Аднавіць паведамленне?';
$labels['responses'] = 'Адказы';
$labels['insertresponse'] = 'Уставіць адказ';
$labels['manageresponses'] = 'Кіраваць адказамі';
$labels['newresponse'] = 'Стварыць новы адказ';
$labels['addresponse'] = 'Дадаць адказ';
$labels['editresponse'] = 'Рэдагаваць адказ';
$labels['editresponses'] = 'Рэдагаваць адказы';
$labels['responsename'] = 'Назва';
$labels['responsetext'] = 'Тэкст адказу';
$labels['attach'] = 'Далучыць';
$labels['attachments'] = 'Далучэнні';
$labels['upload'] = 'Апублікаваць';
$labels['close'] = 'Закрыць';
$labels['messageoptions'] = 'Параметры паведамлення...';
$labels['togglecomposeoptions'] = 'Пераключыць параметры складання';
$labels['low'] = 'Нізкі';
$labels['lowest'] = 'Найнізшы';
$labels['normal'] = 'Звычайны';
$labels['high'] = 'Высокі';
$labels['highest'] = 'Найвышшы';
$labels['nosubject'] = '(без тэмы)';
$labels['showimages'] = 'Паказваць выявы';
$labels['alwaysshow'] = 'Заўсёды паказваць выявы ад $sender';
$labels['isdraft'] = 'Гэта чарнавік.';
$labels['andnmore'] = 'яшчэ $nr...';
$labels['togglemoreheaders'] = 'Паказаць больш загалоўкаў паведамлення';
$labels['togglefullheaders'] = 'Паказаць неапрацаваныя загалоўкі паведамлення';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Звычайны тэкст';
$labels['savesentmessagein'] = 'Захаваць паведамленне ў';
$labels['dontsave'] = 'не захоўваць';
$labels['maxuploadsize'] = 'Максімальна дазволены памер файла — $size';
$labels['addcc'] = 'Копія';
$labels['addbcc'] = 'Схаваная копія';
$labels['addreplyto'] = 'Адказаць-на';
$labels['addfollowupto'] = 'Групавы-адказ-на';
$labels['mdnrequest'] = 'Адпраўнік пажадаў даведацца аб прачытанні гэтага паведамлення. Апавясціць адпраўніка?';
$labels['receiptread'] = 'Пацверджанне атрымання (прачытання)';
$labels['yourmessage'] = 'Гэта пацверджанне аб атрыманні вашага паведамлення';
$labels['receiptnote'] = 'Заўвага: Гэтае пацверджанне значыць адно, што паведамленне было адлюстравана на экране камп\'ютара адрасата. Няма гарантыі, што атрымальнік прачытаў альбо зразумеў змест паведамлення.';
$labels['name'] = 'Экраннае імя';
$labels['firstname'] = 'Імя';
$labels['surname'] = 'Прозвішча';
$labels['middlename'] = 'Другое імя';
$labels['nameprefix'] = 'Прэфікс';
$labels['namesuffix'] = 'Суфікс';
$labels['nickname'] = 'Мянушка';
$labels['jobtitle'] = 'Пасада';
$labels['department'] = 'Аддзел';
$labels['gender'] = 'Пол';
$labels['maidenname'] = 'Дзявоцкае прозвішча';
$labels['email'] = 'Эл. пошта';
$labels['phone'] = 'Тэлефон';
$labels['address'] = 'Адрас';
$labels['street'] = 'Вуліца';
$labels['locality'] = 'Горад';
$labels['zipcode'] = 'Індэкс';
$labels['region'] = 'Рэгіён';
$labels['country'] = 'Краіна';
$labels['birthday'] = 'Дзень народзінаў';
$labels['anniversary'] = 'Юбілей';
$labels['website'] = 'Вэб-сайт';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Занатоўкі';
$labels['male'] = 'мужчына';
$labels['female'] = 'жанчына';
$labels['manager'] = 'Кіраўнік';
$labels['assistant'] = 'Асістэнт';
$labels['spouse'] = 'Жонка';
$labels['allfields'] = 'Усе палі';
$labels['search'] = 'Пошук';
$labels['advsearch'] = 'Пашыраны пошук';
$labels['advanced'] = 'Дадаткова';
$labels['other'] = 'Іншае';
$labels['typehome'] = 'Дом';
$labels['typework'] = 'Праца';
$labels['typeother'] = 'Іншае';
$labels['typemobile'] = 'Мабільны';
$labels['typemain'] = 'Асноўны';
$labels['typehomefax'] = 'Дамашні факс';
$labels['typeworkfax'] = 'Працоўны факс';
$labels['typecar'] = 'Аўта';
$labels['typepager'] = 'Пэйджар';
$labels['typevideo'] = 'Відэа';
$labels['typeassistant'] = 'Асістэнт';
$labels['typehomepage'] = 'Дамашняя старонка';
$labels['typeblog'] = 'Блог';
$labels['typeprofile'] = 'Профіль';
$labels['addfield'] = 'Дадаць поле...';
$labels['addcontact'] = 'Дадаць кантакт';
$labels['editcontact'] = 'Рэдагаваць кантакт';
$labels['contacts'] = 'Кантакты';
$labels['contactproperties'] = 'Уласцівасці кантакта';
$labels['contactnameandorg'] = 'Імя і арганізацыя';
$labels['personalinfo'] = 'Асабістыя звесткі';
$labels['contactphoto'] = 'Асабістае фота';
$labels['edit'] = 'Рэдагаваць';
$labels['cancel'] = 'Скасаваць';
$labels['save'] = 'Захаваць';
$labels['delete'] = 'Выдаліць';
$labels['rename'] = 'Пераназваць';
$labels['addphoto'] = 'Дадаць';
$labels['replacephoto'] = 'Замяніць';
$labels['uploadphoto'] = 'Апублікаваць фота';
$labels['newcontact'] = 'Стварыць новы кантакт';
$labels['deletecontact'] = 'Выдаліць абраных кантактаў';
$labels['composeto'] = 'Скласці ліст да';
$labels['contactsfromto'] = 'Кантакты $from—$to з $count';
$labels['print'] = 'Друкаваць';
$labels['export'] = 'Экспарт';
$labels['exportall'] = 'Экспартаваць усё';
$labels['exportsel'] = 'Экспартаваць абранае';
$labels['exportvcards'] = 'Экспартаваць кантакты ў фармаце vCard';
$labels['newgroup'] = 'Стварыць новую групу';
$labels['grouprename'] = 'Пераназваць групу';
$labels['groupdelete'] = 'Выдаліць групу';
$labels['groupremoveselected'] = 'Выдаліць абраных кантакаў з групы';
$labels['uponelevel'] = 'На адзін узровень уверх';
$labels['previouspage'] = 'Папярэдняя старонка';
$labels['firstpage'] = 'Першая старонка';
$labels['nextpage'] = 'Наступная старонка';
$labels['lastpage'] = 'Апошняя старонка';
$labels['group'] = 'Група';
$labels['groups'] = 'Групы';
$labels['listgroup'] = 'Паказаць сяброў групы';
$labels['personaladrbook'] = 'Асабістыя адрасы';
$labels['searchsave'] = 'Захаваць запытанне';
$labels['searchdelete'] = 'Выдаліць запытанне';
$labels['import'] = 'Імпарт';
$labels['importcontacts'] = 'Імпартаваць кантакты';
$labels['importtarget'] = 'Дадаць канактаў у';
$labels['importreplace'] = 'Замяніць адрасную кнігу цалкам';
$labels['importgroups'] = 'Імпартаваць прызначэнні групы';
$labels['importgroupsall'] = 'Усе (стварыць групы пры неабходнасці)';
$labels['importgroupsexisting'] = 'Толькі для існуючых груп';
$labels['done'] = 'Гатова';
$labels['settingsfor'] = 'Настаўленні для';
$labels['about'] = 'Апісанне';
$labels['preferences'] = 'Параметры';
$labels['userpreferences'] = 'Параметры карыстальніка';
$labels['editpreferences'] = 'Рэдагаваць параметры карыстальніка';
$labels['identities'] = 'Тоеснасці';
$labels['preferhtml'] = 'Паказаць HTML';
$labels['defaultcharset'] = 'Стандартная кадзіроўка';
$labels['htmlmessage'] = 'Паведамленне ў HTML';
$labels['messagepart'] = 'Часць';
$labels['digitalsig'] = 'Электронны подпіс';
$labels['dateformat'] = 'Фармат даты';
$labels['timeformat'] = 'Фармат  часу';
$labels['prettydate'] = 'Даты ў зручным фармаце';
$labels['setdefault'] = 'Зрабіць стандартам';
$labels['autodetect'] = 'Аўтаматычна';
$labels['language'] = 'Мова';
$labels['timezone'] = 'Часавая зона';
$labels['pagesize'] = 'Радкоў на старонку';
$labels['signature'] = 'Подпіс';
$labels['dstactive'] = 'Летні/зімовы час';
$labels['showinextwin'] = 'Адкрываць паведамленні ў новым акне';
$labels['composeextwin'] = 'Складаць у новым акне';
$labels['htmleditor'] = 'Складаць паведамленні ў HTML';
$labels['htmlonreply'] = 'у адказ на паведамленні ў HTML';
$labels['htmlonreplyandforward'] = 'пры перасылцы альбо ў адказ на паведамленні ў HTML';
$labels['htmlsignature'] = 'Подпіс у HTML';
$labels['showemail'] = 'Паказваць адрас электроннай пошты разам з экраннай назвай';
$labels['previewpane'] = 'Панэль прагляду';
$labels['skin'] = 'Тэма інтэрфейсу';
$labels['logoutclear'] = 'Ачышчаць Сметніцу па выхадзе';
$labels['logoutcompact'] = 'Сціскаць Атрыманыя па выхадзе';
$labels['uisettings'] = 'Інтэрфейс карыстальніка';
$labels['serversettings'] = 'Настаўленні сервера';
$labels['mailboxview'] = 'Выгляд скрынкі';
$labels['mdnrequests'] = 'Пры запытанні пацверджанняў аб атрыманні';
$labels['askuser'] = 'спытаць мяне';
$labels['autosend'] = 'адправіць пацверджанне';
$labels['autosendknown'] = 'адпраўляць пацверджанне маім кантактам, іначай спытаць';
$labels['autosendknownignore'] = 'адпраўляць пацверджанне маім кантактам, іначай ігнараваць';
$labels['readwhendeleted'] = 'Пазначаць паведамленне як прачытанае па выдаленні';
$labels['flagfordeletion'] = 'Толькі пазначаць паведамленне на выдаленне, не выдаляць';
$labels['skipdeleted'] = 'Не паказваць выдаленыя паведамленні';
$labels['deletealways'] = 'Як не ўдалося перамясціць паведамленні ў Сметніцу, выдаліць іх';
$labels['deletejunk'] = 'Адразу выдаляць паведамленні ў Спаме';
$labels['showremoteimages'] = 'Паказваць вонкавыя відарысы';
$labels['fromknownsenders'] = 'ад вядомых адпраўнікоў';
$labels['always'] = 'заўсёды';
$labels['showinlineimages'] = 'Паказваць далучаныя відарысы пад паведамленнем';
$labels['autosavedraft'] = 'Аўтаматычна захоўваць чарнавікі';
$labels['everynminutes'] = 'кожныя $n мінут(аў)';
$labels['refreshinterval'] = 'Абнаўленне (праверка новых паведамленняў і г. д.)';
$labels['never'] = 'ніколі';
$labels['immediately'] = 'імгненна';
$labels['messagesdisplaying'] = 'Адлюстраванне  паведамленняў';
$labels['messagescomposition'] = 'Складанне паведамленняў';
$labels['mimeparamfolding'] = 'Назвы далучэнняў';
$labels['2231folding'] = 'Поўны RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Поўны RFC 2047 (інш.)';
$labels['force7bit'] = 'Ужываць MIME-кадзіроўку для 8-бітных знакаў';
$labels['advancedoptions'] = 'Дадатковыя параметры';
$labels['focusonnewmessage'] = 'Актываваць акно браўзера пры новым паведамленні';
$labels['checkallfolders'] = 'Правяраць усе папкі на новыя паведамленні';
$labels['defaultfont'] = 'Стандартны шрыфт паведамлення ў HTML';
$labels['mainoptions'] = 'Асноўныя параметры';
$labels['browseroptions'] = 'Параметры браўзера';
$labels['section'] = 'Секцыя';
$labels['maintenance'] = 'Абслугоўванне';
$labels['newmessage'] = 'Новае паведамленне';
$labels['signatureoptions'] = 'Параметры подпісу';
$labels['whenreplying'] = 'Адказваючы';
$labels['replyempty'] = 'не цытаваць зыходнае паведамленне';
$labels['replytopposting'] = 'пачынаць новае паведамленне над цытаваным';
$labels['replybottomposting'] = 'пачынаць новае паведамленне пад цытаваным';
$labels['replyremovesignature'] = 'Адказваючы, выдаліць стары подпіс з паведамлення';
$labels['autoaddsignature'] = 'Аўтаматычна дадаваць подпіс';
$labels['newmessageonly'] = 'толькі ў новых паведамленнях';
$labels['replyandforwardonly'] = 'толькі ў адказах і перасылках';
$labels['insertsignature'] = 'Уставіць подпіс';
$labels['afternseconds'] = 'пасля $n секунд';
$labels['reqmdn'] = 'Заўсёды запытваць пацверджанне аб атрыманні';
$labels['reqdsn'] = 'Заўсёды запытваць апавяшчэнне аб дастаўцы';
$labels['replysamefolder'] = 'Складваць адказы ў папку зыходнага паведамлення';
$labels['defaultabook'] = 'Стандартная адрасная кніга';
$labels['autocompletesingle'] = 'Прапускаць альтэрнатыўныя адрасы пры аўдадапаўненні';
$labels['listnamedisplay'] = 'Выводзіць спіс кантактаў як';
$labels['spellcheckbeforesend'] = 'Правяраць правапіс перад адпраўкай';
$labels['spellcheckoptions'] = 'Параметры праверкі правапісу';
$labels['spellcheckignoresyms'] = 'Ігнараваць словы з сімваламі';
$labels['spellcheckignorenums'] = 'Ігнараваць словы з лікамі';
$labels['spellcheckignorecaps'] = 'Ігнараваць словы з усімі літарамі ў верхнім рэгістры';
$labels['addtodict'] = 'Дадаць у слоўнік';
$labels['mailtoprotohandler'] = 'Зарэгістраваць апрацоўніка для спасылак mailto:';
$labels['standardwindows'] = 'Успрымаць вокны-бурбалкі як звычайныя вокны';
$labels['forwardmode'] = 'Перасылка паведамленняў';
$labels['inline'] = 'у тэксце';
$labels['asattachment'] = 'як далучэнне';
$labels['replyallmode'] = 'Стандартнае дзеянне кнопкі [Адказаць усім]';
$labels['replyalldefault'] = 'адказаць усім';
$labels['replyalllist'] = 'адказаць толькі ў спіс рассылкі (калі знойдзены)';
$labels['folder'] = 'Папка';
$labels['folders'] = 'Папкі';
$labels['foldername'] = 'Назва папкі';
$labels['subscribed'] = 'Падпісаная';
$labels['messagecount'] = 'Паведамленні';
$labels['create'] = 'Стварыць';
$labels['createfolder'] = 'Стварыць новую папку';
$labels['managefolders'] = 'Парадкаваць папкі';
$labels['specialfolders'] = 'Адмысловыя папкі';
$labels['properties'] = 'Уласцівасці';
$labels['folderproperties'] = 'Уласцівасці папкі';
$labels['parentfolder'] = 'Бацькоўская папка';
$labels['location'] = 'Размяшчэнне';
$labels['info'] = 'Звесткі';
$labels['getfoldersize'] = 'Пстрыкніце, каб даведацца памер папкі';
$labels['changesubscription'] = 'Пстрыкніце, каб змяніць падпіску';
$labels['foldertype'] = 'Тып папкі';
$labels['personalfolder'] = 'Асабістая папка';
$labels['otherfolder'] = 'Папка іншага карыстальніка';
$labels['sharedfolder'] = 'Публічная папка';
$labels['sortby'] = 'Сартаваць паводле';
$labels['sortasc'] = 'Сартаваць на ўзрастанне';
$labels['sortdesc'] = 'Сартаваць на змяншчэнне';
$labels['undo'] = 'Адмяніць';
$labels['installedplugins'] = 'Устаноўленыя плагіны';
$labels['plugin'] = 'Плагін';
$labels['version'] = 'Версія';
$labels['source'] = 'Крыніца';
$labels['license'] = 'Ліцэнзія';
$labels['support'] = 'Падтрымка';
$labels['B'] = 'Б';
$labels['KB'] = 'КБ';
$labels['MB'] = 'МБ';
$labels['GB'] = 'ГБ';
$labels['unicode'] = 'Юнікод';
$labels['english'] = 'англійская';
$labels['westerneuropean'] = 'заходне-еўрапейская';
$labels['easterneuropean'] = 'усходне-еўрапейская';
$labels['southeasterneuropean'] = 'паўднёва-еўрапейская';
$labels['baltic'] = 'балтыйская';
$labels['cyrillic'] = 'кірыліца';
$labels['arabic'] = 'арабская';
$labels['greek'] = 'грэцкая';
$labels['hebrew'] = 'габрэйская';
$labels['turkish'] = 'турэцкая';
$labels['nordic'] = 'паўночная';
$labels['thai'] = 'тайская';
$labels['celtic'] = 'кельцкая';
$labels['vietnamese'] = 'в\'етнамская';
$labels['japanese'] = 'японская';
$labels['korean'] = 'карэйская';
$labels['chinese'] = 'кітайская';
