<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'Arxiva';
$labels['buttontitle'] = 'Arxiva aquest missatge';
$labels['archived'] = 'Arxivat correctament';
$labels['archivedreload'] = 'Arxivat correctament. Recarregueu la pàgina per veure les noves carpetes de l\'arxiu.';
$labels['archiveerror'] = 'Alguns missatges no s\'han pogut arxivar';
$labels['archivefolder'] = 'Arxiu';
$labels['settingstitle'] = 'Arxiu';
$labels['archivetype'] = 'Divideix arxiu per';
$labels['archivetypeyear'] = 'Any (p.ex. Arxiu/2012)';
$labels['archivetypemonth'] = 'Mes (p.ex. Arxiu/2012/06)';
$labels['archivetypetbmonth'] = 'Mes - Compatible amb Thunderbird (p.ex. Arxiu/2012/2102-06)';
$labels['archivetypefolder'] = 'Carpeta original';
$labels['archivetypefolderyear'] = 'L\'any i la carpeta original (p.ex. Arxiu/2012/...)';
$labels['archivetypefoldermonth'] = 'L\'any, el mes i la carpeta original (p.ex. Arxiu/2012/06/...)';
$labels['archivetypesender'] = 'Adreça del remitent';
$labels['unkownsender'] = 'desconegut';
$labels['readonarchive'] = 'Marca el missatge com a llegit a l\'arxiu';
