/**
 * Roundcube webmail styles for the Address Book section
 *
 * Copyright (c) The Roundcube Dev Team
 * Screendesign by FLINT / Büro für Gestaltung, bueroflint.com
 *
 * The contents are subject to the Creative Commons Attribution-ShareAlike
 * License. It is allowed to copy, distribute, transmit and to adapt the work
 * by keeping credits to the original autors in the README file.
 * See http://creativecommons.org/licenses/by-sa/3.0/ for details.
 */

#addressview-left {
	position: absolute;
	top: 0;
	left: 0;
	width: 200px;
	bottom: 0;
	z-index: 2;
}

#addressview-right {
	position: absolute;
	top: 0;
	left: 212px;
	right: 0;
	bottom: 0;
	z-index: 3;
}

#addressbooktoolbar {
	position: absolute;
	top: -6px;
	left: 0;
	height: 40px;
	white-space: nowrap;
	z-index: 10;
}

#directorylistbox {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	bottom: 0;
}

#addresslist {
	position: absolute;
	top: 0;
	left: 0;
	width: 260px;
	bottom: 0;
}

#contacts-box {
	position: absolute;
	top: 0;
	left: 272px;
	right: 0;
	bottom: 0;
}

#addressview-left #quicksearchbar input {
	width: 156px;
}

#directorylist li a,
.treelist li.contactsearch a,
#contacts-table .contact td.name {
	background-image: url(images/listicons.png);
	background-position: -100px 0;
	background-repeat: no-repeat;
	overflow: hidden;
	text-overflow: ellipsis;
}

#directorylist li.addressbook a {
	background-position: 6px -766px;
}

#directorylist ul li.addressbook a {
	background-position: 32px -766px;
}

#directorylist ul ul li.addressbook a {
	background-position: 58px -766px;
}

#directorylist li.addressbook.selected > a {
	background-position: 6px -791px;
}

#directorylist ul li.addressbook.selected > a {
	background-position: 32px -791px;
}

#directorylist ul ul li.addressbook.selected > a {
	background-position: 58px -791px;
}

#directorylist li.contactgroup a {
	background-position: 6px -1554px;
}

#directorylist ul li.contactgroup a {
	background-position: 32px -1554px;
}

#directorylist ul ul li.contactgroup a {
	background-position: 58px -1554px;
}

#directorylist ul ul ul li.contactgroup a {
	background-position: 84px -1554px;
}

#directorylist li.contactgroup.selected a {
	background-position: 32px -1578px;
}

#directorylist ul ul li.contactgroup.selected a {
	background-position: 58px -1578px;
}

#directorylist ul ul ul li.contactgroup.selected a {
	background-position: 84px -1578px;
}

.treelist li.contactsearch a {
	background-position: 6px -1651px;
}

.treelist li.contactsearch.selected a {
	background-position: 6px -1675px;
}

#directorylist li.addressbook div.collapsed,
#directorylist li.addressbook div.expanded {
	top: 15px;
}

#contacts-table .contact.readonly td {
	font-style: italic;
}

#contacts-table td.name {
	width: 95%;
}

#contacts-table td.action {
	width: 24px;
	padding: 4px;
}

#contacts-table td.action a {
	display: block;
	width: 16px;
	height: 14px;
	text-indent: -5000px;
	overflow: hidden;
	background: url(images/listicons.png) -2px -1180px no-repeat;
}

#contacts-table .contact td.name {
	background-position: 4px -1601px;
}

#contacts-table .contact.selected td.name {
	background-position: 4px -1625px;
	font-weight: bold;
}

#contacts-table .group td.name {
	background-position: 4px -1555px;
}

#contacts-table .group.selected td.name {
	background-position: 4px -1578px;
	font-weight: bold;
}

#contacts-table.focus .group.selected.focused td.name {
	background-position: 4px -1578px;
}

#addresslist .boxtitle {
	padding-right: 95px;
	overflow: hidden;
	text-overflow: ellipsis;
}

#addresslist .boxtitle a.poplink {
	color: #004458;
	font-size: 14px;
	line-height: 12px;
	text-decoration: none;
}

#contact-frame {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0px;
	border: 0;
	border-radius: 4px;
}

#headerbuttons {
	position: absolute;
	top: 48px;
	right: 10px;
	width: auto;
	z-index: 10;
}

#sourcename {
	color: #999;
	font-size: 10px;
	margin: -5px 0 8px 2px;
}

#contactphoto {
	float: left;
	margin: 0 18px 20px 0;
	width: 112px;
	border: 0;
	padding: 0;
}

#contactpic {
	width: 112px;
	min-height: 112px;
	background: white;
}

#contactpic img {
	max-width: 112px;
	visibility: inherit;
}

#contactpic.droptarget {
	background-image: url(images/filedrop.png);
	background-position: center;
	background-repeat: no-repeat;
}

#contactpic.droptarget.hover {
	background-color: #d9ecf4;
	box-shadow: 0 0 5px 2px rgba(71,135,177, 0.9);
}

#contactpic.droptarget.active img {
	opacity: 0.15;
}

#contactpic.droptarget.hover img {
	opacity: 0.05;
}

#contactphoto .formlinks a[aria-disabled='true'] {
	visibility: hidden;
}

#contacthead {
	border: 0;
	margin: 0 16em 1em 0;
	padding: 0;
	line-height: 1.5em;
	font-size: 12px;
}

#contacthead > legend {
	display: none;
}

form #contacthead {
	margin-right: 0;
}

#contacthead .names span.namefield,
#contacthead .names input {
	font-size: 140%;
	font-weight: bold;
}

#contacthead .displayname span.namefield {
	font-size: 120%;
	font-weight: bold;
}

#contacthead span.nickname:before,
#contacthead span.nickname:after {
	content: '"';
}

#contacthead input {
	margin-right: 6px;
	margin-bottom: 0.2em;
}

#contacthead .names input,
#contacthead .addnames input {
	width: 180px;
}

#contacthead input.ff_prefix,
#contacthead input.ff_suffix {
	width: 90px;
}

.contactfieldgroup {
	border: 0;
	border-radius: 0;
	background: #f7f7f7;
	margin: 0 0 12px 0;
	padding: 8px;
}

.contactfieldgroup legend {
	display: block;
	margin: 0 -8px;
	width: 100%;
	font-weight: bold;
	padding: 8px 8px 6px 8px;
	background: #e9e9e9;
	border-bottom: 1px solid #dfdfdf;
	border-radius: 0;
}

.contactfieldgroup .row {
	position: relative;
	margin: 0.2em 0;
}

.contactfieldgroup .contactfieldlabel {
	position: absolute;
	top: 0;
	left: 2px;
	width: 110px;
	white-space: nowrap;
	overflow: hidden;
	text-overflow: ellipsis;
	color: #666;
	line-height: 18px;
}

.contactfieldgroup .contactfieldlabel select {
	width: 100%;
	color: #666;
}

.contactfieldgroup .contactfieldcontent {
	padding-left: 120px;
	min-height: 1em;
	line-height: 18px;
}

.contactfieldgroup .contactfield {
	line-height: 1.3em;
}

.contactcontrolleraddress .contactfieldcontent input {
	margin-bottom: 0.1em;
}

.contactfieldcontent.composite {
	padding-bottom: 8px;
}

.contactfieldcontent .contactfieldbutton {
	vertical-align: middle;
	margin-left: 0.5em;
}

.contactfield .ff_notes {
	width: 99%;
}

a.deletebutton {
	position: relative;
	left: 5px;
	top: -3px;
	display: inline-block;
	width: 24px;
	height: 18px;
	text-decoration: none;
	text-indent: -5000px;
	background: url(images/buttons.png) -7px -377px no-repeat;
}

#import-box {
	position: absolute;
	bottom: 0px;
	top: 34px;
	left: 0;
	right: 0;
	overflow: auto;
	padding: 10px;
}

#import-box p,
#import-box .propform {
  max-width: 50em;
}

ul.toolbarmenu li span.qrcode {
	background-position: 0 -2408px;
}

ul.toolbarmenu li span.assigngroup {
	background-position: 0 -2358px;
}

ul.toolbarmenu li span.removegroup {
	background-position: 0 -2384px;
}

#addressbook-selector li a,
#contactgroup-selector li a {
	padding-left: 2px;
}

#addressbook-selector li a span,
#contactgroup-selector li a span {
	background: url(images/listicons.png) 4px 20px no-repeat;
	display: block;
	height: 17px;
	min-height: 14px;
	padding: 4px 4px 1px 28px;
	overflow: hidden;
	max-width: 120px;
	text-overflow: ellipsis;
}

#addressbook-selector li a.addressbook span {
	background-position: 4px -2222px;
}

#addressbook-selector li a.contactgroup span,
#contactgroup-selector li a.contactgroup span {
	background-position: 4px -2245px;
}
