<roundcube:object name="doctype" value="html5" />
<html>
<head>
<roundcube:include file="/includes/links.html" />
</head>
<body class="iframe fullheight">

<div class="readtext">
<roundcube:object name="aboutcontent" />
<h2 class="sysname">Roundcube Webmail <roundcube:object name="version" /></h2>
<p class="copyright"><roundcube:object name="copyright" /></p>
<p class="license"><roundcube:object name="license" /></p>
</div>

<div class="readtext">
<h3><roundcube:label name="installedplugins" /></h3>
<roundcube:object name="pluginlist" id="pluginlist" class="records-table" />
</div>

</body>
</html>
