<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = '欢迎使用 $product';
$labels['username'] = '用户名';
$labels['password'] = '密码';
$labels['server'] = '服务器';
$labels['login'] = '登录';
$labels['menu'] = '菜单';
$labels['logout'] = '注销';
$labels['mail'] = '邮件';
$labels['settings'] = '设置';
$labels['addressbook'] = '通讯录';
$labels['inbox'] = '收件箱';
$labels['drafts'] = '草稿箱';
$labels['sent'] = '已发送邮件';
$labels['trash'] = '已删除邮件';
$labels['junk'] = '垃圾邮件';
$labels['show_real_foldernames'] = '显示特殊文件夹的名字';
$labels['subject'] = '主题';
$labels['from'] = '发件人';
$labels['sender'] = '发件人';
$labels['to'] = '收件人';
$labels['cc'] = '抄送';
$labels['bcc'] = '密送';
$labels['replyto'] = '回复至';
$labels['followupto'] = '投递组';
$labels['date'] = '日期';
$labels['size'] = '大小';
$labels['priority'] = '优先级';
$labels['organization'] = '组织';
$labels['readstatus'] = '阅读状态';
$labels['listoptions'] = '列表选项';
$labels['listoptionstitle'] = '列表选项';
$labels['mailboxlist'] = '邮件夹';
$labels['messagesfromto'] = '从 $from 到 $to，共计 $count 封邮件';
$labels['threadsfromto'] = '从 $from 到 $to，共计 $count 个主题';
$labels['messagenrof'] = '第 $nr 封邮件，共计 $count 封';
$labels['fromtoshort'] = '$from – $to 共计 $count 个';
$labels['copy'] = '复制';
$labels['move'] = '移动';
$labels['moveto'] = '移至...';
$labels['copyto'] = '复制至';
$labels['download'] = '下载';
$labels['open'] = '打开';
$labels['showattachment'] = '显示';
$labels['showanyway'] = '总是显示';
$labels['filename'] = '文件名';
$labels['filesize'] = '文件大小';
$labels['addtoaddressbook'] = '添加至通讯录';
$labels['sun'] = '星期日';
$labels['mon'] = '星期一';
$labels['tue'] = '星期二';
$labels['wed'] = '星期三';
$labels['thu'] = '星期四';
$labels['fri'] = '星期五';
$labels['sat'] = '星期六';
$labels['sunday'] = '星期日';
$labels['monday'] = '星期一';
$labels['tuesday'] = '星期二';
$labels['wednesday'] = '星期三';
$labels['thursday'] = '星期四';
$labels['friday'] = '星期五';
$labels['saturday'] = '星期六';
$labels['jan'] = '一月';
$labels['feb'] = '二月';
$labels['mar'] = '三月';
$labels['apr'] = '四月';
$labels['may'] = '五月';
$labels['jun'] = '六月';
$labels['jul'] = '七月';
$labels['aug'] = '八月';
$labels['sep'] = '九月';
$labels['oct'] = '十月';
$labels['nov'] = '十一月';
$labels['dec'] = '十二月';
$labels['longjan'] = '一月';
$labels['longfeb'] = '二月';
$labels['longmar'] = '三月';
$labels['longapr'] = '四月';
$labels['longmay'] = '五月';
$labels['longjun'] = '六月';
$labels['longjul'] = '七月';
$labels['longaug'] = '八月';
$labels['longsep'] = '九月';
$labels['longoct'] = '十月';
$labels['longnov'] = '十一月';
$labels['longdec'] = '十二月';
$labels['today'] = '今天';
$labels['refresh'] = '刷新';
$labels['checkmail'] = '检查新邮件';
$labels['compose'] = '撰写新邮件';
$labels['writenewmessage'] = '写邮件';
$labels['reply'] = '回复';
$labels['replytomessage'] = '回复发件人';
$labels['replytoallmessage'] = '回复所有';
$labels['replyall'] = '回复全部';
$labels['replylist'] = '回复列表';
$labels['forward'] = '转发';
$labels['forwardinline'] = '直接转发';
$labels['forwardattachment'] = '以附件转发';
$labels['forwardmessage'] = '转发邮件';
$labels['bouncemsg'] = '重发 (回弹)';
$labels['bounce'] = '重发';
$labels['deletemessage'] = '删除邮件';
$labels['movemessagetotrash'] = '移至已删除邮件';
$labels['printmessage'] = '打印邮件';
$labels['previousmessage'] = '显示上一封邮件';
$labels['firstmessage'] = '显示第一封邮件';
$labels['nextmessage'] = '下一封';
$labels['lastmessage'] = '最后一封';
$labels['backtolist'] = '返回邮件列表';
$labels['viewsource'] = '显示来源';
$labels['mark'] = '标记为';
$labels['markmessages'] = '标记选中的邮件为';
$labels['markread'] = '已读';
$labels['markunread'] = '未读';
$labels['markflagged'] = '重要';
$labels['markunflagged'] = ' 不重要';
$labels['moreactions'] = '更多操作...';
$labels['markallread'] = '全部标为已读';
$labels['folders-cur'] = '仅选定的文件夹';
$labels['folders-sub'] = '选定的文件夹及其子文件夹';
$labels['folders-all'] = '所有文件夹';
$labels['more'] = '更多';
$labels['back'] = '返回';
$labels['options'] = '个人选项';
$labels['composeoptions'] = '撰写选项';
$labels['optionsandattachments'] = '选项和附件';
$labels['actions'] = '动作';
$labels['first'] = '首';
$labels['last'] = '尾';
$labels['previous'] = '前一';
$labels['next'] = '后一';
$labels['select'] = '选择';
$labels['all'] = '全部';
$labels['none'] = '无';
$labels['currpage'] = '当前页';
$labels['isread'] = '读';
$labels['unread'] = '未读邮件';
$labels['flagged'] = '已标记邮件';
$labels['unflagged'] = '未标记';
$labels['unanswered'] = '未回复邮件';
$labels['withattachment'] = '包含附件';
$labels['deleted'] = '已删除邮件';
$labels['undeleted'] = '未删除邮件';
$labels['replied'] = '已回复';
$labels['forwarded'] = '已转发';
$labels['invert'] = '反选';
$labels['filter'] = '过滤';
$labels['list'] = '列表';
$labels['threads'] = '主题';
$labels['expand-all'] = '展开全部';
$labels['expand-unread'] = '展开未读';
$labels['collapse-all'] = '收起全部';
$labels['threaded'] = '所有邮件';
$labels['autoexpand_threads'] = '展开消息主题';
$labels['do_expand'] = '所有主题';
$labels['expand_only_unread'] = '仅未读消息';
$labels['fromto'] = '发件人/收件人';
$labels['flag'] = '标志';
$labels['attachment'] = '附件';
$labels['nonesort'] = '无';
$labels['sentdate'] = '发送日期';
$labels['arrival'] = '到达日期';
$labels['asc'] = '升序';
$labels['desc'] = '降序';
$labels['listcolumns'] = '列表列';
$labels['listsorting'] = '排序列';
$labels['listorder'] = '排序';
$labels['listmode'] = '列表视图样式';
$labels['lmode'] = '列表模式';
$labels['layout'] = '布局';
$labels['layoutwidescreen'] = '宽屏';
$labels['layoutdesktop'] = '桌面';
$labels['layoutlist'] = '列表';
$labels['layoutwidescreendesc'] = '宽屏 (3栏)';
$labels['layoutdesktopdesc'] = '桌面 (很宽的列表，邮件预览在下方)';
$labels['layoutlistdesc'] = '纯列表 (无邮件预览)';
$labels['folderactions'] = '文件夹操作...';
$labels['compact'] = '压缩';
$labels['empty'] = '清空';
$labels['importmessages'] = '导入邮件';
$labels['quota'] = '邮箱容量';
$labels['unknown'] = '未知';
$labels['unlimited'] = '无限制';
$labels['quotatype'] = '容量类型';
$labels['quotatotal'] = '限额';
$labels['quotaused'] = '已用';
$labels['quotastorage'] = '存储空间';
$labels['quotamessage'] = '邮件数统计';
$labels['shortheaderdate'] = '在 $date';
$labels['shortheaderto'] = '在 $date 发给 $to';
$labels['shortheaderfrom'] = '在 $date 来自 $from';
$labels['quicksearch'] = '快速查找';
$labels['searchplaceholder'] = '搜索';
$labels['resetsearch'] = '清空';
$labels['searchmod'] = '修改搜索';
$labels['msgtext'] = '整封邮件';
$labels['body'] = '正文';
$labels['type'] = '类型：';
$labels['namex'] = '姓名';
$labels['searchscope'] = '范围';
$labels['currentfolder'] = '当前文件夹';
$labels['subfolders'] = '当前文件夹及其子文件夹';
$labels['allfolders'] = '所有文件夹';
$labels['searchinterval-1W'] = '早于一周';
$labels['searchinterval-1M'] = '早于一个月';
$labels['searchinterval-1Y'] = '早于一年';
$labels['searchinterval1W'] = '不到一周';
$labels['searchinterval1M'] = '不到一个月';
$labels['searchinterval1Y'] = '不到一年';
$labels['openinextwin'] = '在新窗口中打开';
$labels['emlsave'] = '下载(.eml)';
$labels['changeformattext'] = '以文本格式显示';
$labels['changeformathtml'] = '以 HTML 格式显示';
$labels['editasnew'] = '以新邮件编辑';
$labels['send'] = '发送';
$labels['sendmessage'] = '立即发送';
$labels['savemessage'] = '保存为草稿';
$labels['addattachment'] = '添加附件';
$labels['charset'] = '字符集';
$labels['editortype'] = '编辑器类型';
$labels['returnreceipt'] = '需要已读回执';
$labels['dsn'] = '投递状态通知';
$labels['mailreplyintro'] = '在 $date，$sender 写道：';
$labels['originalmessage'] = '原始邮件';
$labels['selectimage'] = '选择图片';
$labels['addimage'] = '添加图片';
$labels['selectmedia'] = '选择影片';
$labels['addmedia'] = '添加影片';
$labels['encrypt'] = '加密';
$labels['encryptmessage'] = '加密邮件';
$labels['encryptmessagemailvelope'] = '用 Mailvelope 加密邮件';
$labels['importpubkeys'] = '导入公钥';
$labels['encryptedsendialog'] = '正在发送加密的邮件';
$labels['encryptandsign'] = '加密并签名';
$labels['keyid'] = '密钥 ID';
$labels['keylength'] = '位';
$labels['keyexpired'] = '已过期';
$labels['keyrevoked'] = '已废除';
$labels['bccinstead'] = '使用密送';
$labels['addheader'] = '添加收件人 (信头)';
$labels['insert'] = '插入';
$labels['recipient'] = '收件人';
$labels['recipientedit'] = '编辑收件人';
$labels['editidents'] = '编辑身份';
$labels['spellcheck'] = '拼写';
$labels['checkspelling'] = '拼写检查';
$labels['resumeediting'] = '继续编辑';
$labels['revertto'] = '恢复至';
$labels['restore'] = '恢复信息';
$labels['restoremessage'] = '是否恢复信息？';
$labels['ignore'] = '忽略';
$labels['responses'] = '回复';
$labels['insertresponse'] = '插入回复';
$labels['manageresponses'] = '管理回复';
$labels['newresponse'] = '创建新回复';
$labels['addresponse'] = '添加回复';
$labels['editresponse'] = '编辑回复';
$labels['editresponses'] = '编辑回复';
$labels['responsename'] = '姓名';
$labels['responsetext'] = '以文本形式回复';
$labels['attach'] = '附加';
$labels['attachments'] = '附件';
$labels['upload'] = '上传';
$labels['uploadprogress'] = '$percent ($current of $total)';
$labels['close'] = '关闭';
$labels['messageoptions'] = '邮件选项...';
$labels['togglecomposeoptions'] = '切换布局选项';
$labels['attachmentrename'] = '重命名附件';
$labels['low'] = '低';
$labels['lowest'] = '最低';
$labels['normal'] = '普通';
$labels['high'] = '高';
$labels['highest'] = '最高';
$labels['nosubject'] = '(无主题)';
$labels['showimages'] = '显示图片';
$labels['allow'] = '允许';
$labels['alwaysshow'] = '总是显示来自 $sender 的图片';
$labels['alwaysallow'] = '总是允许来自 $sender 的信件';
$labels['isdraft'] = '这是一封草稿';
$labels['andnmore'] = '第 $nr 封或更多...';
$labels['headers'] = '信头';
$labels['togglemoreheaders'] = '显示更多消息头';
$labels['togglefullheaders'] = '切换至原始消息头';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = '纯文本';
$labels['savesentmessagein'] = '保存已发送邮件至';
$labels['dontsave'] = '不保存';
$labels['maxuploadsize'] = '上传附件最大不超过 $size';
$labels['addcc'] = '添加抄送';
$labels['addbcc'] = '添加密送';
$labels['addreplyto'] = '添加回复';
$labels['addfollowupto'] = '添加投递组';
$labels['mdnrequest'] = '发件人要求在您阅读这封邮件时发送已读通知。您是否希望通知发件人？';
$labels['receiptread'] = '发送回执(已读)';
$labels['yourmessage'] = '这是您的邮件回执';
$labels['receiptnote'] = '注意：回执只表示邮件在收件人的电脑上被打开过，不表示收件人已经阅读或了解邮件内容。';
$labels['zoomin'] = '放大';
$labels['zoomout'] = '缩小';
$labels['rotate'] = '旋转';
$labels['increaseimage'] = '增加图片大小';
$labels['decreaseimage'] = '减小图片大小';
$labels['rotateimage'] = '旋转图片';
$labels['showtools'] = '显示图像工具';
$labels['hidetools'] = '隐藏图像工具';
$labels['name'] = '显示名称';
$labels['firstname'] = '名字';
$labels['surname'] = '姓氏';
$labels['middlename'] = '中名';
$labels['nameprefix'] = '前缀';
$labels['namesuffix'] = '后缀';
$labels['nickname'] = '昵称';
$labels['jobtitle'] = '职位';
$labels['department'] = '部门';
$labels['gender'] = '性别';
$labels['maidenname'] = '娘家姓';
$labels['email'] = '邮件地址';
$labels['phone'] = '电话';
$labels['address'] = '地址';
$labels['street'] = '街道';
$labels['locality'] = '城市';
$labels['zipcode'] = '邮编';
$labels['region'] = '省份';
$labels['country'] = '国家';
$labels['birthday'] = '生日';
$labels['anniversary'] = '纪念日';
$labels['website'] = '主页';
$labels['instantmessenger'] = '即时通讯';
$labels['notes'] = '备注';
$labels['male'] = '男';
$labels['female'] = '女';
$labels['manager'] = '经理';
$labels['assistant'] = '助理';
$labels['spouse'] = '配偶';
$labels['allfields'] = '所有栏目';
$labels['search'] = '查询';
$labels['searchresult'] = '查找结果';
$labels['advsearch'] = '高级查询';
$labels['advanced'] = '高级选项';
$labels['other'] = '其他';
$labels['printcontact'] = '打印联系人';
$labels['qrcode'] = '二维码';
$labels['typehome'] = '家庭';
$labels['typework'] = '工作';
$labels['typeother'] = '其他';
$labels['typemobile'] = '手机';
$labels['typemain'] = '主要';
$labels['typehomefax'] = '家庭传真';
$labels['typeworkfax'] = '工作传真';
$labels['typecar'] = '车牌';
$labels['typepager'] = '呼机';
$labels['typevideo'] = '视频';
$labels['typeassistant'] = '助理';
$labels['typehomepage'] = '主页';
$labels['typeblog'] = '博客';
$labels['typeprofile'] = '资料';
$labels['addfield'] = '新增条目...';
$labels['addcontact'] = '添加联系人';
$labels['editcontact'] = '编辑联系人';
$labels['contacts'] = '联系人';
$labels['contactproperties'] = '联系人信息';
$labels['contactnameandorg'] = '姓名和公司';
$labels['personalinfo'] = '个人信息';
$labels['personal'] = '个人';
$labels['contactphoto'] = '联系人照片';
$labels['edit'] = '编辑';
$labels['cancel'] = '取消';
$labels['save'] = '保存';
$labels['delete'] = '删除';
$labels['discard'] = '丢弃';
$labels['continue'] = '继续';
$labels['ok'] = '确定';
$labels['rename'] = '重命名';
$labels['addphoto'] = '上传';
$labels['replacephoto'] = '替换照片';
$labels['uploadphoto'] = '上传照片';
$labels['newcontact'] = '新建联系人';
$labels['deletecontact'] = '删除选中的联系人';
$labels['composeto'] = '写信至选中的联系人';
$labels['contactsfromto'] = '第 $from 到 $to 个联系人，共 $count 个';
$labels['print'] = '打印';
$labels['export'] = '导出';
$labels['exportall'] = '导出全部';
$labels['exportsel'] = '导出选中';
$labels['exportvcards'] = '导出联系人为 vCard 格式';
$labels['newgroup'] = '创建新组';
$labels['addgroup'] = '新建组';
$labels['grouprename'] = '重命名群组';
$labels['groupdelete'] = '删除群组';
$labels['groupassign'] = '分配到分组…';
$labels['groupremove'] = '从分组中移除';
$labels['groupremoveselected'] = '删除选中';
$labels['uponelevel'] = '升一级';
$labels['previouspage'] = '上一页';
$labels['firstpage'] = '首页';
$labels['nextpage'] = '下一页';
$labels['lastpage'] = '末页';
$labels['group'] = '分组';
$labels['groups'] = '分组';
$labels['listgroup'] = '列出联系人名单';
$labels['personaladrbook'] = '个人通讯录';
$labels['searchsave'] = '保存搜索';
$labels['searchdelete'] = '删除搜索';
$labels['import'] = '导入';
$labels['importcontacts'] = '导入通讯录';
$labels['importfromfile'] = '从文件导入';
$labels['importtarget'] = '添加联系人至';
$labels['importreplace'] = '替换全部通讯录';
$labels['importgroups'] = '导入群组任务';
$labels['importgroupsall'] = '全部(如果需要则创建新的群组)';
$labels['importgroupsexisting'] = '仅限于已有群组';
$labels['done'] = '完成';
$labels['settingsfor'] = '设置';
$labels['about'] = '关于';
$labels['preferences'] = '选项';
$labels['userpreferences'] = '个人选项';
$labels['editpreferences'] = '修改个人选项';
$labels['identities'] = '发件人身份';
$labels['manageidentities'] = '管理身份';
$labels['newidentity'] = '创建新身份';
$labels['addidentity'] = '添加身份';
$labels['editidentity'] = '编辑身份';
$labels['identityencryption'] = '加密';
$labels['preferhtml'] = '以 HTML 格式显示';
$labels['defaultcharset'] = '默认字符集';
$labels['htmlmessage'] = 'HTML 邮件';
$labels['messagepart'] = '部分';
$labels['digitalsig'] = '数字签名';
$labels['dateformat'] = '日期格式';
$labels['timeformat'] = '时间格式';
$labels['prettydate'] = '短日期格式';
$labels['setdefault'] = '设为默认';
$labels['autodetect'] = '自动';
$labels['language'] = '语言';
$labels['timezone'] = '时区';
$labels['pagesize'] = '每页显示的邮件数量';
$labels['signature'] = '签名';
$labels['dstactive'] = '夏令时';
$labels['showinextwin'] = '在新窗口中打开';
$labels['composeextwin'] = '在新窗口中撰写';
$labels['htmleditor'] = '使用 HTML 编辑器';
$labels['htmlonreply'] = '仅当回复 HTML 邮件时';
$labels['htmlonreplyandforward'] = '仅当回复或转发 HTML 邮件时';
$labels['htmlsignature'] = '使用 HTML 签名';
$labels['showemail'] = '显示邮件地址时显示名字';
$labels['previewpane'] = '显示预览窗口';
$labels['skin'] = '界面皮肤';
$labels['logoutclear'] = '退出时清空回收站';
$labels['logoutcompact'] = '退出时压缩收件箱';
$labels['uisettings'] = '用户界面';
$labels['serversettings'] = '服务端设置';
$labels['mailboxview'] = '显示邮件';
$labels['mdnrequests'] = '发件人请求回执';
$labels['askuser'] = '询问用户';
$labels['autosend'] = '自动发送';
$labels['autosendknown'] = '对我的联系人发送回执，否则询问';
$labels['autosendknownignore'] = '对我的联系人发送回执，否则忽略';
$labels['ignorerequest'] = '忽略请求';
$labels['readwhendeleted'] = '删除后标记为已读';
$labels['flagfordeletion'] = '标记邮件为已删除而不是实际删除';
$labels['skipdeleted'] = '不显示标记为已删除的邮件';
$labels['deletealways'] = '如果移动邮件到回收站失败，则删除';
$labels['deletejunk'] = '直接删除垃圾邮箱中的邮件';
$labels['showremoteimages'] = '显示内嵌的图片';
$labels['allowremoteresources'] = '允许远程资源 (图片和样式表)';
$labels['fromknownsenders'] = '来自已知发件人';
$labels['always'] = '总是';
$labels['alwaysbutplain'] = '始终，除了回复纯文本';
$labels['showinlineimages'] = '在邮件下方显示附件中的图片';
$labels['autosavedraft'] = '自动保存到草稿箱';
$labels['everynminutes'] = '每隔 $n 分钟';
$labels['refreshinterval'] = '刷新间隔';
$labels['never'] = '从不';
$labels['immediately'] = '立即';
$labels['messagesdisplaying'] = '显示参数';
$labels['messagescomposition'] = '撰写邮件';
$labels['mimeparamfolding'] = '附件名';
$labels['2231folding'] = '完整的 RFC 2231（Thunderbird）';
$labels['miscfolding'] = 'RFC 2047/2232（MS Outlook）';
$labels['2047folding'] = '完整的 RFC 2047（其它）';
$labels['force7bit'] = '对 8 位字符使用 MIME 编码';
$labels['savelocalstorage'] = "保存到浏览器的本地存储（临时）";
$labels['advancedoptions'] = '高级选项';
$labels['toggleadvancedoptions'] = '切换高级选项';
$labels['focusonnewmessage'] = '新邮件到达时将窗口提升为焦点窗口';
$labels['checkallfolders'] = '检查所有邮件夹里的新邮件';
$labels['defaultfont'] = '默认的 HTML 格式字体';
$labels['mainoptions'] = '主要选项';
$labels['browseroptions'] = '浏览器选项';
$labels['section'] = '项目';
$labels['maintenance'] = '维护';
$labels['newmessage'] = '新邮件';
$labels['signatureoptions'] = '签名选项';
$labels['whenreplying'] = '当回复时';
$labels['replyempty'] = '不要引用原始邮件';
$labels['replytopposting'] = '在原文上面开始新邮件';
$labels['replytoppostingnoindent'] = '在引用上方开始写新的消息 (不要使用缩进)';
$labels['replybottomposting'] = '在原文下面开始新邮件';
$labels['replyremovesignature'] = '当回复时从邮件移除原始签名';
$labels['autoaddsignature'] = '自动插入签名';
$labels['newmessageonly'] = '仅新邮件';
$labels['replyandforwardonly'] = '仅回复和转发邮件';
$labels['insertsignature'] = '插入签名';
$labels['sigbelow'] = '在引文的下方放置签名';
$labels['sigseparator'] = '强制标准的签名分隔符';
$labels['automarkread'] = '标记为已读';
$labels['afternseconds'] = '$n 秒之后';
$labels['reqmdn'] = '总是要求回执';
$labels['reqdsn'] = '总是要求投递状态通知';
$labels['replysamefolder'] = '保存回复邮件到邮件相同的文件夹';
$labels['defaultabook'] = '默认地址薄';
$labels['autocompletesingle'] = '跳过自动完成的电子邮件地址';
$labels['listnamedisplay'] = '列出联系人为';
$labels['spellcheckbeforesend'] = '发邮件前进行拼写检查';
$labels['spellcheckoptions'] = '拼写检查选项';
$labels['spellcheckignoresyms'] = '忽略带符号的单词';
$labels['spellcheckignorenums'] = '忽略带数字的单词';
$labels['spellcheckignorecaps'] = '忽略所有大写字母的单词';
$labels['addtodict'] = '添加到字典中';
$labels['mailtoprotohandler'] = '注册为处理 mailto 链接的程序';
$labels['standardwindows'] = '以标准窗口的形式弹出窗口';
$labels['forwardmode'] = '邮件转发方式';
$labels['inline'] = '内嵌';
$labels['asattachment'] = '作为附件';
$labels['replyallmode'] = '[回复所有]按钮的默认动作';
$labels['replyalldefault'] = '回复全部';
$labels['replyalllist'] = '只回复邮件列表中的联系人(找到的)';
$labels['folder'] = '文件夹管理';
$labels['folders'] = '文件夹管理';
$labels['foldername'] = '邮件夹名称';
$labels['subscribed'] = '已订阅';
$labels['messagecount'] = '邮件数量';
$labels['create'] = '建立';
$labels['createfolder'] = '建立新邮件夹';
$labels['managefolders'] = '管理邮件夹';
$labels['specialfolders'] = '自定义邮件夹';
$labels['properties'] = '属性';
$labels['folderproperties'] = '文件夹属性';
$labels['parentfolder'] = '父文件夹';
$labels['location'] = '位置';
$labels['info'] = '信息';
$labels['getfoldersize'] = '获得文件夹容量';
$labels['changesubscription'] = '更改订阅';
$labels['foldertype'] = '文件夹类型';
$labels['personalfolder'] = '私有文件夹';
$labels['otherfolder'] = '他人文件夹';
$labels['sharedfolder'] = '共享文件夹';
$labels['findfolders'] = '查找文件夹';
$labels['findcontacts'] = '查找联系人';
$labels['findmail'] = '查找邮件';
$labels['namespace.personal'] = '个人';
$labels['namespace.other'] = '其他用户';
$labels['namespace.shared'] = '已共享';
$labels['dualuselabel'] = '只能包含';
$labels['dualusemail'] = '消息';
$labels['dualusefolder'] = '文件夹';
$labels['generate'] = '生成';
$labels['encryptioncreatekey'] = '创建新密钥对';
$labels['openmailvelopesettings'] = '打开 Mailvelope 设置';
$labels['encryptionprivkeysinmailvelope'] = '你的 Mailvelope 钥匙环中有 $nr 项符合条件的 PGP 私钥：';
$labels['encryptionnoprivkeysinmailvelope'] = '你的 Mailvelope 插件钥匙环中没有符合此发件人身份的 PGP 私钥。你想要生成一个以启用加密消息吗？';
$labels['encryption'] = '加密';
$labels['sortby'] = '排序';
$labels['sortasc'] = '递增排序';
$labels['sortdesc'] = '递减排序';
$labels['undo'] = '撤销';
$labels['installedplugins'] = '已安装插件';
$labels['plugin'] = '插件';
$labels['version'] = '版本';
$labels['source'] = '源代码';
$labels['license'] = '许可协议';
$labels['support'] = '支持';
$labels['savedsearches'] = '已保存的搜索';
$labels['dateformatY'] = 'YYYY';
$labels['dateformaty'] = 'YY';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = '英语';
$labels['westerneuropean'] = '西欧';
$labels['easterneuropean'] = '东欧';
$labels['southeasterneuropean'] = '东南欧';
$labels['baltic'] = '波罗的语';
$labels['cyrillic'] = '西里尔语';
$labels['arabic'] = '阿拉伯语';
$labels['greek'] = '希腊语';
$labels['hebrew'] = '希伯来语';
$labels['turkish'] = '土耳其语';
$labels['nordic'] = '北欧';
$labels['thai'] = '泰语';
$labels['celtic'] = '塞尔特语';
$labels['vietnamese'] = '越南语';
$labels['japanese'] = '日文';
$labels['korean'] = '韩语';
$labels['chinese'] = '中文';
$labels['arialabeltopnav'] = '窗口控制';
$labels['arialabeltasknav'] = '应用事务';
$labels['arialabeltoolbar'] = '应用工具栏';
$labels['arialabelactivetask'] = '活动事务';
$labels['arialabelmessagessearchfilter'] = '邮件列表过滤器';
$labels['arialabelmailsearchform'] = '邮件信息查询表单';
$labels['arialabelcontactsearchform'] = '联系人查询表单';
$labels['arialabelmailquicksearchbox'] = '邮件查询条件';
$labels['arialabelquicksearchbox'] = '查询条件';
$labels['arialabelfoldersearchfilter'] = '文件夹列出过滤器';
$labels['arialabelfoldersearchform'] = '文件夹搜索自';
$labels['arialabelfolderlist'] = '邮件文件夹选择';
$labels['arialabelmessagelist'] = '邮件信息列表';
$labels['arialabelmailpreviewframe'] = '邮件预览';
$labels['arialabelmailboxmenu'] = '文件夹操作菜单';
$labels['arialabellistselectmenu'] = '列表选择菜单';
$labels['arialabelthreadselectmenu'] = '线程列表菜单';
$labels['arialabelmessagelistoptions'] = '邮件列表显示和排序选项';
$labels['arialabelmailimportdialog'] = '邮件导入对话框';
$labels['arialabelmessagenav'] = '邮件导航';
$labels['arialabelmessagebody'] = '邮件正文';
$labels['arialabelmessageactions'] = '邮件动作';
$labels['arialabelcontactquicksearch'] = '联系人查询表单';
$labels['arialabelcontactsearchbox'] = '联系人查询条件';
$labels['arialabelmessageheaders'] = '邮件头';
$labels['arialabelforwardingoptions'] = '转发选项';
$labels['arialabelreplyalloptions'] = '回复全部选项';
$labels['arialabelmoremessageactions'] = '更多邮件选项';
$labels['arialabelmorecontactactions'] = '更多联系人操作';
$labels['arialabelmarkmessagesas'] = '标记选中邮件为...';
$labels['arialabelcomposeoptions'] = '布局选项';
$labels['arialabelresponsesmenu'] = '预设回复菜单';
$labels['arialabelattachmentuploadform'] = '附件上传表单';
$labels['arialabelattachmentmenu'] = '附件选项';
$labels['arialabelmailtomenu'] = '邮件地址选项';
$labels['arialabelattachmentpreview'] = '附件预览';
$labels['ariasummarycomposecontacts'] = '选择联系人或组作为收件人';
$labels['arialabelcontactexportoptions'] = '联系人导出选项';
$labels['arialabelabookgroupoptions'] = '地址簿/组选项';
$labels['arialabelpreferencesform'] = '偏好设置表单';
$labels['arialabelidentityeditfrom'] = '标识编辑表单';
$labels['arialabelresponseeditfrom'] = '回复编辑表单';
$labels['arialabelsearchterms'] = '搜索关键词';
$labels['arialabeldropactionmenu'] = '拖拽选项菜单';
$labels['arialabelheadersmenu'] = '收件人 (信头) 添加菜单';
$labels['arialabelimagetools'] = '图片工具';
$labels['helplistnavigation'] = '列表键盘导航';
$labels['helplistkeyboardnavigation'] = "方向键上/下：移动选中/焦点所在行。
空格键：选中焦点所在行。
Shift + 上/下：再选中上方/下方的行。
Ctrl + 空格键：将焦点所在行添加/移除选中。";
$labels['helplistkeyboardnavmessages'] = "方向键左/右：展开/折叠消息话题（仅话题模式下）
回车键：打开选中/焦点所在消息。
删除键：移动选中消息到垃圾箱。";
$labels['helplistkeyboardnavcontacts'] = "回车：打开选中的联系人";
