/***** modified styles for GoogieSpell *****/

.googie_window {
  font-size: 11px;
  width: 185px;
}

.googie_edit_layer {
  background-color: #ffffff;
  padding: 1px 3px;
  font-size: 9pt;
  font-family: monospace;
}

.googie_edit_layer span {
  font-family: monospace;
}

.googie_list {
  width: 100%;
  margin: 0;
  padding: 0;
}

.googie_list li {
  font-size: 11px;
  cursor: pointer;
  list-style-type: none;
}

.googie_list form {
  padding: 3px;
}

.googie_list_onhover {
  color: #FFFFFF;
  background-color: #CC3333;
}

.googie_list_onout {
  background-color: #fff;
}

.googie_list_selected {
  background-color: #cccccc;
  font-weight: bold;
}

.googie_list_close {
  font-size: 11px;
  color: #b91414;
}

.googie_list_onhover .googie_list_close {
  color: #FFFFFF;
}

.googie_list_revert {
  font-size: 11px;
  color: #b91414;
}

.googie_list_revert:hover {
  color: #fff;
}

.googie_link {
  color: #b91414;
  text-decoration: underline;
  cursor: pointer;
  font-size: 9pt;
  font-family: monospace;
}

.googie_check_spelling_link {
  color: #CC0000;
  font-size: 11px;
  text-decoration: none;
  cursor: pointer;
}

.googie_check_spelling_link:hover {
  text-decoration: underline;
}

.googie_no_style {
  text-decoration: none;
}

.googie_check_spelling_ok,
.googie_resume_editing {
  color: green;
  font-size: 11px;
  cursor: pointer;
}

.googie_check_spelling_ok:hover,
.googie_resume_editing:hover {
  text-decoration: underline;
}

.googie_lang_3d_click img {
  vertical-align: middle;
  border-top: 1px solid #555;
  border-left: 1px solid #555;
  border-right: 1px solid #b1b1b1;
  border-bottom: 1px solid #b1b1b1;
}

.googie_lang_3d_on img {
  vertical-align: middle;
  border-top: 1px solid #b1b1b1;
  border-left: 1px solid #b1b1b1;
  border-right: 1px solid #555;
  border-bottom: 1px solid #555;
}

.googie_ok_button {
  background: url(images/googiespell/ok.gif) no-repeat center center transparent;
  width: 32px;
  height: 16px;
  cursor: pointer;
  margin: 0 5px;
  text-indent: -5000px;
  border: 0 !important;
}
