/**
 * Roundcube webmail styles for the Settings section
 *
 * Copyright (c) The Roundcube Dev Team
 * Screendesign by FLINT / Büro für Gestaltung, bueroflint.com
 *
 * The contents are subject to the Creative Commons Attribution-ShareAlike
 * License. It is allowed to copy, distribute, transmit and to adapt the work
 * by keeping credits to the original autors in the README file.
 * See http://creativecommons.org/licenses/by-sa/3.0/ for details.
 */

#settings-sections {
	position: absolute;
	top: 0;
	left: 0;
	width: 200px;
	bottom: 0;
}

#pluginbody,
#settings-right {
	position: absolute;
	top: 0;
	left: 212px;
	right: 0;
	bottom: 0;
}

#sectionslist {
	position: absolute;
	top: 0;
	left: 0;
	width: 260px;
	bottom: 0;
}

#preferences-box {
	position: absolute;
	top: 0;
	left: 272px;
	right: 0;
	bottom: 0;
}

#preferences-frame {
	border: 0;
	border-radius: 4px;
}

#preferences-details fieldset.advanced legend {
	position: relative;
	display: block;
	width: 100%;
	cursor: pointer;
}

#preferences-details fieldset.advanced .propform {
	display: none;
}

#preferences-details fieldset.advanced .advanced-toggle {
	position: absolute;
	display: block;
	top: 0px;
	right: 6px;
	text-decoration: none;
	color: #666;
	font-size: 11px;
	width: 20px;
	height: 18px;
	background: url('images/listicons.png') 0 -1157px no-repeat;
	text-indent: -5000px;
	overflow: hidden;
}

#preferences-details fieldset.advanced .collapsed .advanced-toggle {
	background-position: -24px -1137px;
}

#preferences-details .identity-encryption-block {
	background-color: #eee;
	padding: 8px 10px;
}

#preferences-details .identity-encryption-block ul.keylist {
	list-style: none;
	margin: 8px 0 12px 0;
}

#preferences-details .identity-encryption-block ul.keylist {
	display: block;
	padding: 4px 10px 4px 0;
}

#sections-table tbody td,
#sections-table .listitem span,
#settings-sections .listitem a,
#settings-sections .tablink a {
	padding-left: 36px;
	background-image: url(images/listicons.png);
	background-position: -100px 0;
	background-repeat: no-repeat;
}

/* note: support span.tablink because this is used by plugins */
#settings-sections .listitem a,
#settings-sections .tablink a {
	background-position: 6px -862px;
}

#settings-sections .selected a,
#settings-sections .tablink.selected a {
	background-position: 6px -887px;
}

#settings-sections .preferences a {
	background-position: 6px -431px;
}

#settings-sections .preferences.selected a {
	background-position: 6px -455px;
}

#settings-sections .folders a {
	background-position: 6px 2px;
}

#settings-sections .folders.selected a {
	background-position: 6px -22px;
}

#sections-table #rcmrowfolders .section {
	background-position: 4px 2px;
}

#sections-table #rcmrowfolders.selected .section {
	background-position: 4px -22px;
}

#settings-sections .identities a {
	background-position: 6px -478px;
}

#settings-sections .identities.selected a {
	background-position: 6px -502px;
}

#settings-sections .filter a {
	background-position: 6px -1746px;
}

#settings-sections .filter.selected a {
	background-position: 6px -1770px;
}

#settings-sections .password a {
	background-position: 6px -1795px;
}

#settings-sections .password.selected a {
	background-position: 6px -1819px;
}

#settings-sections .responses a {
	background-position: 6px -1972px;
}

#settings-sections .responses.selected a {
	background-position: 6px -1996px;
}

#sections-table #rcmrowgeneral .section {
	background-position: 4px -573px;
}

#sections-table #rcmrowgeneral.selected .section {
	background-position: 4px -598px;
}

#sections-table #rcmrowmailbox .section {
	background-position: 4px -621px;
}

#sections-table #rcmrowmailbox.selected .section {
	background-position: 4px -646px;
}

#sections-table #rcmrowcompose .section {
	background-position: 4px -670px;
}

#sections-table #rcmrowcompose.selected .section {
	background-position: 4px -695px;
}

#sections-table #rcmrowmailview .section {
	background-position: 4px -718px;
}

#sections-table #rcmrowmailview.selected .section {
	background-position: 4px -742px;
}

#sections-table #rcmrowaddressbook .section {
	background-position: 4px -766px;
}

#sections-table #rcmrowaddressbook.selected .section {
	background-position: 4px -791px;
}

#sections-table #rcmrowserver .section {
	background-position: 4px -814px;
}

#sections-table #rcmrowserver.selected .section {
	background-position: 4px -838px;
}

#sections-table #rcmrowcalendar .section {
	background-position: 4px -526px;
}

#sections-table #rcmrowcalendar.selected .section {
	background-position: 4px -550px;
}

#sections-table #rcmrowencryption .section {
	background-position: 7px -2437px;
}

#sections-table #rcmrowencryption.selected .section {
	background-position: 7px -2461px;
}

#folderslist .boxtitle a.iconbutton.search {
	background-position: -2px -317px;
	cursor: pointer;
	position: absolute;
	right: 8px;
	top: 8px;
	width: 16px;
}

#folderslist .listsearchbox + .scroller {
	top: 34px;
}

.listsearchbox select {
	width: 100%;
	margin: 0 0 4px 0;
}

#folderslist,
#identitieslist,
#responseslist {
	position: absolute;
	top: 0;
	left: 0;
	width: 260px;
	bottom: 0;
}

#identities-table,
#responses-table {
	width: 100%;
	table-layout: fixed;
}

#identities-table tbody td.mail {
	width: 100%;
	overflow: hidden;
	text-overflow: ellipsis;
}

#identities-table tbody tr.readonly td {
	font-style: italic;
}

#folder-details,
#identity-details,
#response-details {
	position: absolute;
	top: 0;
	left: 272px;
	right: 0;
	bottom: 0;
}

#subscription-table li.root {
	font-size: 5%;
	line-height: 5px;
	height: 5px;
	padding: 2px;
}

#subscription-table li input {
	position: absolute;
	right: 8px;
	top: 4px;
	margin-right: 0;
}

#subscription-table li a {
	padding-right: 28px;
}

.skinselection {
	display: block;
}

.skinselection span {
	display: inline-block;
	vertical-align: middle;
	padding-right: 1em;
}

.skinselection .skinname {
	font-weight: bold;
}

.skinselection .skinlicense,
.skinselection .skinlicense a {
	font-style: italic;
	color: #666;
	text-decoration: none;
}

.skinselection .skinlicense a:hover {
	text-decoration: underline;
}

img.skinthumbnail {
	width: 64px;
	height: 64px;
	border: 1px solid #ccc;
	background: #fff;
	border-radius: 4px;
}

#pluginlist td.version {
	width: 5em;
}

.webkit #pluginlist td.version {
	width: 6em;
}

#pluginlist td.license,
#pluginlist td.source {
	width: 8em;
}

.webkit #pluginlist td.license,
.webkit #pluginlist td.source {
	width: 9em;
}

#rcmfd_signature {
	width: 99%;
	min-width: 390px;
	font-family: monospace;
}

#rcmfd_signature_toolbar1 td,
#rcmfd_signature_toolbar2 td {
	width: auto;
}

.mailtoprotohandler-status {
	padding-left: 1em;
	font-style: italic;
}

#pluginlist {
	table-layout: auto;
}

#pluginlist th.version {
	width: 1%;
}

.readtext {
	width: 45em;
	padding: 12px;
	font-size: 12px;
}

.readtext > h1,
.readtext > h2,
.readtext > h3 {
	margin-top: 0;
}
