<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Compartilhamento';
$labels['myrights'] = 'Permissões de Acesso';
$labels['username'] = 'Usuário:';
$labels['advanced'] = 'Modo avançado';
$labels['add'] = 'Adicionar';
$labels['newuser'] = 'Adicionar entrada';
$labels['editperms'] = 'Editar permissões';
$labels['actions'] = 'Ações de direito de acesso...';
$labels['anyone'] = 'Todos os usuários (qualquer um)';
$labels['anonymous'] = 'Convidados (anônimos)';
$labels['identifier'] = 'Identificador';
$labels['acll'] = 'Pesquisar';
$labels['aclr'] = 'Ler mensagens';
$labels['acls'] = 'Manter estado de enviado';
$labels['aclw'] = 'Salvar marcadores';
$labels['acli'] = 'Inserir (Cópia em)';
$labels['aclp'] = 'Enviar';
$labels['aclc'] = 'Criar subpastas';
$labels['aclk'] = 'Criar subpastas';
$labels['acld'] = 'Apagar mensagens';
$labels['aclt'] = 'Apagar mensagens';
$labels['acle'] = 'Expurgar';
$labels['aclx'] = 'Excluir pasta';
$labels['acla'] = 'Administrar';
$labels['acln'] = 'Inserir anotações nas mensagens';
$labels['aclfull'] = 'Controle total';
$labels['aclother'] = 'Outro';
$labels['aclread'] = 'Ler';
$labels['aclwrite'] = 'Salvar';
$labels['acldelete'] = 'Excluir';
$labels['shortacll'] = 'Pesquisar';
$labels['shortaclr'] = 'Ler';
$labels['shortacls'] = 'Manter';
$labels['shortaclw'] = 'Salvar';
$labels['shortacli'] = 'Inserir';
$labels['shortaclp'] = 'Enviar';
$labels['shortaclc'] = 'Criar';
$labels['shortaclk'] = 'Criar';
$labels['shortacld'] = 'Excluir';
$labels['shortaclt'] = 'Excluir';
$labels['shortacle'] = 'Expurgar';
$labels['shortaclx'] = 'Excluir pasta';
$labels['shortacla'] = 'Administrar';
$labels['shortacln'] = 'Anotar';
$labels['shortaclother'] = 'Outro';
$labels['shortaclread'] = 'Ler';
$labels['shortaclwrite'] = 'Salvar';
$labels['shortacldelete'] = 'Excluir';
$labels['longacll'] = 'A pasta está visível nas listas e pode ser inscrita para';
$labels['longaclr'] = 'A pasta pode ser aberta para leitura';
$labels['longacls'] = 'Marcador de Mensagem Enviada pode ser modificadas';
$labels['longaclw'] = 'Marcadores de mensagens e palavras-chave podem ser modificadas, exceto de Enviadas e Excluídas';
$labels['longacli'] = 'As mensagens podem ser escritas ou copiadas para a pasta';
$labels['longaclp'] = 'As mensagens podem ser enviadas para esta pasta';
$labels['longaclc'] = 'As pastas podem ser criadas (ou renomeadas) diretamente sob esta pasta';
$labels['longaclk'] = 'As pastas podem ser criadas (ou renomeadas) diretamente sob esta pasta';
$labels['longacld'] = 'O marcador de Mensagens Excluídas podem ser modificadas';
$labels['longaclt'] = 'O marcador de Mensagens Excluídas podem ser modificadas';
$labels['longacle'] = 'As mensagens podem ser expurgadas';
$labels['longaclx'] = 'A pasta pode ser apagada ou renomeada';
$labels['longacla'] = 'As permissões de acesso da pasta podem ser alteradas';
$labels['longacln'] = 'Metadados compartilhados das mensagens (anotações) podem ser alterados';
$labels['longaclfull'] = 'Controle total incluindo a pasta de administração';
$labels['longaclread'] = 'A pasta pode ser aberta para leitura';
$labels['longaclwrite'] = 'As mensagens podem ser marcadas, salvas ou copiadas para a pasta';
$labels['longacldelete'] = 'Mensagens podem ser apagadas';
$labels['longaclother'] = 'Outras permissões de acesso';
$labels['ariasummaryacltable'] = 'Lista de permissões de acesso';
$labels['arialabelaclactions'] = 'Lista de ações';
$labels['arialabelaclform'] = 'Formulário de permissões de acesso';
$messages['deleting'] = 'Apagando permissões de acesso...';
$messages['saving'] = 'Salvando permissões de acesso...';
$messages['updatesuccess'] = 'Permissões de acesso alteradas com sucesso';
$messages['deletesuccess'] = 'Permissões de acesso apagadas com sucesso';
$messages['createsuccess'] = 'Permissões de acesso adicionadas com sucesso';
$messages['updateerror'] = 'Não foi possível atualizar as permissões de acesso';
$messages['deleteerror'] = 'Não foi possível apagar as permissões de acesso';
$messages['createerror'] = 'Não foi possível adicionar as permissões de acesso';
$messages['deleteconfirm'] = 'Tem certeza que deseja remover as permissões de acesso do(s) usuário(s) delecionado(s)?';
$messages['norights'] = 'Não foram definidas permissões!';
$messages['nouser'] = 'Nome de usuário não especificado!';
