<roundcube:object name="doctype" value="html5" />
<html>
<head>
<roundcube:include file="/includes/links.html" />
</head>
<body>

<h1 class="voice"><roundcube:object name="productname" /> <roundcube:label name="login" /></h1>

<div id="login-form">
<div class="box-inner" role="main">
<roundcube:object name="logo" src="/images/roundcube_logo.png" id="logo" />

<roundcube:form name="form" method="post">
<roundcube:object name="loginform" form="form" size="40" submit=true />
</form>

</div>

<div class="box-bottom" role="complementary">
	<roundcube:object name="message" id="message" />
	<noscript>
		<p class="noscriptwarning"><roundcube:label name="noscriptwarning" /></p>
	</noscript>
</div>

<div id="bottomline" role="contentinfo">
	<roundcube:object name="productname" condition="config:display_product_info &gt; 0" /> <roundcube:object name="version" condition="config:display_product_info == 2" />
	<roundcube:if condition="config:support_url" />
		&nbsp;&#9679;&nbsp; <a href="<roundcube:var name='config:support_url' />" target="_blank" class="support-link"><roundcube:label name="support" /></a>
	<roundcube:endif />
	<roundcube:container name="loginfooter" id="bottomline" />
</div>
</div>

<roundcube:include file="/includes/footer.html" />

<roundcube:object name="preloader" images="
  /images/ajaxloader.gif
  /images/ajaxloader_dark.gif
  /images/buttons.png
  /images/addcontact.png
  /images/filetypes.png
  /images/listicons.png
  /images/messages.png
  /images/messages_dark.png
  /images/quota.png
  /images/selector.png
  /images/splitter.png
  /images/watermark.jpg
" />

</body>
</html>
