<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Compartición';
$labels['myrights'] = 'Drechos d\'accesu';
$labels['username'] = 'Usuariu:';
$labels['advanced'] = 'Mou avanzáu';
$labels['add'] = 'Amestar';
$labels['newuser'] = 'Amestar entrada';
$labels['editperms'] = 'Editar permisos';
$labels['actions'] = 'Aición de drechos d\'accesu...';
$labels['anyone'] = 'Tolos usuarios (toos)';
$labels['anonymous'] = 'Convidaos (anónimos)';
$labels['identifier'] = 'Identificador';
$labels['acll'] = 'Guetar';
$labels['aclr'] = 'Lleer mensaxes';
$labels['acls'] = 'Estáu Caltener Vistu';
$labels['aclw'] = 'Escribir banderes';
$labels['acli'] = 'Inxertar (copiar a)';
$labels['aclc'] = 'Crear subcarpetes';
$labels['aclk'] = 'Crear subcarpetes';
$labels['acld'] = 'Desaniciar mensaxes';
$labels['aclt'] = 'Desaniciar mensaxes';
$labels['acle'] = 'Desanciar';
$labels['aclx'] = 'Desaniciar carpeta';
$labels['acla'] = 'Alministrar';
$labels['aclfull'] = 'Control total';
$labels['aclother'] = 'Otru';
$labels['aclread'] = 'Lleer';
$labels['aclwrite'] = 'Escribir';
$labels['acldelete'] = 'Desaniciar';
$labels['shortacll'] = 'Guetar';
$labels['shortaclr'] = 'Lleer';
$labels['shortacls'] = 'Caltener';
$labels['shortaclw'] = 'Escribir';
$labels['shortacli'] = 'Inxertar';
$labels['shortaclc'] = 'Crear';
$labels['shortaclk'] = 'Crear';
$labels['shortacld'] = 'Desaniciar';
$labels['shortaclt'] = 'Desaniciar';
$labels['shortacle'] = 'Desaniciar';
$labels['shortaclx'] = 'Desaniciu de carpeta';
$labels['shortacla'] = 'Alministrar';
$labels['shortaclother'] = 'Otru';
$labels['shortaclread'] = 'Lleer';
$labels['shortaclwrite'] = 'Escribir';
$labels['shortacldelete'] = 'Desaniciar';
$labels['longacll'] = 'La carpeta ye visible nes llistes y pue soscribise a';
$labels['longaclr'] = 'La carpeta nun pue abrise pa leer';
$labels['longaclx'] = 'La carpeta pue desaniciase o renomase';
$labels['longacla'] = 'Puen camudase los drechos d\'accesu de la carpeta';
$labels['longaclfull'] = 'Control completu incluyendo l\'alminitración de carpeta';
$labels['longaclread'] = 'La carpeta pue abrise pa llectura';
$labels['longaclwrite'] = 'Los mensaxes puen conseñase, escribise o copiase a la carpeta';
$labels['longacldelete'] = 'Los mensaxes puen desaniciase';
$labels['longaclother'] = 'Otros drechos d\'accesu';
$labels['ariasummaryacltable'] = 'Llista de drechos d\'accesu';
$messages['deleting'] = 'Desaniciando los drechos d\'accesu...';
$messages['saving'] = 'Guardando los drechos d\'accesu...';
$messages['updatesuccess'] = 'Camudaos con ésitu los drechos d\'accesu';
$messages['deletesuccess'] = 'Desaniciaos con ésitu los drechos d\'accesu';
$messages['createsuccess'] = 'Amestaos con ésitu los drechos d\'accesu';
$messages['updateerror'] = 'Nun puen anovase los drechos d\'accesu';
$messages['deleteerror'] = 'Nun puen desaniciase los drechos d\'accesu';
$messages['createerror'] = 'Nun puen amestase los drechos d\'accesu';
$messages['deleteconfirm'] = '¿De xuru quies desaniciar los drechos d\'accesu al(a los) usuariu(os) esbilláu(os)?';
