<roundcube:object name="doctype" value="html5" />
<html>
<head>
<roundcube:include file="/includes/links.html" />
</head>
<body class="iframe">

<h1 class="boxtitle"><roundcube:label name="contactproperties" /></h1>

<div id="contact-details" class="boxcontent">
	<roundcube:if condition="strlen(env:sourcename)" />
		<div id="sourcename"><roundcube:label name="addressbook" />: <roundcube:var name="env:sourcename" /></div>
	<roundcube:endif />

	<div id="contactphoto"><roundcube:object name="contactphoto" id="contactpic" placeholder="/images/contactpic.png" placeholderGroup="/images/contactgroup.png" /></div>
	<roundcube:object name="contacthead" id="contacthead" />
	<br style="clear:both" />

	<div id="contacttabs" class="tabbed">
		<roundcube:object name="contactdetails" />
	</div>

</div>

<div id="headerbuttons" class="formbuttons">
	<roundcube:button command="edit" type="input" class="button mainaction" label="editcontact" condition="!ENV:readonly" />
</div>

<roundcube:include file="/includes/footer.html" />

</body>
</html>
