<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Deiling';
$labels['myrights'] = 'Atgongdar-rættindi';
$labels['username'] = 'Brúkari:';
$labels['advanced'] = 'Víðkað útgáva';
$labels['add'] = 'Legg aftrat';
$labels['newuser'] = 'Legg inn';
$labels['editperms'] = 'Broyt atgonguloyvi';
$labels['actions'] = 'Stillingar til atgongu-rættindi';
$labels['anyone'] = 'Allir brúkarir (øll)';
$labels['anonymous'] = 'Gestir (dulnevnd)';
$labels['identifier'] = 'dátuheiti';
$labels['acll'] = 'Slá upp';
$labels['aclr'] = 'Les boð';
$labels['acls'] = 'Varveit lisna støðu';
$labels['aclw'] = 'Hvít Fløgg';
$labels['acli'] = 'Set inn (Copy into)';
$labels['aclp'] = 'Send';
$labels['aclc'] = 'Ger undurmappur';
$labels['aclk'] = 'Ger undurmappur';
$labels['acld'] = 'Strika boð';
$labels['aclt'] = 'Strika boð';
$labels['acle'] = 'Strika út';
$labels['aclx'] = 'Strika mappu';
$labels['acla'] = 'Umsit';
$labels['acln'] = 'Viðmerk boð';
$labels['aclfull'] = 'Full stýring';
$labels['aclother'] = 'Annað';
$labels['aclread'] = 'Les';
$labels['aclwrite'] = 'Skriva';
$labels['acldelete'] = 'Strika';
$labels['shortacll'] = 'Leita';
$labels['shortaclr'] = 'Les';
$labels['shortacls'] = 'Varveit';
$labels['shortaclw'] = 'Skriva';
$labels['shortacli'] = 'Legg inn';
$labels['shortaclp'] = 'Send';
$labels['shortaclc'] = 'Stovna';
$labels['shortaclk'] = 'Stovna';
$labels['shortacld'] = 'Strika';
$labels['shortaclt'] = 'Strika';
$labels['shortacle'] = 'Strika út';
$labels['shortaclx'] = 'Strika mappu';
$labels['shortacla'] = 'Umsit';
$labels['shortacln'] = 'Viðmerk';
$labels['shortaclother'] = 'Annað';
$labels['shortaclread'] = 'Les';
$labels['shortaclwrite'] = 'Skriva';
$labels['shortacldelete'] = 'Strika';
$labels['longacll'] = 'Mappan er sjónlig á listum og til ber at tekna seg fyri hana';
$labels['longaclr'] = 'Mappan kann verða opna til lesná';
$labels['longacls'] = 'Viðmerki ið vísur á lisin boð kann broytast';
$labels['longaclw'] = 'Boð viðmerki og lyklaorð kunnu øll broytast, undantikið Sæð og Strika';
$labels['longacli'] = 'Boð kunnu verða skriva og flutt til eina aðra mappu';
$labels['longaclp'] = 'Boð kunnu verða send til hesa mappu';
$labels['longaclc'] = 'Mappur kunnu verða stovnaðar (ella umdoyptar) beinleiðis undir hesu mappu';
$labels['longaclk'] = 'Mappur kunnu verða stovnaðar (ella umdoyptar) beinleiðis undir hesu mappu';
$labels['longacld'] = 'Viðmerki ið vísur á strika boð kann broytast';
$labels['longaclt'] = 'Viðmerki ið vísur á strika boð kann broytast';
$labels['longacle'] = 'Boð kunnu verða strika út';
$labels['longaclx'] = 'Mappan kann verða strika ella umdoypt';
$labels['longacla'] = 'Atgongdu-rættindini til hesa mappu kunnu broytast';
$labels['longacln'] = '"Metadata" (viðmerking) av boðum kann broytast';
$labels['longaclfull'] = 'Full stýring, írokna mappu-umsiting';
$labels['longaclread'] = 'Mappan kann latast upp til lesná';
$labels['longaclwrite'] = 'Boð kunnu verða viðmerkt, skriva ella avritast til mappuna';
$labels['longacldelete'] = 'Boð kunnu verða strikað';
$labels['longaclother'] = 'Aðrar heimildir';
$labels['ariasummaryacltable'] = 'Listi yvir brúkara heimildum';
$labels['arialabelaclactions'] = 'Vís gerðir';
$labels['arialabelaclform'] = 'Heimilda frymil';
$messages['deleting'] = 'Strikar atgongu-rættindi...';
$messages['saving'] = 'Goymur atgongu-rættindi...';
$messages['updatesuccess'] = 'Atgongu-rættindi broytt væleyndað';
$messages['deletesuccess'] = 'Atgongu-rættindi strika væleyndað';
$messages['createsuccess'] = 'Atgongu-rættindi stovna væleyndað';
$messages['updateerror'] = 'Til ber ikki at dagføra atgongu-rættindi';
$messages['deleteerror'] = 'Til ber ikki at strika atgongu-rættindi';
$messages['createerror'] = 'Til ber ikki at leggja aftrat atgongu-rættindi';
$messages['deleteconfirm'] = 'Ert tú vís/ur í at tú ynskir at strika atgongu-rættindini hjá valdum brúkar(um)?';
$messages['norights'] = 'Eingi rættindi tilskilað!';
$messages['nouser'] = 'Einki brúkaranavn var tilskilað!';
