<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = '보관';
$labels['buttontitle'] = '이 메시지를 보관 편지함에 저장';
$labels['archived'] = '성공적으로 보관함';
$labels['archivedreload'] = '성공적으로 보관되었습니다. 페이지를 다시 불러와서 새로운 보관 편지함 폴더를 확인하세요.';
$labels['archiveerror'] = '일부 메시지가 보관되지 않음';
$labels['archivefolder'] = '보관 편지함';
$labels['settingstitle'] = '보관 편지함';
$labels['archivetype'] = '보관된 메시지 정리 기준';
$labels['archivetypeyear'] = '연도 (예: 보관/2012)';
$labels['archivetypemonth'] = '월 (예: 보관/2012/06)';
$labels['archivetypetbmonth'] = '월 - 썬더버드 호환 (예: 보관/2012/2012-06)';
$labels['archivetypefolder'] = '원본 폴더';
$labels['archivetypefolderyear'] = '연도 및 원래 폴더 (예: 보관/2012/...)';
$labels['archivetypefoldermonth'] = '연, 월 및 원래 폴더 (예: 보관/2012/06/...)';
$labels['archivetypesender'] = '발송자 이메일';
$labels['unkownsender'] = '알 수 없음';
$labels['readonarchive'] = '보관 편지함에서 메시지를 읽음으로 표시';
