<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'ברוך בואך אל $product';
$labels['username'] = 'שם משתמש';
$labels['password'] = 'סיסמה';
$labels['server'] = 'שרת';
$labels['login'] = 'כניסה';
$labels['oauthlogin'] = 'כניסה עם provider$';
$labels['menu'] = 'תפריט';
$labels['logout'] = 'יציאה';
$labels['mail'] = 'רשימת הודעות';
$labels['settings'] = 'הגדרות אישיות';
$labels['addressbook'] = 'פנקס כתובות';
$labels['darkmode'] = 'רקע כהה';
$labels['lightmode'] = 'רקע בהיר';
$labels['inbox'] = 'נכנס';
$labels['drafts'] = 'טיוטות';
$labels['sent'] = 'נשלח';
$labels['trash'] = 'אשפה';
$labels['junk'] = 'זבל';
$labels['show_real_foldernames'] = 'הצגת שמות אמיתיים של תיקיות מיוחדות';
$labels['subject'] = 'נושא';
$labels['from'] = 'מאת';
$labels['sender'] = 'השולח';
$labels['to'] = 'אל';
$labels['cc'] = 'לידיעה';
$labels['bcc'] = 'מכותב מוסתר';
$labels['replyto'] = 'כתובת למענה';
$labels['followupto'] = 'כתובת להעברת הודעה';
$labels['date'] = 'תאריך';
$labels['size'] = 'גודל';
$labels['priority'] = 'עדיפות';
$labels['organization'] = 'ארגון';
$labels['readstatus'] = 'נקרא';
$labels['listoptions'] = 'הצגת אפשרויות...';
$labels['listoptionstitle'] = 'רשימת אפשרויות';
$labels['mailboxlist'] = 'תיקיות';
$labels['messagesfromto'] = 'הודעות $from עד $to מתוך $count';
$labels['threadsfromto'] = 'שרשור $from עד $to מתוך $count';
$labels['messagenrof'] = 'הודעה $nr מתוך $count';
$labels['fromtoshort'] = '$from – $to מתוך $count';
$labels['copy'] = 'העתק';
$labels['move'] = 'העבר';
$labels['moveto'] = 'תיוק ב...';
$labels['copyto'] = 'העתקה אל...';
$labels['download'] = 'הורדה';
$labels['open'] = 'לפתוח';
$labels['showattachment'] = 'הצגה';
$labels['showanyway'] = 'להציג בכל מקרה';
$labels['filename'] = 'שם קובץ';
$labels['filesize'] = 'גודל קובץ';
$labels['addtoaddressbook'] = 'הוספה לפנקס כתובות';
$labels['sun'] = 'יום א';
$labels['mon'] = 'יום ב';
$labels['tue'] = 'יום ג';
$labels['wed'] = 'יום ד';
$labels['thu'] = 'יום ה';
$labels['fri'] = 'יום ו';
$labels['sat'] = 'יום ש';
$labels['sunday'] = 'ראשון';
$labels['monday'] = 'שני';
$labels['tuesday'] = 'שלישי';
$labels['wednesday'] = 'רביעי';
$labels['thursday'] = 'חמישי';
$labels['friday'] = 'ששי';
$labels['saturday'] = 'שבת';
$labels['jan'] = 'ינו';
$labels['feb'] = 'פבר';
$labels['mar'] = 'מרץ';
$labels['apr'] = 'אפר';
$labels['may'] = 'מאי';
$labels['jun'] = 'יונ';
$labels['jul'] = 'יול';
$labels['aug'] = 'אוג';
$labels['sep'] = 'ספט';
$labels['oct'] = 'אוק';
$labels['nov'] = 'נוב';
$labels['dec'] = 'דצמ';
$labels['longjan'] = 'ינואר';
$labels['longfeb'] = 'פברואר';
$labels['longmar'] = 'מרץ';
$labels['longapr'] = 'אפריל';
$labels['longmay'] = 'מאי';
$labels['longjun'] = 'יוני';
$labels['longjul'] = 'יולי';
$labels['longaug'] = 'אוגוסט';
$labels['longsep'] = 'ספטמבר';
$labels['longoct'] = 'אוקטובר';
$labels['longnov'] = 'נובמבר';
$labels['longdec'] = 'דצמבר';
$labels['today'] = 'היום';
$labels['refresh'] = 'רענון';
$labels['checkmail'] = 'משיכת הודעות חדשות';
$labels['compose'] = 'כתיבת הודעה';
$labels['writenewmessage'] = 'יצירת הודעה חדשה';
$labels['reply'] = 'תגובה';
$labels['replytomessage'] = 'מענה לשולח';
$labels['replytoallmessage'] = 'מענה לשולח ולכל הנמענים';
$labels['replyall'] = 'מענה לכולם';
$labels['replylist'] = 'מענה לרשימת תפוצה';
$labels['forward'] = 'העברה';
$labels['forwardinline'] = 'העבר בגוף ההודעה';
$labels['forwardattachment'] = 'העבר כצרופה';
$labels['forwardmessage'] = 'העבר הודעה';
$labels['bouncemsg'] = 'שליחה מחדש (כי המערכת החזירה את המשלוח)';
$labels['bounce'] = 'שליחה מחדש';
$labels['deletemessage'] = 'מחיקה';
$labels['movemessagetotrash'] = 'השלכה לאשפה';
$labels['printmessage'] = 'הדפסה';
$labels['previousmessage'] = 'הצגת הודעה קודמת';
$labels['firstmessage'] = 'הצגת ההודעה הראשונה';
$labels['nextmessage'] = 'הצגת ההודעה הבאה';
$labels['lastmessage'] = 'הצגת ההודעה האחרונה';
$labels['backtolist'] = 'חזרה אל רשימת ההודעות';
$labels['viewsource'] = 'הצגת קוד מקור';
$labels['mark'] = 'סימון';
$labels['markmessages'] = 'סימון הודעות';
$labels['markread'] = 'כנקראו';
$labels['markunread'] = 'כלא נקראו';
$labels['markflagged'] = 'כמסומן';
$labels['markunflagged'] = 'כלא מסומן';
$labels['moreactions'] = 'פעולות נוספות...';
$labels['markallread'] = 'סימון כל ההודעות כאילו נקראו';
$labels['folders-cur'] = 'רק התיקיה שנבחרה';
$labels['folders-sub'] = 'רק התיקיה שנבחרה ותת התיקיות שלה';
$labels['folders-all'] = 'כל התיקיות';
$labels['more'] = 'עוד';
$labels['back'] = 'חזרה';
$labels['options'] = 'אפשרויות';
$labels['composeoptions'] = 'אפשרויות יצירת הודעה';
$labels['optionsandattachments'] = 'אפשרויות וצרופות';
$labels['actions'] = 'פעולות';
$labels['first'] = 'ראשונה';
$labels['last'] = 'אחרונה';
$labels['previous'] = 'הקודמת';
$labels['next'] = 'הבאה';
$labels['select'] = 'בחירה';
$labels['selection'] = 'בחירה';
$labels['all'] = 'הכל';
$labels['none'] = 'כלום';
$labels['currpage'] = 'דף נוכחי';
$labels['isread'] = 'קריאה';
$labels['unread'] = 'לא נקראו';
$labels['flagged'] = 'מסומן';
$labels['unflagged'] = 'לא מדוגלת';
$labels['unanswered'] = 'לא נענה';
$labels['withattachment'] = 'עם צרופה';
$labels['deleted'] = 'נמחק';
$labels['undeleted'] = 'לא נמחק';
$labels['replied'] = 'נענתה';
$labels['forwarded'] = 'קודמה';
$labels['invert'] = 'היפוך הסימון';
$labels['filter'] = 'סינון';
$labels['list'] = 'רשימה';
$labels['threads'] = 'שרשור';
$labels['expand-all'] = 'הרחבה כלית';
$labels['expand-unread'] = 'הרחבה טרם נקרא';
$labels['collapse-all'] = 'כינוס כללי';
$labels['threaded'] = 'משורשר';
$labels['showunread'] = 'הצגת הודעות שלא נקראו';
$labels['autoexpand_threads'] = 'הרחבת הודעות משורשרות';
$labels['do_expand'] = 'כל השרשורים';
$labels['expand_only_unread'] = 'רק עם הודעות שטרם נקראו';
$labels['fromto'] = 'שולח/נמען';
$labels['flag'] = 'דגל';
$labels['attachment'] = 'צרופה';
$labels['nonesort'] = 'כלום';
$labels['sentdate'] = 'תאריך משלוח';
$labels['arrival'] = 'תאריך הגעה';
$labels['asc'] = 'בסדר עולה';
$labels['desc'] = 'בסדר יורד';
$labels['listcolumns'] = 'רשימת עמודות';
$labels['listsorting'] = 'המיון לפי העמודה';
$labels['listorder'] = 'סדר מיון';
$labels['listmode'] = 'אופן הצגת רשימה';
$labels['lmode'] = 'מצב רשימה';
$labels['layout'] = 'מערך';
$labels['layoutwidescreen'] = 'מסך רחב';
$labels['layoutdesktop'] = 'מחשב שולחני';
$labels['layoutlist'] = 'רשימה';
$labels['layoutwidescreendesc'] = 'פריסה רחבה (3 טורים)';
$labels['layoutdesktopdesc'] = 'שולחן עבודה (פריסה רחבה והצגת ההודעה למטה)';
$labels['layoutlistdesc'] = 'רשימה (ללא הצגת ההודעה)';
$labels['folderactions'] = 'פעולות על תיקיות';
$labels['compact'] = 'פינוי שטח לא מנוצל';
$labels['empty'] = 'ריקון';
$labels['importmessages'] = 'ייבוא הודעות';
$labels['mailimportdesc'] = 'ניתן להעלות דוא"ל באמצעות קבצים המקודדים כ MIME או MBOX';
$labels['mailimportzip'] = 'ניתן לדחוס מספר קבצים לתוך ארכיון ZIP';
$labels['quota'] = 'ניצול קיבולת';
$labels['unknown'] = 'לא ידוע';
$labels['unlimited'] = 'ללא הגבלה';
$labels['quotatype'] = 'טיפוס קווטה';
$labels['quotatotal'] = 'הגבלה';
$labels['quotaused'] = 'בשימוש';
$labels['quotastorage'] = 'נפח כונן';
$labels['quotamessage'] = 'ספירת הודעות';
$labels['shortheaderdate'] = 'ביום $date';
$labels['shortheaderto'] = 'עד $to ביום $date';
$labels['shortheaderfrom'] = 'מ- $from בתאריך $date';
$labels['quicksearch'] = 'חיפוש מהיר';
$labels['searchplaceholder'] = 'חיפוש...';
$labels['resetsearch'] = 'ניקוי תיבת החיפוש';
$labels['searchmod'] = 'מאפייני חיפוש';
$labels['msgtext'] = 'כל ההודעה';
$labels['body'] = 'גוף ההודעה';
$labels['type'] = 'סוג';
$labels['namex'] = 'שם';
$labels['searchscope'] = 'היקף';
$labels['currentfolder'] = 'תיקיה נוכחית';
$labels['subfolders'] = 'תיקיה זו ותת תיקיות';
$labels['allfolders'] = 'כל התיקיות';
$labels['searchinterval-1W'] = 'יותר משבוע';
$labels['searchinterval-1M'] = 'יותר מחודש';
$labels['searchinterval-1Y'] = 'יותר משנה';
$labels['searchinterval1W'] = 'פחות משבוע';
$labels['searchinterval1M'] = 'פחות מחודש';
$labels['searchinterval1Y'] = 'פחות משנה';
$labels['openinextwin'] = 'פתיחה בחלון חדש';
$labels['emlsave'] = 'הורדת הודעה בפורמט  EML';
$labels['changeformattext'] = 'הצגה בפורמט לא מעוצב';
$labels['changeformathtml'] = 'הצגה בפורמט HTML';
$labels['editasnew'] = 'עריכת ההודעה כחדשה';
$labels['send'] = 'שלח';
$labels['sendmessage'] = 'משלוח מיידי';
$labels['savemessage'] = 'שמירת טיוטה';
$labels['addattachment'] = 'צירוף קובץ';
$labels['charset'] = 'קידוד';
$labels['editortype'] = 'סוג עורך';
$labels['returnreceipt'] = 'אישור קבלה';
$labels['dsn'] = 'הודעה על מצב המסירה';
$labels['mailreplyintro'] = ':כתב $sender, $date בתאריך';
$labels['originalmessage'] = 'הודעה מקורית';
$labels['selectimage'] = 'בחר תמונה';
$labels['addimage'] = 'הוסף תמונה';
$labels['selectmedia'] = 'בחר סרטון';
$labels['addmedia'] = 'הוסף סרטון';
$labels['encrypt'] = 'הצפנה';
$labels['encryptmessage'] = 'הצפנת הודעה';
$labels['encryptmessagemailvelope'] = 'הצפנה באמצעות Mailvelope';
$labels['importpubkeys'] = 'ייבוא מפתחות ציבוריים';
$labels['encryptedsendialog'] = 'נשלחת הודעה מוצפנת';
$labels['encryptandsign'] = 'להצפין ולחתום';
$labels['keyid'] = 'קוד זיהוי מפתח';
$labels['keylength'] = 'סיביות';
$labels['keyexpired'] = 'פג תוקף';
$labels['keyrevoked'] = 'נשלל';
$labels['bccinstead'] = 'שימוש במכותבים נסתרים';
$labels['addheader'] = 'הוספת נמען (כותרת)';
$labels['insert'] = 'הוספה בין ערכים';
$labels['insertcontact'] = 'פה יש להוסיף איש קשר';
$labels['recipient'] = 'הנמען';
$labels['recipientedit'] = 'עריכת נמענים';
$labels['editidents'] = 'עריכת זהויות';
$labels['spellcheck'] = 'איות';
$labels['checkspelling'] = 'בדיקת איות';
$labels['resumeediting'] = 'המשך עריכה';
$labels['revertto'] = 'חזור למצב קודם';
$labels['restore'] = 'שיחזור';
$labels['restoremessage'] = 'לשחזר הודעה?';
$labels['ignore'] = 'להתעלם';
$labels['responses'] = 'תגובות';
$labels['insertresponse'] = 'הכנסת תגובה';
$labels['manageresponses'] = 'ניהול תגובות';
$labels['newresponse'] = 'צור מענה חדש';
$labels['addresponse'] = 'הוסף מענה';
$labels['editresponse'] = 'עריכת תגובה';
$labels['editresponses'] = 'עריכת תגובות';
$labels['responsename'] = 'שם';
$labels['responsetext'] = 'גוף התגובה';
$labels['attach'] = 'צירוף';
$labels['attachments'] = 'צרופות';
$labels['upload'] = 'העלאה';
$labels['uploadprogress'] = '$percent ($current מתוך $total)';
$labels['close'] = 'סגירה';
$labels['messageoptions'] = 'אפשרויות הודעה...';
$labels['togglecomposeoptions'] = 'בחירה בין הגדרות בסיסיות או מתקדמות של יצירת הודעה';
$labels['attachmentrename'] = 'שינוי שם הצרופה';
$labels['low'] = 'נמוך';
$labels['lowest'] = 'נמוך ביותר';
$labels['normal'] = 'רגיל';
$labels['high'] = 'גבוה';
$labels['highest'] = 'גבוה ביותר';
$labels['nosubject'] = '(ללא נושא)';
$labels['showimages'] = 'הצגת תמונות';
$labels['allow'] = 'הרשאה';
$labels['alwaysshow'] = '$sender תמיד להציג תמונות מאת';
$labels['alwaysallow'] = 'תמיד לקבל מ- $sender';
$labels['isdraft'] = 'זו טיוטה של הודעה';
$labels['andnmore'] = 'עוד  $nr';
$labels['details'] = 'פרטים';
$labels['summary'] = 'סיכום';
$labels['headers'] = 'כותרות';
$labels['allheaders'] = 'כל הכותרות';
$labels['togglemoreheaders'] = 'הראה נתוני מערכת נוספים של ההודעה';
$labels['togglefullheaders'] = 'הראה / בטל צפיה בנתוני מערכת של ההודעה';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'ללא עיצוב';
$labels['savesentmessagein'] = 'היכן לשמור ההודעה?';
$labels['dontsave'] = 'ללא שמירה';
$labels['maxuploadsize'] = 'גודל מקסימלי לקובץ הוא  $size';
$labels['addcc'] = 'הוספת מכותב לידיעה';
$labels['addbcc'] = 'הוספת מכותב נסתר';
$labels['addreplyto'] = 'הוספת כתובת למענה';
$labels['addfollowupto'] = 'הוספת כתובת להעברת הודעה';
$labels['sendreceipt'] = 'לשלוח אישור קבלה?';
$labels['mdnrequest'] = 'השולח ביקש לדעת אם ההודעה נקראה. האם להודיע לשולח?';
$labels['receiptread'] = 'אישור קבלה (נקרא)';
$labels['yourmessage'] = 'אישור קבלה להודעתך';
$labels['receiptnote'] = 'הערה: האישור אינו מבטיח שהנמען קרא או הבין את תוכן ההודעה.';
$labels['sendalwaysto'] = 'לשלוח תמיד אל email$';
$labels['zoomin'] = 'מבט עמוק יותר לפרטים';
$labels['zoomout'] = 'מבט רחוק יותר מהפרטים';
$labels['rotate'] = 'לסובב';
$labels['increaseimage'] = 'להגדיל תמונה';
$labels['decreaseimage'] = 'להקטין תמונה';
$labels['rotateimage'] = 'לסובב תמונה';
$labels['showtools'] = 'הצגת כלים לעיבוד תמונה';
$labels['hidetools'] = 'הסתרת כלים לעיבוד תמונה';
$labels['name'] = 'שם להצגה';
$labels['firstname'] = 'שם פרטי';
$labels['surname'] = 'שם משפחה';
$labels['middlename'] = 'שם אמצעי';
$labels['nameprefix'] = 'קידומת';
$labels['namesuffix'] = 'סיומת';
$labels['nickname'] = 'שם חיבה';
$labels['jobtitle'] = 'תפקיד באירגון';
$labels['department'] = 'מחלקה';
$labels['gender'] = 'מגדר';
$labels['maidenname'] = 'שם משפחה לפני נישואין';
$labels['email'] = 'כתובת דוא"ל';
$labels['phone'] = 'מספר טלפון';
$labels['address'] = 'כתובת';
$labels['street'] = 'רחוב';
$labels['locality'] = 'עיר';
$labels['zipcode'] = 'מיקוד';
$labels['region'] = 'אישור';
$labels['country'] = 'מדינה';
$labels['birthday'] = 'יום הולדת';
$labels['anniversary'] = 'יום נישואין';
$labels['website'] = 'אתר אינטרנט';
$labels['instantmessenger'] = 'כינוי בצ\'ט';
$labels['notes'] = 'הערות';
$labels['male'] = 'זכר';
$labels['female'] = 'נקבה';
$labels['manager'] = 'מנהל/ת';
$labels['assistant'] = 'עוזר/ת';
$labels['spouse'] = 'בן/בת זוג';
$labels['allfields'] = 'כל השדות';
$labels['search'] = 'חיפוש';
$labels['searchresult'] = 'תוצאת חיפוש';
$labels['advsearch'] = 'חיםוש מתקדם';
$labels['advanced'] = 'מתקדם';
$labels['other'] = 'אחר';
$labels['printcontact'] = 'הדפסת נתונים של איש קשר';
$labels['qrcode'] = 'קוד QR';
$labels['typehome'] = 'בית';
$labels['typework'] = 'עבודה';
$labels['typeother'] = 'אחר';
$labels['typemobile'] = 'נייד';
$labels['typemain'] = 'עיקרי';
$labels['typehomefax'] = 'פקס בית';
$labels['typeworkfax'] = 'פקס עבודה';
$labels['typecar'] = 'מכונית';
$labels['typepager'] = 'זימונית';
$labels['typevideo'] = 'וידאו';
$labels['typeassistant'] = 'עוזר/ת';
$labels['typehomepage'] = 'דף הבית';
$labels['typeblog'] = 'יומן רשת';
$labels['typeprofile'] = 'פרופיל';
$labels['addfield'] = 'הוסף שדה';
$labels['addcontact'] = 'הוסף איש קשר';
$labels['editcontact'] = 'עריכת איש קשר';
$labels['contacts'] = 'אנשי קשר';
$labels['contactproperties'] = 'מאפייני איש קשר';
$labels['contactnameandorg'] = 'שם וארגון';
$labels['personalinfo'] = 'מידע אישי';
$labels['personal'] = 'אישי';
$labels['contactphoto'] = 'תצלום איש קשר';
$labels['edit'] = 'עריכה';
$labels['cancel'] = 'ביטול';
$labels['save'] = 'שמירה';
$labels['delete'] = 'מחיקה';
$labels['discard'] = 'להפטר';
$labels['continue'] = 'המשך';
$labels['ok'] = 'אשר/י';
$labels['rename'] = 'שינוי שם';
$labels['addphoto'] = 'הוספה';
$labels['replacephoto'] = 'החלפה';
$labels['uploadphoto'] = 'העלאת תמונה';
$labels['choosefile'] = 'יש לבחור קובץ...';
$labels['choosefiles'] = 'יש לבחור קבצים...';
$labels['browse'] = 'דפדוף';
$labels['newcontact'] = 'צור איש קשר חדש';
$labels['deletecontact'] = 'מחיקת אנשי קשר מסומנים';
$labels['composeto'] = 'יצירת הודעה אל';
$labels['contactsfromto'] = 'אנשי קשר $from עד $to מתוך $count';
$labels['print'] = 'הדפסה';
$labels['export'] = 'ייצוא';
$labels['exportall'] = 'יצוא של כל הרשומות';
$labels['exportsel'] = 'צוא של רשומות נבחרות';
$labels['exportvcards'] = 'ייצוא אנשי קשר בפורמט vCard';
$labels['newgroup'] = 'הוסף קבוצה חדשה';
$labels['addgroup'] = 'הוספת קבוצה';
$labels['grouprename'] = 'שינוי שם קבוצה';
$labels['groupdelete'] = 'מחיקת קבוצה';
$labels['groupassign'] = 'שיוך לקבוצה...';
$labels['groupremove'] = 'הסרה מקבוצה';
$labels['groupremoveselected'] = 'אנשי הקשר שנבחרו יוסרו מהקבוצה';
$labels['uponelevel'] = 'רמה אחת מעלה';
$labels['previouspage'] = 'הצגת הקבוצה הקודמת';
$labels['firstpage'] = 'הצגת הקבוצה הראשונה';
$labels['nextpage'] = 'הצגת הקבוצה הבאה';
$labels['lastpage'] = 'הצגת הקבוצה האחרונה';
$labels['group'] = 'קבוצה';
$labels['groups'] = 'קבוצות';
$labels['listgroup'] = 'רשימה של חברי קבוצה';
$labels['personaladrbook'] = 'כתובות פרטיות';
$labels['searchsave'] = 'שמירת החיפוש';
$labels['searchdelete'] = 'מחיקת החיפוש';
$labels['import'] = 'ייבוא';
$labels['importcontacts'] = 'ייבוא אנשי קשר';
$labels['importfromfile'] = 'ייבוא מקובץ';
$labels['importtarget'] = 'הוספת אנשי קשר אל ';
$labels['importreplace'] = 'החלפת כל פנקס הכתובות';
$labels['importgroups'] = 'ייבוא הגדרות קבוצה';
$labels['importgroupsall'] = 'הכל (יש להקים קבוצות אם צריך)';
$labels['importgroupsexisting'] = 'רק עבור קבוצות קיימות';
$labels['importdesc'] = 'ניתן להעלות אנשי קשר מפנקס כתובות קיים.  כרגע יש תמיכה ביבוא רשומות הערוכות בצורת vCard או CSV (מופרד פסיקים)';
$labels['importmapdesc'] = 'נא לאשר את מיפוי השדות שלהלן לפני שנמשיך עם יבוא קובץ נתונים מסוג CSV (מופרדים ע"י פסיקים)';
$labels['fieldnotmapped'] = 'השדה ללא מיפוי (לא לייבא)';
$labels['skipheader'] = 'לא לייבא שורה ראשונה (כותרות)';
$labels['done'] = 'בוצע';
$labels['settingsfor'] = 'הגדרות עבור';
$labels['about'] = 'אודות';
$labels['preferences'] = 'העדפות';
$labels['userpreferences'] = 'העדפות משתמש';
$labels['editpreferences'] = 'עריכה של העדפות משתמש';
$labels['identities'] = 'זהויות';
$labels['manageidentities'] = 'נהל זהויות';
$labels['newidentity'] = 'צור זהות חדשה';
$labels['addidentity'] = 'הוסף זהות';
$labels['editidentity'] = 'ערוך זהות';
$labels['identityencryption'] = 'הצפנה';
$labels['preferhtml'] = 'הצגת HTML';
$labels['defaultcharset'] = 'ברירת מחדל של תווים';
$labels['htmlmessage'] = 'תוכן HTML';
$labels['messagepart'] = 'גוף ההודעה';
$labels['digitalsig'] = 'חתימה דיגיטלית';
$labels['dateformat'] = 'פורמט התאריך';
$labels['timeformat'] = 'פורמט השעה';
$labels['prettydate'] = 'תאריכים מעוצבים';
$labels['setdefault'] = 'קביעה כברירת מחדל';
$labels['autodetect'] = 'אוטומטי';
$labels['language'] = 'שפה';
$labels['timezone'] = 'איזור זמן';
$labels['pagesize'] = 'מספר שורות בדף';
$labels['signature'] = 'חתימה';
$labels['dstactive'] = 'שעון קיץ';
$labels['showinextwin'] = 'צפיה בהודעה בחלון חדש';
$labels['composeextwin'] = 'יצירת הודעה בחלון חדש';
$labels['htmleditor'] = 'יצירת הודעה מעוצבת';
$labels['htmlonreply'] = 'רק במענה להודעת HTML';
$labels['htmlonreplyandforward'] = 'להעביר או להשיב להודעה שהגיעה בפורמט HTML';
$labels['htmlsignature'] = 'חתימה מעוצבת';
$labels['showemail'] = 'הצגת כתובת דוא"ל עם שם השולח';
$labels['previewpane'] = 'תצוגה מוקדמת';
$labels['skin'] = 'ערכת מראה';
$labels['logoutclear'] = 'ריקון סל אשפה ביציאה';
$labels['logoutcompact'] = 'פינוי שטח לא מנוצל ביציאה';
$labels['uisettings'] = 'ממשק משתמש';
$labels['serversettings'] = 'הגדרות שרת';
$labels['mailboxview'] = 'הצגת תיבת ההודעות';
$labels['mdnrequests'] = 'משלוח אישור מסירה';
$labels['askuser'] = 'שאל את המשתמש';
$labels['autosend'] = 'שליחה אוטומטית';
$labels['autosendknown'] = 'משלוח אישור קבלה רק לאנשי הקשר שלי';
$labels['autosendknownignore'] = 'משלוח אישור קבלה לאנשי הקשר שלי בלבד ולהתעלם מאחרים';
$labels['autosendtrusted'] = 'לשלוח אישור קבלה לשולחים מוכרים, בכל מקרה אחר לבקש אישור';
$labels['autosendtrustedignore'] = 'לשלוח אישור קבלה לשולחים מוכרים, אחרת להתעלם';
$labels['ignorerequest'] = 'להתעלם מהבקשה';
$labels['readwhendeleted'] = 'סימון הודעה כנקראה לאחר מחיקה';
$labels['flagfordeletion'] = 'סימון הודעה כמחוקה במקום מחיקה';
$labels['skipdeleted'] = 'הסתרת הודעות שנמחקו';
$labels['deletealways'] = 'אם העברה לתיקית מחיקה נכשלת יש למחוק לתמיד';
$labels['deletejunk'] = 'מחיקה ישירה של הודעות זבל';
$labels['showremoteimages'] = 'הצגת תמונות משרת מרוחק בגוף ההודעה';
$labels['allowremoteresources'] = 'אישור שימוש במשאבים מרוחקים (תמונות, סגנונות)';
$labels['fromknownsenders'] = 'משולחים מוכרים';
$labels['fromtrustedsenders'] = 'התקבל משולחים מוכרים';
$labels['frommycontacts'] = 'מאנשי הקשר שלי';
$labels['always'] = 'תמיד';
$labels['alwaysbutplain'] = 'תמיד, למעט בעת מענה לטקסט פשוט';
$labels['showinlineimages'] = 'הצגת תמונות מצורפות בתחתית ההודעה';
$labels['autosavedraft'] = 'שמירה אוטומטית של טיוטה';
$labels['everynminutes'] = 'כל $n דקות';
$labels['refreshinterval'] = 'רענון ההתצוגה לשם בדיקת קיום של הודעות חדשות וכדומה';
$labels['never'] = 'אף פעם';
$labels['immediately'] = 'מיידית';
$labels['messagesdisplaying'] = 'הצגת הודעות';
$labels['messagescomposition'] = 'כתיבת הודעות';
$labels['mimeparamfolding'] = 'שמות קבצים מצורפים';
$labels['2231folding'] = 'תאימות מלאה 2231 תאנדרבירד';
$labels['miscfolding'] = 'תאימות 2047/2231 אאוטלוק';
$labels['2047folding'] = 'תאימות מלאה 2047 אחרים';
$labels['force7bit'] = 'קידוד MIME עבור תווים בעלי 8 ביטים';
$labels['savelocalstorage'] = "שמירה באיחסון מקומי של הדפדפן (ארעית)";
$labels['advancedoptions'] = 'הגדרות נוספות';
$labels['toggleadvancedoptions'] = 'בחירה בין הגדרות בסיסיות או מתקדמות';
$labels['focusonnewmessage'] = 'מיקוד הסמן על החלון עם ההודעה החדשה';
$labels['checkallfolders'] = 'בדיקת הודעות חדשות בכל התיקיות';
$labels['displaynext'] = 'הצגת הרשומה הבאה לאחר מחיקה/העברה';
$labels['defaultfont'] = 'גופן ברירת מחדל להודעה בפורמט HTML';
$labels['mainoptions'] = 'אפשרויות עיקריות';
$labels['browseroptions'] = 'אפשרויות דפדפן';
$labels['section'] = 'קטע';
$labels['maintenance'] = 'תחזוקה';
$labels['newmessage'] = 'הודעה חדשה';
$labels['signatureoptions'] = 'אפשרויות לשיבוץ חתימה';
$labels['whenreplying'] = 'כאשר עונים';
$labels['replyempty'] = 'לא לצטט הודעה מקורית';
$labels['replytopposting'] = 'הודעה חדשה תתחיל מעל ההודעה המקורית';
$labels['replytoppostingnoindent'] = 'הודעה תתחיל מעל הקטע המצוטט (ללא נסיגה)';
$labels['replybottomposting'] = 'הודעה חדשה תתחיל מתחת להודעה המקורית';
$labels['replyremovesignature'] = 'החתימה תוסר מההודעה המקורית במענה להודעה';
$labels['autoaddsignature'] = 'הוספה אוטומטית של חתימה';
$labels['newmessageonly'] = 'הודעה חדשה בלבד';
$labels['replyandforwardonly'] = 'מענה והעברת הודעה בלבד';
$labels['insertsignature'] = 'שיבוץ חתימה';
$labels['sigbelow'] = 'למקם חתימה מתחת להודעת המצוטטת';
$labels['sigseparator'] = 'חובת שימוש במפריד תקני בחתימה';
$labels['automarkread'] = 'סימון הודעה כנקראה';
$labels['afternseconds'] = 'לאחר $n שניות';
$labels['reqmdn'] = 'תמיד יש לדרוש אישור קבלה';
$labels['reqdsn'] = 'תמיד לבקש הודעה על מצב המסירה';
$labels['replysamefolder'] = 'המענה ישמר בתיקיה של ההודעה המקורית';
$labels['defaultabook'] = 'ברירת המחדל של רשימת כתובות';
$labels['autocompletesingle'] = 'לדלג על כתובת דואר חילופית בעת שימוש בהשלמה אוטומטית של הקלדה';
$labels['listnamedisplay'] = 'הצגת איש הקשר בתור';
$labels['contactformmode'] = 'הצגה של טופס איש קשר';
$labels['privatemode'] = 'פרטי (בית)';
$labels['businessmode'] = 'עיסקי (עבודה)';
$labels['collectedaddresses'] = 'כתובות שלוקטו';
$labels['collectedrecipients'] = 'נמענים שלוקטו';
$labels['collectedrecipientsopt'] = 'לשמור כתובות נמענים של דואר יוצא ב-';
$labels['collectedsendersopt'] = 'לשמור שולחים מוכרים ב-';
$labels['trustedsenders'] = 'שולחים מוכרים';
$labels['spellcheckbeforesend'] = 'בדיקת איות לפני המשלוח';
$labels['spellcheckoptions'] = 'אפשריות בדיקת איות';
$labels['spellcheckignoresyms'] = 'התעלמות ממילים המכילות סמלים';
$labels['spellcheckignorenums'] = 'התעלמות ממילים המכילות מספרים';
$labels['spellcheckignorecaps'] = 'התעלמות ממילים עם אותציות ראשיות';
$labels['addtodict'] = 'הוספה למילון';
$labels['mailtoprotohandler'] = 'קביעת הפרוטוקול לטיפול בקישור מסוג  mailto:links';
$labels['standardwindows'] = 'חלונות קופצים יטופלו כחלונות רגילים';
$labels['forwardmode'] = 'הפנית הודעות';
$labels['inline'] = 'חלק מההודעה';
$labels['asattachment'] = 'כצרופה';
$labels['replyallmode'] = 'ברירת המחדל של כפתור [מענה לכולם]';
$labels['replyalldefault'] = 'מענה לכולם';
$labels['replyalllist'] = 'מענה לרשימת תפוצה בלבד (אם קיימת)';
$labels['folder'] = 'תיקיה';
$labels['folders'] = 'תיקיות';
$labels['foldername'] = 'שם תיקיה';
$labels['subscribed'] = 'מנוי';
$labels['messagecount'] = 'הודעות';
$labels['create'] = 'יצירה';
$labels['createfolder'] = 'יצירת תיקיה חדשה';
$labels['managefolders'] = 'ניהול תיקיות';
$labels['specialfolders'] = 'תיקיות מיוחדות';
$labels['properties'] = 'מאפיינים';
$labels['folderproperties'] = 'מאפייני תיקיה';
$labels['parentfolder'] = 'תיקית אב';
$labels['location'] = 'מיקום';
$labels['info'] = 'מידע';
$labels['getfoldersize'] = 'הקשה להצגה של גודל תיקיה';
$labels['changesubscription'] = 'הקשה לשינוי הרשמה';
$labels['foldertype'] = 'סוג תיקיה';
$labels['personalfolder'] = 'תיקיה פרטית';
$labels['otherfolder'] = 'תיקית משתמש נוספת';
$labels['sharedfolder'] = 'תיקיה ציבורית';
$labels['findfolders'] = 'חיפוש תיקיות';
$labels['findcontacts'] = 'חיפוש אנשי קשר';
$labels['findmail'] = 'חפש הודעות דואר';
$labels['namespace.personal'] = 'אישי';
$labels['namespace.other'] = 'משתמשים אחרים';
$labels['namespace.shared'] = 'משותף';
$labels['dualuselabel'] = 'יכול רק להכיל';
$labels['dualusemail'] = 'הודעות';
$labels['dualusefolder'] = 'תיקיות';
$labels['generate'] = 'לחולל';
$labels['encryptioncreatekey'] = 'יצירה של צמד מפתחות';
$labels['openmailvelopesettings'] = 'הצגת אפשרויות לתוכנת ההצפנה';
$labels['encryptionprivkeysinmailvelope'] = 'קיימים $nr מפתחות פרטיים תואמים ברשימת המפתחות שלך בתוכנת ההצפנה';
$labels['encryptionnoprivkeysinmailvelope'] = 'לזהות השולחת אין עדיין מפתח הצפנה פרטי השמור בתוכנת ההצפנה שלך. האם ליצור כזה
כדי לאפשר הצפנת הודעות?';
$labels['encryption'] = 'הצפנה';
$labels['mailvelopeoptions'] = 'אפשרויות למעטפת ההודעה';
$labels['mailvelopemainkeyring'] = 'השתמש/י בטבעצ מפתחות עיקרית של מעטפת ההודעה';
$labels['mailvelopenotfound'] = 'ההרחבה העוסקת במעטפת ההודעה אינה מותקנת או מופעלת בדפדפן';
$labels['sortby'] = 'מיון לפי';
$labels['sortasc'] = 'מיון בסדר עולה';
$labels['sortdesc'] = 'מיון בסדר יורד';
$labels['undo'] = 'ביטול שינוי';
$labels['installedplugins'] = 'תוספים מותקנים';
$labels['plugin'] = 'תוסף תוכנה';
$labels['version'] = 'גירסה';
$labels['source'] = 'מקור';
$labels['destination'] = 'יעד';
$labels['license'] = 'רשיון';
$labels['support'] = 'קבלת תמיכה';
$labels['savedsearches'] = 'חיפושים שנשמרו';
$labels['dateformatY'] = 'YYYY';
$labels['dateformaty'] = 'YY';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'בייט';
$labels['KB'] = 'ק"ב';
$labels['MB'] = 'מ"ב';
$labels['GB'] = 'ג"ב';
$labels['unicode'] = 'יוניקוד';
$labels['english'] = 'אנגלית';
$labels['westerneuropean'] = 'מערב אירופי';
$labels['easterneuropean'] = 'מזרח אירופי';
$labels['southeasterneuropean'] = 'דרום מזרח אירופה';
$labels['baltic'] = 'בלטי';
$labels['cyrillic'] = 'קירילי';
$labels['arabic'] = 'ערבי';
$labels['greek'] = 'יווני';
$labels['hebrew'] = 'עברי';
$labels['turkish'] = 'טורקי';
$labels['nordic'] = 'נורדי';
$labels['thai'] = 'תאי';
$labels['celtic'] = 'קלטי';
$labels['vietnamese'] = 'וויטנאמי';
$labels['japanese'] = 'יפני';
$labels['korean'] = 'קוריאני';
$labels['chinese'] = 'סיני';
$labels['arialabeltopnav'] = 'בקרת חלון';
$labels['arialabeltasknav'] = 'משימות יישום';
$labels['arialabeltoolbar'] = 'סרגל כלים יישום';
$labels['arialabellistnav'] = 'רשימת ניווט';
$labels['arialabelactivetask'] = 'משימה פעילה';
$labels['arialabelmessagessearchfilter'] = 'מסנן של רשימת ההודעות';
$labels['arialabelmailsearchform'] = 'טופס חיפוש בתוך הודעות';
$labels['arialabelcontactsearchform'] = 'תבנית חיפוש אנשי קשר';
$labels['arialabelmailquicksearchbox'] = 'הקשת מילות חיפוש';
$labels['arialabelquicksearchbox'] = 'קלט חיפוש';
$labels['arialabelfoldersearchfilter'] = 'מסנן רשימת תיקיות';
$labels['arialabelfoldersearchform'] = 'מסך חיפוש תיקייה';
$labels['arialabelfolderlist'] = 'בחירה של תיקית הודעות';
$labels['arialabelmessagelist'] = 'רשימת הודעות';
$labels['arialabelmailpreviewframe'] = 'תצוגה מקדמית של הודעה';
$labels['arialabelmailboxmenu'] = 'תפריט פעולות תפריט';
$labels['arialabellistselectmenu'] = 'רשימת פריטים לבחירה';
$labels['arialabelthreadselectmenu'] = 'בחירת פתילים של הודעות מתוך רשימה';
$labels['arialabelmessagelistoptions'] = 'אפשרויות להצגת הודעות ומיונן';
$labels['arialabelmailimportdialog'] = 'תהליך ייבוא הודעות';
$labels['arialabelmessagenav'] = 'ניווט הודעה';
$labels['arialabelmessagebody'] = 'גוף הודעה';
$labels['arialabelmessageactions'] = 'פעולות הודעה';
$labels['arialabelcontactquicksearch'] = 'תבנית חיפוש אנשי קשר';
$labels['arialabelcontactsearchbox'] = 'קלט חיפוש איש קשר';
$labels['arialabelmessageheaders'] = 'תקורות הודעה';
$labels['arialabelforwardingoptions'] = 'אפשרויות העברה';
$labels['arialabelreplyalloptions'] = 'אפשרויות מענה לכולם';
$labels['arialabelmoremessageactions'] = 'עוד פעולות הודעה';
$labels['arialabelmorecontactactions'] = 'פעולות נוספות על אנשי קשר';
$labels['arialabelmarkmessagesas'] = 'סימון הודעות נבחרות בתור...';
$labels['arialabelcomposeoptions'] = 'אפשרויות הלחנה';
$labels['arialabelresponsesmenu'] = 'תפריט של תגובות מוכנות מראש';
$labels['arialabelattachmentuploadform'] = 'תבנית העלאת צרופה';
$labels['arialabelattachmentmenu'] = 'אפשרויות צרופה';
$labels['arialabelmailtomenu'] = 'אפשרויות כתובת דואר';
$labels['arialabelattachmentpreview'] = 'תצוגה מקדמית של צרופה';
$labels['ariasummarycomposecontacts'] = 'רשימה של אנשי קשר וקבוצות שיבחרו כנמענים';
$labels['arialabelcontactexportoptions'] = 'אפשרויות ייצוא איש קשר';
$labels['arialabelabookgroupoptions'] = 'אפשרויות קבוצה/פנקס כתובות';
$labels['arialabelpreferencesform'] = 'תבנית העדפות';
$labels['arialabelidentityeditfrom'] = 'טופס עריכת זהות';
$labels['arialabelresponseeditfrom'] = 'טופס עריכת מענה';
$labels['arialabelsearchterms'] = 'מילות חיםוש';
$labels['arialabeldropactionmenu'] = 'תפריט גרירה';
$labels['arialabelheadersmenu'] = 'תפריט הוספת (כותרת) נמען';
$labels['arialabelimagetools'] = 'כלים לעיבוד תמונה';
$labels['helplistnavigation'] = 'ניווט ברשימה באמצעות לוח המקשים';
$labels['helplistkeyboardnavigation'] = "חיצים למלעלה/למטה: בחירת שורה/מיקוד בשורה
מקש רווח: בחירה בשורת המיקוד
מקש SHIFT+חץ למעלה/למטה: בחירה בשורות נוספות מעל/מתחת לשורה הנוכחית
מקש CTRL+רווח: הוספה/הסרה של שורה מהקבוצה שנבחרה";
$labels['helplistkeyboardnavmessages'] = "חץ ימין/שמאל: הרחבה/צימצום של פתיל ההודעות (במצב של הצגת פתילים בלבד)
ENTER: פתיחה של ההודעה שנבחרה
DELETE: העברה של ההודעה שנבחרה לפח האשפה";
$labels['helplistkeyboardnavcontacts'] = "ENTER: פתיחה של איש הקשר שסומן ";
