<!DOCTYPE html>
<html>
<head>
<roundcube:include file="/includes/links.html" />
</head>
<roundcube:if condition="!env:framed && env:error_task != 'error-login'" />
<body class="error<roundcube:exp expression="env:extwin ? ' extwin' : ''" />">
<roundcube:include file="/includes/header.html" />
<roundcube:else />
<body class="error iframe">
<roundcube:endif />

<div class="uibox centerbox errorbox">
$__page_content
</div>

</body>
</html>
