<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Сумесны доступ';
$labels['myrights'] = 'Правы доступу';
$labels['username'] = 'Карыстальнік:';
$labels['advanced'] = 'Пашыраны рэжым';
$labels['add'] = 'Дадаць';
$labels['newuser'] = 'Дадаць запіс';
$labels['editperms'] = 'Рэдагаваць правы доступу';
$labels['actions'] = 'Дзеянні з правамі доступу...';
$labels['anyone'] = 'Усе карыстальнікі (любыя)';
$labels['anonymous'] = 'Госці (ананімныя)';
$labels['identifier'] = 'Ідэнтыфікатар';
$labels['acll'] = 'Пошук';
$labels['aclr'] = 'Прачытаць паведамленні';
$labels['acls'] = 'Пакінуць стан Бачанае';
$labels['aclw'] = 'Флагі запісвання';
$labels['acli'] = 'Уставіць (капіраваць у)';
$labels['aclp'] = 'Адправіць';
$labels['aclc'] = 'Стварыць укладзеныя папкі';
$labels['aclk'] = 'Стварыць укладзеныя папкі';
$labels['acld'] = 'Выдаліць паведамленні';
$labels['aclt'] = 'Выдаліць паведамленні';
$labels['acle'] = 'Знішчыць паведамленні';
$labels['aclx'] = 'Выдаліць папку';
$labels['acla'] = 'Адміністраваць';
$labels['acln'] = 'Анатаваць паведамленні';
$labels['aclfull'] = 'Поўны доступ';
$labels['aclother'] = 'Іншае';
$labels['aclread'] = 'Чытанне';
$labels['aclwrite'] = 'Запіс';
$labels['acldelete'] = 'Выдаленне';
$labels['shortacll'] = 'Пошук';
$labels['shortaclr'] = 'Чытанне';
$labels['shortacls'] = 'Пакінуць';
$labels['shortaclw'] = 'Запісванне';
$labels['shortacli'] = 'Даданне';
$labels['shortaclp'] = 'Адпраўленне';
$labels['shortaclc'] = 'Стварэнне';
$labels['shortaclk'] = 'Стварэнне';
$labels['shortacld'] = 'Выдаленне';
$labels['shortaclt'] = 'Выдаленне';
$labels['shortacle'] = 'Знішчэнне';
$labels['shortaclx'] = 'Выдаленне папкі';
$labels['shortacla'] = 'Адміністраванне';
$labels['shortacln'] = 'Анатаваць';
$labels['shortaclother'] = 'Іншае';
$labels['shortaclread'] = 'Чытанне';
$labels['shortaclwrite'] = 'Запіс';
$labels['shortacldelete'] = 'Выдаленне';
$labels['longacll'] = 'Папку можна пабачыць у спісах і падпісацца на яе';
$labels['longaclr'] = 'Папку можна адкрыць для чытання';
$labels['longacls'] = 'На паведамленнях можна пераключаць флаг Бачанае';
$labels['longaclw'] = 'На паведамленнях можна мяняць ключавыя словы і пераключаць флагі, апроч Бачанае і Выдаленае';
$labels['longacli'] = 'Паведамленні могуць быць запісаныя альбо скапіяваныя ў папку';
$labels['longaclp'] = 'Паведамленні могуць быць адпраўленыя ў гэтую папку';
$labels['longaclc'] = 'Папкі могуць быць створаны (альбо перайменаваны) наўпрост пад гэтай папкай';
$labels['longaclk'] = 'Папкі могуць быць створаны (альбо перайменаваны) наўпрост пад гэтай папкай';
$labels['longacld'] = 'На паведамленнях можна пераключаць флаг Выдаленае';
$labels['longaclt'] = 'На паведамленнях можна пераключаць флаг Выдаленае';
$labels['longacle'] = 'Паведамленні могуць быць знішчаны';
$labels['longaclx'] = 'Папку можна выдаліць альбо перайменаваць';
$labels['longacla'] = 'Правы доступу на папку можна змяняць';
$labels['longacln'] = 'Анатацыі паведамленняў (супольныя метаданыя) можна змяняць';
$labels['longaclfull'] = 'Поўны доступ, уключна з адмінстраваннем папкі';
$labels['longaclread'] = 'Папку можна адкрыць для чытання';
$labels['longaclwrite'] = 'Паведамленні могуць быць пазначаныя, запісаныя альбо скапіяваныя ў папку';
$labels['longacldelete'] = 'Паведамленні можна выдаліць';
$labels['longaclother'] = 'Іншыя правы доступу';
$labels['ariasummaryacltable'] = 'Спіс правоў доступу';
$labels['arialabelaclactions'] = 'Спіс дзеянняў';
$labels['arialabelaclform'] = 'Форма правоў доступу';
$messages['deleting'] = 'Правы доступу выдаляюцца...';
$messages['saving'] = 'Правы доступу захоўваюцца...';
$messages['updatesuccess'] = 'Правы доступу зменены';
$messages['deletesuccess'] = 'Правы доступу выдалены';
$messages['createsuccess'] = 'Правы доступу дададзены';
$messages['updateerror'] = 'Не ўдалося абнавіць правы доступу';
$messages['deleteerror'] = 'Не ўдалося выдаліць правы доступу';
$messages['createerror'] = 'Не ўдалося дадаць правы доступу';
$messages['deleteconfirm'] = 'Напраўду выдаліць правы доступу для вылучанага карыстальніка(ў)?';
$messages['norights'] = 'Жадных правоў не зададзена!';
$messages['nouser'] = 'Жадных імёнаў карыстальнікаў не зададзена!';
