<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<roundcube:include file="/includes/links.html" />
<script type="text/javascript" src="/functions.js"></script>
</head>
<body>

<roundcube:include file="/includes/taskbar.html" />
<roundcube:include file="/includes/header.html" />
<roundcube:if condition="env:task == 'settings'" />
  <roundcube:include file="/includes/settingstabs.html" />
<roundcube:endif />

<div id="mainscreen">
<roundcube:object name="plugin.body" />
</div>

<roundcube:object name="plugin.footer" />

<script type="text/javascript">
rcube_init_mail_ui();
</script>

</body>
</html>
