<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-newmail_notifier/
*/

$labels['basic'] = 'Taispeáin fógraí sa líonléitheoir nuair a fhaightear teachtaireacht nua';
$labels['desktop'] = 'Taispeáin fógraí ar an deasc nuair a fhaightear teachtaireacht nua';
$labels['sound'] = 'Seinn an fhuaim nuair a bhíonn teachtaireacht nua ann';
$labels['test'] = 'Tástáil';
$labels['title'] = 'Ríomhphost Nua!';
$labels['body'] = 'Tá teachtaireacht nua agat.';
$labels['testbody'] = 'Níl sa rud seo ach fógra dearbhála.';
$labels['desktopdisabled'] = 'Tá fógraí deasca díchumasaithe i do líonléitheoir.';
$labels['desktopunsupported'] = 'Ní thacaíonn do líonléitheoir le fógraí deasca.';
$labels['desktoptimeout'] = 'Dún an fógra ar an ndeasc';
