<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Deiling';
$labels['myrights'] = 'Aðgangsheimildir';
$labels['username'] = 'Notandi:';
$labels['advanced'] = 'Flóknari hamur';
$labels['add'] = 'Bæta við';
$labels['newuser'] = 'Bæta við færslu';
$labels['editperms'] = 'Breyta heimildum';
$labels['anyone'] = 'Allir notendur (hver sem er)';
$labels['anonymous'] = 'Gestir (nafnlausir)';
$labels['identifier'] = 'Auðkenni';
$labels['acll'] = 'Uppfletting';
$labels['aclr'] = 'Lesa skilaboð';
$labels['acli'] = 'Setja inn (afrita inn í)';
$labels['aclc'] = 'Búa til undirmöppur';
$labels['aclk'] = 'Búa til undirmöppur';
$labels['acld'] = 'Eyða skilaboðum';
$labels['aclt'] = 'Eyða skilaboðum';
$labels['aclx'] = 'Eyða möppu';
$labels['acla'] = 'Stjórna';
$labels['aclfull'] = 'Full stjórn';
$labels['aclother'] = 'Annað';
$labels['aclread'] = 'Lesið';
$labels['aclwrite'] = 'Skrifa';
$labels['acldelete'] = 'Eyða';
$labels['shortacll'] = 'Uppfletting';
$labels['shortaclr'] = 'Lesið';
$labels['shortacls'] = 'Halda';
$labels['shortaclw'] = 'Skrifa';
$labels['shortacli'] = 'Setja inn';
$labels['shortaclc'] = 'Búa til';
$labels['shortaclk'] = 'Búa til';
$labels['shortacld'] = 'Eyða';
$labels['shortaclt'] = 'Eyða';
$labels['shortaclx'] = 'Eyða möppu';
$labels['shortacla'] = 'Stjórna';
$labels['shortaclother'] = 'Annað';
$labels['shortaclread'] = 'Lesið';
$labels['shortaclwrite'] = 'Skrifa';
$labels['shortacldelete'] = 'Eyða';
$labels['longaclc'] = 'Hægt er að útbúa (eða endurnefna) möppur beint inni í þessari möppu';
$labels['longaclk'] = 'Hægt er að útbúa (eða endurnefna) möppur beint inni í þessari möppu';
$labels['arialabelaclactions'] = 'Telja upp aðgerðir';
